import { useState } from 'react';
import {
    Button,
    Modal,
    Group,
    TextInput,
    Text
} from '@mantine/core';
import { Plus } from 'tabler-icons-react';
import { sprintf, __ } from "@wordpress/i18n";
import { showNotification } from '@mantine/notifications';


export default function AddQuiz(props) {
    const [opened, setOpened] = useState(false);
    const [quiz_title, setQuizTitle] = useState('');
    const { courseList, setCourseList, courseData, setCourseData } = props;

    const createNewQuiz = () => {
        let data = {
            action: 'ir_fqb_new_quiz',
            nonce: ir_fcb_loc.nonce,
            course_id: props.course_id,
            post_title: quiz_title
        };
        let parent = 'course';

        if ('lesson_id' in props) {
            data.lesson_id = props.lesson_id;
            parent = 'lesson';
        }

        if ('topic_id' in props) {
            data.topic_id = parseInt(props.topic_id);
            parent = 'topic';
        }
        let quiz_tree = {};

        jQuery.ajax({
            url: ir_fcb_loc.ajax_url,
            method: 'POST',
            data,
            dataType: 'JSON',
            timeout: 30000,
            success: function (response) {
                if ('success' === response.status) {
                    // Update course data store if not present.
                    if (!courseData.hasOwnProperty(response.post_id)) {
                        let _courseData = { ...courseData };
                        _courseData[response.post_id] = {
                            post_title: response.post.post_title,
                            post_modified: response.post.post_modified,
                            post_status: response.post.post_status
                        };
                        setCourseData(_courseData);
                    }
                    switch (parent) {
                        case 'course':
                            quiz_tree = { ...courseList.h["sfwd-quiz"] };
                            quiz_tree[response.post_id] = response.post.post_title;

                            setCourseList({
                                ...courseList,
                                h: {
                                    ...courseList.h,
                                    "sfwd-quiz": quiz_tree
                                }
                            });
                            break;

                        case 'lesson':
                            quiz_tree = { ...courseList.h["sfwd-lessons"][props.lesson_id]["sfwd-quiz"] };
                            quiz_tree[response.post_id] = response.post.post_title;

                            setCourseList({
                                ...courseList,
                                h: {
                                    ...courseList.h,
                                    "sfwd-lessons": {
                                        ...courseList.h["sfwd-lessons"],
                                        [props.lesson_id]: {
                                            ...courseList.h["sfwd-lessons"][props.lesson_id],
                                            "sfwd-quiz": quiz_tree
                                        }
                                    }
                                }
                            });
                            break;

                        case 'topic':
                            quiz_tree = { ...courseList.h["sfwd-lessons"][props.lesson_id]["sfwd-topic"][props.topic_id]["sfwd-quiz"] };
                            quiz_tree[response.post_id] = response.post.post_title;

                            setCourseList({
                                ...courseList,
                                h: {
                                    ...courseList.h,
                                    "sfwd-lessons": {
                                        ...courseList.h["sfwd-lessons"],
                                        [props.lesson_id]: {
                                            ...courseList.h["sfwd-lessons"][props.lesson_id],
                                            "sfwd-topic": {
                                                ...courseList.h["sfwd-lessons"][props.lesson_id]["sfwd-topic"],
                                                [props.topic_id]: {
                                                    ...courseList.h["sfwd-lessons"][props.lesson_id]["sfwd-topic"][props.topic_id],
                                                    "sfwd-quiz": quiz_tree
                                                }
                                            }
                                        }
                                    }
                                }
                            });
                            break;
                    }
                    window.open( response.quiz_url, '_blank' );
                } else {
                    // console.log(response);
                }
            },
        });

        setOpened(false);
        showNotification({
            title: sprintf(__('%s Added', 'wdm_instructor_role'), ir_fcb_loc.quiz_label),
            message: sprintf(__('New %s successfully created as draft!!', 'wdm_instructor_role'), ir_fcb_loc.lower_quiz_label),
        })
        setQuizTitle('');
    }

    return (
        <>
            <Modal className="ir-topic-modal"
                opened={opened}
                onClose={() => setOpened(false)}
                title={sprintf(__('Add New %s', 'wdm_instructor_role'), ir_fcb_loc.quiz_label)}
                size='830px'
            >
                <Group align="center" mt={25} mb={5}>
                    <TextInput className="ir-section-input"
                        placeholder={sprintf(__('Add %s name here', 'wdm_instructor_role'), ir_fcb_loc.lower_quiz_label)}
                        size="md"
                        value={quiz_title}
                        onChange={(event) => setQuizTitle(event.currentTarget.value)}
                    />
                    <Button size="md" variant="outline" onClick={createNewQuiz}>{__('Add', 'wdm_instructor_role')}</Button>
                </Group>
                <Text mb={25} c="#6F717C">{sprintf(__('A new %s will be added to this %s and you will be redirected to the %s builder', 'wdm_instructor_role'), ir_fcb_loc.lower_quiz_label, ir_fcb_loc.lower_course_label, ir_fcb_loc.lower_quiz_label)}</Text>
            </Modal>
            <Group align="center" position="center">
            <Button onClick={() => setOpened(true)} size="sm" className={"ir-fed-add-quiz "+ props.class} radius="md" variant="filled" leftIcon={<Plus size={22} color={'#2067FA'} />}>
                {sprintf(__('Add New %s', 'wdm_instructor_role'), ir_fcb_loc.quiz_label)}
            </Button>
            </Group>
        </>
    );
}