import { useState } from 'react';
import {
    Input,
    Button,
    Modal,
    Group,
    TextInput
} from '@mantine/core';
import { Plus } from 'tabler-icons-react';
import { sprintf, __ } from "@wordpress/i18n";
import { showNotification } from '@mantine/notifications';


export default function AddSection(props) {
    const [opened, setOpened] = useState(false);
    const [section, setSection] = useState('');
    const { courseList, setCourseList } = props;

    const createNewSection = () => {
        let sections = [];
        // List of sections
        jQuery('.ir-builder .ir-builder-top-element').each((ind, section) => {
            if (!jQuery(section).hasClass('ir-section')) {
                return true;
            }
            let steps = [];
            const next_steps = jQuery(section).parents('.ir-fed-sections').nextAll();
            if (0 < next_steps.length) {
                for (let loop = 0; loop < next_steps.length; loop++) {
                    const node = next_steps[loop];
                    if (jQuery(node).hasClass('ir-fed-sections')) {
                        break;
                    }
                    steps.push(parseInt(jQuery(node).find('.ir-builder-lesson').val()));
                }
            }
            sections.push(
                {
                    "ID": jQuery(section).data('id'),
                    "post_title": jQuery(section).val(),
                    "order": ind,
                    "type": "section-heading",
                    "tree": [],
                    "steps": steps
                }
            )
        });

        const new_section = {
            ID: Date.now(),
            post_title: section,
            order: document.getElementsByClassName('ir-builder-top-element').length,
            type: "section-heading",
            steps: []
        }
        sections.push(new_section);

        setCourseList({
            ...courseList,
            sections: sections
        });

        setOpened(false);
        showNotification({
            title: __('Section Added', 'wdm_instructor_role'),
            message: __('Your section has successfully been updated!!', 'wdm_instructor_role'),
        })
        setSection('');
    }

    return (
        <>
            <Modal className="ir-topic-modal"
                opened={opened}
                onClose={() => setOpened(false)}
                title={__('Add New Section', 'wdm_instructor_role')}
                size='830px'
            >
                <Group align="center" mt={50} mb={50}>
                    <TextInput className="ir-section-input"
                        placeholder={__('Add section name here', 'wdm_instructor_role')}
                        size="md"
                        value={section}
                        onChange={(event) => setSection(event.currentTarget.value)}
                    />
                    <Button size="md" variant="outline" onClick={createNewSection}>{__('Add', 'wdm_instructor_role')}</Button>
                </Group>
            </Modal>

            <Button onClick={() => setOpened(true)} size="md" className="ir-fed-add-quiz ir-btn-outline" radius="md" variant="filled" leftIcon={<Plus size={22} color={'#2067FA'} />}>
                {__('Add New Section', 'wdm_instructor_role')}
            </Button>
        </>
    );
}