import { useState, useEffect } from 'react';

import {
    Text,
    Input,
    Group,
    TextInput,
    Switch,
    Radio,
    NumberInput,
    Select,
    MultiSelect,
    Tooltip,
    Button
} from '@mantine/core';
import { InfoCircle } from 'tabler-icons-react';
import { sprintf, __ } from "@wordpress/i18n";
import apiFetch from '@wordpress/api-fetch';

export default function CourseAccess(props) {
    const { form, course_id, instructorSettings } = props;
    const [course_list, setCourses] = useState([]);

    useEffect(() => {
        // Get Course List.
        apiFetch({
            path: "/ldlms/v2/sfwd-courses/?per_page=100",
            method: 'GET'
        }).then((data) => {
            let _course_list = [];
            data.map((course) => {
                if ( course_id != course.id ) {
                    _course_list.push({
                        label:course.title.rendered,
                        value:course.id
                    })
                }
            })
            setCourses(_course_list);
        })
    }, []);

    return (
        <>
            <div>
                <Radio.Group mt={15} className="ir-parent-settings-label"
                    name="Access Mode"
                    orientation="vertical"
                    label={__("Access Mode", "wdm_instructor_role")}
                    defaultValue="open"
                    {...form.getInputProps('price_type')}
                >
                    {null !== instructorSettings && ('off' !== instructorSettings?.enable_open_pricing) && (
                        <Radio
                            value="open"
                            label={__("Open", 'wdm_instructor_role')}
                            description={sprintf(__("The %s is not protected. Any user can access its content without the need to be logged-in or enrolled.", 'wdm_instructor_role'), ir_fcb_loc.lower_course_label)}
                        />
                    )}
                    {null !== instructorSettings && ('off' !== instructorSettings?.enable_free_pricing) && (
                        <Radio
                            value="free"
                            label={__("Free", 'wdm_instructor_role')}
                            description={sprintf(__("The %s is protected. Registration and enrollment are required in order to access the content.", 'wdm_instructor_role'), ir_fcb_loc.lower_course_label)}
                        />
                    )}
                    {null !== instructorSettings && ('off' !== instructorSettings?.enable_buy_pricing) && (
                        <Radio
                            value="paynow"
                            label={__("Buy now", 'wdm_instructor_role')}
                            description={sprintf(__("The %s is protected via the LearnDash built-in PayPal and/or Stripe. Users need to purchase the %s (one-time fee) in order to gain access.", 'wdm_instructor_role'), ir_fcb_loc.lower_course_label, ir_fcb_loc.lower_course_label)}
                        />
                    )}
                    <div className="ir-conditional-settings">
                        <TextInput className="ir-input-settings ir-radio-sub-settings ir-text-horizontal"
                            placeholder=""
                            label={sprintf(__("%s price", 'wdm_instructor_role'), ir_fcb_loc.course_label)}
                            labelPosition="left"
                            type="number"
                            styles={{ input: { width: 85, borderRadius: '10px' } }}
                            {...form.getInputProps('price_type_paynow_price')}
                        />
                        <Group className="ir-text-horizontal" spacing={0} mt={20}>
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {sprintf(__('%s enrollment URL', 'wdm_instructor_role'), ir_fcb_loc.course_label)}
                                <div className="ir-textinfo">
                                    <Tooltip label={sprintf(__("Enter the URL of the page you want to redirect your enrollees after signing up for this specific %s", 'wdm_instructor_role'), ir_fcb_loc.lower_course_label)} withArrow>
                                        <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'}/></Button>
                                    </Tooltip>
                                </div>
                            </Text>
                            <TextInput className="ir-input-settings ir-radio-sub-settings ir-text-horizontal w-70"
                                placeholder={__("Enter link/URL here", 'wdm_instructor_role')}
                                labelPosition="left"
                                styles={{ input: { borderRadius: '10px' } }}
                                {...form.getInputProps('price_type_paynow_enrollment_url')}
                            />
                        </Group>
                        
                    </div>
                    {null !== instructorSettings && ('off' !== instructorSettings?.enable_recurring_pricing) && (
                        <Radio
                            value="subscribe"
                            label={__("Recurring", 'wdm_instructor_role')}
                            description={sprintf(__("The %s is protected via the LearnDash built-in PayPal and/or Stripe. Users need to purchase the %s (recurring fee) in order to gain access.", 'wdm_instructor_role'), ir_fcb_loc.lower_course_label, ir_fcb_loc.lower_course_label)}
                        />
                    )}
                    <div className="ir-conditional-settings">
                        <TextInput className="ir-input-settings ir-radio-sub-settings ir-text-horizontal"
                            placeholder=""
                            label={sprintf(__("%s price", 'wdm_instructor_role'), ir_fcb_loc.lower_course_label)}
                            labelPosition="left"
                            type="number"
                            styles={{ input: { width: 85, borderRadius: '10px' } }}
                            {...form.getInputProps('price_type_subscribe_price')}
                        />
                        <Group mt={20} align="center">
                            <Text className="w-30 mantine-InputWrapper-label">{__('Billing cycle', 'wdm_instructor_role')}</Text>
                            <Group className="ir-flex-1">
                                <TextInput className="ir-input-settings ir-radio-sub-settings ir-text-horizontal"
                                    placeholder="0"
                                    type="number"
                                    styles={{ input: { width: 85, borderRadius: '10px' } }}
                                    {...form.getInputProps('price_type_subscribe_price_billing_cycle')}
                                />
                                <Select className="ir-horizontal-settings w-300"
                                    placeholder={__("Select interval", 'wdm_instructor_role')}
                                    data={[
                                        { value: 'D', label: __('day(s)', 'wdm_instructor_role') },
                                        { value: 'W', label: __('week(s)', 'wdm_instructor_role') },
                                        { value: 'M', label: __('month(s)', 'wdm_instructor_role') },
                                        { value: 'Y', label: __('year(s)', 'wdm_instructor_role') },
                                    ]}
                                    {...form.getInputProps('price_type_subscribe_price_billing_interval')}
                                />
                            </Group>
                        </Group>
                        <Group className="ir-text-horizontal" spacing={0} mt={20}>
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {__('Recurring times', 'wdm_instructor_role')}
                                <div className="ir-textinfo">
                                    <Tooltip label={__("How many times the billing cycle repeats. Leave empty for unlimited repeats.", 'wdm_instructor_role')} withArrow>
                                        <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'}/></Button>
                                    </Tooltip>
                                </div>
                            </Text>
                            <TextInput className="ir-input-settings ir-radio-sub-settings ir-text-horizontal w-70"
                                placeholder=""
                                labelPosition="left"
                                type="number"
                                styles={{ input: { width: 85, borderRadius: '10px' } }}
                                {...form.getInputProps('price_type_subscribe_billing_recurring_times')}
                            />
                        </Group>
                        <Group className="ir-text-horizontal" spacing={0} mt={20}>
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {sprintf(__('%s trial price', 'wdm_instructor_role'), ir_fcb_loc.course_label)}
                                <div className="ir-textinfo">
                                    <Tooltip label={sprintf(__("Enter the price for the trial period for this %s.", 'wdm_instructor_role'), ir_fcb_loc.lower_course_label)} withArrow>
                                        <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'}/></Button>
                                    </Tooltip>
                                </div>
                            </Text>
                            <TextInput className="ir-input-settings ir-radio-sub-settings ir-text-horizontal w-70"
                                placeholder=""
                                labelPosition="left"
                                type="number"
                                styles={{ input: { width: 85, borderRadius: '10px' } }}
                                {...form.getInputProps('trial_price')}
                            />
                        </Group>
                        
                        
                        <Group mt={20} align="center">
                            <Text className="w-30 mantine-InputWrapper-label ir-d-flex">
                                {__('Trial duration', 'wdm_instructor_role')}
                                <div className="ir-textinfo">
                                    <Tooltip label={sprintf(__("The length of the trial period, after the trial is over, the normal %s price billing goes into effect.", 'wdm_instructor_role'), 'wdm_instructor_role')} withArrow>
                                        <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'}/></Button>
                                    </Tooltip>
                                </div>
                            </Text>
                            <Group className="ir-flex-1">
                                <TextInput className="ir-input-settings ir-radio-sub-settings ir-text-horizontal"
                                    placeholder="0"
                                    type="number"
                                    styles={{ input: { width: 85, borderRadius: '10px' } }}
                                    {...form.getInputProps('trial_duration')}
                                />
                                <Select className="ir-horizontal-settings w-300"
                                    placeholder={__("Select interval", 'wdm_instructor_role')}
                                    data={[
                                        { value: 'D', label: __('day(s)', 'wdm_instructor_role') },
                                        { value: 'W', label: __('week(s)', 'wdm_instructor_role') },
                                        { value: 'M', label: __('month(s)', 'wdm_instructor_role') },
                                        { value: 'Y', label: __('year(s)', 'wdm_instructor_role') },
                                    ]}
                                    {...form.getInputProps('trial_duration_interval')}
                                />
                            </Group>
                        </Group>
                        <Group className="ir-text-horizontal" spacing={0} mt={20}>
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {sprintf(__('%s enrollment URL', 'wdm_instructor_role'), ir_fcb_loc.course_label)}
                                <div className="ir-textinfo">
                                    <Tooltip label={sprintf(__("Enter the URL of the page you want to redirect your enrollees after signing up for this specific %s.", 'wdm_instructor_role'), ir_fcb_loc.lower_course_label)} withArrow>
                                        <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'}/></Button>
                                    </Tooltip>
                                </div>
                            </Text>
                            <TextInput className="ir-input-settings ir-radio-sub-settings ir-text-horizontal w-70"
                                placeholder={__("Enter link/URL here", 'wdm_instructor_role')}
                                labelPosition="left"
                                styles={{ input: { borderRadius: '10px' } }}
                                {...form.getInputProps('price_type_subscribe_enrollment_url')}
                            />
                        </Group>
                        
                    </div>

                    {null !== instructorSettings && ('off' !== instructorSettings?.enable_closed_pricing) && (
                        <Radio
                            value="closed"
                            label={__("Closed", 'wdm_instructor_role')}
                            description={sprintf(__("The %s can only be accessed through admin enrollment (manual), group enrollment, or integration (shopping cart or membership) enrollment. No enrollment button will be displayed, unless a URL is set (optional).", 'wdm_instructor_role'), ir_fcb_loc.lower_course_label)}
                        />
                    )}
                    <div className="ir-conditional-settings">
                        <TextInput className="ir-input-settings ir-radio-sub-settings ir-text-horizontal"
                            placeholder=""
                            label={sprintf(__("%s price", 'wdm_instructor_role'), ir_fcb_loc.course_label)}
                            labelPosition="left"
                            type="number"
                            styles={{ input: { width: 85, borderRadius: '10px' } }}
                            {...form.getInputProps('price_type_closed_price')}
                        />
                        <Group className="ir-text-horizontal" spacing={0} mt={20}>
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {__('Button URL', 'wdm_instructor_role')}
                                <div className="ir-textinfo">
                                    <Tooltip label={sprintf(__("Redirect the 'Take this %s' button to a specific URL.", 'wdm_instructor_role'), ir_fcb_loc.course_label)} withArrow>
                                        <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'}/></Button>
                                    </Tooltip>
                                </div>
                            </Text>
                            <TextInput className="ir-input-settings ir-radio-sub-settings ir-text-horizontal w-70"
                                placeholder={__("Enter link/URL here", 'wdm_instructor_role')}
                                labelPosition="left"
                                styles={{ input: { borderRadius: '10px' } }}
                                {...form.getInputProps('price_type_closed_custom_button_url')}
                            />
                        </Group>
                        
                    </div>
                </Radio.Group>
                <Switch
                    checked={form.values.prerequisite_enabled}
                    onChange={(event) => form.setFieldValue('prerequisite_enabled', event.currentTarget.checked)}
                    className={form.values.prerequisite_enabled ? 'ir-checked ir-course-access-p-settings ir-parent-settings-label' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings-label'}
                    size="lg" mt={20} labelPosition="left" label={sprintf(__("%s prerequisties", 'wdm_instructor_role'), ir_fcb_loc.course_label)} />
                <div className="ir-conditional-settings">
                    <Radio.Group mt={15}
                        name="Compare Mode"
                        orientation="vertical"
                        label={__("Compare Mode", 'wdm_instructor_role')}
                        default="Any selected"
                        {...form.getInputProps('prerequisite_compare')}
                    >
                        <Radio value="ANY" label={__("Any selected", 'wdm_instructor_role')} description={sprintf(__("The user must complete any one of the selected %s in order to access this %s.", 'wdm_instructor_role'), ir_fcb_loc.courses_label, ir_fcb_loc.lower_course_label)}
                        />
                        <Radio value="ALL" label={__("All selected", 'wdm_instructor_role')} description={sprintf(__("The user must complete all selected %s in order to access this %s.", 'wdm_instructor_role'), ir_fcb_loc.courses_label, ir_fcb_loc.lower_course_label)}
                        />
                    </Radio.Group>
                    <MultiSelect className="ir-horizontal-settings" mt={25}
                        label={sprintf(__("%s to complete", 'wdm_instructor_role'), ir_fcb_loc.courses_label)}
                        placeholder={sprintf(__("Select a %s", 'wdm_instructor_role'), ir_fcb_loc.course_label)}
                        data={course_list}
                        {...form.getInputProps('prerequisites')}
                    />
                </div>
                <Switch
                    checked={form.values.points_enabled}
                    onChange={(event) => form.setFieldValue('points_enabled', event.currentTarget.checked)}
                    className={form.values.points_enabled ? 'ir-checked ir-course-access-p-settings ir-parent-settings-label' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings-label'}
                    size="lg" mt={20} labelPosition="left" label={sprintf(__("%s points", 'wdm_instructor_role'), ir_fcb_loc.course_label)} />
                <div className="ir-conditional-settings">
                    <Group spacing={0} mt={25}>
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {__('Required for access', 'wdm_instructor_role')}
                            <div className="ir-textinfo">
                                <Tooltip label={sprintf(__("Number of points required in order to gain access to this %s.", 'wdm_instructor_role'), ir_fcb_loc.lower_course_label)} withArrow>
                                    <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'}/></Button>
                                </Tooltip>
                            </div>
                        </Text>
                        <TextInput className="ir-label-right"
                            label="point(s)"
                            labelPosition="right"
                            styles={{ input: { width: 85, borderRadius: '10px' } }}
                            {...form.getInputProps('points_access')}
                        />
                    </Group>
                    <Group spacing={0} mt={25}>
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {__('Awarded on completion', 'wdm_instructor_role')}
                            <div className="ir-textinfo">
                                <Tooltip label={sprintf(__("Number of points awarded for completing this %s.", 'wdm_instructor_role'), ir_fcb_loc.lower_course_label)} withArrow>
                                    <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'}/></Button>
                                </Tooltip>
                            </div>
                        </Text>
                        <TextInput className="ir-label-right"
                            label="point(s)"
                            labelPosition="right"
                            styles={{ input: { width: 85, borderRadius: '10px' } }}
                            {...form.getInputProps('points_amount')}
                        />
                    </Group>
                </div>
                <Switch
                    {...form.getInputProps('expire_access', {type: 'checkbox'})}
                    // checked={form.values.expire_access}
                    // onChange={(event) => form.setFieldValue('expire_access', event.currentTarget.checked)}
                    className={form.values.expire_access ? 'ir-checked ir-course-access-p-settings ir-parent-settings-label' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings-label'}
                    size="lg" mt={20} labelPosition="left" label={sprintf(__("%s access expiration", 'wdm_instructor_role'), ir_fcb_loc.course_label)} />
                <div className="ir-conditional-settings">
                    <Group spacing={0} mt={25}>
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {__('Access Period', 'wdm_instructor_role')}
                            <div className="ir-textinfo">
                                <Tooltip label={sprintf(__("Set the number of days a user will have access to the %s from enrollment date.", 'wdm_instructor_role'), ir_fcb_loc.lower_course_label)} withArrow>
                                    <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'}/></Button>
                                </Tooltip>
                            </div>
                        </Text>
                        <TextInput className="ir-label-right"
                            label={__("days", 'wdm_instructor_role')}
                            labelPosition="right"
                            type="number"
                            styles={{ input: { width: 85, borderRadius: '10px' } }}
                            {...form.getInputProps('expire_access_days')}
                        />
                    </Group>
                    <Group spacing={0} mt={25} align="center">
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {__('Data deletion', 'wdm_instructor_role')}
                            <div className="ir-textinfo">
                                <Tooltip label={sprintf(__("Delete the user's %s and quiz data when the %s access expires.", 'wdm_instructor_role'), ir_fcb_loc.lower_course_label, ir_fcb_loc.lower_course_label)} withArrow>
                                    <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'}/></Button>
                                </Tooltip>
                            </div>
                        </Text>
                        <Switch size="md"
                            {...form.getInputProps('expire_access_delete_progress', {type:'checkbox'})}
                        />
                    </Group>
                </div>
            </div>
        </>
    );
}