import { useState, useEffect } from 'react';

import {
    Loader,
    Text,
    MultiSelect
} from '@mantine/core';

import { sprintf, __ } from "@wordpress/i18n";
import apiFetch from '@wordpress/api-fetch';

export default function CourseShare(props) {
    const { form, course_id } = props;
    const [loading, setLoading] = useState(true);
    const [instructors, setInstructors] = useState([]);
    const [shared_instructors, setSharedinstructors] = useState([]);
    const [users, setUsers] = useState([]);
    const [current_user, setCurrentUser] = useState(null);

    const fetchSharedCourseInstructors = () => {
        setLoading(true);

        // Fetch current user details.
        apiFetch({
            path: 'wp/v2/users/me',
            method: 'GET'
        }).then((userdata) => {
            setCurrentUser(userdata);
        });

        // Fetch all instructors.
        apiFetch(
            {
                path: "/ir/v1/instructors/",
                method: 'GET',
            }
        ).then((data) => {
            let userlist = [];
            if ( data.length ) {
                data.map((instructor) => {
                    if ( parseInt(instructor.value) !== parseInt(ir_fcb_loc.course_info.post_author) ) {
                        userlist.push(instructor);
                    }
                })
            }
            setInstructors(userlist);
            // Fetch shared instructors for course.
            apiFetch(
                {
                    path: "/ir/v1/instructors/" + course_id,
                    method: 'GET',
                }
            ).then((data) => {
                if (data.length) {
                    let _shared_users = [];
                    data.map((user) => {
                        _shared_users.push(user.value);
                    });
                    setSharedinstructors(_shared_users);
                    form.setFieldValue('shared_instructors', _shared_users);
                }
                setLoading(false);
            });
        });
    }

    const setUserDetails = (transfer_list) => {
        setUsers(transfer_list);
        let _users = [];

        transfer_list[1].map((user) => {
            _users.push(user.value);
        });

        form.setFieldValue('course_users', _users);
    }

    useEffect(() => {
        fetchSharedCourseInstructors();
    }, []);

    return (
        <>
            {loading && (<Loader size="sm" />)}
            {!loading && null !== current_user && ( (form.values.author === current_user.id.toString() ) || ir_fcb_loc.is_admin) &&(
                <MultiSelect
                    label={sprintf(__("Select the list of instructors you wish to share this %s with", 'wdm_instructor_role'), ir_fcb_loc.lower_course_label)}
                    data={instructors}
                    placeholder={__("Select instructors", 'wdm_instructor_role')}
                    searchable
                    onChange={(value) => {
                        setSharedinstructors(value);
                        form.setFieldValue('shared_instructors', value);
                    }}
                    value={shared_instructors}
                    nothingFound={__('No instructors found', 'wdm_instructor_role')}
                />
            )}
            { ( !ir_fcb_loc.is_admin ) ? 
                (!loading && null !== current_user && form.values.author !== current_user.id.toString() && (
                    <Text>
                        {sprintf(__('Sorry, but you cannot share this %s with anyone. Please contact the original author of this %s.', 'wdm_instructor_role'), ir_fcb_loc.lower_course_label, ir_fcb_loc.lower_course_label)}
                    </Text>
                )) : ''
            }
        </>
    );
}