import { useState, useEffect } from 'react';

import {
    TransferList,
    TransferListData,
    Loader,
    Text
} from '@mantine/core';

import { sprintf, __ } from "@wordpress/i18n";
import apiFetch from '@wordpress/api-fetch';

export default function CourseUser(props) {
    const { form, course_id } = props;
    const [loading, setLoading] = useState(true);
    const [userdata, setUsers] = useState([[], []]);

    const fetchUserData = () => {
        // Fetch site users
        apiFetch(
            {
                path: "/wp/v2/users/?per_page=9999",
                method: 'GET',
            }
        ).then((data) => {

            let users = [];
            data.map((user, ind) => {
                users.push({
                    value: user.id.toString(),
                    label: user.name
                })
            })

            // Fetch course users.
            apiFetch(
                {
                    path: "/ir/v1/sfwd-courses/" + course_id + "/users",
                    method: 'GET',
                }
            ).then((data) => {

                let course_users = [];
                data.map((user, ind) => {
                    course_users.push({
                        value: user.id,
                        label: user.name
                    })
                    let indexOfObject = users.findIndex(object => {
                        return object.value == user.id;
                    });

                    users.splice(indexOfObject, 1);
                })

                setUsers([users, course_users]);
                setLoading(false);
            });
        });
    }

    const setUserDetails = (transfer_list) => {
        setUsers(transfer_list);
        let _users = [];

        transfer_list[1].map((user)=>{
            _users.push(user.value);
        });
        form.setFieldValue('course_users', _users);
    }

    useEffect(() => {
        fetchUserData();
    }, []);

    return (
        <>
            {false !== loading && (<Loader size="sm" type="bars" />)}
            {false === loading && 'open' !== form.values.price_type &&(
                <div>
                    <TransferList
                        value={userdata}
                        onChange={(transfer_list) => (setUserDetails(transfer_list))}
                        searchPlaceholder={[sprintf(__('Search all %s users', 'wdm_instructor_role'), ir_fcb_loc.lower_course_label), sprintf(__('Search assigned %s users', 'wdm_instructor_role'), ir_fcb_loc.lower_course_label)]}
                        nothingFound={__("Nothing here", 'wdm_instructor_role')}
                        breakpoint="sm"
                    />
                </div>
            )}
            {false === loading && 'open' === form.values.price_type && (
                <Text>{sprintf(__('The %s price type is set to "open". This means ALL are automatically enrolled.', 'wdm_instructor_role'), ir_fcb_loc.course_label)}</Text>
            )}
        </>
    );
}