import { useState, useEffect } from 'react';

import {
    AppShell,
    Navbar,
    Header,
    Accordion,
    MantineProvider,
    Text,
    Title,
    Grid,
    Paper,
    Input,
    Checkbox,
    Button,
    Group,
    Space,
    Center,
    CloseButton,
    Skeleton,
    TextInput,
    Modal,
    Tabs,
    FileButton,
    Switch,
    Radio,
    NumberInput,
    MultiSelect,
    Loader,
    Divider,
    Select,
    Tooltip,
    Textarea
} from '@mantine/core';

import { InfoCircle } from 'tabler-icons-react';

import { sprintf, __ } from "@wordpress/i18n";
import apiFetch from '@wordpress/api-fetch';

export default function DisplayContent(props) {
    const { form, course_id } = props;
    const [certificates, setCertificates] = useState([]);
    const [exams, setExams] = useState([]);

    useEffect(() => {
        apiFetch({
            path: 'ir/v1/sfwd-certificates',
            method: 'GET'
        }
        ).then((data) => setCertificates(data));

        apiFetch({
            path: 'ir/v1/ld-exams',
            method: 'GET'
        }
        ).then((data) => setExams(data));
    }, []);

    return (
        <>
            <div>
                <Group className="ir-course-material-wrap" spacing={0} mt={25} align="center">
                    <Text size="md" weight={600} className="w-40 mantine-InputWrapper-label ir-d-flex">
                        {sprintf(__('%s Material', 'wdm_instructor_role'), ir_fcb_loc.course_label)}
                        <div className="ir-textinfo">
                            <Tooltip label={sprintf(__("List and display support materials for the %s. This is visible to all users (including non-enrollees) by default.", 'wdm_instructor_role'), ir_fcb_loc.lower_course_label)} withArrow>
                                <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
                            </Tooltip>
                        </div>
                        <Text className="ir-sep-desc" size="sm" weight={400} color="#6F717C">
                            {sprintf(__('Any content added below is displayed on the main %s page', 'wdm_instructor_role'), ir_fcb_loc.course_label)}
                        </Text>
                    </Text>
                    <Switch
                        checked={form.values.materials_enabled}
                        onChange={(event) => form.setFieldValue('materials_enabled', event.currentTarget.checked)}
                        className={form.values.materials_enabled ? 'ir-checked ir-course-access-p-settings ir-parent-settings-label' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings-label'}
                        size="md" />
                    <div className="ir-conditional-settings">
                        <Textarea
                            className="ir-tiny-mce-editors"
                            id="ir-course-material-editor"
                            minRows={15}
                            {...form.getInputProps("materials")}
                        />
                    </div>
                </Group>
                <Select className="ir-horizontal-settings ir-parent-settings-label" mt={25}
                    label={sprintf(__("%s certificate", 'wdm_instructor_role'), ir_fcb_loc.courses_label)}
                    placeholder={__("Select a certificates", 'wdm_instructor_role')}
                    clearable
                    data={certificates}
                    nothingFound={__("No certificates found", "wdm_instructor_role")}
                    {...form.getInputProps('certificate')}
                />
                <Select className="ir-horizontal-settings ir-parent-settings-label" mt={25}
                    label={__("Challenge exam show", 'wdm_instructor_role')}
                    placeholder={__("Select a Challenge exam", 'wdm_instructor_role')}
                    clearable
                    data={exams}
                    nothingFound={__("No exam challenges found", "wdm_instructor_role")}
                    {...form.getInputProps('exam_challenge')}
                />
                <Group className="ir-course-content-visibility" spacing={0} mt={25} align="center">
                    <Text size="md" weight={600} className="mantine-InputWrapper-label ir-d-flex">
                        {sprintf(__('%s content', 'wdm_instructor_role'), ir_fcb_loc.course_label)}
                        <div className="ir-textinfo">
                            <Tooltip label={sprintf(__("Choose whether to display the %s content table to ALL users or only enrollees.", 'wdm_instructor_role'), ir_fcb_loc.lower_course_label)} withArrow>
                                <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
                            </Tooltip>
                        </div>
                    </Text>
                    <Radio.Group mt={15} pl={25}
                        name="disable_content_table"
                        orientation="vertical"
                        defaultValue="visible"
                        {...form.getInputProps('disable_content_table')}
                    >
                        <Radio value="visible" label={__("Always visible", 'wdm_instructor_role')} />
                        <Radio value="enrollees" label={__("Only visible to enrollees", 'wdm_instructor_role')} />
                    </Radio.Group>
                </Group>
                <Switch
                    description={sprintf(__("Customize the pagination options for this %s content table and %s navigation widget.", 'wdm_instructor_role'), ir_fcb_loc.lower_course_label, ir_fcb_loc.lower_course_label)}
                    checked={form.values.lessons_per_page}
                    onChange={(event) => form.setFieldValue('lessons_per_page', event.currentTarget.checked)}
                    className={form.values.lessons_per_page ? 'ir-checked ir-course-access-p-settings ir-parent-settings-label' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings-label'}
                    size="md" mt={20} labelPosition="left" label={__('Custom Pagination', 'wdm_instructor_role')} />
                <div className="ir-conditional-settings">
                    <Group spacing={0} mt={25}>
                        <Text className="w-40 mantine-InputWrapper-label">{sprintf(__('%s', 'wdm_instructor_role'), ir_fcb_loc.lessons_label)}</Text>
                        <TextInput className="ir-label-right"
                            label="per page"
                            labelPosition="right"
                            type="number"
                            styles={{ input: { width: 85, borderRadius: '10px' } }}
                            {...form.getInputProps('lesson_per_page_custom')}
                        />
                    </Group>
                    <Group spacing={0} mt={25}>
                        <Text className="w-40 mantine-InputWrapper-label">{sprintf(__('%s', 'wdm_instructor_role'), ir_fcb_loc.topics_label)}</Text>
                        <TextInput className="ir-label-right"
                            label="per page"
                            labelPosition="right"
                            type="number"
                            styles={{ input: { width: 85, borderRadius: '10px' } }}
                            {...form.getInputProps('topic_per_page_custom')}
                        />
                    </Group>
                </div>
            </div>
        </>
    );
}