import { useState, useEffect } from 'react';
import {
    Accordion,
    Grid,
    Paper,
    Text,
    Group,
    TransferList,
    Loader
} from '@mantine/core';
import { sprintf, __ } from "@wordpress/i18n";
import apiFetch from '@wordpress/api-fetch';

export default function CourseGroups(props) {
    const { form, course_id } = props;
    const [loading, setLoading] = useState(true);
    const [groups_data, setCourseGroups] = useState([[], []]);

    const fetchGroupsData = () => {
        // Fetch groups
        let path = "/ir/v1/groups";
        if ( ir_fcb_loc.is_admin) {
            path = "/ldlms/v2/groups";
        }
        apiFetch(
            {
                path,
                method: 'GET',
            }
        ).then((data) => {
            let groups = [];
            data.map((group, ind) => {
                groups.push({
                    value: group.id.toString(),
                    label: group.title.rendered
                })
            });

            // Fetch course groups
            let path = "/ir/v1/sfwd-courses/"+course_id+"/groups";
            if ( ir_fcb_loc.is_admin) {
                path = "/ldlms/v2/sfwd-courses/"+course_id+"/groups";
            }

            apiFetch(
                {
                    path,
                    method: 'GET',
                }
            ).then((data) => {
                let course_groups = [];
                data.map((group, ind) => {
                    course_groups.push({
                        value: group.id.toString(),
                        label: group.title.rendered
                    })
                    let indexOfObject = groups.findIndex(object => {
                        return object.value == group.id;
                    });

                    groups.splice(indexOfObject, 1);
                })

                setCourseGroups([groups, course_groups]);
                setLoading(false);
            });
        });
    }

    const setGroupDetails = (transfer_list) => {
        setCourseGroups(transfer_list);
        let _groups = [];

        transfer_list[1].map((group) => {
            _groups.push(group.value);
        });
        form.setFieldValue('course_groups', _groups);
    }

    useEffect(() => {
        fetchGroupsData();
    }, []);

    return (
        <Grid>
            <Grid.Col span={8} offset={2}>
                <Paper p="xl" radius="xl" className="ir-fed-course-settings">
                    <Group noWrap>
                        <div>
                            <Text className="ir-uppercase" size="md" weight={600}>{sprintf(__('%s Groups', 'wdm_instructor_role'), ir_fcb_loc.course_label)}</Text>
                            <Text size="sm" color="#6F717C" weight={400} mt={10}>
                                {sprintf(__('Users enrolled via %1$s using this %2$s are excluded from the listings below and should be manage via the %3$s admin screen.', 'wdm_instructor_role'), ir_fcb_loc.groups_label, ir_fcb_loc.course_label, ir_fcb_loc.lower_group_label)}
                            </Text>
                        </div>
                    </Group>
                    {false !== loading && (<Loader size="sm" type="bars" />)}
                    {false === loading && (
                        <div>
                            <TransferList
                                value={groups_data}
                                onChange={(transfer_list) => (setGroupDetails(transfer_list))}
                                searchPlaceholder={[sprintf(__('Search all %s', 'wdm_instructor_role'), ir_fcb_loc.groups_label), sprintf(__('Search %1$s %2$s', 'wdm_instructor_role'), ir_fcb_loc.course_label, ir_fcb_loc.groups_label)]}
                                nothingFound={__("Nothing here", 'wdm_instructor_role')}
                                breakpoint="sm"
                                mt={20}
                            />
                        </div>
                    )}
                </Paper>
            </Grid.Col>
        </Grid>
    );
}