import { useState, useEffect } from 'react';
import { useForm } from '@mantine/form';
import {
	AppShell,
	Navbar,
	Header,
	Accordion,
	MantineProvider,
	Text,
	Title,
	Grid,
	Paper,
	Input,
	Checkbox,
	Button,
	Group,
	Space,
	Center,
	CloseButton,
	Skeleton,
	TextInput,
	Modal,
	Tabs,
	FileButton,
	Switch,
	Radio,
	NumberInput,
	MultiSelect,
	Loader,
	Divider,
	Image,
	Textarea,
	Tooltip,
	Select,
	Anchor
} from '@mantine/core';
import { showNotification } from '@mantine/notifications';
import { openConfirmModal } from '@mantine/modals';
import { Upload, Trash, Plus, X, ExclamationMark, PhotoUp, Replace } from 'tabler-icons-react';
import { sprintf, __ } from "@wordpress/i18n";
import apiFetch from '@wordpress/api-fetch';
import { MediaUpload } from '@wordpress/media-utils';

export default function CoursePage(props) {
	const [featured_image, setFeaturedImage] = useState(null);
	const [new_category, setNewCategory] = useState('');
	const [parent_category, setParentCategory] = useState('');
	const [showTagLoader, setShowTagLoader] = useState(false);
	const [editSlug, setEditSlug] = useState(false);
	const [loading, setLoader] = useState(false);
	const [process_review, setReviewLoader] = useState(false);
	const { form, course_title, setCourseTitle, course_id, instructorSettings, setInstructorSettings, review_data, setReviewData } = props;

	const [courseCategories, setCourseCategories] = useState([]);
	const [courseTags, setCourseTags] = useState(null);
	const [showCatFields, setShowCatFields] = useState(false);
	const [category_loading, setCategoryLoader] = useState(false);
	const [authors, setAuthors] = useState([]);

	const fetchCoursePageData = () => {
		if ("yes" === ir_fcb_loc.ld_cat_tag?.course_tag) {
			// Fetch course tags
			apiFetch(
				{
					path: "/wp/v2/ld_course_tag?per_page=100",
					method: 'GET',
				}
			).then((data) => {
				let tags = [];
				data.map((tag, ind) => {
					tags.push({
						label: tag.name,
						value: tag.id.toString()
					})
				})
				setCourseTags(tags)
			});
		}

		if ("yes" === ir_fcb_loc.ld_cat_tag?.course) {
			// Fetch course categories
			apiFetch(
				{
					path: "/ir/v1/ld-course-category?per_page=100",
					method: 'GET',
				}
			).then((data) => {
				let categories = [];
				data.map((category, ind) => {
					if (category.hasOwnProperty('children')) {
						categories.push({
							label: category.name,
							value: category.id.toString(),
							children: category.children
						});
					} else {
						categories.push({
							label: category.name,
							value: category.id.toString()
						});
					}
				})
				setCourseCategories(categories);
			});
		}

		// Fetch course details
		apiFetch(
			{
				path: "/ldlms/v2/sfwd-courses/" + course_id,
				method: 'GET',
			}
		).then((data) => {
			setCourseTitle(data.title.rendered);
			tinymce.get("ir-content-editor").setContent(data.content.rendered);
			tinymce.get("ir-course-material-editor").setContent(data.materials.rendered);
			form.setValues({
				title: data.title.rendered,
				status: data.status,
				content: data.content.rendered,
				slug: data.slug,
				featured_media: data.featured_media,
				ld_course_category: data.ld_course_category?.toString().split(','),
				ld_course_tag: data.ld_course_tag?.map(String),
				materials_enabled: data.materials_enabled,
				materials: data.materials.rendered,
				certificate: data.certificate,
				exam_challenge: data.exam_challenge,
				disable_content_table: (data.disable_content_table) ? 'enrollees' : 'visible',
				lessons_per_page: data.lessons_per_page,
				lesson_per_page_custom: data.lesson_per_page_custom,
				topic_per_page_custom: data.topic_per_page_custom,
				price_type: data.price_type,
				price_type_paynow_price: data.price_type_paynow_price,
				price_type_paynow_enrollment_url: data.price_type_paynow_enrollment_url,
				price_type_subscribe_price: data.price_type_subscribe_price,
				trial_price: data.trial_price,
				price_type_subscribe_enrollment_url: data.price_type_subscribe_enrollment_url,
				price_type_closed_price: data.price_type_closed_price,
				price_type_closed_custom_button_url: data.price_type_closed_custom_button_url,
				prerequisite_enabled: data.prerequisite_enabled,
				prerequisite_compare: data.prerequisite_compare,
				prerequisites: data.prerequisites,
				points_enabled: data.points_enabled,
				points_access: data.points_access,
				points_amount: data.points_amount,
				progression_disabled: (data.progression_disabled) ? "free" : "linear",
				expire_access: data.expire_access,
				expire_access_days: data.expire_access_days,
				expire_access_delete_progress: data.expire_access_delete_progress,
				featured_media: data.featured_media,
				author: data.author.toString(),
				link: data.link,
				date: (data.date.length) ? new Date(data.date) : new Date(),
				time: (data.date.length) ? new Date(data.date) : new Date(),
				password: data.password
			});
			setLoader(true);

			// Set featured image.
			if (data.featured_media) {
				setLoader(false);
				apiFetch(
					{
						path: "/wp/v2/media/" + data.featured_media,
						method: 'GET',
					}
				).then((data) => {
					form.setValues({
						featured_image_url: data.source_url
					});
					setFeaturedImage({
						id: data.featured_media,
						url: data.source_url
					});
					setLoader(true);
				})
			}

			// Set course visibility
			let _visibility = 'public';
			if (data.content.protected) {
				_visibility = 'password';
			} else if ('private' === data.status) {
				_visibility = 'private';
				// Remove keyword Private from title.
				// if ( -1 !== data.title.rendered.indexOf('Private:')) {
				// 	const post_title = data.title.rendered;
				// 	form.setFieldValue('title', post_title.replace('Private:', ''));
				// }
			}

			form.setFieldValue('visibility', _visibility);
		});

		// Set remaining course data.
		apiFetch(
			{
				path: "/ir/v1/sfwd-courses/" + course_id + "/remaining",
				method: 'GET',
			}
		).then((data) => {
			form.setValues({
				price_type_subscribe_price_billing_cycle: parseInt(data.price_type_subscribe_price_billing_cycle),
				price_type_subscribe_price_billing_interval: data.price_type_subscribe_price_billing_interval,
				trial_duration: parseInt(data.trial_duration),
				trial_duration_interval: data.trial_duration_interval,
				price_type_subscribe_billing_recurring_times: parseInt(data.price_type_subscribe_billing_recurring_times),
				is_published: data.is_published
			});
			form.setFieldValue('lessons_per_page', (data.hasOwnProperty('lessons_per_page') && data?.lessons_per_page.length > 0) ? true : false);

			// Set instructor settings for instructors.
			if (!ir_fcb_loc.is_admin) {
				setInstructorSettings({
					category_hide_check: data.category_hide_check,
					category_restrict_check: data.category_restrict_check,
					enable_buy_pricing: data.enable_buy_pricing,
					enable_closed_pricing: data.enable_closed_pricing,
					enable_free_pricing: data.enable_free_pricing,
					enable_open_pricing: data.enable_open_pricing,
					enable_permalinks: data.enable_permalinks,
					enable_recurring_pricing: data.enable_recurring_pricing,
				});
			}
		});

		// Get author users.
		apiFetch(
			{
				path: "/ir/v1/users?roles=wdm_instructor,administrator",
				method: "GET"
			}
		).then((data) => {
			let author_list = [];
			data.map((user) => {
				author_list.push({
					label: user.name,
					value: user.id.toString()
				});
			})
			setAuthors(author_list);
		});

		// Fetch Course Review Data
		if (ir_fcb_loc.instructor_settings?.review_course && ir_fcb_loc.is_admin) {
			// Get review data.
			apiFetch(
				{
					path: "/ir/v1/sfwd-courses/" + course_id + "/review",
					method: "GET"
				}
			).then((data) => {
				setReviewData(data);
			});
		}
	}
	useEffect(() => {
		wp.editor.initialize(
			'ir-content-editor',
			{
				tinymce: {
					wpautop: true,
					height: '300px',
					plugins: 'charmap colorpicker compat3x directionality hr image lists media paste tabfocus textcolor wordpress wpautoresize wpdialogs wpeditimage link',
					toolbar1: 'formatselect bold italic underline strikethrough | bullist numlist | blockquote hr wp_more | alignleft aligncenter alignright | link unlink |  media wp_add_media'
				},
				quicktags: false,
				mediaButtons: true,
			}
		);
		wp.editor.initialize(
			'ir-course-material-editor',
			{
				tinymce: {
					wpautop: true,
					height: '300px',
					plugins: 'charmap colorpicker compat3x directionality hr image lists media paste tabfocus textcolor wordpress wpautoresize wpdialogs wpeditimage link',
					toolbar1: 'formatselect bold italic underline strikethrough | bullist numlist | blockquote hr wp_more | alignleft aligncenter alignright | link unlink |  media wp_add_media'
				},
				quicktags: false,
				mediaButtons: true,
			}
		);
		fetchCoursePageData();
	}, []);

	const createNewCourseTag = (query) => {
		// Create New Course Tag.
		setShowTagLoader(true);
		apiFetch(
			{
				path: "/wp/v2/ld_course_tag",
				method: 'POST',
				data: {
					name: query
				}
			}
		).then((response) => {
			if (false != response && response.hasOwnProperty('id')) {
				setShowTagLoader(false);
				const item = { value: response.id.toString(), label: response.name };
				setCourseTags((current) => [...current, item]);
				form.setFieldValue('ld_course_tag', [...form.values.ld_course_tag, response.id.toString()])
			}
		});
	}

	const setSlug = (link) => {
		link = link.replace(/\/$/, "");
		link = link.substring(0, link.lastIndexOf("/") + 1);
		if (form.values.slug == undefined) {
			form.values.slug = form.values.slug
		}
		// props.setQuizData({
		//     ...props.quizData,
		//     link: link+props.quizForm.values.slug,
		//     slug: props.quizForm.values.slug
		// })
		form.setValues({
			link: link + form.values.slug,
			slug: form.values.slug
		})
		setEditSlug(false);
	}

	const GetLinkWithoutSlug = (props) => {
		let link = props.link.replace(/\/$/, "");
		link = link.substring(0, link.lastIndexOf("/") + 1);
		return (
			<>
				<Anchor color="#2067FA" size="sm">
					{link}
				</Anchor>
			</>
		);
	}

	const createCourseCategory = () => {
		if (new_category.length === 0) {
			showNotification({
				title: __('Warning', 'wdm_instructor_role'),
				message: __('Category name cannot be empty', 'wdm_instructor_role'),
				icon: <ExclamationMark />,
				color: 'yellow'
			});
			return;
		}

		setCategoryLoader(true);
		let data = {
			name: new_category
		}
		if (null !== parent_category && parent_category.length > 0) {
			data.parent = parent_category;
		}

		// Create New Course Category.
		apiFetch(
			{
				path: "/wp/v2/ld_course_category",
				method: 'POST',
				data
			}
		).then((response) => {
			if (false != response && response.hasOwnProperty('id')) {
				const item = { value: response.id.toString(), label: response.name };
				setCourseCategories((current) => [...current, item]);
				form.setFieldValue('ld_course_category', [...form.values.ld_course_category, response.id.toString()])
			}
			setShowCatFields(false);
			setCategoryLoader(false);
			setParentCategory('');
			setNewCategory('');
		});
	}

	const html_entity_decode = (message) => {
		var domParser = new DOMParser();
		var decodedString = domParser.parseFromString(message, 'text/html').body.textContent;
		return decodedString;
	}

	const approveModal = () => openConfirmModal({
		modal: 'approve-course-updates',
		title: __('Approve Instructor Updates', 'wdm_instructor_role'),
		children: (
			<Text size="sm">
				{sprintf(__('This will approve all the changes made by the instructor and the %s updates will be published?', 'wdm_instructor_role'), ir_fcb_loc.course_label)}
			</Text>
		),
		labels: { confirm: 'Yes', cancel: 'Cancel' },
		confirmProps: { color: 'red' },
		modalId: "bgdvbsj",
		onCancel: () => console.log('Cancel'),
		onConfirm: () => approveInstructorUpdates(),
	});

	const approveInstructorUpdates = () => {
		setReviewLoader(true);
		jQuery.ajax({
			url: ir_fcb_loc.ajax_url,
			method: 'POST',
			data: {
				action: 'approve_instructor_update_ajax',
				post_id: course_id
			},
			success: function (response) {
				showNotification({
					title: __('Instructor updates approved successfully !!', 'wdm_instructor_role')
				})
				setReviewLoader(false);
				setReviewData([]);
			}
		});
	}

	return (
		<>
			<Grid>
				<Grid.Col span={8}>
					<Paper radius="xl" p="xl" className="ir-fed-course-page">
						<Group align="center" mt={10}>
							<TextInput className="ir-tt-text ir-parent-settings"
								label={sprintf(__('%s Title', 'wdm_instructor_role'), ir_fcb_loc.course_label)}
								placeholder={__('Write title here', 'wdm_instructor_role')}
								size="lg"
								value={html_entity_decode(course_title)}
								onChange={(value) => setCourseTitle(value.currentTarget.value)}
							/>
						</Group>
						{!editSlug && (ir_fcb_loc.is_admin || (false !== ir_fcb_loc.instructor_settings && ('off' !== ir_fcb_loc.instructor_settings?.enable_permalinks))) && (
							<Group className="ir-link-section" align="center" mt={20} pl={10} spacing="xs">
								<Text>{sprintf(__('%s URL:', 'wdm_instructor_role'), ir_fcb_loc.course_label)}</Text>
								<Anchor color="#2067FA" size="sm" href={form.values.link} target="_blank">
									{form.values.link}
								</Anchor>
								<Button onClick={() => setEditSlug(true)} size="xs" className="ir-btn-outline" disabled={form.values.status === 'draft' ? true : false}>{__('Edit', 'wdm_instructor_role')}</Button>
							</Group>
						)}
						{editSlug && (ir_fcb_loc.is_admin || (false !== ir_fcb_loc.instructor_settings && ('off' !== ir_fcb_loc.instructor_settings?.enable_permalinks))) && (
							<Group className="ir-link-section" align="center" mt={20} pl={10} spacing="xs">
								<Text>{sprintf(__('%s URL:', 'wdm_instructor_role'), ir_fcb_loc.course_label)}</Text>
								<GetLinkWithoutSlug link={form.values.link} />
								<TextInput className="ir-slug-input" size="xs"
									defaultValue={form.values.slug}
									{...form.getInputProps('slug')}
								/>
								<Button onClick={() => setSlug(form.values.link)} size="xs" className="ir-btn-filled">{__('Ok', 'wdm_instructor_role')}</Button>
								<Button onClick={() => setEditSlug(false)} size="xs" className="ir-btn-outline">{__('Cancel', 'wdm_instructor_role')}</Button>
							</Group>
						)}
						<Group mb={34} mt={30} p={8} className="ir-featured-image-section">
							{null === featured_image && (

								<MediaUpload
									onSelect={(media) => {
										setFeaturedImage({
											id: media.id,
											url: media.url
										});
										form.setValues({
											featured_image: media.id
										})
									}}
									allowedTypes={['image']}
									render={({ open }) => (
										<Group>
											<img src={require('/images/featured-placeholder.png')} />
											<Button fw={400} className="ir-btn-subtle" onClick={open} leftIcon={<PhotoUp size={23} strokeWidth={1} />}  >{__('Set Featured Image', 'wdm_instructor_role')}</Button>
										</Group>
									)}
								/>
							)}
							{null !== featured_image && (
								<Group>
									<div style={{ width: 88, marginLeft: 'auto', marginRight: 'auto' }}>
										<Image
											width={88}
											height={61}
											radius="md"
											src={featured_image.url}
										/>
									</div>
									<div>
										<MediaUpload
											onSelect={(media) => {
												setFeaturedImage({
													id: media.id,
													url: media.url
												});
												form.setValues({
													featured_image: media.id
												})
											}}
											allowedTypes={['image']}
											value={featured_image.id}
											render={({ open }) => (
												<>
													<Button fw={400} className="ir-btn-subtle" onClick={open} leftIcon={<Replace size={23} strokeWidth={1} />} >{__('Replace', 'wdm_instructor_role')}</Button>
													<Button fw={400} className="ir-btn-subtle ir-red-txt" onClick={() => {
														setFeaturedImage(null);
														form.setValues({
															featured_image: null
														})
													}} leftIcon={<Trash size={23} strokeWidth={1} />} >{__('Remove', 'wdm_instructor_role')}</Button>
												</>
											)}
										/>
									</div>
								</Group>
							)}
						</Group>

						{/* <Group spacing="xs" mb={34}> */}
						<Text className="ir-parent-settings" size="lg">{sprintf(__('%s Description', 'wdm_instructor_role'), ir_fcb_loc.course_label)}</Text>
						<Textarea
							className="ir-tiny-mce-editors"
							id="ir-content-editor"
							minRows={20}
							{...form.getInputProps('content')}
						/>
					</Paper>
				</Grid.Col>
				<Grid.Col span={4}>
					{ir_fcb_loc.instructor_settings?.review_course && ir_fcb_loc.is_admin && (
						<Paper radius="xl" p="xl" mb={20}>
							<Group spacing="xs" className="ir-fc-100">
								<Text className="ir-parent-settings ir-capitalize-letter" size="lg" width="100%">{__('Pending Approvals', 'wdm_instructor_role')}</Text>
								{review_data && review_data.length > 0 && (
									<div className='ir-review-content'>
										{review_data.map((review_post) => (
											<Group position="apart" align="top" noWrap='true' id={"ir-review-post-" + review_post.post_id} mb={18}>
												<Text fw={600} size={14} c="#3C3C3E" className='ir-review-truncate'>
													{html_entity_decode(review_post.title)}
												</Text>
												<Text fw={400} size={14} c="#A0A3BD">
													{review_post.time}
												</Text>
											</Group>
										))}
									</div>
								)}
								{review_data.length == 0 && (
									<Text size={14} weight={400} color='#A0A3BD' mt={5} mb={5}>{__('No pending approvals', 'wdm_instructor_role')}</Text>
								)}
								{review_data && review_data.length > 0 && (
									<Group position='right'>
										<Button
											className="ir-btn-outline"
											mt={15}
											variant="outline"
											radius="md"
											size="sm"
											loading={process_review}
											loaderPosition="right"
											onClick={approveModal}
										>
											{__('Approve Instructor Updates', 'wdm_instructor_role')}
										</Button>
									</Group>
								)}
							</Group>
						</Paper>
					)}
					<Paper radius="xl" p="xl">
						{ir_fcb_loc.is_admin && (
							<Group spacing="xs" mb={34} className="ir-fc-100">
								<Text className="ir-parent-settings ir-capitalize-letter" size="lg" width="100%" >{__('Author', 'wdm_instructor_role')}</Text>
								<Accordion width="100%" variant="contained" radius="md">
									<Accordion.Item value="course-author">
										<Accordion.Control>
											{__('Author', 'wdm_instructor_role')}
										</Accordion.Control>
										<Accordion.Panel>
											<Select mt={6}
												placeholder={sprintf(__("Select %s Author", "wdm_instructor_role"), ir_fcb_loc.course_label)}
												data={authors}
												{...form.getInputProps('author')}
											/>
										</Accordion.Panel>
									</Accordion.Item>
								</Accordion>
							</Group>
						)}

						<Group spacing="xs" mb={34} className="ir-fc-100">
							<Text className="ir-parent-settings ir-capitalize-letter" size="lg" width="100%" >
								{__('Tags and Categories', 'wdm_instructor_role')}
							</Text>
							<Accordion width="100%" variant="contained" radius="md" defaultValue="customization">
								<Accordion.Item value="ld_course_tag">
									<Accordion.Control>
										{sprintf(__('%s Tags', 'wdm_instructor_role'), ir_fcb_loc.course_label)}
									</Accordion.Control>
									<Accordion.Panel>
										{null !== courseTags && (
											<MultiSelect className="ir-multiselect-loader"
												icon={showTagLoader && (<Loader size="xs" />)}
												label={sprintf(__("Add %s tags", 'wdm_instructor_role'), ir_fcb_loc.course_label)}
												data={courseTags}
												placeholder={__("Select items", 'wdm_instructor_role')}
												searchable
												creatable
												getCreateLabel={(query) => `+ Create ${query}`}
												onCreate={createNewCourseTag}
												{...form.getInputProps('ld_course_tag')}
											/>
										)}
										{"yes" !== ir_fcb_loc.ld_cat_tag?.course_tag && (
											<Text color="dimmed" weight={400}>{sprintf(__("%s tags are disabled from Learndash settings.", 'wdm_instructor_role'), ir_fcb_loc.course_label)} </Text>
										)}
									</Accordion.Panel>
								</Accordion.Item>


								<Accordion.Item value="ld_course_category">
									<Accordion.Control>
										{sprintf(__('%s Categories', 'wdm_instructor_role'), ir_fcb_loc.course_label)}
									</Accordion.Control>
									<Accordion.Panel>
										{((ir_fcb_loc.is_admin && "yes" === ir_fcb_loc.ld_cat_tag?.course) || false !== ir_fcb_loc.instructor_settings && (('off' !== ir_fcb_loc.instructor_settings?.enable_ld_category) && "yes" === ir_fcb_loc.ld_cat_tag?.course)) && (
											<>
												<Text size="xs" color="dimmed" weight={400} mb={10} fs="italic">
													<strong>{__('Note: ', 'wdm_instructor_role')}</strong>{__("Child categories cannot be created from here.", "wdm_instructor_role")}
												</Text>
												<Checkbox.Group
													{...form.getInputProps('ld_course_category')}
													orientation="vertical"
												>
													{courseCategories && courseCategories.map((category, index) => (
														<div>
															<Checkbox size="md" value={category.value} label={category.label} />
															{category.hasOwnProperty('children') && category.children.map((child) => (
																<Checkbox ml={20} mt={20} size="md" value={child.id.toString()} label={child.name} />
															))}
														</div>
													))}
												</Checkbox.Group>
												{null !== instructorSettings && (!instructorSettings?.category_restrict_check) && (
													<Group align="center" spacing="xs" mt={20}>
														<Text className="ir-add-cat" size={14} color="#2067FA" fw={600} onClick={() => setShowCatFields(true)}>{sprintf(__('Add new %s category', 'wdm_instructor_role'), ir_fcb_loc.lower_course_label)}</Text>
														{!showCatFields && (
															<Plus onClick={() => setShowCatFields(true)}
																size={18}
																strokeWidth={2}
																color={'#2067FA'}

															/>
														)}
														{showCatFields && (
															<X onClick={() => setShowCatFields(false)}
																size={18}
																strokeWidth={2}
																color={'#2067FA'}

															/>
														)}
													</Group>
												)}
												{showCatFields && (
													<div>
														<TextInput
															placeholder="Enter new category name"
															value={new_category}
															onChange={(event) => setNewCategory(event.currentTarget.value)}
														/>
														{/* <Select mt={6}
																clearable
																placeholder="Select Parent Course Category "
																data={courseCategories}
																value={parent_category} onChange={setParentCategory}
														/> */}
														<Button mt={6} className="ir-btn-filled" onClick={createCourseCategory} loading={category_loading}>Add</Button>
													</div>
												)}
											</>
										)}
										{((false === ir_fcb_loc.instructor_settings || (('off' === ir_fcb_loc.instructor_settings?.enable_ld_category) || "yes" !== ir_fcb_loc.ld_cat_tag?.course))) && (
											<Text color="dimmed" weight={400}>{sprintf(__("%s categories are disabled from Learndash settings.", 'wdm_instructor_role'), ir_fcb_loc.course_label)} </Text>
										)}
									</Accordion.Panel>
								</Accordion.Item>
							</Accordion>
						</Group>
						{/* <Group spacing="xs" mb={34} className="ir-fc-100">
                            <Text className="ir-parent-settings" size="lg" width="100%">{sprintf(__('%s URL', 'wdm_instructor_role'), ir_fcb_loc.course_label)}</Text>
                            <Accordion width="100%" variant="contained" radius="md" defaultValue="customization">

                                <Accordion.Item value="permalink">
                                    <Accordion.Control>{sprintf(__('%s URL', 'wdm_instructor_role'), ir_fcb_loc.course_label)}</Accordion.Control>
                                    <Accordion.Panel>
                                        <TextInput className="ir-input-settings ir-url-slug"
                                            placeholder={__("Enter here", 'wdm_instructor_role')}
                                            label={__("URL Slug", 'wdm_instructor_role')}
                                            labelPosition="left"
                                            disabled={!form.values.is_published}
                                            {...form.getInputProps('slug')}
                                        />
                                        <Group mt={12}>
                                            <Text size={14} className="ir-uppercase">{sprintf(__('View %s', 'wdm_instructor_role'), ir_fcb_loc.course_label)}</Text>
                                            <Text component="a" color="#2067FA" size="sm" href={form.values.link}>
                                                {form.values.link}
                                            </Text>
                                        </Group>
                                    </Accordion.Panel>
                                </Accordion.Item>
                            </Accordion>
                        </Group> */}
					</Paper>
				</Grid.Col>
			</Grid>
		</>
	);
}
