import { useState } from 'react';

import {
    Accordion,
    Text,
    Title,
    Grid,
    Paper,
    Input,
    Checkbox,
    Button,
    Group,
    TextInput,
    FileButton,
    Switch,
    Radio,
    NumberInput,
    MultiSelect,
    Loader,
    Divider
} from '@mantine/core';

import { Upload } from 'tabler-icons-react';
import { sprintf, __ } from "@wordpress/i18n";

import CourseAccess from '/src/components/course-settings/courseAccess.js';
import CourseNavigation from '/src/components/course-settings/courseNavigation.js';
import DisplayContent from '/src/components/course-settings/displayContent.js';
import CourseUser from '/src/components/course-settings/courseUser.js';
import CourseShare from '/src/components/course-settings/courseShare.js';

export default function CourseSettings(props) {
    const { form, course_id, instructorSettings } = props;

    const settingsItem = [
        {
            id: 'course-access-settings',
            label: sprintf(__('%s access settings', 'wdm_instructor_role'), ir_fcb_loc.course_label),
            description: sprintf(__('Controls how users will gain access to the %s', 'wdm_instructor_role'), ir_fcb_loc.lower_course_label),
            content: <CourseAccess form={form} course_id={course_id} instructorSettings={instructorSettings}/>
        },

        {
            id: 'course-navigation-settings',
            label: sprintf(__('%s navigation settings', 'wdm_instructor_role'), ir_fcb_loc.course_label),
            description: __('Controls how users interact with the content and their navigational experience', 'wdm_instructor_role'),
            content: <CourseNavigation form={form} course_id={course_id} />
        },

        {
            id: 'display-and-content-options',
            label: __('Display and content options', 'wdm_instructor_role'),
            description: sprintf(__('Controls the look and feel of the %s and optional content settings', 'wdm_instructor_role'), ir_fcb_loc.lower_course_label),
            content: <DisplayContent form={form} course_id={course_id}/>
        },

        {
            id: 'course-user',
            label: sprintf(__('%s users', 'wdm_instructor_role'), ir_fcb_loc.course_label),
            description: sprintf(__('Users enrolled via %s using this %s are excluded from the listings below and should be manage via the %s admin screen', 'wdm_instructor_role'), ir_fcb_loc.groups_label, ir_fcb_loc.course_label, ir_fcb_loc.group_label),
            content: <CourseUser form={form} course_id={course_id} />
        },

        {
            id: 'course-sharing',
            label: sprintf(__('Share %s Settings', 'wdm_instructor_role'), ir_fcb_loc.course_label),
            description: sprintf(__('Share %s with multiple instructors', 'wdm_instructor_role'), ir_fcb_loc.lower_course_label),
            content: <CourseShare form={form} course_id={course_id} />
        },
    ];

    return (
        <>
            <Grid>
                <Grid.Col span={8} offset={2}>
                    <Paper radius="xl" className="ir-fed-course-settings">
                        <Accordion radius="xl" chevronPosition="right" variant="contained">
                            {settingsItem.map((item) => (
                                <Accordion.Item p="xs" value={item.id} key={item.label}>
                                    <Accordion.Control>
                                        <Group noWrap>
                                            <div>
                                                <Text className="ir-uppercase" size="md" weight={600}>{item.label}</Text>
                                                <Text size="sm" color="#6F717C" weight={400}>
                                                    {item.description}
                                                </Text>
                                            </div>
                                        </Group>
                                    </Accordion.Control>
                                    <Accordion.Panel>
                                        {item.content}
                                    </Accordion.Panel>
                                </Accordion.Item>
                            ))}
                        </Accordion>
                    </Paper>
                </Grid.Col>
            </Grid>
        </>
    );
}
