import { useState, useEffect } from 'react';

import {
	AppShell,
	Navbar,
	Header,
	Accordion,
	MantineProvider,
	Text,
	Title,
	Grid,
	Paper,
	Input,
	Checkbox,
	Button,
	Group,
	Space,
	Center,
	CloseButton,
	Skeleton,
	TextInput,
	Modal,
	Tabs,
	FileButton,
	Switch,
	Radio,
	NumberInput,
	MultiSelect,
	Loader,
	Image,
	Tooltip,
	Select,
	Textarea,
	Popover
} from '@mantine/core';

import { TimeInput, DatePicker } from '@mantine/dates';
import { showNotification } from '@mantine/notifications';
import { openConfirmModal } from '@mantine/modals';
import { useForm } from '@mantine/form';

import { sprintf, __ } from "@wordpress/i18n";
import apiFetch from '@wordpress/api-fetch';
import { MediaUpload } from '@wordpress/media-utils';

import { InfoCircle, DeviceDesktop, DeviceTablet, DeviceMobile, ArrowsMaximize, ArrowsMinimize, PhotoUp, Replace, ClockHour4, CalendarEvent } from 'tabler-icons-react';
import { Plus } from 'tabler-icons-react';
import { GridDots } from 'tabler-icons-react';
import { LetterL } from 'tabler-icons-react';
import { LetterT } from 'tabler-icons-react';
import { LetterQ } from 'tabler-icons-react';
import { PencilMinus } from 'tabler-icons-react';
import { X } from 'tabler-icons-react';
import { ChevronDown } from 'tabler-icons-react';
import { Search } from 'tabler-icons-react';
import { ArrowBackUp } from 'tabler-icons-react';
import { Upload } from 'tabler-icons-react';
import { Trash } from 'tabler-icons-react';
import { Eye } from 'tabler-icons-react';

export default function EditModule(props) {
	const [opened, setOpened] = useState(false);
	const [visible, setVisible] = useState(false);
	const [loading, setLoader] = useState(false);
	const [reviewing, setReviewLoader] = useState(false);
	const [file, setFile] = useState(File | null > (null));
	const initialValue = '<p></p>';
	const [value, onChange] = useState(initialValue);
	const [advance_option, setAdvanceOption] = useState(null);
	const [grading_type, setGradingType] = useState('auto_approve');
	const [featured_image, setFeaturedImage] = useState(null);
	const [showTagLoader, setShowTagLoader] = useState(false);
	const { courseData, setCourseData, instructorSettings, review_data, setReviewData } = props;
	const [categories, setCategories] = useState([]);
	const [tags, setTags] = useState([]);
	const [editorRefresh, setEditorRefresh] = useState(0);
	const [initialStatus, setInitialStatus] = useState('draft');
	const [expand, setExpand] = useState('');
	const [showCatFields, setShowCatFields] = useState(false);
	const [review_content, setReviewContent] = useState(null);

	const [new_category, setNewCategory] = useState('');
	const [parent_category, setParentCategory] = useState('');
	const [category_loading, setCategoryLoader] = useState(false);
	let current_cat = ir_fcb_loc.ld_cat_tag?.lesson
	let current_tag = ir_fcb_loc.ld_cat_tag?.lesson_tag

	if (props.label === "Topic") {
		current_cat = ir_fcb_loc.ld_cat_tag?.topic
		current_tag = ir_fcb_loc.ld_cat_tag?.topic_tag
	}
	const [authors, setAuthors] = useState([]);
	const editform = useForm({
		initialValues: {
			title: '',
			status: 'draft',
			video_enabled: false,
			video_shown: 'BEFORE',
			assignment_upload_enabled: false,
			forced_timer_enabled: false,
			content: '<p></p>',
			materials: '<p></p>',
			tags: [],
			category: [],
			time: '',
			date: '',
			password: '',
			visibility: 'public'
			// image: '',
			// video_url: '',
			// video_auto_complete: false,
			// video_auto_complete_delay: 0,
			// video_show_complete_button: false,
			// video_auto_start: false,
			// video_show_controls: false,
			// video_focus_pause: false,
			// video_resume: false,
			// assignment_upload_limit_extensions: '',
			// assignment_points_enabled: false,
			// assignment_points_amount: 0,
			// assignment_auto_approve: false,
		},
		validate: {
			title: (value) => (value.length > 0 ? null : __('Please enter a valid title.', 'wdm_instructor_role'))
		}
	});

	// useEffect(() => {
	//     setEditorContent('test');
	// }, []);

	useEffect(() => {
		wp.editor.initialize(
			'ir-edit-content-editor',
			{
				tinymce: {
					wpautop: true,
					height: '300px',
					plugins: 'charmap colorpicker compat3x directionality hr image lists media paste tabfocus textcolor wordpress wpautoresize wpdialogs wpeditimage link',
					toolbar1: 'formatselect bold italic underline strikethrough | bullist numlist | blockquote hr wp_more | alignleft aligncenter alignright | link unlink | media wp_add_media'
				},
				quicktags: false,
				mediaButtons: true,
			}
		);
		wp.editor.initialize(
			'ir-edit-material-editor',
			{
				tinymce: {
					wpautop: true,
					height: '300px',
					plugins: 'charmap colorpicker compat3x directionality hr image lists media paste tabfocus textcolor wordpress wpautoresize wpdialogs wpeditimage link',
					toolbar1: 'formatselect bold italic underline strikethrough | bullist numlist | blockquote hr wp_more | alignleft aligncenter alignright | link unlink | media wp_add_media'
				},
				quicktags: false,
				mediaButtons: true,
			}
		);
	}, [editorRefresh]);

	const openEditModal = () => {

		setOpened(true);
		setVisible(true);

		let path = "/ldlms/v2/sfwd-topic/" + props.topic;

		if (ir_fcb_loc.lesson_label === props.label) {
			path = "/ldlms/v2/sfwd-lessons/" + props.lesson;
		}

		apiFetch(
			{
				path: path,
				method: 'GET',
			}
		).then((data) => {
			setInitialStatus(data.status);
			// Set common properties.
			if (data.video_enabled) {
				setAdvanceOption('video_enabled')
			} else if (data.assignment_upload_enabled) {
				setAdvanceOption('assignment_upload_enabled')
			} else if (data.forced_timer_enabled) {
				setAdvanceOption('forced_timer_enabled')
			}

			setEditorRefresh(editorRefresh + 1);


			setGradingType(data.assignment_auto_approve ? 'auto_approve' : 'manual_grade');

			// Set specific day visibility.
			if (data.visible_after_specific_date) {
				const enrollment_date = new Date(parseInt(data.visible_after_specific_date) * 1000);
				editform.setValues({
					enrollment_date_mm: enrollment_date.getMonth() + 1,
					enrollment_date_dd: enrollment_date.getDate(),
					enrollment_date_yy: enrollment_date.getFullYear(),
					enrollment_date_hh: enrollment_date.getHours(),
					enrollment_date_min: enrollment_date.getMinutes()
				});
			}

			// Fix video shown value
			let video_shown_value = data.video_shown;
			if ('BEFORE' !== video_shown_value && 'AFTER' !== video_shown_value) {
				video_shown_value = 'BEFORE';
			}

			editform.setValues({
				title: html_entity_decode(data.title.rendered),
				content: data.content.rendered,
				video_enabled: data.video_enabled,
				video_shown: video_shown_value,
				assignment_upload_enabled: data.assignment_upload_enabled,
				forced_timer_enabled: data.forced_timer_enabled,
				materials: data.materials.rendered,
				image: data.image,
				video_url: data.video_url,
				video_auto_complete: data.video_auto_complete,
				video_auto_complete_delay: data.video_auto_complete_delay,
				video_show_complete_button: data.video_show_complete_button,
				video_auto_start: data.video_auto_start,
				video_show_controls: data.video_show_controls,
				video_focus_pause: data.video_focus_pause,
				video_resume: data.video_resume,
				assignment_upload_limit_extensions: data.assignment_upload_limit_extensions,
				assignment_upload_limit_size: data.assignment_upload_limit_size,
				assignment_points_enabled: data.assignment_points_enabled,
				assignment_points_amount: data.assignment_points_amount,
				slug: data.slug,
				materials_enabled: data.materials_enabled,
				visible_type: data.visible_type,
				visible_after: data.visible_after,
				featured_media: data.featured_media,
				status: data.status,
				author: data.author.toString(),
				link: data.link,
				assignment_deletion_enabled: data.assignment_deletion_enabled,
				assignment_upload_limit_count: data.assignment_upload_limit_count,
				date: (data.date.length) ? new Date(data.date) : new Date(),
				time: (data.date.length) ? new Date(data.date) : new Date(),
				password: data.password
			});
			tinymce.get('ir-edit-content-editor').setContent(data.content.rendered);
			tinymce.get('ir-edit-material-editor').setContent(data.materials.rendered);

			if (data.featured_media) {
				apiFetch(
					{
						path: "/wp/v2/media/" + data.featured_media,
						method: 'GET',
					}
				).then((data) => {
					editform.setValues({
						featured_image_url: data.source_url
					})
					setFeaturedImage({
						id: data.featured_media,
						url: data.source_url
					});
				})
			}

			// Set sample lesson and other lesson specific properties.
			if (ir_fcb_loc.lesson_label === props.label) {
				// Set lesson props.
				editform.setValues({
					is_sample: data.is_sample
				})
			}

			const timer_amount = data.forced_timer_amount;
			let remaining_time = 0;
			if (0 < timer_amount) {
				const timer_hh = parseInt(timer_amount / 3600);
				remaining_time = timer_amount % 3600;
				const timer_mm = parseInt(remaining_time / 60);
				remaining_time = remaining_time % 60;
				const timer_ss = remaining_time;
				editform.setValues({
					timer_hh: timer_hh,
					timer_mm: timer_mm,
					timer_ss: timer_ss,
				})
			}

			let category_path = "/ir/v1/ld-lesson-category?per_page=100";
			let tag_path = "/wp/v2/ld_lesson_tag?per_page=100";
			let tag_flag = ir_fcb_loc.ld_cat_tag?.lesson_tag;
			let cat_flag = ir_fcb_loc.ld_cat_tag?.lesson;
			if (ir_fcb_loc.topic_label === props.label) {
				tag_flag = ir_fcb_loc.ld_cat_tag?.topic_tag;
				cat_flag = ir_fcb_loc.ld_cat_tag?.topic;
				category_path = "/ir/v1/ld-topic-category?per_page=100";
				tag_path = "/wp/v2/ld_topic_tag?per_page=100";
			}

			if ("yes" === tag_flag) {
				// Fetch Tags
				apiFetch(
					{
						path: tag_path,
						method: 'GET',
					}
				).then((tag_data) => {
					let content_tags = [];
					tag_data.map((tag, ind) => {
						content_tags.push({
							label: tag.name,
							value: tag.id.toString()
						})
					})
					setTags(content_tags);

					if (ir_fcb_loc.lesson_label === props.label) {
						if (0 < data.ld_lesson_tag.length) {
							editform.setValues({
								tags: data.ld_lesson_tag?.map(String),
							})
						}
					} else {
						if (0 < data.ld_topic_tag.length) {
							editform.setValues({
								tags: data.ld_topic_tag?.map(String),
							})
						}
					}

				});
			}

			if ("yes" === cat_flag) {
				// Fetch Categories
				apiFetch(
					{
						path: category_path,
						method: 'GET',
					}
				).then((category_data) => {
					let content_categories = [];
					category_data.map((category, ind) => {
						if (category.hasOwnProperty('children')) {
							content_categories.push({
								label: category.name,
								value: category.id.toString(),
								children: category.children
							});
						} else {
							content_categories.push({
								label: category.name,
								value: category.id.toString()
							});
						}
					})
					setCategories(content_categories);
					if (ir_fcb_loc.lesson_label === props.label) {
						if (0 < data.ld_lesson_category.length) {
							editform.setValues({
								category: data.ld_lesson_category?.toString().split(',')
							})
						}
					} else {
						if (0 < data.ld_topic_category.length) {
							editform.setValues({
								category: data.ld_topic_category?.toString().split(',')
							})
						}
					}
				});
			}
			setVisible(false);

			// Set visibility
			setVisibility(data);
		});

		// Get author users.
		apiFetch(
			{
				path: "/ir/v1/users?roles=wdm_instructor,administrator",
				method: "GET"
			}
		).then((data) => {
			let author_list = [];
			data.map((user) => {
				author_list.push({
					label: user.name,
					value: user.id.toString()
				});
			})
			setAuthors(author_list);
		});

		if (ir_fcb_loc.instructor_settings?.review_course && ir_fcb_loc.is_admin) {
			path = "/ir/v1/sfwd-topic/" + props.topic + "/review";

			if (ir_fcb_loc.lesson_label === props.label) {
				path = "/ir/v1/sfwd-lessons/" + props.lesson + "/review";
			}
			// Get lesson/topic review info
			apiFetch(
				{
					path,
					method: "GET"
				}
			).then((data) => {
				setReviewContent(data);
			});
		}

	}

	const updateStep = (values) => {
		setLoader(true);
		const timer_amount = (parseInt(values.timer_hh) * 60 * 60) + (parseInt(values.timer_mm) * 60) + (parseInt(values.timer_ss));

		let status = values.status;

		// Check if future published date.
		if (new Date().getTime() < getCombinedDate(editform.values.date, editform.values.time).getTime()) {
			status = 'future';
		}

		// Check if private lesson/topic
		if ('draft' !== status && 'private' === editform.values.visibility) {
			status = 'private';
		}

		let path = "/ldlms/v2/sfwd-lessons/" + props.lesson;
		let dataset = {
			title: values.title,
			content: tinymce.get("ir-edit-content-editor").getContent(),
			status: status,
			course: props.course,
			lesson: props.lesson,
			slug: values.slug,
			materials: tinymce.get("ir-edit-material-editor").getContent(),
			materials_enabled: values.materials_enabled,
			video_enabled: values.video_enabled,
			video_url: values.video_url,
			video_shown: values.video_shown,
			video_auto_complete: values.video_auto_complete,
			video_auto_complete_delay: values.video_auto_complete_delay,
			video_show_complete_button: values.video_show_complete_button,
			video_auto_start: values.video_auto_start,
			video_show_controls: values.video_show_controls,
			video_focus_pause: values.video_focus_pause,
			video_resume: values.video_resume,
			assignment_upload_enabled: values.assignment_upload_enabled,
			assignment_points_enabled: values.assignment_points_enabled,
			assignment_points_amount: values.assignment_points_amount,
			assignment_auto_approve: values.assignment_auto_approve,
			assignment_deletion_enabled: values.assignment_deletion_enabled,
			forced_timer_enabled: values.forced_timer_enabled,
			forced_timer_amount: timer_amount,
			assignment_upload_limit_extensions: values.assignment_upload_limit_extensions,
			assignment_upload_limit_size: values.assignment_upload_limit_size,
			assignment_upload_limit_count: parseInt(values.assignment_upload_limit_count),
			visible_type: values.visible_type,
			visible_after: values.visible_after,
			featured_media: values.featured_media,
			author: values.author,
			password: values.password,
			date: getCombinedDate(values.date, values.time)
		};

		if (ir_fcb_loc.topic_label === props.label) {
			path = "/ldlms/v2/sfwd-topic/" + props.topic;
			dataset.ld_topic_category = values.category.filter(function (value) {
				return parseInt(value);
			});
			dataset.ld_topic_tag = values.tags;
		} else {
			dataset.ld_lesson_category = values.category.filter(function (value) {
				return parseInt(value);
			});
			dataset.ld_lesson_tag = values.tags;
			dataset.is_sample = values.is_sample;
		}

		if ('visible_after_specific_date' === values.visible_type) {
			const date_str = values.enrollment_date_yy + "-" + values.enrollment_date_mm + "-" + values.enrollment_date_dd + " " + values.enrollment_date_hh + ":" + values.enrollment_date_min;
			// dataset.visible_after_specific_date = date_str;
			const enrollment_date = new Date(date_str);
			dataset.visible_after_specific_date = Math.trunc(enrollment_date.getTime() / 1000).toString();
		}
		apiFetch(
			{
				path: path,
				method: 'POST',
				data: dataset
			}
		).then((response) => {
			if (false != response) {
				// Update course data store if not present.
				if (courseData.hasOwnProperty(response.id)) {
					let _courseData = { ...courseData };
					_courseData[response.id].post_title = response.title.rendered;
					_courseData[response.id].post_status = response.status;
					if (response.hasOwnProperty('is_sample')) {
						_courseData[response.id].is_sample = response.is_sample;
					}
					setCourseData(_courseData);
				}

				if ('draft' === response.status) {
					showNotification({
						title: sprintf(__('Saved as Draft', 'wdm_instructor_role'), ir_fcb_loc.topic_label),
						message: sprintf(__('Your %s has been successfully saved as a draft', 'wdm_instructor_role'), props.label),
					});
				} else {
					// Check if course review enabled.
					if (ir_fcb_loc.instructor_settings?.review_course && !ir_fcb_loc.is_admin) {
						showNotification({
							message: sprintf(__('Your %1$s has been submitted for review to the administrator. Please wait for approval before it can be published. In the meantime, your %1$s is saved as draft.', 'wdm_instructor_role'), ir_fcb_loc.lower_course_label),
							autoClose: 5000
						})
					} else {
						if ('draft' === initialStatus) {
							showNotification({
								title: sprintf(__('%s Published!', 'wdm_instructor_role'), props.label),
								message: sprintf(__('Your %s is successfully published and live now!', 'wdm_instructor_role'), props.label),
							});
						} else {
							showNotification({
								title: sprintf(__('%s Updated', 'wdm_instructor_role'), props.label),
								message: sprintf(__('Your %s has successfully been updated!!', 'wdm_instructor_role'), props.label),
							});
						}
					}
				}
				setInitialStatus(response.status);
				setOpened(false);
				editform.setFieldValue('link', response.link);

				if ('visible_after_specific_date' === values.visible_type) {
					const lesson_id = (ir_fcb_loc.topic_label === props.label) ? props.topic : props.lesson;
					apiFetch(
						{
							path: "/ir/v1/sfwd-courses/" + props.course + "/remaining",
							method: 'POST',
							data: JSON.stringify({
								id: props.course,
								lesson_id: lesson_id,
								type: 'release_schedule',
								post_type: props.label.toLowerCase(),
								specific_date: dataset.visible_after_specific_date
							})
						}
					);
				}
			}
			setLoader(false);
			wp.editor.remove('ir-edit-content-editor');
			wp.editor.remove('ir-edit-material-editor');
		});
	}

	const switchDraft = () => {
		confirmDraft();
	}

	const openIframeInTab = (device, url) => {
		var win = window.open();
		win.document.write('<iframe style="width:' + device + '; height:100vh; display:block; margin: auto;" src="' + url + '" frameborder="0" allowfullscreen></iframe>')
	}

	const confirmDraft = () => openConfirmModal({
		modal: 'switch-draft',
		title: __('Switch to draft', 'wdm_instructor_role'),
		children: (
			<Text size="sm">
				{sprintf(__('Are you sure you want to Unpublish this %s ?', 'wdm_instructor_role'), props.label)}
				{__('This will be saved as draft.', 'wdm_instructor_role')}
			</Text>
		),
		labels: { confirm: 'Yes', cancel: 'Cancel' },
		confirmProps: { color: 'red' },
		modalId: "bgdvbsj",
		onCancel: () => console.log('Cancel'),
		onConfirm: () => {
			editform.values.status = 'draft';
			updateStep(editform.values);
		}
	});

	const createNewTag = (query) => {
		setShowTagLoader(true);
		let path = "/wp/v2/ld_topic_tag";

		if (ir_fcb_loc.lesson_label === props.label) {
			path = "/wp/v2/ld_lesson_tag";
		}
		// Create New Tag.
		apiFetch(
			{
				path,
				method: 'POST',
				data: {
					name: query
				}
			}
		).then((response) => {
			if (false != response && response.hasOwnProperty('id')) {
				setShowTagLoader(false);
				const item = { value: response.id.toString(), label: response.name };
				setTags((current) => [...current, item]);
				editform.setFieldValue('tags', [...editform.values.tags, response.id.toString()])
			}
		});
	}

	const createNewCategory = () => {
		if (new_category.length === 0) {
			showNotification({
				title: __('Warning', 'wdm_instructor_role'),
				message: __('Category name cannot be empty', 'wdm_instructor_role'),
				icon: <ExclamationMark />,
				color: 'yellow'
			});
			return;
		}

		setCategoryLoader(true);
		let data = {
			name: new_category
		}
		if (null !== parent_category && parent_category.length > 0) {
			data.parent = parent_category;
		}

		let path = "/wp/v2/ld_topic_category";

		if (ir_fcb_loc.lesson_label === props.label) {
			path = "/wp/v2/ld_lesson_category";
		}
		// Create New Category.
		apiFetch(
			{
				path,
				method: 'POST',
				data
			}
		).then((response) => {
			if (false != response && response.hasOwnProperty('id')) {
				const item = { value: response.id.toString(), label: response.name };
				setCategories((current) => [...current, item]);
				editform.setFieldValue('category', [...editform.values.category, response.id.toString()])
			}
			setShowCatFields(false);
			setCategoryLoader(false);
			setParentCategory('');
			setNewCategory('');
		});
	}

	const html_entity_decode = (message) => {
		var domParser = new DOMParser();
		var decodedString = domParser.parseFromString(message, 'text/html').body.textContent;
		return decodedString;
	}

	const approveContent = () => {
		setReviewLoader(true);
		const post_id = (ir_fcb_loc.topic_label === props.label) ? props.topic : props.lesson;

		jQuery.ajax({
			url: ir_fcb_loc.ajax_url,
			method: 'POST',
			data: {
				action: 'approve_instructor_update_ajax',
				post_id: post_id
			},
			success: function (response) {
				showNotification({
					title: __('Instructor updates approved successfully !!', 'wdm_instructor_role')
				})
				setReviewLoader(false);
				setReviewContent(null);

				updateReviewData(post_id);
			}
		});
	}

	const updateReviewData = (post_id) => {
		const _review_data = review_data.filter(item => item.post_id !== post_id);
		setReviewData(_review_data);
	}

	const getVisibility = () => {
		let visibility = __('Public', 'wdm_instructor_role');
		if ('password' === editform.values.visibility) {
			visibility = __('Password Protected', 'wdm_instructor_role');
		} else if ('private' === editform.values.visibility) {
			visibility = __('Private', 'wdm_instructor_role')
		}
		return visibility;
	}

	const getPublishedDate = () => {
		let date_string = '';
		const options = { month: 'long', day: 'numeric', hour12: true, hour: 'numeric', minute: 'numeric' };
		const publish_date = getCombinedDate(editform.values.date, editform.values.time);

		return publish_date.toLocaleDateString(undefined, options);
	}

	const getCombinedDate = (date_object, time_object) => {
		if ( date_object instanceof Date && time_object instanceof Date ) {
			let combined_date = '';
			combined_date = date_object.getFullYear() + '-' + (date_object.getMonth() + 1) + '-' + date_object.getDate() + ' ' + time_object.getHours() + ':' + time_object.getMinutes() + ':' + time_object.getSeconds();
	
			return new Date(combined_date);
		} else {
			return new Date();
		}
	}

	const setVisibility = (data) => {
		// Set lesson/topic visibility
		let _visibility = data.status;
		if (data.content.protected) {
			_visibility = 'password';
		} else if ('private' === data.status) {
			_visibility = 'private';
			// Remove keyword Private from title.
			// if ( -1 !== data.title.rendered.indexOf('Private:')) {
			// 	const post_title = data.title.rendered;
			// 	editform.setFieldValue('title', post_title.replace('Private:', ''));
			// }
		} else {
			_visibility = 'public';
		}

		editform.setFieldValue('visibility', _visibility);
	}

	const handleVisibilityChange = (value) => {
		if ('private' === value) {
			editform.setFieldValue('password', '');
			// openConfirmModal({
			// 	modal: 'switch-draft',
			// 	title: sprintf(__('Publish %s Privately?', 'wdm_instructor_role'), ir_fcb_loc.course_label),
			// 	children: (
			// 		<Text size="sm">
			// 			{sprintf(__('Would you like to privately publish this %s now?', 'wdm_instructor_role'), ir_fcb_loc.lower_course_label)}
			// 		</Text>xllcccccx
			// 	),
			// 	labels: { confirm: 'Confirm', cancel: 'Cancel' },
			// 	onCancel: () => console.log('Cancel'),
			// 	onConfirm: () => {
			// 		setLoading(true);
			// 		// Update course settings.
			// 		apiFetch(
			// 			{
			// 				path: "/ldlms/v2/sfwd-courses/" + course_id,
			// 				method: 'POST',
			// 				data: {
			// 					status: value,
			// 				}
			// 			}
			// 		).then((resp) => {
			// 			setLoading(false);
			// 		})
			// 	},
			// });
			editform.setFieldValue('visibility', value);
		} else if ('password' === value) {
			editform.setFieldValue('visibility', value);
		} else {
			editform.setFieldValue('password', '');
			editform.setFieldValue('visibility', value);
		}
	}

	return (
		<>
			<Modal className="ir-topic-modal"
				opened={opened}
				onClose={() => {
					setOpened(false);
					wp.editor.remove('ir-edit-content-editor');
					wp.editor.remove('ir-edit-material-editor');
				}}
				fullScreen={expand}
				title={props.label}
				size='830px'
				overflow="outside"
			>
				<form onSubmit={editform.onSubmit(updateStep)}>
					{expand && (

						<Button className="ir-expand-modal ir-btn-subtle" onClick={() => setExpand('')}>
							<ArrowsMinimize
								size={25}
								strokeWidth={2}
								color={'#000000'}
							/>
						</Button>
					)}
					{!expand && (
						<Button className="ir-expand-modal ir-btn-subtle" onClick={() => setExpand('fullScreen')}>
							<ArrowsMaximize
								size={25}
								strokeWidth={2}
								color={'#000000'}
							/>
						</Button>
					)}
					<Tabs defaultValue="Content" styles={{
						tab: {
							color: '#A0A3BD',
							fontSize: "16px",
							'&[data-active]': {
								color: '#000000',
							},
						},

					}}>
						<Tabs.List>
							<Tabs.Tab value="Content">{__('Content', 'wdm_instructor_role')}</Tabs.Tab>
							<Tabs.Tab value="Material">{__('Material', 'wdm_instructor_role')}</Tabs.Tab>
							<Tabs.Tab value="settings">{__('Settings', 'wdm_instructor_role')}</Tabs.Tab>
						</Tabs.List>
						<Tabs.Panel className="ir-panel-overflow" value="Content" pt="lg">
							{ir_fcb_loc.instructor_settings?.review_course && null !== review_content && 'pending' === review_content?.status && (
								<Paper className="ir-fed-answers" mb={16} mt={16} radius="lg" p="sm" withBorder>
									<Group align="center" spacing="xs" position="apart">
										{/* <Group position="apart" className='ir-fc-100' align="center" mb={10} spacing="xs"> */}
										<Text className="ir-parent-settings ir-capitalize-letter" size="lg" width="100%">{__('Pending Approval', 'wdm_instructor_role')}</Text>
										<Button
											className="ir-btn-outline"
											variant="outline"
											radius="md"
											size="sm"
											loading={reviewing}
											loaderPosition="right"
											onClick={approveContent} >
											{__('Approve Instructor Updates', 'wdm_instructor_role')}
										</Button>
										{/* </Group> */}
									</Group>
								</Paper>
							)}
							<Group align="center" mt={10}>
								<TextInput className="ir-tt-text ir-parent-settings ir-flex-1"
									label={sprintf(__('%s Title', 'wdm_instructor_role'), props.label)}
									placeholder={__('Write title here', 'wdm_instructor_role')}
									size="lg"
									{...editform.getInputProps('title')}
								/>
							</Group>
							<Group mb={34} mt={20} p={8} className="ir-featured-image-section">
								{null === featured_image && (
									<MediaUpload
										onSelect={(media) => {
											setFeaturedImage({
												id: media.id,
												url: media.url
											});
											editform.setFieldValue('featured_media', media.id);
										}}
										allowedTypes={['image']}
										render={({ open }) => (
											<Group>
												<img src={require('/images/featured-placeholder.png')} />
												<Button fw={400} className="ir-btn-subtle" onClick={open} leftIcon={<PhotoUp size={23} strokeWidth={1} />}  >{__('Set Featured Image', 'wdm_instructor_role')}</Button>
											</Group>
										)}
									/>
								)}
								{null !== featured_image && (
									<Group>
										<div style={{ width: 88, marginLeft: 'auto', marginRight: 'auto' }}>
											<Image
												width={88}
												height={61}
												radius="md"
												src={featured_image.url}
											/>
										</div>
										<div>
											<MediaUpload
												onSelect={(media) => {
													setFeaturedImage({
														id: media.id,
														url: media.url
													});
													editform.setFieldValue('featured_media', media.id);
												}}
												allowedTypes={['image']}
												value={featured_image.id}
												render={({ open }) => (
													<>
														<Button fw={400} className="ir-btn-subtle" onClick={open} leftIcon={<Replace size={23} strokeWidth={1} />} >{__('Replace', 'wdm_instructor_role')}</Button>
														<Button fw={400} className="ir-btn-subtle ir-red-txt" onClick={() => {
															setFeaturedImage(null);
															editform.setFieldValue('featured_media', null);
														}} leftIcon={<Trash size={23} strokeWidth={1} />} >{__('Remove', 'wdm_instructor_role')}</Button>
													</>
												)}
											/>
										</div>
									</Group>
								)}
							</Group>
							{/* <Group spacing="xs" mb={34}> */}
							<Text className="ir-parent-settings" size="lg">{sprintf(__('%s Content', 'wdm_instructor_role'), props.label)}</Text>
							<Textarea
								className="ir-tiny-mce-editors"
								id="ir-edit-content-editor"
								minRows={20}
								{...editform.getInputProps('content')}
							/>
							{/* </Group> */}
							<Group spacing="xs" mb={34} mt={34} className="ir-fc-100">
								<Group position="apart" align="center" mb={10}>
									<Text className="ir-parent-settings" size="lg">{__('ADVANCE CONTENT OPTION', 'wdm_instructor_role')}</Text>
									<Text className="ir-section-name" size="md">{__('You can use only one option at a time', 'wdm_instructor_role')}</Text>
								</Group>
								<Accordion width="100%" variant="contained" radius="md"
									defaultValue={null}
									value={advance_option}
									onChange={(option) => {
										setAdvanceOption(option)
										editform.setValues({
											video_enabled: (option == 'video_enabled') ? true : false,
											assignment_upload_enabled: (option == 'assignment_upload_enabled') ? true : false,
											forced_timer_enabled: (option == 'forced_timer_enabled') ? true : false,
										})
									}}
								>
									<Accordion.Item value="video_enabled">
										<Group className="ir-acc-left ir-no-chevron" position="apart" align="center">
											<Text size="md" className="ir-d-flex">
												{__('Video Progression', 'wdm_instructor_role')}
												<div className="ir-textinfo">
													<Tooltip label={sprintf(__("Require users to watch the full video as part of the %s progression. Use shortcode [ld_video] to move within the post content.", "wdm_instructor_role"), ir_fcb_loc.lower_course_label)} withArrow>
														<Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
													</Tooltip>
												</div>
											</Text>
											<Accordion.Control><img className="ir-disable" src={require('/images/switch.png')} /><img className="ir-enable" src={require('/images/switchon.png')} /></Accordion.Control>
										</Group>
										<Accordion.Panel className="ir-pl-35">
											<TextInput className="ir-input-settings"
												placeholder={__("Enter your video link/URL here", 'wdm_instructor_role')}
												label={__("Video URL", "wdm_instructor_role")}
												labelPosition="left"
												{...editform.getInputProps('video_url')}
											/>

											<Radio.Group mt={35}
												name="Display Timing"
												orientation="vertical"
												label={__("Display Timing", "wdm_instructor_role")}
												defaultValue='BEFORE'
												{...editform.getInputProps('video_shown')}
											>
												<Radio value="BEFORE" label={__("Before completed sub-steps", "wdm_instructor_role")} description={sprintf(__("The video will be shown and must be fully watched before the user can access the %s's associated steps.", "wdm_instructor_role"), props.label)} />
												<Radio value="AFTER" label={__("After completing sub-steps", "wdm_instructor_role")} description={sprintf(__("The video will be visible after the user has completed the %s`s associated steps. The full video must be watched in order to complete the %s.", "wdm_instructor_role"), props.label, props.label)} />
												<div className="ir-conditional-settings pl-0">
													<Group className="ir-acss" spacing={0} align="center" pl={32}>
														<Text className="mantine-InputWrapper-label ir-d-flex">
															{sprintf(__("%s auto-completion", "wdm_instructor_role"), props.label)}
															<div className="ir-textinfo">
																<Tooltip label={sprintf(__("Automatically mark the %s as completed once the user has watched the full video.", "wdm_instructor_role"), props.label)} withArrow>
																	<Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
																</Tooltip>
															</div>
														</Text>
														<Switch className="ir-vp-settings ir-acss" labelPosition="left" value={"" + props.label + " auto-completion"} {...editform.getInputProps('video_auto_complete', { type: 'checkbox' })} />
													</Group>
													<Group className="ir-acss" spacing={0} align="center" pl={32} mt={15}>
														<Text className="mantine-InputWrapper-label ir-d-flex">
															{__('Completion delay', 'wdm_instructor_role')}
															<div className="ir-textinfo">
																<Tooltip label={sprintf(__("Specify a delay between video completion and %s completion.", "wdm_instructor_role"), props.label)} withArrow>
																	<Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
																</Tooltip>
															</div>
														</Text>
														<TextInput className="ir-input-settings ir-acss"
															placeholder="0"
															labelPosition="left"
															styles={{ input: { width: 85, borderRadius: '6px' } }}
															{...editform.getInputProps('video_auto_complete_delay')}
														/>
													</Group>
													<Group className="ir-acss" spacing={0} align="center" pl={32} mt={15} mb={15}>
														<Text className="mantine-InputWrapper-label ir-d-flex">
															{__("Mark Complete Button", 'wdm_instructor_role')}
															<div className="ir-textinfo">
																<Tooltip label={sprintf(__("Display the Mark Complete button on a %s even if not yet clickable.", "wdm_instructor_role"), props.label)} withArrow>
																	<Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
																</Tooltip>
															</div>
														</Text>
														<Switch className="ir-vp-settings ir-acss" labelPosition="left" value="Mark Complete Button" {...editform.getInputProps('video_show_complete_button', { type: 'checkbox' })} />
													</Group>
												</div>
											</Radio.Group>
											<Group spacing={0} align="center" mt={20}>
												<Text className="mantine-InputWrapper-label ir-d-flex w-50">
													{__("Autostart", "wdm_instructor_role")}
													<div className="ir-textinfo">
														<Tooltip label={__("Note, due to browser requirements videos will be automatically muted for autoplay to work.", "wdm_instructor_role")} withArrow>
															<Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
														</Tooltip>
													</div>
												</Text>
												<Switch className="w-50 ir-settings-right" labelPosition="right" value="Autostart" label={__("If enabled, The video starts automatically on page load", "wdm_instructor_role")} {...editform.getInputProps('video_auto_start', { type: 'checkbox' })} />
											</Group>
											<Group spacing={0} align="center" mt={20}>
												<Text className="mantine-InputWrapper-label ir-d-flex w-50">
													{__("Video Controls Display", "wdm_instructor_role")}
													<div className="ir-textinfo">
														<Tooltip label={__("Only available for YouTube and local videos. Vimeo supported if autostart is enabled.", "wdm_instructor_role")} withArrow>
															<Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
														</Tooltip>
													</div>
												</Text>
												<Switch className="w-50 ir-settings-right" labelPosition="right" label={__("Users can pause, move backward and forward within the video", "wdm_instructor_role")} {...editform.getInputProps('video_show_controls', { type: 'checkbox' })} />
											</Group>
											<Switch className="ir-vp-settings" mt={20} labelPosition="left" description={__("Pause the video if user switches to a different window.", "wdm_instructor_role")} label={__("Video Pause on Window Unfocused", "wdm_instructor_role")} {...editform.getInputProps('video_focus_pause', { type: 'checkbox' })} />
											<Switch className="ir-vp-settings" mt={20} labelPosition="left" description={__("Allows user to resume video position. Uses browser cookie.", "wdm_instructor_role")} label={__("Video resume", "wdm_instructor_role")} {...editform.getInputProps('video_resume', { type: 'checkbox' })} />
										</Accordion.Panel>
									</Accordion.Item>

									<Accordion.Item value="assignment_upload_enabled">
										<Group className="ir-acc-left ir-no-chevron" position="apart" align="center">
											<Text size="md" className="ir-d-flex">
												{__('Assignment Uploads', 'wdm_instructor_role')}
											</Text>
											<Accordion.Control><img className="ir-disable" src={require('/images/switch.png')} /><img className="ir-enable" src={require('/images/switchon.png')} /></Accordion.Control>
										</Group>
										<Accordion.Panel className="ir-pl-35">
											<Group spacing={0} align="center" mb={24}>
												<Text className="mantine-InputWrapper-label ir-d-flex w-50">
													{__('File Extensions', 'wdm_instructor_role')}
													<div className="ir-textinfo">
														<Tooltip label={__("Specify the type of files users can upload. Leave blank for any.", "wdm_instructor_role")} withArrow>
															<Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
														</Tooltip>
													</div>
												</Text>
												<TextInput className="ir-input-settings ir-vp-settings ir-au-settings w-50"
													placeholder={__("Enter extension here pdf, xls or zip", "wdm_instructor_role")}
													{...editform.getInputProps('assignment_upload_limit_extensions')}
												/>
											</Group>
											<Group spacing={0} align="center" mb={24}>
												<Text className="mantine-InputWrapper-label ir-d-flex w-50">
													{__('File Size Limit', 'wdm_instructor_role')}
													<div className="ir-textinfo">
														<Tooltip label={__("Default maximum file size supported is controlled by your host.", "wdm_instructor_role")} withArrow>
															<Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
														</Tooltip>
													</div>
												</Text>
												<TextInput className="ir-input-settings ir-vp-settings ir-au-settings w-50"
													placeholder="512 MB"
													{...editform.getInputProps('assignment_upload_limit_size')}
												/>
											</Group>


											<Switch className="ir-vp-settings" mt={20} labelPosition="left" label="Points" description={__("Award points for submitting assignments", "wdm_instructor_role")} {...editform.getInputProps('assignment_points_enabled', { type: 'checkbox' })} />
											<TextInput className="ir-input-settings ir-vcd-text ir-settings-right" pl={32}
												placeholder=""
												label={__("available point(s)", "wdm_instructor_role")}
												labelPosition="left"
												styles={{ input: { width: 85, borderRadius: '6px' } }}
												{...editform.getInputProps('assignment_points_amount')}
											/>
											<Radio.Group mt={35}
												name="Grading Type"
												orientation="vertical"
												label={__("Grading Type", "wdm_instructor_role")}
												onChange={(value) => {
													editform.setValues(
														{
															assignment_auto_approve: ('auto_approve' === value) ? true : false
														}
													);
													setGradingType(value);
												}}
												value={grading_type}
											>
												<Radio value="auto_approve" label={__("Auto-approve", "wdm_instructor_role")} description={__("No grading or approval needed. The assignment will be automatically approved and full points will be awarded.", "wdm_instructor_role")} />
												<Radio value="manual_grade" label={__("Manually grade", "wdm_instructor_role")} description={sprintf(__("Admin or Group leader approval and grading required. The %s cannot be completed until the assignment is approved", 'wdm_instructor_role'), props.label)} />
												<div className="ir-conditional-settings pl-0">
													<TextInput className="ir-input-settings ir-acss" pl={32}
														placeholder=""
														label={__("Limit number of uploaded files", "wdm_instructor_role")}
														labelPosition="left"
														styles={{ input: { width: 85, borderRadius: '6px' } }}
														{...editform.getInputProps('assignment_upload_limit_count')}
													/>
													<Switch className="ir-vp-settings ir-acss" pl={32} mt={15} mb={15} labelPosition="left" label={__("Allow file deletion", "wdm_instructor_role")} {...editform.getInputProps('assignment_deletion_enabled', { type: 'checkbox' })} />
												</div>
											</Radio.Group>
										</Accordion.Panel>
									</Accordion.Item>
									<Accordion.Item value="forced_timer_enabled">
										<Group className="ir-acc-left ir-no-chevron" position="apart" align="center">
											<Text size="md" className="ir-d-flex">
												{sprintf(__('%s Timer', 'wdm_instructor_role'), props.label)}
												<div className="ir-textinfo">
													<Tooltip label={__("The module cannot be marked as completed until the set time has elapsed.", "wdm_instructor_role")} withArrow>
														<Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
													</Tooltip>
												</div>
											</Text>

											<Accordion.Control><img className="ir-disable" src={require('/images/switch.png')} /><img className="ir-enable" src={require('/images/switchon.png')} /></Accordion.Control>
										</Group>
										<Accordion.Panel>
											<Group position="center" align="center">
												<NumberInput className="ir-input-settings ir-acss"
													placeholder="HH"
													labelPosition="left"
													styles={{ input: { width: 85, borderRadius: '6px' } }}
													{...editform.getInputProps('timer_hh')}
												/>
												<NumberInput className="ir-input-settings ir-acss"
													placeholder="MM"
													labelPosition="left"
													styles={{ input: { width: 85, borderRadius: '6px' } }}
													{...editform.getInputProps('timer_mm')}
												/>
												<NumberInput className="ir-input-settings ir-acss"
													placeholder="SS"
													labelPosition="left"
													styles={{ input: { width: 85, borderRadius: '6px' } }}
													{...editform.getInputProps('timer_ss')}
												/>
											</Group>
										</Accordion.Panel>
									</Accordion.Item>
								</Accordion>
							</Group>
							<Group spacing="xs" mb={34} className="ir-fc-100">

								{(__('Tags and Categories', 'wdm_instructor_role'))}

								<Accordion width="100%" variant="contained" radius="md" defaultValue="customization">

									<Accordion.Item value={(props.label === ir_fcb_loc.lesson_label ? 'ld_lesson_tag' : 'ld_topic_tag')}>
										<Accordion.Control>
											{sprintf(__('%s Tags', 'wdm_instructor_role'), props.label)}
										</Accordion.Control>
										<Accordion.Panel>
											{current_tag && (
												<MultiSelect className="ir-multiselect-loader"
													icon={showTagLoader && (<Loader size="xs" />)}
													label={sprintf(__("Add %s tags", 'wdm_instructor_role'), props.label)}
													data={tags}
													placeholder={__("Select items", 'wdm_instructor_role')}
													searchable
													creatable
													getCreateLabel={(query) => `+ Create ${query}`}
													onCreate={createNewTag}
													{...editform.getInputProps('tags')}
												/>
											)}
											{!current_tag && (
												<Text color="dimmed" weight={400}>{sprintf(__("%s tags are disabled from Learndash settings.", 'wdm_instructor_role'), props.label)} </Text>
											)}
										</Accordion.Panel>
									</Accordion.Item>


									<Accordion.Item value={(props.label === ir_fcb_loc.lesson_label ? 'ld_lesson_category' : 'ld_topic_category')}>
										<Accordion.Control>
											{sprintf(__('%s Categories', 'wdm_instructor_role'), props.label)}
											<Text size="sm" color="dimmed" weight={400}>
												{__("Child categories cannot be created from here.", "wdm_instructor_role")}
											</Text>
										</Accordion.Control>
										<Accordion.Panel>
											{((ir_fcb_loc.is_admin && current_cat) || (false !== ir_fcb_loc.instructor_settings && ('off' !== ir_fcb_loc.instructor_settings?.enable_ld_category) && current_cat)) && (
												<>
													{null !== categories && (
														<Checkbox.Group
															{...editform.getInputProps('category')}
															orientation="vertical"
														>
															{null !== categories && categories.map((category, index) => (
																<div>
																	<Checkbox value={category.value} label={category.label} />
																	{category.hasOwnProperty('children') && category.children.map((child) => (
																		<Checkbox ml={20} mt={20} size="md" value={child.id.toString()} label={child.name} />
																	))}
																</div>
															))}
														</Checkbox.Group>
													)}
													<Group align="center" spacing="xs" mt={20}>
														<Text className="ir-add-cat" size={14} color="#2067FA" fw={600} onClick={() => setShowCatFields(true)}>{sprintf(__('Add new %s category', 'wdm_instructor_role'), props.label)}</Text>
														{!showCatFields && (
															<Plus onClick={() => setShowCatFields(true)}
																size={18}
																strokeWidth={2}
																color={'#2067FA'}

															/>
														)}
														{showCatFields && (
															<X onClick={() => setShowCatFields(false)}
																size={18}
																strokeWidth={2}
																color={'#2067FA'}

															/>
														)}
													</Group>
													{showCatFields && (
														<div>
															<TextInput
																placeholder="Enter new category name"
																value={new_category}
																onChange={(event) => setNewCategory(event.currentTarget.value)}
															/>
															{/* <Select mt={6}
																		placeholder="Select Parent Course Category "
																		data={categories}
																		value={parent_category} onChange={setParentCategory}
																/> */}
															<Button
																mt={6}
																className="ir-btn-filled"
																onClick={createNewCategory}
																loading={category_loading}
															>Add</Button>
														</div>
													)}
												</>
											)}
											{((!ir_fcb_loc.is_admin && (false === ir_fcb_loc.instructor_settings || 'off' === ir_fcb_loc.instructor_settings?.enable_ld_category)) || "yes" !== current_cat) && (
												<Text color="dimmed" weight={400}>{sprintf(__("%s categories are disabled from Learndash settings.", 'wdm_instructor_role'), props.label)} </Text>
											)}
										</Accordion.Panel>
									</Accordion.Item>
								</Accordion>
							</Group>

							{ir_fcb_loc.is_admin && (
								<Group spacing="xs" mb={34} className="ir-fc-100">
									<Text className="ir-parent-settings ir-capitalize-letter" size="lg" width="100%" >{__('Author', 'wdm_instructor_role')}</Text>
									<Accordion width="100%" variant="contained" radius="md">
										<Accordion.Item value="course-author">
											<Accordion.Control>
												{__('Author', 'wdm_instructor_role')}
											</Accordion.Control>
											<Accordion.Panel>
												<Select mt={6}
													placeholder={sprintf(__("Select %s Author", "wdm_instructor_role"), ir_fcb_loc.course_label)}
													data={authors}
													{...editform.getInputProps('author')}
												/>
											</Accordion.Panel>
										</Accordion.Item>
									</Accordion>
								</Group>
							)}

							{(ir_fcb_loc.is_admin || (false !== ir_fcb_loc.instructor_settings && ('off' !== ir_fcb_loc.instructor_settings?.enable_permalinks))) && (
								<Group spacing="xs" mb={34} className="ir-fc-100">
									<Text className="ir-parent-settings" size="lg" width="100%">{sprintf(__('%s URL', 'wdm_instructor_role'), props.label)}</Text>
									<Accordion width="100%" variant="contained" radius="md" defaultValue="customization">

										<Accordion.Item value='permalink'>
											<Accordion.Control>{sprintf(__('%s URL', 'wdm_instructor_role'), props.label)}</Accordion.Control>
											<Accordion.Panel>
												<TextInput className="ir-input-settings ir-url-slug"
													placeholder="Enter here"
													label="URL Slug "
													labelPosition="left"
													{...editform.getInputProps('slug')}
												/>
												<Group mt={12}>
													<Text className="ir-view-module" size="md">{sprintf(__('View ', 'wdm_instructor_role'), props.label)}</Text>
													<Text component="a" color="#2067FA" size="sm" href={editform.values.link}>
														{editform.values.link}
													</Text>
												</Group>
											</Accordion.Panel>
										</Accordion.Item>
									</Accordion>
								</Group>
							)}
						</Tabs.Panel>
						<Tabs.Panel className="ir-panel-overflow" value="Material" pt="lg">
							<Switch mb={10}
								labelPosition="left"
								label={sprintf(__('%s Material', 'wdm_instructor_role'), props.label)}
								size="lg"
								checked={editform.values.materials_enabled}
								onChange={(event) => editform.setFieldValue('materials_enabled', event.currentTarget.checked)}
								className={editform.values.materials_enabled ? 'ir-checked ir-course-access-p-settings ir-switch ir-parent-settings ir-material' : 'ir-unchecked ir-course-access-p-settings ir-switch ir-parent-settings ir-material'}
								description={__('Any content added below is displayed on a separate tab, alongside your main content.', 'wdm_instructor_role')}
							/>
							<div className="ir-conditional-disabled">
								<Textarea
									className="ir-tiny-mce-editors"
									id="ir-edit-material-editor"
									minRows={20}
									{...editform.getInputProps('materials')}
								/>
							</div>
						</Tabs.Panel>
						<Tabs.Panel className="ir-panel-overflow" value="settings" pt="lg">
							<Group position="apart" align="center" mb={10}>
								<Text size="lg" className="ir-parent-settings">{sprintf(__('%s Access Option', 'wdm_instructor_role'), props.label)}</Text>
								<Text className="ir-section-name" size="md">{sprintf(__('Controls the timing and way %s can be accessed', 'wdm_instructor_role'), props.label)}</Text>
							</Group>
							<div className="ir-module-settings">
								{props.label === ir_fcb_loc.lesson_label &&
									<Switch mb={20} className="ir-trs"
										labelPosition="left"
										label={__('Sample Lesson', 'wdm_instructor_role')}
										size="lg"
										{...editform.getInputProps('is_sample', { type: 'checkbox' })}
									/>
								}
								<Radio.Group className="ir-trs"
									name="TopicRelease"
									orientation="vertical"
									label={sprintf(__('%s Release Schedule', 'wdm_instructor_role'), props.label)}
									defaultValue=""
									{...editform.getInputProps('visible_type')}
								>
									<Radio value="" label={__('Immediately', 'wdm_instructor_role')} description={sprintf(__("The %s is made available on course enrollment", 'wdm_instructor_role'), props.label)} />
									<Radio value="visible_after" label={__('Enrollment-based', 'wdm_instructor_role')} description={sprintf(__('The %s will be available X days after course enrollment', 'wdm_instructor_role'), props.label)} />
									<TextInput className="ir-input-settings ir-vcd-text" pl={32}
										placeholder=""
										label="days(s)"
										labelPosition="right"
										type="number"
										styles={{ input: { width: 85, borderRadius: '10px' } }}
										{...editform.getInputProps('visible_after')}
									/>
									<Radio value="visible_after_specific_date" label={__('Specific date', 'wdm_instructor_role')} description={sprintf(__('The %s will be available on a specific date.', 'wdm_instructor_role'), props.label)} />
									<Group className="ir-sp-date" pl={32}>
										<Select
											placeholder="MM"
											labelPosition="right"
											styles={{ input: { width: 62, borderRadius: '10px' } }}
											data={[
												{ value: 1, label: 'Jan' },
												{ value: 2, label: 'Feb' },
												{ value: 3, label: 'Mar' },
												{ value: 4, label: 'Apr' },
												{ value: 5, label: 'May' },
												{ value: 6, label: 'Jun' },
												{ value: 7, label: 'Jul' },
												{ value: 8, label: 'Aug' },
												{ value: 9, label: 'Sep' },
												{ value: 10, label: 'Oct' },
												{ value: 11, label: 'Nov' },
												{ value: 12, label: 'Dec' },
											]}
											{...editform.getInputProps('enrollment_date_mm')}
										/>
										<TextInput
											placeholder="DD"
											labelPosition="right"
											type="number"
											styles={{ input: { width: 62, borderRadius: '10px' } }}
											{...editform.getInputProps('enrollment_date_dd')}
										/>,
										<TextInput
											placeholder="YYYY"
											labelPosition="right"
											type="number"
											styles={{ input: { width: 72, borderRadius: '10px' } }}
											{...editform.getInputProps('enrollment_date_yy')}
										/>@
										<TextInput
											placeholder="HH"
											labelPosition="right"
											type="number"
											styles={{ input: { width: 62, borderRadius: '10px' } }}
											{...editform.getInputProps('enrollment_date_hh')}
										/>:
										<TextInput
											placeholder="MN"
											labelPosition="right"
											type="number"
											styles={{ input: { width: 62, borderRadius: '10px' } }}
											{...editform.getInputProps('enrollment_date_min')}
										/>
									</Group>
								</Radio.Group>
							</div>
						</Tabs.Panel>
					</Tabs>
					<Group spacing="xs" mt={34} className="ir-tm-bottom-actions" position="apart" align="center">
						<Group>
							{/* (loading || visible ) && (<Loader size="md" variant="dots"/>) */}
						</Group>
						<Group spacing="xs">
							<Popover width={165} position="bottom" withArrow shadow="lg" radius={6}>
								<Popover.Target>
									<Button size="sm" fw={600} className="ir-btn-subtle" radius="md" variant="subtle" leftIcon={<Eye size={22} />} >
										{sprintf(__('View %s', 'wdm_instructor_role'), props.label)}
									</Button>
								</Popover.Target>
								<Popover.Dropdown className="ir-preview-module">
									<Button className="ir-btn-subtle" onClick={() => openIframeInTab('100%', editform.values.link)} size="sm" variant="subtle" leftIcon={<DeviceDesktop size={22} color={'#000000'} />} >
										{__('Desktop view', 'wdm_instructor_role')}
									</Button>
									<Button className="ir-btn-subtle" onClick={() => openIframeInTab('768px', editform.values.link)} size="sm" variant="subtle" leftIcon={<DeviceTablet size={22} color={'#000000'} />} >
										{__('Tablet view', 'wdm_instructor_role')}
									</Button>
									<Button className="ir-btn-subtle" onClick={() => openIframeInTab('475px', editform.values.link)} size="sm" variant="subtle" leftIcon={<DeviceMobile size={22} color={'#000000'} />} >
										{__('Mobile view', 'wdm_instructor_role')}
									</Button>
								</Popover.Dropdown>
							</Popover>
							<Popover position="bottom" withArrow shadow="lg" radius={6} width={320}>
								<Popover.Target>
									<Button
										size="sm"
										fw={600}
										className="ir-btn-subtle"
										radius="md"
										variant="subtle"
									>
										{__('Status and Visibility', 'wdm_instructor_role')}
									</Button>
								</Popover.Target>
								<Popover.Dropdown className="ir-status-and-visibility">
									<Accordion width={320}>
										<Accordion.Item value="visibility" variant="filled">
											<Accordion.Control>
												<Group align="center" spacing="xs" position="apart">
													<Text size="sm" fw={600}>{__('Visibility', 'wdm_instructor_role')}</Text>
													<Text size="sm" fw={600} color="#2067FA;">{getVisibility()}</Text>
												</Group>
											</Accordion.Control>
											<Accordion.Panel>
												<Radio.Group
													defaultValue='public'
													orientation='vertical'
													value={editform.values.visibility}
													onChange={handleVisibilityChange}
												>
													<Radio value="public" label={__('Public', 'wdm_instructor_role')} description={__('Visible to everyone', 'wdm_instructor_role')} />
													<Radio value="private" label={__('Private', 'wdm_instructor_role')} description={__('Only visible to site admins and editors', 'wdm_instructor_role')} />
													<Radio value="password" label={__('Password Protected', 'wdm_instructor_role')} description={__('Protected with a password you choose. Only those with the password can view this post.', 'wdm_instructor_role')} />
												</Radio.Group>
												{'password' === editform.values.visibility && (
													<TextInput
														mt={5}
														placeholder={__('Use a secure Password', 'wdm_instructor_role')}
														size="sm"
														{...editform.getInputProps('password')}
													/>
												)}
											</Accordion.Panel>
										</Accordion.Item>

										<Accordion.Item value="publish">
											<Accordion.Control>
												<Group align="center" spacing="xs" position="apart">
													<Text size="sm" fw={600}>{__('Publish', 'wdm_instructor_role')}</Text>
													<Text size="sm" fw={600} color="#2067FA;">{getPublishedDate()}</Text>
												</Group>
											</Accordion.Control>
											<Accordion.Panel>
												<TimeInput
													className='ir-noborder'
													format="12"
													label={__('Time', 'wdm_instructor_role')}
													defaultValue={new Date()}
													icon={<ClockHour4 size={16} />}
													{...editform.getInputProps('time')}
												/>
												<DatePicker
													label={__('Date', 'wdm_instructor_role')}
													defaultValue={new Date()}
													icon={<CalendarEvent size={16} />}
													{...editform.getInputProps('date')}
												/>
											</Accordion.Panel>
										</Accordion.Item>
									</Accordion>
								</Popover.Dropdown>
							</Popover>
							{'draft' === editform.values.status && (<Button className="ir-btn-outline" variant="outline" type="submit" onClick={() => {
								editform.values.status = 'draft';
							}} loading={(loading || visible)}>
								{__('Save to draft', 'wdm_instructor_role')}
							</Button>)}

							{('publish' === editform.values.status || 'private' === editform.values.status || 'future' === editform.values.status ) && (<Button className="ir-btn-outline" variant="outline" onClick={() => switchDraft()}
								loading={(loading || visible)}>
								{__('Switch to draft', 'wdm_instructor_role')}
							</Button>)}

							<Button className="ir-btn-filled" variant="filled" type="submit" onClick={() => {
								editform.setFieldValue('status', 'publish');
							}}
								loading={(loading || visible)}
							>
								{'draft' === editform.values.status && __('Publish', 'wdm_instructor_role')}
								{('publish' === editform.values.status || 'private' === editform.values.status ) && __('Update', 'wdm_instructor_role')}
								{'future' === editform.values.status && __('Schedule', 'wdm_instructor_role')}
							</Button>
						</Group>
					</Group>
				</form>
			</Modal>

			<PencilMinus onClick={() => openEditModal()}
				size={24}
				strokeWidth={2}
				color={'#2067FA'}
			/>
		</>
	);
}
