import { useState } from 'react';
import {
    Input,
    Button,
    Modal,
    Group,
    TextInput
} from '@mantine/core';
import { sprintf, __ } from "@wordpress/i18n";
import { PencilMinus } from 'tabler-icons-react';
import { showNotification } from '@mantine/notifications';

export default function EditSection(props) {

    const {courseList, setCourseList} = props;
    const {edit_section} = props;

    const [section_name, setSection] = useState(edit_section.post_title);
    const [opened, setOpened] = useState(false);

    const updateSection = () => {
        let _courseList = {...courseList};
        let _section = {};

        _courseList.sections = [];
        courseList.sections.map((section) => {
            _section = {...section};
            if ( section.ID === edit_section.ID ) {
                _section.post_title = section_name;
            }
            _courseList.sections.push(_section)
        })

        setCourseList(_courseList);
        setOpened(false);
        showNotification({
            title: __('Section Updated', 'wdm_instructor_role'),
            message: __('Your section has successfully been updated!!', 'wdm_instructor_role'),
        })
        setSection('');
    }

    return (
        <>
            <Modal className="ir-topic-modal"
                opened={opened}
                onClose={() => setOpened(false)}
                title={__('Edit Section', 'wdm_instructor_role')}
                size='830px'
            >
                <Group align="center" mt={50} mb={50}>
                    <TextInput className="ir-section-input"
                        placeholder={__('Edit section name here', 'wdm_instructor_role')}
                        size="md"
                        value={section_name}
                        onChange={(event) => setSection(event.currentTarget.value)}
                    />
                    <Button size="md" variant="outline" onClick={updateSection}>{__('Update', 'wdm_instructor_role')}</Button>
                </Group>
            </Modal>

            <PencilMinus onClick={() => setOpened(true)}
                size={24}
                strokeWidth={2}
                color={'#2067FA'}
            />
        </>
    );
}