import { useState, useEffect } from 'react';
import {
    Text,
    Paper,
    Checkbox,
    Button,
    Group,
    TextInput,
    Switch,
    Image,
    Textarea,
} from '@mantine/core';
import { Plus, PhotoUp, Replace, InfoCircle, PencilMinus, X, GridDots, Upload, Trash, Eye } from 'tabler-icons-react';
import { MediaUpload } from '@wordpress/media-utils';
import { showNotification } from '@mantine/notifications';
import { __ } from "@wordpress/i18n";


export default function MatrixAnswer(props) {
    const {questionType, editQuestionData, editQuestionForm, setEditQuestionData, answerPoints} = props;
    const [addMatrixAnswer, setAddMatrixAnswer] = useState(false);
    const [newMatrixAnswerText, setNewMatrixAnswerText] = useState(null);
    const [editMatrixAnswer, setEditMatrixAnswer] = useState({});
    const [error, setError] = useState({});

    useEffect(() => {
        const _editMatrixAnswer = {...editMatrixAnswer}
        for(let i=0; i<editQuestionData.answer_data?.length; i++){
            _editMatrixAnswer[i] = false
        }
        setEditMatrixAnswer(_editMatrixAnswer);
    }, []);

    useEffect(() => {
        if(questionType === 'matrix_sort_answer'){
            const _editMatrixAnswer = {...editMatrixAnswer}
            for(let i=0; i<editQuestionData?.answer_data?.length; i++){
                _editMatrixAnswer[i] = false
            }
            setEditMatrixAnswer(_editMatrixAnswer);
        }
    }, [questionType]);

    const removeMatrixAnswer = (index) => {
        const _editQuestionData = {...editQuestionData};
        _editQuestionData.answer_data.splice(index, 1);
        setEditQuestionData(_editQuestionData);
    }

    const addMediaToNewAnswer = (url) => {
        const _newMatrixAnswerText = {...newMatrixAnswerText};
        let _prevText = '';
        if(editQuestionForm.values.matrixAnswer !== undefined){
            _prevText = editQuestionForm.values.matrixAnswer;
        }
        _newMatrixAnswerText.text = _prevText + '<img src="'+url.toString()+'"/>';
        editQuestionForm.setValues({
            matrixAnswer: _newMatrixAnswerText.text
        });
        setNewMatrixAnswerText(_newMatrixAnswerText);
    }

    const addMediaToNewSortElement = (url) => {
        const _newMatrixAnswerText = {...newMatrixAnswerText};
        let _prevText = '';
        if(editQuestionForm.values.sortString !== undefined){
            _prevText = editQuestionForm.values.sortString;
        }
        _newMatrixAnswerText.sortString = _prevText + '<img src="'+url.toString()+'"/>';
        editQuestionForm.setValues({
            sortString: _newMatrixAnswerText.sortString
        });
        setNewMatrixAnswerText(_newMatrixAnswerText);
    }

    const addMediaToEditAnswer = (url, answer, index) => {
        const _editQuestionData = {...editQuestionData};
        let prevText = _editQuestionData.answer_data[index]._answer;
        if(editQuestionForm.values['_editMatrixanswer'+index] !== undefined){
            prevText = editQuestionForm.values['_editMatrixanswer'+index];
        }
        _editQuestionData.answer_data[index]._html = true;
        _editQuestionData.answer_data[index]._answer = prevText + '<img src="'+url.toString()+'"/>';
        editQuestionForm.setValues({
            ['_editMatrixHtml'+index]: true,
            ['_editMatrixanswer'+index]: _editQuestionData.answer_data[index]._answer
        });
        setEditQuestionData(_editQuestionData);
    }

    const addMediaToEditSortElement = (url, answer, index) => {
        const _editQuestionData = {...editQuestionData};
        let prevText = _editQuestionData.answer_data[index]._sortString;
        if(editQuestionForm.values['_editMatrixSortString'+index] !== undefined){
            prevText = editQuestionForm.values['_editMatrixSortString'+index];
        }
        _editQuestionData.answer_data[index]._sortStringHtml = true;
        _editQuestionData.answer_data[index]._sortString = prevText + '<img src="'+url.toString()+'"/>';
        editQuestionForm.setValues({
            ['_editMatrixSortStringHtml'+index]: true,
            ['_editMatrixSortString'+index]: _editQuestionData.answer_data[index]._editMatrixSortString
        });
        setEditQuestionData(_editQuestionData);
    }

    const addNewMatrixAnswer = () => {
        const newAnswer = {};
        const _editQuestionData = {...editQuestionData}
        const _editMatrixAnswer = {...editMatrixAnswer}
        if(_editQuestionData.answer_data === null){
            _editQuestionData.answer_data = [];
        }
        const index = _editQuestionData.answer_data.length;
        newAnswer._answer = editQuestionForm.values.matrixAnswer;
        newAnswer._sortString = editQuestionForm.values.sortString;
        newAnswer._html = editQuestionForm.values._html;
        newAnswer._sortStringHtml = editQuestionForm.values._sortStringHtml;
        newAnswer._points = editQuestionForm.values._editMatrixPoints;
        if(newAnswer._answer?.trim() === '' || newAnswer._answer === undefined){
            showNotification({ message: 'Please add answer', color: 'red' });
            const _error = {...error}
            _error.answer = true;
            _error.sortElement = false;
            setError(_error);
        }
        else if(newAnswer._sortString?.trim() === '' || newAnswer._sortString === undefined){
            showNotification({ message: 'Please add sort element', color: 'red' });
            const _error = {...error}
            _error.sortElement = true;
            _error.answer = false;
            setError(_error);
        }
        else{
            _editQuestionData.answer_data.push(newAnswer);
            _editMatrixAnswer[index] = false;
            setEditMatrixAnswer(_editMatrixAnswer);
            setEditQuestionData(_editQuestionData);
            setAddMatrixAnswer(false);
            const _error = {...error}
            _error.answer = false;
            _error.sortElement = false;
            setError(_error);
            editQuestionForm.setValues({
                matrixAnswer: '',
                sortString: '',
                answers: _editQuestionData.answer_data,
            });
        }
        
    }

    const saveMatrixAnswerData = (index, answer) => {
        const _editQuestionData = {...editQuestionData};
        const _editMatrixAnswer = {...editMatrixAnswer};
        editQuestionForm.values["_editMatrixanswer"+index] !== undefined && (_editQuestionData.answer_data[index]._answer = editQuestionForm.values["_editMatrixanswer"+index])
        editQuestionForm.values["_editMatrixSortString"+index] !== undefined && (_editQuestionData.answer_data[index]._sortString = editQuestionForm.values["_editMatrixSortString"+index]);
        editQuestionForm.values["_editMatrixHtml"+index] !== undefined && (_editQuestionData.answer_data[index]._html = editQuestionForm.values["_editMatrixHtml"+index]);
        editQuestionForm.values["_editMatrixSortStringHtml"+index] !== undefined && (_editQuestionData.answer_data[index]._sortStringHtml = editQuestionForm.values["_editMatrixSortStringHtml"+index]);
        editQuestionForm.values["_editMatrixPoints"+index] !== undefined && (_editQuestionData.answer_data[index]._points = editQuestionForm.values["_editMatrixPoints"+index]);
        if(_editQuestionData.answer_data[index]._answer?.trim() === '' || _editQuestionData.answer_data[index]._answer === undefined){
            showNotification({ message: 'Please add answer', color: 'red' });
            const _error = {...error}
            _error["editanswer"+index] = true;
            _error["editsortElement"+index] = false;
            setError(_error);
        }
        else if(_editQuestionData.answer_data[index]._sortString?.trim() === '' || _editQuestionData.answer_data[index]._sortString === undefined){
            showNotification({ message: 'Please add sort element', color: 'red' });
            const _error = {...error}
            _error["editsortElement"+index] = true;
            _error["editanswer"+index] = false;
            setError(_error);
        }
        else{
            const _error = {...error}
            _error["editsortElement"+index] = false;
            _error["editanswer"+index] = false;
            setError(_error);
            setEditQuestionData(_editQuestionData);
            _editMatrixAnswer[index] = false;
            setEditMatrixAnswer(_editMatrixAnswer);
        }
        
    }
    return (
        <>  
            {questionType === 'matrix_sort_answer' && (
                <div>
                    <Text size={14} fw={400} c="#6F717C" mb={23}>
                        <b>{__('Note: ', 'wdm_instructor_role')}</b>
                        {__("Allows adjustment of the left column's width, and the right column will auto-fill the rest of the available space. Increase this to allow accommodate longer criterion text. Defaults to 20%.", "wdm_instructor_role")} <br />
                    </Text>
                    <Group mb={25}>
                        <Text size={14} fw={600} c="#444444">{__('Width percentage', 'wdm_instructor_role')}</Text>
                        <Group>
                            <TextInput styles={{ input: { width: 80, borderRadius: '6px' }}} 
                                {...editQuestionForm.getInputProps('answer_criteria_width')}
                            />
                            <Text>%</Text>
                        </Group>
                    </Group>
                    <div className="ir-sortable-answers">
                        {null !== editQuestionData && editQuestionData.answer_data?.map(( answer , index) => (
                            <div>
                                {editMatrixAnswer[index] === false && (
                                    <Paper className={"ir-fed-answers"} mb={16} radius="lg" p="sm" withBorder>
                                        <Group align="center" spacing="xs" position="apart">
                                            <GridDots
                                                size={20}
                                                strokeWidth={2}
                                                color={'#2067FA'}
                                            />
                                            <Group className="ir-quizzes-acc-top" align="center">
                                                <Group align="center" spacing="xs">
                                                    <div className="ir-matrix-answer-part">
                                                        <Text fz="md" fw={600} c="#222222" truncate>{answer._answer}</Text>
                                                        <input id={"ir-builder-element-"} className='ir-builder-quiz' type="hidden" />
                                                    </div>
                                                    
                                                </Group>
                                            </Group>
                                            <Group className="ir-quizzes-acc-top" align="center">
                                                <Group align="center" spacing="xs">
                                                    <div className="ir-matrix-answer-part">
                                                        <Text fz="md" fw={600} c="#222222" truncate>{answer._sortString}</Text>
                                                        <input id={"ir-builder-element-"} className='ir-builder-quiz' type="hidden" />
                                                    </div>
                                                    
                                                </Group>
                                            </Group>
                                            <Group align="center" spacing="sm">
                                                <PencilMinus
                                                    size={24}
                                                    strokeWidth={2}
                                                    color={'#2067FA'}
                                                    onClick={() => {
                                                        const _editMatrixAnswer = {...editMatrixAnswer}
                                                        _editMatrixAnswer[index] = true
                                                        setEditMatrixAnswer(_editMatrixAnswer)

                                                    }}
                                                />
                                                <X onClick={() => removeMatrixAnswer(index)}
                                                    size={24}
                                                    strokeWidth={2}
                                                    color={'#2067FA'}
                                                />
                                            </Group>
                                        </Group>
                                    </Paper>
                                )}
                                {editMatrixAnswer[index] === true && (
                                    <Group className={`ir-answer-section ir-border br-10`} mb={16} p={15}>
                                        <div className="w-100">
                                            <Textarea label={__('Criterion', 'wdm_instructor_role')} className="ir-flex-1" minRows={2}
                                                key={answer._answer}
                                                defaultValue={answer._answer}
                                                {...editQuestionForm.getInputProps('_editMatrixanswer'+index)}
                                                error={error["editanswer"+index]}
                                            />
                                            <Group mt={15} position="apart">
                                                <Group>
                                                    <MediaUpload
                                                        onSelect={(media) => {
                                                            addMediaToEditAnswer(media.url, answer, index)
                                                        }}
                                                        allowedTypes={['image']}
                                                        render={({ open }) => (
                                                            <Button fw={400} className="ir-btn-subtle h-auto ir-btn-p-0" onClick={open} leftIcon={<PhotoUp size={23} strokeWidth={1} />}  >{__('Add media', 'wdm_instructor_role')}</Button>
                                                        )}
                                                    />
                                                    <Switch className="ir-d-flex" label={__('Allow HTML', 'wdm_instructor_role')}
                                                        key={answer._html}
                                                        defaultChecked={answer._html}
                                                        {...editQuestionForm.getInputProps('_editMatrixHtml'+index)}
                                                    />
                                                </Group>
                                            </Group>
                                            <Textarea label={__('Sort elements', 'wdm_instructor_role')} className="ir-flex-1" minRows={2} mt={30}
                                                key={answer._sortString}
                                                defaultValue={answer._sortString}
                                                {...editQuestionForm.getInputProps('_editMatrixSortString'+index)}
                                                error={error["editsortElement"+index]}
                                            />
                                            <Group mt={15} position="apart">
                                                <Group>
                                                    <MediaUpload
                                                        onSelect={(media) => {
                                                            addMediaToEditSortElement(media.url, answer, index)
                                                        }}
                                                        allowedTypes={['image']}
                                                        render={({ open }) => (
                                                            <Button fw={400} className="ir-btn-subtle h-auto ir-btn-p-0" onClick={open} leftIcon={<PhotoUp size={23} strokeWidth={1} />}  >{__('Add media', 'wdm_instructor_role')}</Button>
                                                        )}
                                                    />
                                                    <Switch className="ir-d-flex" label={__('Allow HTML', 'wdm_instructor_role')}
                                                        key={answer._sortStringHtml}
                                                        defaultChecked={answer._sortStringHtml}
                                                        {...editQuestionForm.getInputProps('_editMatrixSortStringHtml'+index)}
                                                    />
                                                </Group>
                                            </Group>
                                        </div>
                                        <Group position="right" align="center" spacing="xs" className="w-100">
                                            {answerPoints && (
                                                <TextInput className="ir-input-settings input-p-0 label-spacing-10" label={__('Points', 'wdm_instructor_role')} styles={{ input: { height: 32, width: 32, borderRadius: '6px' } }} 
                                                    defaultValue={answer._points}
                                                    {...editQuestionForm.getInputProps('_editMatrixPoints'+index)}
                                                />
                                            )}
                                        </Group>
                                        <Group position="apart" align="center" spacing="xs" className="w-100">
                                            <Button onClick={() => {
                                                const _editMatrixAnswer = {...editMatrixAnswer}
                                                _editMatrixAnswer[index] = false
                                                setEditMatrixAnswer(_editMatrixAnswer)
                                                removeMatrixAnswer(index)
                                            }} fw={400} className="ir-btn-subtle ir-red-txt" leftIcon={<Trash size={23} strokeWidth={1} />}  >{__('Delete', 'wdm_instructor_role')}</Button>
                                            <Group spacing={0}>
                                                <Button className="ir-btn-subtle" onClick={() => {
                                                    const _editMatrixAnswer = {...editMatrixAnswer}
                                                    _editMatrixAnswer[index] = false
                                                    setEditMatrixAnswer(_editMatrixAnswer)
                                                }}
                                                    variant="subtle" size="xs">{__('Cancel', 'wdm_instructor_role')}</Button>
                                                <Button className="ir-btn-filled" onClick={() => saveMatrixAnswerData(index, answer)} size="xs">{__('Save', 'wdm_instructor_role')}</Button>
                                            </Group>
                                        </Group>
                                    </Group>
                                )}
                            </div>
                        ))}
                    </div>
                    {addMatrixAnswer && (
                        <Group className={`ir-answer-section ir-border br-10`} mb={16} p={15}>
                            <div className="w-100">
                                <Textarea label={__('Criterion', 'wdm_instructor_role')} className="ir-flex-1" minRows={2}
                                    value={newMatrixAnswerText?.text}
                                    {...editQuestionForm.getInputProps('matrixAnswer')}
                                    error={error.answer}
                                />
                                <Group mt={15} position="apart">
                                    <Group>
                                        <MediaUpload
                                            onSelect={(media) => {
                                                addMediaToNewAnswer(media.url)
                                            }}
                                            allowedTypes={['image']}
                                            render={({ open }) => (
                                                <Button fw={400} className="ir-btn-subtle h-auto ir-btn-p-0" onClick={open} leftIcon={<PhotoUp size={23} strokeWidth={1} />}  >{__('Add media', 'wdm_instructor_role')}</Button>
                                            )}
                                        />
                                        <Switch className="ir-d-flex" label={__('Allow HTML', 'wdm_instructor_role')}
                                            {...editQuestionForm.getInputProps('_html')}
                                        />
                                    </Group>
                                </Group>
                                <Textarea label={__('Sort elements', 'wdm_instructor_role')} className="ir-flex-1" minRows={2} mt={30}
                                    value={newMatrixAnswerText?.sortString}
                                    {...editQuestionForm.getInputProps('sortString')}
                                    error={error.sortElement}
                                />
                                <Group mt={15} position="apart">
                                    <Group>
                                        <MediaUpload
                                            onSelect={(media) => {
                                                addMediaToNewSortElement(media.url)
                                            }}
                                            allowedTypes={['image']}
                                            render={({ open }) => (
                                                <Button fw={400} className="ir-btn-subtle h-auto ir-btn-p-0" onClick={open} leftIcon={<PhotoUp size={23} strokeWidth={1} />}  >{__('Add media', 'wdm_instructor_role')}</Button>
                                            )}
                                        />
                                        <Switch className="ir-d-flex" label={__('Allow HTML', 'wdm_instructor_role')}
                                            {...editQuestionForm.getInputProps('_sortStringHtml')}
                                        />
                                    </Group>
                                </Group>
                            </div>
                            <Group position="right" align="center" spacing="xs" className="w-100">
                                {answerPoints && (
                                    <TextInput className="ir-input-settings input-p-0 label-spacing-10" label={__('Points', 'wdm_instructor_role')} styles={{ input: { height: 32, width: 32, borderRadius: '6px' } }} 
                                        {...editQuestionForm.getInputProps('_editMatrixPoints')}
                                    />
                                )}
                            </Group>
                            <Group position="right" align="center" spacing="xs" className="w-100">
                                <Group spacing={0}>
                                    <Button className="ir-btn-subtle" onClick={() => setAddMatrixAnswer(false)}
                                        variant="subtle" size="xs">{__('Cancel', 'wdm_instructor_role')}</Button>
                                    <Button className="ir-btn-filled" onClick={() => addNewMatrixAnswer()} size="xs">{__('Save', 'wdm_instructor_role')}</Button>
                                </Group>
                            </Group>
                        </Group>
                    )}
                    <Group position="center">
                        <Button onClick={() => setAddMatrixAnswer(true)} size="md" className="ir-btn-filled" radius="md" variant="filled" leftIcon={<Plus size={18} color={'#ffffff'} />}>
                            {__('Add new Answer', 'wdm_instructor_role')}
                        </Button>
                    </Group>
                </div>
            )}
        </>
    );
}