import { useState, useEffect, forwardRef } from 'react';
import {
    AppShell,
    Navbar,
    Header,
    Accordion,
    MantineProvider,
    Text,
    Title,
    Grid,
    Paper,
    Input,
    Checkbox,
    Button,
    Group,
    Space,
    Center,
    CloseButton,
    Skeleton,
    TextInput,
    Modal,
    Tabs,
    FileButton,
    Switch,
    Radio,
    NumberInput,
    MultiSelect,
    Loader,
    Image,
    Textarea,
    Select,
    Tooltip,
    Avatar,
    SimpleGrid
} from '@mantine/core';
import { Plus, PhotoUp, Replace, InfoCircle } from 'tabler-icons-react';
import { PencilMinus } from 'tabler-icons-react';
import { X } from 'tabler-icons-react';
import { GridDots } from 'tabler-icons-react';
import { Upload } from 'tabler-icons-react';
import { Trash } from 'tabler-icons-react';
import { Eye } from 'tabler-icons-react';
import { __ } from "@wordpress/i18n";
import { showNotification, NotificationsProvider } from '@mantine/notifications';
import { ModalsProvider } from '@mantine/modals';
import { openConfirmModal } from '@mantine/modals';
import { RichTextEditor } from '@mantine/rte';
import { useForm } from '@mantine/form';
import apiFetch from '@wordpress/api-fetch';
import { MediaUpload } from '@wordpress/media-utils';
import MatrixAnswer from '/src/quiz-builder/components/editQuestion/matrixAnswer.js';


export default function EditQuestionModal(props) {
    const [opened, setOpened] = useState(false);
    const [editAnswer, setEditAnswer] = useState({});
    const [addNewAnswer, setAddNewAnswer] = useState(false);
    const [editQuestionData, setEditQuestionData] = useState(null);
    const [newAnswerText, setNewAnswerText] = useState(null);
    const [answerPoints, setAnswerPoints] = useState(false);
    const [questionType, setQuestionType] = useState('single');
    const [featured_image, setFeaturedImage] = useState(null);
    const [showQLoader, setShowQLoader] = useState(false);
    const [showQDLoader, setShowQDLoader] = useState(false);
    const [file, setFile] = useState(File | null > (null));
    const [checkedList, setCheckedList] = useState([false, false, false]);
    const [error, setError] = useState({});
    let descTimer = 0; 
    
    const questionTypeData = [
      {
        image: require('/images/single.png'),
        label: __('Single Choice', 'wdm_instructor_role'),
        value: 'single',
      },

      {
        image: require('/images/multiple.png'),
        label: __('Multiple Choice', 'wdm_instructor_role'),
        value: 'multiple',
      },
      {
        image: require('/images/free.png'),
        label: __('Free Choice', 'wdm_instructor_role'),
        value: 'free_answer',
      },
      {
        image: require('/images/matrix.png'),
        label: __('Matrix Sorting Choice', 'wdm_instructor_role'),
        value: 'matrix_sort_answer',
      },
      {
        image: require('/images/sorting.png'),
        label: __('Sorting Choice', 'wdm_instructor_role'),
        value: 'sort_answer',
      },
      {
        image: require('/images/cloze.png'),
        label: __('Fill in the blanks', 'wdm_instructor_role'),
        value: 'cloze_answer',
      },
      {
        image: require('/images/assessment.png'),
        label: __('Assessment', 'wdm_instructor_role'),
        value: 'assessment_answer',
      },
      {
        image: require('/images/essay.png'),
        label: __('Essay/Open Answer', 'wdm_instructor_role'),
        value: 'essay',
      },
      
    ];

    const SelectItem = forwardRef(
      ({ image, label, description, ...others }, ref) => (
        <div ref={ref} {...others}>
          <Group noWrap>
            <Avatar className="select-img" src={image} />

            <div>
              <Text size="sm">{label}</Text>
              <Text size="xs" opacity={0.65}>
                {description}
              </Text>
            </div>
          </Group>
        </div>
      )
    );

    const handleChange = (index) => {
        const _checkedList = [...checkedList];
        _checkedList[index] = !_checkedList[index];
        setCheckedList(_checkedList);
    }

    const editQuestionForm = useForm({
        initialValues: {
            answers: [],
            _title: '',
            question: '',
            points_total: '',
            content: '<p></p>',
            featured_image_url: null,
            featured_image: null
        },
        validate: {
            _title: (value) => (value.length > 0 ? null : __('Please enter a valid title.', 'wdm_instructor_role')),
            question: (value) => (tinyMCE.get('ir-question-content').getContent() !== '' ? null : __('Please enter a question.', 'wdm_instructor_role')),
            points_total: (value) => ((value > 0 || (answerPoints && (questionType !== 'essay'))) ? null : __('Please enter valid points.', 'wdm_instructor_role')),
            answers: (value) => ((checkAnswerLength(value) && hasCorrectAnswer(value)) ? null : __('Please add answers.', 'wdm_instructor_role')),
            cloze_answer: (value) => (hasAnswer() ? null : __('Please enter answer.', 'wdm_instructor_role')),
            free_answer: (value) => ((questionType !== 'free_answer' || (questionType === 'free_answer' && editQuestionForm.values.free_answer !== '')) ? null : __('Please enter answer.', 'wdm_instructor_role')),
        }
    })

    const hasCorrectAnswer = (value) => {
        let isCorrect = false;
        if(questionType === 'cloze_answer' || questionType === 'assessment_answer' || questionType === 'essay' || questionType === 'free_answer' || questionType === 'sort_answer' || questionType === 'matrix_sort_answer'){
            return true;
        }
        value.map((answerItem) => {
            if(answerItem._correct === true){
                isCorrect = true
            }
        }
            
        );
        return isCorrect;
    }

    const checkAnswerLength = (value) => {
        let answer_length = false;
        if(questionType === 'cloze_answer' || questionType === 'assessment_answer' || questionType === 'essay'){
            return true;
        }
        else{
            if(value?.length > 0){
                answer_length = true;
            }

        }
        return answer_length;
    }

    const hasAnswer = () => {
        let answer = true;
        if(questionType === 'cloze_answer'){
            if(tinyMCE.get('ir-cloze-content').getContent() == ''){
                answer = false;
            }
        }
        else if(questionType === 'assessment_answer'){
            if(tinyMCE.get('ir-assessment-content').getContent() == ''){
                answer = false;
            }
        }
        return answer;
    }

    const handleErrors = (errors) => {
        if (errors._title) {
            showNotification({ message: sprintf(__('Please fill %s title field', 'wdm_instructor_role'), ir_fqb_loc.lower_question_label), color: 'red' });
        }
        else if (errors.question) {
            showNotification({ message: sprintf(__('Please fill %s field', 'wdm_instructor_role'), ir_fqb_loc.lower_question_label), color: 'red' });
        }
        else if (errors.points_total){
            showNotification({ message: __('Please enter valid points', 'wdm_instructor_role'), color: 'red' });
        }
        else if (errors.answers){
            if(questionType === 'sort_answer' || questionType === 'matrix_sort_answer'){
                showNotification({ message: __('Please add at least one answer', 'wdm_instructor_role'), color: 'red' });
            }
            else{
                showNotification({ message: __('Please add at least one answer and mark as correct', 'wdm_instructor_role'), color: 'red' });
            }
        }
        else if (errors.cloze_answer){
            showNotification({ message: __('Please enter answer', 'wdm_instructor_role'), color: 'red' });
        }
        else if (errors.free_answer){
            showNotification({ message: __('Please enter answer', 'wdm_instructor_role'), color: 'red' });
        }

        if (errors.question)
        {
            jQuery('#ir-question-content_ifr').addClass('ir-invalid-field');
        }
        else
        {
            jQuery('#ir-question-content_ifr').removeClass('ir-invalid-field')
        }
        if (errors.answers)
        {
            jQuery('.ir-quiz-answers').addClass('ir-invalid-field');
        }
        else
        {
            jQuery('.ir-quiz-answers').removeClass('ir-invalid-field')
        }
        if (errors.cloze_answer)
        {
            jQuery('#ir-cloze-content_ifr').addClass('ir-invalid-field');
            jQuery('#ir-assessment-content_ifr').addClass('ir-invalid-field');
        }
        else
        {
            jQuery('#ir-cloze-content_ifr').removeClass('ir-invalid-field');
            jQuery('#ir-assessment-content_ifr').removeClass('ir-invalid-field');
        }
        if (errors.free_answer)
        {
            jQuery('#ir-sort-answer').addClass('ir-invalid-field');
        }
        else
        {
            jQuery('#ir-sort-answer').removeClass('ir-invalid-field');
        }
    };

    const setFormValues = (data) => {
        editQuestionForm.setValues({
            _title: data.title,
            question_type: data.question_type,
            points_total: data.points_total,
            points_per_answer: data.points_per_answer,
            points_show_in_message: data.points_show_in_message,
            incorrect_message: data.incorrect_message,
            correct_message: data.correct_message,
            answers: data.answer_data,
            question: data.question,
            featured_media: data.featured_media,
            hints_enabled: data.hints_enabled,
            hints_message: data.hints_message,
            cloze_answer: data.answer_data ? data.answer_data[0]?._answer : '',
            _gradedType: data.answer_data ? data.answer_data[0]?._gradedType : '',
            _gradingProgression: data.answer_data ? data.answer_data[0]?._gradingProgression : '',
            free_answer: data.answer_data ? data.answer_data[0]?._answer : '',
            answer_criteria_width: data.question_type === 'matrix_sort_answer' ? data.answer_criteria_width : ''
        });
        data.answer_data?.map((answerItem, index) => {
            editQuestionForm.setValues({
                ['_editanswer'+index]: answerItem._answer,
            });
        }
        );
    }

    const trashQuestion = () => {
        apiFetch(
            {
                path: "/ir/v1/sfwd-question/" + props.questionId,
                method: 'POST',
                data: {
                    post_status: 'trash'
                }
            }
        ).then((data) => {
            let _questionData =  [...props.questionData];
            const objWithIdIndex = _questionData.findIndex((obj) => obj.id === props.questionId);

            if (objWithIdIndex > -1) {
                _questionData.splice(objWithIdIndex, 1);
            }
            for (var i = objWithIdIndex; i<_questionData.length; i++){
                if(i == (_questionData.length - 1)){
                    _questionData[i].menu_order = objWithIdIndex + 1;
                }
                else{

                    _questionData[i].menu_order = i + 2;
                }
            } 
            const sorted = [..._questionData.sort((a, b) => parseFloat(a.menu_order) - parseFloat(b.menu_order))];
            props.setQuestionData(sorted);
            setOpened(false); 
            showNotification({
                title: sprintf(__('%s Trashed', 'wdm_instructor_role'), ir_fqb_loc.question_label),
                message: sprintf(__('Your %s has successfully been trashed', 'wdm_instructor_role'), ir_fqb_loc.question_label),
            })  
        });
    }


    const UpdateQuestion = (status) => {
        let answer_data = editQuestionData.answer_data;
        if (questionType === 'cloze_answer' || questionType === 'assessment_answer' || questionType === 'free_answer'){
            const newAnswer = {};
            newAnswer._answer = questionType === 'free_answer' ? editQuestionForm.values.free_answer : editQuestionForm.values.cloze_answer;
            answer_data = [];
            answer_data.push(newAnswer);
        }
        if(questionType === 'essay'){
            const newAnswer = {};
            newAnswer._answer = '';
            newAnswer._graded = '1';
            newAnswer._gradedType = editQuestionForm.values._gradedType;
            newAnswer._gradingProgression = editQuestionForm.values._gradingProgression;            
            answer_data = [];
            answer_data.push(newAnswer);
        }
        if(status === 'draft'){
            setShowQDLoader(true)
            status = 'draft';
        }
        else{
            setShowQLoader(true)
            status = 'publish';
        }
        apiFetch(
            {
                path: "/ir/v1/sfwd-question/" + props.questionId,
                method: 'POST',
                data: {
                    quiz: props.quizId,
                    title: editQuestionForm.values._title,
                    question_type: questionType,
                    points_total: editQuestionForm.values.points_total,
                    points_per_answer: answerPoints,
                    points_show_in_message: editQuestionForm.values.points_show_in_message,
                    incorrect_message: editQuestionForm.values.incorrect_message,
                    correct_message: editQuestionForm.values.correct_message,
                    answer_data: answer_data,
                    question: editQuestionForm.values.question,
                    featured_media: editQuestionData.featured_media,
                    hints_enabled: editQuestionForm.values.hints_enabled,
                    hints_message: editQuestionForm.values.hints_message,
                    menu_order: props.questionData[props.questionIndex].menu_order,
                    post_status: status,
                    answer_criteria_width: questionType === 'matrix_sort_answer' ? editQuestionForm.values.answer_criteria_width : ''                
                }
            }
        ).then((data) => {
            setShowQLoader(false);
            setShowQDLoader(false);
            if(status === 'publish'){
                wp.editor.remove('ir-question-content');
                wp.editor.remove('ir-cloze-content');
                wp.editor.remove('ir-assessment-content');
                setOpened(false); 
                showNotification({
                    title: sprintf(__('%s Updated', 'wdm_instructor_role'), ir_fqb_loc.question_label),
                    message: sprintf(__('Your %s has successfully been updated', 'wdm_instructor_role'), ir_fqb_loc.question_label),
                })
            }
            else{
                wp.editor.remove('ir-question-content');
                wp.editor.remove('ir-cloze-content');
                wp.editor.remove('ir-assessment-content');
                setOpened(false); 
                showNotification({
                    title: sprintf(__('%s Drafted', 'wdm_instructor_role'), ir_fqb_loc.question_label),
                    message: sprintf(__('Your %s has successfully been drafted', 'wdm_instructor_role'), ir_fqb_loc.question_label),
                })
            }
            const _questionData = [...props.questionData];
            const _allQuestions = [...props.allQuestions];
            _questionData[props.questionIndex].title.rendered = data.title;
            _questionData[props.questionIndex].question_type = data.question_type;
            _questionData[props.questionIndex].points_total = data.points_total;
            _questionData[props.questionIndex].post_status = data.post_data.post_status;
            const sorted = [..._questionData.sort((a, b) => parseFloat(a.menu_order) - parseFloat(b.menu_order))];
            
            props.setAllQuestions(_allQuestions)
            props.setQuestionData(sorted)  
        });
    }

    const addAnswer = () => {
        const newAnswer = {};
        const _editQuestionData = {...editQuestionData}
        const _editAnswer = {...editAnswer}
        if(_editQuestionData.answer_data === null){
            _editQuestionData.answer_data = [];
        }
        const index = _editQuestionData.answer_data.length
        if(editQuestionForm.values._correct === true && questionType === 'single'){
            _editQuestionData.answer_data.map((answerItem) =>
                answerItem._correct = false
            );
        }
        newAnswer._answer = editQuestionForm.values._answer;
        newAnswer._correct = editQuestionForm.values._correct;
        newAnswer._points = editQuestionForm.values._points;
        newAnswer._html = editQuestionForm.values._html;
        if(newAnswer._answer?.trim() === '' || newAnswer._answer === undefined){
            showNotification({ message: 'Please add answer', color: 'red' });
            const _error = {...error}
            _error.answer = true;
            setError(_error);
        }
        else{
            const _error = {...error}
            _error.answer = false;
            setError(_error);
            _editQuestionData.answer_data.push(newAnswer);
            _editAnswer[_editQuestionData.answer_data.length - 1] = false;
            editQuestionForm.setValues({
                answers: _editQuestionData.answer_data,
                ['_editanswer'+index]: newAnswer._answer
            });
            editQuestionForm.values['_editanswer'+index] = newAnswer._answer; 
            setEditAnswer(_editAnswer);
            setEditQuestionData(_editQuestionData);
            setAddNewAnswer(false);
            editQuestionForm.setValues({
                _answer: '',
                _correct: false,
                _html: false,
                _points: '',
            });
            editQuestionForm.values._answer = '';
            editQuestionForm.values._correct = false;
            editQuestionForm.values._html = false;
            editQuestionForm.values._points = '';    
        }
    }

    const answerPointsHandling = (event) => {
        if(event === true){
            setAnswerPoints(true);
        }
        else{
            setAnswerPoints(false);   
        }
    }

    const setQuestionTypeFunc = (value) => {
        const _editQuestionData = {...editQuestionData};
        // console.log('type changed');
        // console.log(value);
        if (value === 'single' && _editQuestionData.answer_data?.length > 0){
            _editQuestionData.answer_data.map((answerItem) =>
                answerItem._correct = false
            );
            _editQuestionData.answer_data[0]._correct = true;
        }
        if (value === 'assessment_answer'){
            _editQuestionData.points_per_answer = true;
            setAnswerPoints(true);
        }
        else{
            _editQuestionData.points_per_answer = false;   
            setAnswerPoints(false);
        }
        if (value === 'essay' && (editQuestionForm.values._gradedType === '' || editQuestionForm.values._gradedType === null)){
            editQuestionForm.setValues({
                _gradedType: 'text',
                _gradingProgression: 'not-graded-none'
            });
        }
        setQuestionType(value);
        setEditQuestionData(_editQuestionData);
    }

    const saveAnswerData = (index, answer, question_type) => {
        const _editQuestionData = {...editQuestionData};
        const _editAnswer = {...editAnswer};
        if (questionType === 'single' && editQuestionForm.values["_editcorrect"+index] !== undefined){
            _editQuestionData.answer_data.map((answerItem) =>
                answerItem._correct = false
            );
        }
        editQuestionForm.values["_editanswer"+index] !== undefined && (_editQuestionData.answer_data[index]._answer = editQuestionForm.values["_editanswer"+index])
        editQuestionForm.values["_editcorrect"+index] !== undefined && (_editQuestionData.answer_data[index]._correct = editQuestionForm.values["_editcorrect"+index]);
        editQuestionForm.values["_editpoints"+index] !== undefined && (_editQuestionData.answer_data[index]._points = parseInt(editQuestionForm.values["_editpoints"+index]));
        editQuestionForm.values["_edithtml"+index] !== undefined && (_editQuestionData.answer_data[index]._html = editQuestionForm.values["_edithtml"+index]);
        if(_editQuestionData.answer_data[index]._answer?.trim() === '' || _editQuestionData.answer_data[index]._answer === undefined){
            showNotification({ message: 'Please add answer', color: 'red' });
            const _error = {...error}
            _error["_editanswer"+index] = true;
            setError(_error);
        }
        else{
            const _error = {...error}
            _error["_editanswer"+index] = false;
            setError(_error);
            editQuestionForm.setValues({
                answers: _editQuestionData.answer_data
            });
            setEditQuestionData(_editQuestionData);
            _editAnswer[index] = false;
            setEditAnswer(_editAnswer);
        }
    }

    const addMedia = (url, answer, index) => {
        let prevText = '';
        if(editQuestionForm.values['_editanswer'+index] !== undefined){
            prevText = editQuestionForm.values['_editanswer'+index];
        }
        const _editQuestionData = {...editQuestionData};
        _editQuestionData.answer_data[index]._html = true;
        _editQuestionData.answer_data[index]._answer = prevText + '<img src="'+url.toString()+'"/>';
        editQuestionForm.setValues({
            ['_edithtml'+index]: true,
            ['_editanswer'+index]: _editQuestionData.answer_data[index]._answer
        });
        setEditQuestionData(_editQuestionData);
    }

    const addMediaToNewAnswer = (url) => {
        const _newAnswerText = {...newAnswerText};
        let _prevText = '';
        if(editQuestionForm.values._answer !== undefined){
            _prevText = editQuestionForm.values._answer;
        }
        _newAnswerText.text = _prevText + '<img src="'+url.toString()+'"/>';
        editQuestionForm.setValues({
            _html: true,
            _answer: _newAnswerText.text
        });
        editQuestionForm.values._answer = _newAnswerText.text;
        setNewAnswerText(_newAnswerText);
    }

    const removeAnswer = (index) => {
        const _editQuestionData = {...editQuestionData};
        _editQuestionData.answer_data.splice(index, 1);
        editQuestionForm.setValues({
            answers: _editQuestionData.answer_data
        });
        setEditQuestionData(_editQuestionData);
    }

    const setQuestionDescription = (event) => {  
        clearTimeout(descTimer);
        descTimer = setTimeout(function () {
            editQuestionForm.setValues({
                question: event.contentWindow.document.body.innerHTML
            });
        }, 500);
    }

    const setAnswerDescription = (event) => {  
        clearTimeout(descTimer);
        descTimer = setTimeout(function () {
            editQuestionForm.setValues({
                cloze_answer: event.contentWindow.document.body.innerHTML
            });
        }, 500);
    } 


    const openEditQuestionModal = () => {
        apiFetch(
            {
                path: "/ir/v1/sfwd-question/" + props.questionId,
                method: 'GET'
            }
        ).then((data) => {
            setOpened(true);
            const _checkedList = [...checkedList];
            _checkedList[0] = data.incorrect_message;
            _checkedList[1] = data.hints_enabled;
             _checkedList[2] = data.correct_message;
            const _editAnswer = {...editAnswer}
            for(let i=0; i<data.answer_data?.length; i++){
                _editAnswer[i] = false
            }
            setFormValues(data);
            setEditAnswer(_editAnswer);
            setCheckedList(_checkedList);
            setEditQuestionData(data); 
            setAnswerPoints(data.points_per_answer);
            if (0 !== data.featured_media) {
                apiFetch(
                {
                    path: "/wp/v2/media/" + data.featured_media,
                    method: 'GET',
                }
                ).then((data) => {
                    setFeaturedImage({
                        id: data.featured_media,
                        url: data.source_url
                    });
                })
            }
            setQuestionType(data.question_type);
        });
    }

    const confirmDraft = () => {
        setShowQDLoader(true);
        openConfirmModal({
            modal: 'switch-draft',
            title: __('Switch to draft', 'wdm_instructor_role'),
            children: (
                <Text size="sm">
                    {sprintf(__('Are you sure you want to unpublish this %s? ', 'wdm_instructor_role'), ir_fqb_loc.lower_question_label)}
                    {sprintf(__('This will be saved as draft. Make sure to publish it before updating the %s ', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)}
                </Text>
            ),
            labels: { confirm: 'Yes', cancel: 'Cancel' },
            confirmProps: { color: 'red' },
            modalId: "bgdvbsj",
            onCancel: () => setShowQDLoader(false),
            onConfirm: () => UpdateQuestion('draft'),
        });
    }


    useEffect(() => {
        wp.editor.initialize(
            'ir-question-content',
            {
                tinymce: {
                    setup:function(ed) {
                        ed.on('keyup change', function(e) {
                            setQuestionDescription(ed);
                        });
                    },
                    wpautop: true,
                    height: '300px',
                    plugins: 'charmap colorpicker compat3x directionality hr image lists media paste tabfocus textcolor wordpress wpautoresize wpdialogs wpeditimage link',
                    toolbar1: 'formatselect bold italic underline strikethrough | bullist numlist | blockquote hr wp_more | alignleft aligncenter alignright | link unlink |  media wp_add_media'
                },
                quicktags: false,
                mediaButtons: true,

            }
        );
        sortAnswers();
    }, [editQuestionData]);

    const sortAnswers = () => {
        jQuery(".ir-sortable-answers").sortable();
        jQuery(".ir-sortable-answers").sortable('destroy');
        setTimeout(function () {
            jQuery(".ir-sortable-answers").sortable({
                stop: function (event, ui) {
                    const toIndex = parseInt(jQuery(ui.item).index());
                    jQuery(".ir-sortable-answers").sortable('cancel');
                    const fromIndex = parseInt(jQuery(ui.item).index());
                    const _editQuestionData = {...editQuestionData}
                    const element = _editQuestionData.answer_data[fromIndex];
                    _editQuestionData.answer_data.splice(fromIndex, 1);
                    _editQuestionData.answer_data.splice(toIndex, 0, element);
                    setEditQuestionData(_editQuestionData);
                }
            })
        })
    }

    useEffect(() => {
        if (questionType === 'cloze_answer'){
            wp.editor.remove('ir-assessment-content');
            wp.editor.initialize(
                'ir-cloze-content',
                {
                    tinymce: {
                        setup:function(ed) {
                            ed.on('keyup change', function(e) {
                                setAnswerDescription(ed);
                            });
                        },
                        wpautop: true,
                        height: '300px',
                        plugins: 'charmap colorpicker compat3x directionality hr image lists media paste tabfocus textcolor wordpress wpautoresize wpdialogs wpeditimage link',
                        toolbar1: 'formatselect bold italic underline strikethrough | bullist numlist | blockquote hr wp_more | alignleft aligncenter alignright | link unlink |  media wp_add_media'
                    },
                    quicktags: false,
                    mediaButtons: true,

                }
            );
            
        }
        else if(questionType === 'assessment_answer'){
            wp.editor.remove('ir-cloze-content');
            wp.editor.initialize(
                'ir-assessment-content',
                {
                    tinymce: {
                        setup:function(ed) {
                            ed.on('keyup change', function(e) {
                                setAnswerDescription(ed);
                            });
                        },
                        wpautop: true,
                        height: '300px',
                        plugins: 'charmap colorpicker compat3x directionality hr image lists media paste tabfocus textcolor wordpress wpautoresize wpdialogs wpeditimage link',
                        toolbar1: 'formatselect bold italic underline strikethrough | bullist numlist | blockquote hr wp_more | alignleft aligncenter alignright | link unlink |  media wp_add_media'
                    },
                    quicktags: false,
                    mediaButtons: true,

                }
            );
        }
        else {
            wp.editor.remove('ir-cloze-content');
            wp.editor.remove('ir-assessment-content');
        }

        if(questionType === 'single' || questionType === 'multiple'){
            const _editAnswer = {...editAnswer}
            for(let i=0; i<editQuestionData?.answer_data?.length; i++){
                _editAnswer[i] = false
            }
            setEditAnswer(_editAnswer);
        }
        
    }, [questionType, editQuestionData]);

    return (
        <>
            <Modal className="ir-topic-modal"
                opened={opened}
                onClose={() => {
                    setOpened(false)
                    wp.editor.remove('ir-question-content');
                    wp.editor.remove('ir-cloze-content');
                    wp.editor.remove('ir-assessment-content');
                }}
                title={sprintf(__('%s', 'wdm_instructor_role'), ir_fqb_loc.question_label)}
                size='830px'
            >
                <form onSubmit={editQuestionForm.onSubmit(UpdateQuestion, handleErrors)}>
                    {editQuestionData !== null && (
                    <Tabs defaultValue="Question" styles={{
                        tab: {
                            color: '#A0A3BD',
                            fontSize: "16px",
                            '&[data-active]': {
                                color: '#000000',
                            },
                        },

                    }}>
                        <Tabs.List>
                           <Tabs.Tab value="Question">{sprintf(__('%s', 'wdm_instructor_role'), ir_fqb_loc.question_label)}</Tabs.Tab>
                           <Tabs.Tab value="Answer">{__('Answer', 'wdm_instructor_role')}</Tabs.Tab>
                        </Tabs.List>
                        <Tabs.Panel className="ir-panel-overflow" value="Question" pt="lg">
                            <Group align="center" mt={10}>
                                <TextInput className="ir-tt-text ir-parent-settings ir-flex-1 ir-question-name"
                                    label={sprintf(__('%s title', 'wdm_instructor_role'), ir_fqb_loc.question_label)}
                                    placeholder={__('Write title here (only used for internal purpose)', 'wdm_instructor_role')}
                                    size="lg"
                                    defaultValue={editQuestionData.title}
                                    {...editQuestionForm.getInputProps('_title')}
                                />
                            </Group>
                            <Text color="#6F717C" size={12} mt={5}>{sprintf(__('Note : %s title is only used for internal purpose like better %s management. This is not displayed on the %s page', 'wdm_instructor_role'), ir_fqb_loc.question_label, ir_fqb_loc.lower_question_label, ir_fqb_loc.lower_quiz_label)}</Text>
                            <Group mb={34} mt={20} p={8} className="ir-featured-image-section">
                               {null === featured_image && (
                                   <MediaUpload
                                       onSelect={(media) => {
                                           setFeaturedImage({
                                               id: media.id,
                                               url: media.url
                                           });
                                           setEditQuestionData({
                                              ...editQuestionData,
                                              featured_media: media.id
                                            })
                                       }}
                                       allowedTypes={['image']}
                                       render={({ open }) => (
                                           <Group>
                                               <img src={require('/images/featured-placeholder.png')} />
                                               <Button fw={400} className="ir-btn-subtle" onClick={open} leftIcon={<PhotoUp size={23} strokeWidth={1} />}  >{__('Set Featured Image', 'wdm_instructor_role')}</Button>
                                           </Group>
                                       )}
                                   />
                               )}
                               {null !== featured_image && (
                                   <Group>
                                       <div style={{ width: 88, marginLeft: 'auto', marginRight: 'auto' }}>
                                           <Image
                                               width={88}
                                               height={61}
                                               radius="md"
                                               src={featured_image.url}
                                           />
                                       </div>
                                       <div>
                                           <MediaUpload
                                               onSelect={(media) => {
                                                   setFeaturedImage({
                                                       id: media.id,
                                                       url: media.url
                                                   });
                                                   setEditQuestionData({
                                                       ...editQuestionData,
                                                       featured_media: media.id
                                                   })
                                               }}
                                               allowedTypes={['image']}
                                               value={featured_image.id}
                                               render={({ open }) => (
                                                   <>
                                                       <Button fw={400} className="ir-btn-subtle" onClick={open} leftIcon={<Replace size={23} strokeWidth={1} />} >{__('Replace', 'wdm_instructor_role')}</Button>
                                                       <Button fw={400} className="ir-btn-subtle ir-red-txt" onClick={() => {
                                                           setFeaturedImage(null);
                                                           setEditQuestionData({
                                                               ...editQuestionData,
                                                               featured_media: null
                                                           })
                                                       }} leftIcon={<Trash size={23} strokeWidth={1} />} >{__('Remove', 'wdm_instructor_role')}</Button>
                                                   </>
                                               )}
                                           />
                                       </div>
                                   </Group>
                                )}
                            </Group>
                            <Text mt={10} className="ir-d-flex ir-capitalize-letter" size={16} fw={600}>
                                {sprintf(__('%s type', 'wdm_instructor_role'), ir_fqb_loc.question_label)}
                            </Text>
                            <Select mt={10}
                                className="lh-1 ir-select-width-250"
                                size="sm"
                                data={questionTypeData}
                                itemComponent={SelectItem}
                                placeholder="Question Type"
                                value={questionType}
                                onChange={(e) => setQuestionTypeFunc(e) }

                            />
                            <Group spacing="xs" mt={32} mb={34}>
                                <Group position="apart" className="w-100">
                                <Text className="ir-parent-settings ir-d-flex ir-capitalize-letter" size="lg">
                                    {sprintf(__('%s', 'wdm_instructor_role'), ir_fqb_loc.question_label)}
                                    <div className="ir-textinfo">
                                        <Tooltip p={15} multiline width={260} label={sprintf(__('You have to write your %s here. In case of fill in the blanks, matrix or any other type will be created on the next Answer page.', 'wdm_instructor_role'), ir_fqb_loc.lower_question_label)} withArrow>
                                            <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'}/></Button>
                                        </Tooltip>
                                    </div>
                                </Text>
                                <Text c="#6F717C" size={12}>
                                    {sprintf(__('Write %s here and answer on the next page', 'wdm_instructor_role'), ir_fqb_loc.lower_question_label)}
                                </Text>
                                </Group>
                                <Textarea id="ir-question-content" className="w-100"
                                    {...editQuestionForm.getInputProps('question')}
                                />
                            </Group>
                            <Group className='ir-parent-settings' position="apart" align="center" mb={10}>
                                <Text className="ir-capitalize-letter" size={16} fw={600}>{__('Points', 'wdm_instructor_role')}</Text>
                                <Text className="ir-section-name ir-capitalize-letter " size={12}>{sprintf(__('Points for this %s (Standard is 1 point)', 'wdm_instructor_role'), ir_fqb_loc.lower_question_label)}</Text>
                            </Group>
                            <div className="ir-module-settings">
                                <TextInput className="ir-input-settings ir-right-label ir-text-desc ir-points"
                                    disabled={answerPoints && (questionType !== 'essay')}
                                    placeholder=""
                                    label="Points"
                                    labelPosition="right"
                                    description={sprintf(__('These points will be rewarded, only if the user chooses the %s correctly', 'wdm_instructor_role'), ir_fqb_loc.lower_question_label)}
                                    styles={{ input: { width: 85, borderRadius: '6px' } }}
                                    defaultValue={editQuestionData.points_total}
                                    {...editQuestionForm.getInputProps('points_total')}
                                />
                                <Group className="ir-parent-settings" spacing="xs" mt={15}>
                                    <Checkbox 
                                        disabled={questionType === 'assessment_answer' || questionType === 'essay'}
                                        defaultChecked={editQuestionData.points_per_answer}
                                        key={editQuestionData.points_per_answer}
                                        value="Different points for each answer" label={__('Different points for each answer', 'wdm_instructor_role')} 
                                        description={__('If you enable this option, you can enter different points for every answer.', 'wdm_instructor_role')} 
                                        {...editQuestionForm.getInputProps('points_per_answer')}
                                        onChange={(event) => answerPointsHandling(event.target.checked)}
                                    />
                                </Group>
                                <Group className="ir-parent-settings" spacing="xs" mt={15}>
                                    <Checkbox 
                                        disabled={!answerPoints || (questionType === 'assessment_answer' || questionType === 'essay')}
                                        defaultChecked={editQuestionData.points_show_in_message}
                                        value="Show reached points in the correct- and incorrect message?" label={__('Show reached points in the correct- and incorrect message?', 'wdm_instructor_role')}
                                        {...editQuestionForm.getInputProps('points_show_in_message')}
                                    />
                                </Group>
                            </div>
                            <div className="ir-module-settings ir-mt-25 ir-single-setting">
                                <Switch onClick={() => handleChange(1)} className={checkedList[1] ? 'ir-checked ir-course-access-p-settings ir-switch ir-parent-settings ir-material' : 'ir-unchecked ir-course-access-p-settings ir-switch ir-parent-settings ir-material'} mt={10} mb={10}
                                    labelPosition="left"
                                    label={__('Hint', 'wdm_instructor_role')}
                                    size="md"
                                    key={editQuestionData.hints_enabled}
                                    defaultChecked={editQuestionData.hints_enabled}
                                    {...editQuestionForm.getInputProps('hints_enabled')}
                                />
                                <div className="ir-conditional-settings">
                                    <Textarea id="ir-hint-message" mb={20} minRows={3}
                                        defaultValue={editQuestionData.hints_message}
                                        {...editQuestionForm.getInputProps('hints_message')}
                                    />
                                </div>
                            </div>
                        </Tabs.Panel>
                        <Tabs.Panel className="ir-panel-overflow" value="Answer" pt="lg">
                            <Group position="apart" mb={10} mt={10}>
                                <Text className="ir-parent-settings">{__('ANSWER', 'wdm_instructor_role')}</Text>
                                <Group align="center">
                                    <Text className="ir-parent-settings">{sprintf(__('%s type', 'wdm_instructor_role'), ir_fqb_loc.question_label)}</Text>
                                    <Select
                                        className="lh-1"
                                        size="xs"
                                        placeholder="Question Type"
                                        data={[
                                            { value: 'single', label: __('Single Choice', 'wdm_instructor_role') },
                                            { value: 'multiple', label: __('Multiple Choice', 'wdm_instructor_role') },
                                            { value: 'free_answer', label: __('Free Choice', 'wdm_instructor_role') },
                                            { value: 'matrix_sort_answer', label: __('Matrix Sorting Choice', 'wdm_instructor_role') },
                                            { value: 'sort_answer', label: __('Sorting Choice', 'wdm_instructor_role') },
                                            { value: 'cloze_answer', label: __('Fill in the blanks', 'wdm_instructor_role') },
                                            { value: 'assessment_answer', label: __('Assessment', 'wdm_instructor_role') },
                                            { value: 'essay', label: __('Essay/Open Answer', 'wdm_instructor_role') }
                                        ]}
                                        value={questionType}
                                        onChange={(e) => setQuestionTypeFunc(e) }

                                    />
                                </Group>
                            </Group>
                            <div className="ir-quiz-answers">
                                {editQuestionData.answer_data?.length < 1 && (questionType === 'single' || questionType === 'multiple') && (
                                    <Text align="center" fw={700} c="#000000" size={16} mb={23}>{sprintf(__('%s have no answers', 'wdm_instructor_role'), ir_fqb_loc.question_label)}</Text>
                                )}
                                {(questionType==='sort_answer') && (
                                    <Text size={14} fw={400} c="#6F717C" mb={23}>
                                        <b>{__('Note: ', 'wdm_instructor_role')}</b>
                                        {__('Please sort the answers in right order. The answers will be displayed randomly.', 'wdm_instructor_role')} <br />
                                    </Text>
                                )}
                                {(questionType === 'single' || questionType === 'multiple' || questionType === 'sort_answer') && (
                                    <div>
                                        <div className="ir-sortable-answers">
                                            {null !== editQuestionData && editQuestionData.answer_data?.map(( answer , index) => (
                                                <div className="ir-sortable-container">
                                                    {editAnswer[index] === false && (
                                                        <Paper className={(answer._correct && questionType !== 'sort_answer') ? "ir-fed-answers ir-correct" : "ir-fed-answers"} mb={16} radius="lg" p="sm" withBorder>
                                                            <Group align="center" spacing="xs" position="apart">
                                                                <Group className="ir-quizzes-acc-top" align="center">
                                                                    <GridDots
                                                                        size={20}
                                                                        strokeWidth={2}
                                                                        color={'#2067FA'}
                                                                    />
                                                                    <Group align="center" spacing="xs">
                                                                        <div style={{ width: 580 }}>
                                                                            <Text fz="md" fw={600} c="#222222" truncate>{answer._answer}</Text>
                                                                            <input id={"ir-builder-element-"} className='ir-builder-quiz' type="hidden" />
                                                                        </div>
                                                                        
                                                                    </Group>
                                                                </Group>
                                                                <Group align="center" spacing="sm">
                                                                    <PencilMinus
                                                                        size={24}
                                                                        strokeWidth={2}
                                                                        color={'#2067FA'}
                                                                        onClick={() => {
                                                                            const _editAnswer = {...editAnswer}
                                                                            _editAnswer[index] = true
                                                                            setEditAnswer(_editAnswer)

                                                                        }}
                                                                    />
                                                                    <X onClick={() => removeAnswer(index)}
                                                                        size={24}
                                                                        strokeWidth={2}
                                                                        color={'#2067FA'}
                                                                    />
                                                                </Group>
                                                            </Group>
                                                        </Paper>
                                                    )}
                                                    {editAnswer[index] === true && (
                                                        <Group className={`ir-answer-section ir-border br-10 ${answer._correct ? "ir-correct" : ""}`} mb={16} p={15}>
                                                            <div className="w-100">
                                                                <Textarea className="ir-flex-1" minRows={3}
                                                                    key={answer._answer}
                                                                    defaultValue={answer._answer} 
                                                                    {...editQuestionForm.getInputProps('_editanswer'+index)}
                                                                    error={error['_editanswer'+index]}
                                                                />
                                                                <Group mt={15} position="apart">
                                                                    <Group>
                                                                        <MediaUpload
                                                                            onSelect={(media) => {
                                                                                addMedia(media.url, answer, index)
                                                                            }}
                                                                            allowedTypes={['image']}
                                                                            render={({ open }) => (
                                                                                <Button fw={400} className="ir-btn-subtle h-auto" onClick={open} leftIcon={<PhotoUp size={23} strokeWidth={1} />}  >{__('Add media', 'wdm_instructor_role')}</Button>
                                                                            )}
                                                                        />
                                                                        <Switch className="ir-d-flex" label={__('Allow HTML', 'wdm_instructor_role')}
                                                                            defaultChecked={answer._html}
                                                                            {...editQuestionForm.getInputProps('_edithtml'+index)}
                                                                        />
                                                                    </Group>
                                                                    <Group align="center" spacing="md">
                                                                        {answerPoints && (
                                                                            <TextInput className="ir-input-settings input-p-0 label-spacing-10" label={__('Points', 'wdm_instructor_role')} styles={{ input: { height: 32, width: 32, borderRadius: '6px' } }} 
                                                                                defaultValue={answer._points}
                                                                                {...editQuestionForm.getInputProps('_editpoints'+index)}
                                                                            />
                                                                        )}
                                                                        {questionType !== 'sort_answer' && (
                                                                            <Center>
                                                                                <Checkbox fw={600} labelPosition="left" label={__('Mark as correct answer', 'wdm_instructor_role')} 
                                                                                    defaultChecked={answer._correct}
                                                                                    {...editQuestionForm.getInputProps('_editcorrect'+index)}
                                                                                />
                                                                            </Center>
                                                                        )}
                                                                    </Group>
                                                                </Group>
                                                            </div>
                                                            <Group position="apart" align="center" spacing="xs" className="w-100" mt={15}>
                                                                <Button onClick={() => {
                                                                    const _editAnswer = {...editAnswer}
                                                                    _editAnswer[index] = false
                                                                    setEditAnswer(_editAnswer)
                                                                    removeAnswer(index)
                                                                }} fw={400} className="ir-btn-subtle ir-red-txt" leftIcon={<Trash size={23} strokeWidth={1} />}  >{__('Delete', 'wdm_instructor_role')}</Button>
                                                                <Group spacing={0}>
                                                                    <Button className="ir-btn-subtle" onClick={() => {
                                                                        const _editAnswer = {...editAnswer}
                                                                        _editAnswer[index] = false
                                                                        setEditAnswer(_editAnswer)
                                                                    }}
                                                                        variant="subtle" size="xs">{__('Cancel', 'wdm_instructor_role')}</Button>
                                                                    <Button className="ir-btn-filled" onClick={() => saveAnswerData(index, answer, editQuestionData.question_type)} size="xs">{__('Save', 'wdm_instructor_role')}</Button>
                                                                </Group>
                                                            </Group>
                                                        </Group>
                                                    )}
                                                </div>
                                            ))}
                                        </div>
                                        {addNewAnswer &&
                                            <Group className="ir-answer-section ir-border br-10" p={15}>
                                                <div className="w-100">
                                                    <Textarea className="ir-flex-1" minRows={3}
                                                        value={newAnswerText?.text}
                                                        {...editQuestionForm.getInputProps('_answer')}
                                                        error={error.answer}
                                                    />
                                                    <Group mt={15} position="apart">
                                                        <Group>
                                                            <MediaUpload
                                                                onSelect={(media) => {
                                                                    addMediaToNewAnswer(media.url)
                                                                }}
                                                                allowedTypes={['image']}
                                                                render={({ open }) => (
                                                                    <Button fw={400} className="ir-btn-subtle h-auto" onClick={open} leftIcon={<PhotoUp size={23} strokeWidth={1} />}  >{__('Add media', 'wdm_instructor_role')}</Button>
                                                                )}
                                                            />
                                                            <Switch 
                                                                className="ir-d-flex" label={__('Allow HTML', 'wdm_instructor_role')}
                                                                {...editQuestionForm.getInputProps('_html')}
                                                            />
                                                        </Group>
                                                        <Group align="center" spacing="md">
                                                            {answerPoints && (
                                                                <TextInput className="ir-input-settings input-p-0 label-spacing-10" label={__('Points', 'wdm_instructor_role')} styles={{ input: { height: 32, width: 32, borderRadius: '6px' } }}
                                                                    {...editQuestionForm.getInputProps('_points')}
                                                                />
                                                            )}
                                                            {questionType !== 'sort_answer' && (
                                                                <Center>
                                                                    <Checkbox fw={600} labelPosition="left" label={__('Mark as correct answer', 'wdm_instructor_role')} 
                                                                        {...editQuestionForm.getInputProps('_correct')}
                                                                    />
                                                                </Center>
                                                            )}
                                                        </Group>
                                                    </Group>
                                                </div>
                                                <Group position="apart" align="center" spacing="xs" className="w-100" mt={15}>
                                                    <Button fw={400} className="ir-btn-subtle ir-red-txt" leftIcon={<Trash size={23} strokeWidth={1} />}  >{__('Delete', 'wdm_instructor_role')}</Button>
                                                    <Group spacing={0}>
                                                        <Button className="ir-btn-subtle" onClick={() => setAddNewAnswer(false)} variant="subtle" size="xs">{__('Cancel', 'wdm_instructor_role')}</Button>
                                                        <Button className="ir-btn-filled" onClick={() => addAnswer()} size="xs">{__('Save', 'wdm_instructor_role')}</Button>
                                                    </Group>
                                                </Group>
                                            </Group>
                                        }
                                        <Group align="center" spacing="sm" position="center" mt={25}>
                                            <Button onClick={() => setAddNewAnswer(true)} size="md" className="ir-btn-filled" radius="md" variant="filled" leftIcon={<Plus size={18} color={'#ffffff'} />}>
                                                {__('Add new Answer', 'wdm_instructor_role')}
                                            </Button>
                                        </Group>
                                    </div>
                                )}

                                {questionType === 'free_answer' && (
                                    <div>
                                    <Text size={14} fw={400} c="#6F717C" mb={23}>
                                        <b>{__('Note: ', 'wdm_instructor_role')}</b>
                                        {__('Correct answers (one per line) (answers will be converted to lower case). If mode "Different points for each answer" is activated, you can assign points to each answer using "|". Example: One|15. The default point value is 1.', 'wdm_instructor_role')} <br />
                                    </Text>
                                    <Textarea id="ir-sort-answer"
                                        minRows={4}
                                        {...editQuestionForm.getInputProps('free_answer')}
                                    />
                                    </div>
                                )}

                                <MatrixAnswer 
                                    questionType={questionType}
                                    editQuestionData={editQuestionData}
                                    editQuestionForm={editQuestionForm}
                                    setEditQuestionData={setEditQuestionData}
                                    answerPoints={answerPoints}
                                />

                                {questionType === 'cloze_answer' && (
                                    <div>
                                    <Text size={14} fw={400} c="#6F717C" mb={23}>
                                        <b>{__('Note: ', 'wdm_instructor_role')}</b>
                                        {__('Enclose the searched words with {}; e.g. I {play} soccer. Capital and small letters will be ignored.', 'wdm_instructor_role')} <br />
                                        {__('You can specify multiple options for a search word. Enclose the word with [ ] e.g. I {[play][love][hate]} soccer. In this case answers "play", "love" OR "hate" are correct.', 'wdm_instructor_role')} <br />
                                        {__('If mode "Different points for each answer" is activated, you can assign points to each answer using |. The default point value is be 1.', 'wdm_instructor_role')} <br />
                                        {__('I play {[football][soccer|2][golf|5]}. In this example there are three possible answer, "football" is 1 point, "soccer" is 2 points, and "golf" is 5 point.', 'wdm_instructor_role')} <br />
                                        {__('The total possible points will be the total of the highest points values from each answer set.', 'wdm_instructor_role')}
                                    </Text>
                                    <Textarea id="ir-cloze-content"
                                        defaultValue={editQuestionData.answer_data ? editQuestionData.answer_data[0]?._answer : ''}
                                        {...editQuestionForm.getInputProps('cloze_answer')}
                                    />
                                    </div>
                                )}

                                {questionType === 'assessment_answer' && (
                                    <div>
                                    <Text size={14} fw={400} c="#6F717C" mb={23}>
                                        <b>{__('Note: ', 'wdm_instructor_role')}</b>
                                        {__('Here you can create an assessment question.', 'wdm_instructor_role')} <br />
                                        {__('Enclose a assesment with {}. The individual assessments are marked with [].', 'wdm_instructor_role')} <br />
                                        {__('The number of options in the maximum score.', 'wdm_instructor_role')} <br />
                                        {__('Examples:', 'wdm_instructor_role')} <br />
                                        {__('* less true {[1] [2] [3] [4] [5]} more true', 'wdm_instructor_role')} <br />
                                        {__('* less true {[a] [b] [c]} more true', 'wdm_instructor_role')} <br />
                                    </Text>
                                    <Textarea id="ir-assessment-content"
                                        defaultValue={editQuestionData.answer_data ? editQuestionData.answer_data[0]?._answer : ''}
                                        {...editQuestionForm.getInputProps('cloze_answer')}
                                    />
                                    </div>
                                )}

                                {questionType === 'essay' && (
                                    <div>
                                    <Select
                                        className="lh-1 ir-open-answer"
                                        size="md"
                                        placeholder="Submission Type"
                                        data={[
                                            { value: 'text', label: __('Open Answer', 'wdm_instructor_role') },
                                            { value: 'upload', label: __('Upload', 'wdm_instructor_role') },
                                        ]}
                                        {...editQuestionForm.getInputProps('_gradedType')}
                                    />
                                    <Text size={14} fw={400} c="#6F717C" mb={15} mt={15}>
                                        <b>{__('Note: ', 'wdm_instructor_role')}</b>
                                        {__('This is a question that can be graded and potentially prevent a user from progressing to the next step of the course.', 'wdm_instructor_role')} <br />
                                        {__('The user can only progress if the essay is marked as "Graded" and if the user has enough points to move on.', 'wdm_instructor_role')} <br />
                                        {__('How should the answer to this question be marked and graded upon quiz submission?', 'wdm_instructor_role')}
                                    </Text>
                                    <Select
                                        className="lh-1 ir-sub-type"
                                        size="md"
                                        placeholder="Grading Type"
                                        data={[
                                            { value: 'not-graded-none', label: __('Not Graded, No Points Awarded', 'wdm_instructor_role') },
                                            { value: 'not-graded-full', label: __('Not Graded, Full Points Awarded', 'wdm_instructor_role') },
                                            { value: 'graded-full', label: __('Graded, Full Points Awarded', 'wdm_instructor_role') }
                                        ]}
                                        {...editQuestionForm.getInputProps('_gradingProgression')}
                                    />
                                    </div>
                                )}
                                
                            </div>
                            {questionType !== 'assessment_answer' && questionType !== 'essay' && (
                                <div>
                                    <Switch mt={25} onChange={() => handleChange(0)} className={checkedList[0] ? 'ir-checked ir-course-access-p-settings ir-switch ir-parent-settings ir-material' : 'ir-unchecked ir-course-access-p-settings ir-switch ir-parent-settings ir-material'} mb={10}
                                        labelPosition="left"
                                        label={__('Wrong Answer message', 'wdm_instructor_role')}
                                        size="md"
                                        key={editQuestionData.incorrect_message}
                                        defaultChecked={editQuestionData.incorrect_message === "" ? false : true}
                                    />
                                    <div className="ir-conditional-settings">
                                        <Textarea id="ir-wrong-message" minRows={3}
                                            defaultValue={editQuestionData.incorrect_message}
                                            {...editQuestionForm.getInputProps('incorrect_message')}
                                        />
                                    </div>
                                </div>
                            )}
                            <Switch mt={25} onChange={() => handleChange(2)} className={checkedList[2] ? 'ir-checked ir-course-access-p-settings ir-switch ir-parent-settings ir-material' : 'ir-unchecked ir-course-access-p-settings ir-switch ir-parent-settings ir-material'} mb={10}
                                labelPosition="left"
                                label={questionType === 'essay' ? __('Message after essay is submitted', 'wdm_instructor_role') : __('Right Answer message', 'wdm_instructor_role')}
                                size="md"
                                key={editQuestionData.correct_message}
                                defaultChecked={editQuestionData.correct_message === "" ? false : true}
                            />
                            <div className="ir-conditional-settings">
                                <Textarea id="ir-right-message" minRows={3}
                                    defaultValue={editQuestionData.correct_message}
                                    {...editQuestionForm.getInputProps('correct_message')}
                                />
                            </div>
                        </Tabs.Panel>
                    </Tabs>
                    )}
                    <Group spacing="xs" mt={34} className="ir-tm-bottom-actions" position="apart" align="center">
                        <Group>
                        </Group>
                        <Group spacing="xs">
                            <Button className="ir-btn-outline" onClick={() => {
                                        {editQuestionData?.post_data.post_status === 'draft' && (
                                            UpdateQuestion('draft')
                                        )}
                                        {editQuestionData?.post_data.post_status === 'publish' && (
                                            confirmDraft()
                                        )}
                                        
                                    }   
                                } variant="outline" disabled={showQDLoader}>
                                {editQuestionData?.post_data.post_status === 'draft' && (
                                __('Save to draft', 'wdm_instructor_role')
                                )}
                                {editQuestionData?.post_data.post_status === 'publish' && (
                                __('Switch to draft', 'wdm_instructor_role')
                                )}
                                {showQDLoader && <Loader color="#2067FA" ml={10} size={15} />}
                            </Button>
                            <Button
                                className="ir-btn-filled" variant="filled" type="submit" disabled={showQLoader}>
                                {editQuestionData?.post_data.post_status === 'draft' && (
                                __('Publish', 'wdm_instructor_role')
                                )}
                                {editQuestionData?.post_data.post_status === 'publish' && (
                                __('Update', 'wdm_instructor_role')
                                )}
                                {showQLoader && <Loader color="#ffffff" ml={10} size={15} />}
                            </Button>
                        </Group>
                    </Group>
                </form>
            </Modal>

            <PencilMinus
                onClick={() => openEditQuestionModal()}
                size={24}
                strokeWidth={2}
                color={'#2067FA'}
            />
        </>
    );
}