import { useState, useEffect } from 'react';

import {
    Text,
    Input,
    Group,
    TextInput,
    Switch,
    Radio,
    NumberInput,
    Select,
    Tooltip,
    Button,
    Checkbox,
    Popover,
    Textarea,
    Alert
} from '@mantine/core';
import { showNotification } from '@mantine/notifications';
import { openConfirmModal } from '@mantine/modals';

import { InfoCircle, X, Plus, PencilMinus, GridDots, AlertCircle } from 'tabler-icons-react';

import { __ } from "@wordpress/i18n";
import apiFetch from '@wordpress/api-fetch';

export default function AdminDataHandling(props) {

    const [checkedList, setCheckedList] = useState([props.quizData.statistics_enabled, props.quizData.email_enabled, props.wisdmQuizData?.statistics_ip_lock_enabled, props.wisdmQuizData?.time_limit_cookie > 0 ? true : false, props.wisdmQuizData?.time_limit_cookie > 0 ? true : false, false, false, props.wisdmQuizData?.toplist_enabled, props.wisdmQuizData?.toplist_data_add_multiple, props.wisdmQuizData?.toplist_data_showin_enabled, props.wisdmQuizData?.custom_fields?.length > 0 ? true : false]);
    const handleChange = (index) => {
        const _checkedList = [...checkedList];
        _checkedList[index] = !_checkedList[index];
        setCheckedList(_checkedList);
    }
    const [isEditable, setIsEditable] = useState([]);
    const { customField, setCustomField } = props;
    const [template_loading, setTemplateLoader] = useState(false);
    const { save_template, setSaveTemplate } = props;

    useEffect(() => {
        const _checkedList = [...checkedList];
        _checkedList[2] = props.wisdmQuizData?.statistics_ip_lock_enabled;
        _checkedList[4] = props.wisdmQuizData?.time_limit_cookie > 0 ? true : false;
        _checkedList[5] = props.wisdmQuizData?.time_limit_cookie > 0 ? true : false;
        _checkedList[7] = props.wisdmQuizData?.toplist_enabled;
        _checkedList[8] = props.wisdmQuizData?.toplist_data_add_multiple;
        _checkedList[9] = props.wisdmQuizData?.toplist_data_showin_enabled;
        _checkedList[10] = props.wisdmQuizData?.custom_fields.length > 0 ? true : false;
        setCheckedList(_checkedList);
        if (props.quizForm.values.toplist_data_add_permissions === '') {
            props.quizForm.setValues({
                toplist_data_add_permissions: '1'
            })
        }
        if (props.quizForm.values.toplist_data_sort === '') {
            props.quizForm.setValues({
                toplist_data_sort: '1'
            })
        }
        props.quizForm.setValues({
            custom_field_display_position: (props.quizForm.values.custom_field_display_position === undefined || props.quizForm.values.custom_field_display_position === '') ? "0" : props.quizForm.values.custom_field_display_position
        })
    }, [props.wisdmQuizData]);

    const addNewField = () => {
        const _customField = [...customField];
        const index = _customField.length + 1;
        const editableIndex = _customField.length - 1;
        const field = {};
        field.fieldName = 'Field ' + index;
        field.fieldType = '0';
        field.required = false;
        const _isEditable = [...isEditable];
        _isEditable[_customField.length] = false;
        setIsEditable(_isEditable);
        _customField.push(field);
        setCustomField(_customField);
    }

    const removeCustomField = (index) => {
        const _customField = [...customField];
        const _isEditable = [...isEditable];
        _isEditable[index] = false;
        _isEditable.splice(index, 1);
        setIsEditable(_isEditable);
        _customField.splice(index, 1);
        setCustomField(_customField);
    }

    const SaveEditedFields = (e, index, field) => {
        // console.log(e);
        const _customField = [...customField];
        const _isEditable = [...isEditable];
        if (e === '7' || e === '8') {
            _isEditable[index] = true;
            setIsEditable(_isEditable);
        }
        else {
            _isEditable[index] = false;
            setIsEditable(_isEditable);
        }
        _customField[index][field] = e.target ? e.target.value : e;
        setCustomField(_customField);
    }

    const editList = (e, index) => {
        const _customField = [...customField];
        _customField[index].fieldData = props.quizForm.values['add_list' + index] !== undefined ? props.quizForm.values['add_list' + index] : _customField[index].fieldData;
        setCustomField(_customField);
        jQuery(e.target).parents('.ir-field-popover').prev().trigger('click');
    }

    useEffect(() => {
        sortFields();
    }, [customField]);

    const sortFields = () => {
        jQuery(".ir-sortable-fields").sortable();
        jQuery(".ir-sortable-fields").sortable('destroy');
        setTimeout(function () {
            jQuery(".ir-sortable-fields").sortable({
                stop: function (event, ui) {
                    const toIndex = parseInt(jQuery(ui.item).index());
                    jQuery(".ir-sortable-fields").sortable('cancel');
                    const fromIndex = parseInt(jQuery(ui.item).index());
                    const _customField = [...customField]
                    const element = _customField[fromIndex];
                    _customField.splice(fromIndex, 1);
                    _customField.splice(toIndex, 0, element);
                    setCustomField(_customField);
                }
            })
        })
    }

    const getSaveTemplateData = () => {
        let _quiz_templates = [...props.wisdmQuizData.quiz_templates];
        _quiz_templates.unshift({
            label: __('Create New Template', 'wdm_instructor_role'),
            value: 'new'
        });

        return _quiz_templates;
    }

    const loadTemplate = () => {
        setTemplateLoader(true);
        openConfirmModal({
            modal: 'switch-draft',
            title: sprintf(__('Load %s Settings Template', 'wdm_instructor_role'), ir_fqb_loc.quiz_label),
            children: (
                <div>
                    <Text size="sm">
                        {sprintf(__('Note: If you haven\'t saved changes you made to the %1$s, they will disappear when you apply the %1$s template. Make sure you have saved the changes (if any) before applying the template.', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)}
                    </Text>
                    <Text size="sm" mt={10}>
                        {__('Click Yes to proceed', 'wdm_instructor_role')}
                    </Text>
                </div>
            ),
            labels: { confirm: 'Yes', cancel: 'Cancel' },
            confirmProps: { color: 'red' },
            modalId: "bgdvbsj",
            onCancel: () => setTemplateLoader(false),
            onClose: () => setTemplateLoader(false),
            onConfirm: () => {
                jQuery.ajax({
                    url: ir_fqb_loc.ajax_url,
                    method: 'POST',
                    dataType: 'JSON',
                    data: {
                        action: 'ir_fqb_load_quiz_template',
                        quiz_id: props.quizData.id,
                        name: props.quizData.title.rendered,
                        template_id: props.quizForm.values.load_template_id,
                        nonce: ir_fqb_loc.template_load_nonce
                    },
                    success: function (response) {
                        if ('success' === response.status) {
                            showNotification({
                                title: __('Template loaded successfully !!', 'wdm_instructor_role')
                            });
                            setTemplateLoader(false);
                            window.location.reload();
                        }
                        setTemplateLoader(false);
                    }
                });
            },
        });
    }
    return (
        <>
            {props.wisdmQuizData && (
                <div>
                    <Switch
                        key={props.wisdmQuizData?.custom_fields?.length}
                        defaultChecked={props.wisdmQuizData?.custom_fields?.length > 0 ? true : false}
                        onClick={() => handleChange(10)} className={checkedList[10] ? 'ir-checked ir-course-access-p-settings ir-parent-settings' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings'}
                        mt={25} labelPosition="left" label={sprintf(__('Custom fields', 'wdm_instructor_role'))}
                    />
                    <div className="ir-conditional-settings ir-sortable-fields pl-0">
                        <div className="ir-sortable-fields">
                            {customField.map((field, index) => (
                                <Group mt={20} spacing="xl">
                                    <GridDots
                                        size={24}
                                        strokeWidth={2}
                                        color={'#2067FA'}
                                        className="ir-cf-handle"
                                    />
                                    <TextInput label={sprintf(__('Field name', 'wdm_instructor_role'))} styles={{ input: { width: 300 } }}
                                        value={field.fieldName}
                                        onChange={(e) => SaveEditedFields(e, index, 'fieldName')}
                                    />
                                    <div className="ir-pos-r">
                                        <Select className="ir-select-width-250"
                                            label={sprintf(__('Type', 'wdm_instructor_role'))}
                                            placeholder={__('Select an option', 'wdm_instructor_role')}
                                            data={[
                                                { value: '0', label: __('Text', 'wdm_instructor_role') },
                                                { value: '1', label: __('Textarea', 'wdm_instructor_role') },
                                                { value: '3', label: __('Checkbox', 'wdm_instructor_role') },
                                                { value: '7', label: __('Drop-Down menu', 'wdm_instructor_role') },
                                                { value: '8', label: __('Radio', 'wdm_instructor_role') },
                                                { value: '2', label: __('Number', 'wdm_instructor_role') },
                                                { value: '4', label: __('Email', 'wdm_instructor_role') },
                                                { value: '5', label: __('Yes/No', 'wdm_instructor_role') },
                                                { value: '6', label: __('Date', 'wdm_instructor_role') },
                                            ]}
                                            value={field.fieldType}
                                            onChange={(e) => SaveEditedFields(e, index, 'fieldType')}
                                        />
                                        {((isEditable[index] !== undefined && isEditable[index]) || (field.fieldType === "8" || field.fieldType === "7")) && (
                                            <Popover width={265} height={190} position="left" shadow="md">
                                                <Popover.Target>
                                                    <Button className="ir-btn-subtle ir-btn-p-0 ir-edit-field">
                                                        <PencilMinus
                                                            size={24}
                                                            strokeWidth={2}
                                                            color={'#2067FA'}
                                                        />
                                                    </Button>
                                                </Popover.Target>
                                                <Popover.Dropdown className="ir-field-popover">
                                                    <Text size={14} fw={600} mb={3}>{__('One entry per line', 'wdm_instructor_role')}</Text>
                                                    <Textarea minRows={4} defaultValue={field.fieldData}
                                                        {...props.quizForm.getInputProps('add_list' + index)}
                                                    />
                                                    <Button onClick={(e) => editList(e, index)} className="ir-btn-filled" size="xs" mt={5}>{__('Ok', 'wdm_instructor_role')}</Button>
                                                </Popover.Dropdown>
                                            </Popover>
                                        )}
                                    </div>
                                    <div className="ir-flexstart">
                                        <Text fw={600} size={14} mb={20}>{sprintf(__('Required', 'wdm_instructor_role'))}</Text>
                                        <Switch
                                            key={field.required}
                                            defaultChecked={field.required}
                                            onChange={(e) => {
                                                // console.log('e');
                                                // console.log(e);
                                                SaveEditedFields(e.target.checked, index, 'required')
                                            }
                                            }
                                        />
                                    </div>
                                    <X
                                        size={24}
                                        strokeWidth={2}
                                        color={'#FF1F00'}
                                        mt={20}
                                        className="ir-remove-field"
                                        onClick={() => removeCustomField(index)}
                                    />
                                </Group>
                            ))}
                        </div>
                        <Button fw={600} mt={15} ml={35} onClick={() => addNewField()} className="ir-btn-subtle h-auto ir-add-field" leftIcon={<Plus size={23} strokeWidth={2} />}  >{__('Add field', 'wdm_instructor_role')}</Button>
                        <Radio.Group className="ir-trs ir-display-position" mt={15} pl={26}
                            key={props.quizForm.values.custom_field_display_position}
                            defaultValue="0"
                            name="QuizRelease1"
                            orientation="vertical"
                            label={sprintf(__('Display position', 'wdm_instructor_role'))}
                            {...props.quizForm.getInputProps('custom_field_display_position')}
                        >
                            <Radio value="0" label={__('On the quiz startpage', 'wdm_instructor_role')} />
                            <Radio value="1" label={__('At the end of the quiz (before the quiz result)', 'wdm_instructor_role')} />
                        </Radio.Group>
                    </div>
                    <Switch
                        defaultChecked={props.wisdmQuizData?.toplist_enabled}
                        onClick={() => handleChange(7)} className={checkedList[7] ? 'ir-checked ir-course-access-p-settings ir-parent-settings' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings'}
                        mt={25} labelPosition="left" label={sprintf(__('Leaderboard', 'wdm_instructor_role'))}
                        {...props.quizForm.getInputProps('toplist_enabled')}
                    />
                    <div className="ir-conditional-settings">
                        <Group spacing={0} mt={25} align="center">
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {__('Who can apply', 'wdm_instructor_role')}
                            </Text>
                            <Select className="ir-select-width-400" mt={5}
                                placeholder={__('Select an option', 'wdm_instructor_role')}
                                defaultValue='1'
                                data={[
                                    { value: '1', label: __('All Users', 'wdm_instructor_role') },
                                    { value: '2', label: __('Registered users only', 'wdm_instructor_role') },
                                    { value: '3', label: __('Anonymous users only', 'wdm_instructor_role') }
                                ]}
                                {...props.quizForm.getInputProps('toplist_data_add_permissions')}
                            />
                        </Group>
                        <Group spacing={0} mt={25}>
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {sprintf(__('Multiple Applications per user', 'wdm_instructor_role'))}
                            </Text>
                            <Switch
                                defaultChecked={props.wisdmQuizData.toplist_data_add_multiple}
                                onClick={() => handleChange(8)} className={checkedList[8] ? 'ir-checked' : 'ir-unchecked'}
                                label={sprintf(__('Users can apply more than once to the leaderboard', 'wdm_instructor_role'))}
                                {...props.quizForm.getInputProps('toplist_data_add_multiple')}
                            />
                            <div className="ir-conditional-settings w-100">
                                <Group spacing={0} mt={5} mb={15}>
                                    <Text className="w-40"></Text>
                                    <div className="ir-conditional-settings-2">
                                        <Text fw={600}>{__('Re-apply after', 'wdm_instructor_role')}</Text>
                                        <NumberInput className="ir-label-right ir-jc-end" mt={15}
                                            defaultValue={0}
                                            min={0}
                                            labelPosition="right"
                                            styles={{ input: { width: 85, borderRadius: '10px' } }}
                                            label={__('Minutes', 'wdm_instructor_role')}
                                            {...props.quizForm.getInputProps('toplist_data_time')}
                                        />
                                    </div>
                                </Group>
                            </div>
                        </Group>
                        <Group spacing={0} mt={25}>
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {__('Automatic user entry', 'wdm_instructor_role')}
                            </Text>
                            <Checkbox
                                {...props.quizForm.getInputProps('toplist_data_add_automatic', { type: 'checkbox' })}
                            />
                        </Group>
                        <Group spacing={0} mt={25}>
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {__('Number of displayed entries ', 'wdm_instructor_role')}
                            </Text>
                            <NumberInput className="ir-label-right"
                                defaultValue={0}
                                min={0}
                                labelPosition="right"
                                styles={{ input: { width: 85, borderRadius: '10px' } }}
                                {...props.quizForm.getInputProps('toplist_data_show_limit')}
                            />
                        </Group>
                        <Group spacing={0} mt={25}>
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {sprintf(__('Sort list by?', 'wdm_instructor_role'))}
                            </Text>
                            <Select className="ir-select-width-400"
                                placeholder={__('Select an option', 'wdm_instructor_role')}
                                defaultValue='1'
                                data={[
                                    { value: '1', label: __('Best user', 'wdm_instructor_role') },
                                    { value: '2', label: __('Newest entry', 'wdm_instructor_role') },
                                    { value: '3', label: __('Oldest entry', 'wdm_instructor_role') }
                                ]}
                                {...props.quizForm.getInputProps('toplist_data_sort')}
                            />
                        </Group>
                        <Group spacing={0} mt={25}>
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex ir-parent-settings">
                                {sprintf(__('Display on %s results page', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)}
                            </Text>
                            <Switch
                                defaultChecked={props.wisdmQuizData?.toplist_data_showin_enabled}
                                onClick={() => handleChange(9)} className={checkedList[9] ? 'ir-checked' : 'ir-unchecked'}
                                {...props.quizForm.getInputProps('toplist_data_showin_enabled')}
                            />
                            <div className="ir-conditional-settings w-100">
                                <Group className="ir-parent-settings" spacing={0} mt={10} mb={10}>
                                    <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                    </Text>
                                    <Radio.Group
                                        defaultValue="1"
                                        name="quizResultDisplay1"
                                        orientation="vertical"
                                        {...props.quizForm.getInputProps('toplist_data_showin')}
                                    >
                                        <Radio value="1" label={__('Below the result text', 'wdm_instructor_role')}
                                        />
                                        <Radio value="2" label={__('In a button', 'wdm_instructor_role')}
                                        />

                                    </Radio.Group>
                                </Group>
                            </div>
                        </Group>
                        <Group spacing={0} mt={25}>
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {__('Really simple CAPTCHA', 'wdm_instructor_role')}
                                <div className="ir-textinfo">
                                    <Tooltip multiline width={260} p={15} label={sprintf(__('This option requires additional plugin: Really Simple CAPTCHA', 'wdm_instructor_role'))} withArrow>
                                        <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
                                    </Tooltip>
                                </div>
                            </Text>
                            <Checkbox
                                disabled={!ir_fqb_loc.is_captcha_installed}
                                {...props.quizForm.getInputProps('really_simple_captcha', { type: 'checkbox' })}
                            />
                        </Group>
                    </div>
                    <Switch
                        defaultChecked={props.quizData.statistics_enabled}
                        onClick={() => handleChange(0)} className={checkedList[0] ? 'ir-checked ir-course-access-p-settings ir-parent-settings' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings'}
                        mt={25} labelPosition="left" label={sprintf(__('%s statistics', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}
                        {...props.quizForm.getInputProps('statistics_enabled')}
                    />
                    <div className="ir-conditional-settings">
                        <Group spacing={0} mt={25} align="center">
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {__('Front-end profile display', 'wdm_instructor_role')}
                            </Text>
                            <Switch
                                defaultChecked={props.quizData.view_profile_statistics_enabled}
                                {...props.quizForm.getInputProps('view_profile_statistics_enabled')}
                            />
                        </Group>
                        <Group spacing={0} mt={25} align="center">
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {__('Statistics IP-lock', 'wdm_instructor_role')}
                            </Text>
                            {props.wisdmQuizData && (
                                <Switch
                                    key={props.wisdmQuizData?.statistics_ip_lock_enabled}
                                    defaultChecked={props.wisdmQuizData?.statistics_ip_lock_enabled}
                                    onClick={() => handleChange(2)} className={checkedList[2] ? 'ir-checked' : 'ir-unchecked'}
                                    {...props.quizForm.getInputProps('statistics_ip_lock_enabled')}
                                />
                            )}
                            {props.wisdmQuizData && (
                                <div className="ir-conditional-settings w-100">
                                    <Group spacing={0} mt={5} mb={15}>
                                        <Text className="w-40"></Text>
                                        <div className="ir-conditional-settings-2">
                                            <Text fw={600}>{__('IP-lock time limit', 'wdm_instructor_role')}</Text>
                                            <Text c="#6F717C">{__('Protect the statistics from spam. Results will only be saved every X minutes.', 'wdm_instructor_role')}</Text>
                                            <TextInput className="ir-label-right ir-jc-end" mt={15}
                                                labelPosition="right"
                                                styles={{ input: { width: 85, borderRadius: '10px' } }}
                                                label={__('minutes', 'wdm_instructor_role')}
                                                defaultValue={props.wisdmQuizData?.statistics_ip_lock_enabled_value / 60}
                                                {...props.quizForm.getInputProps('statistics_ip_lock_enabled_value')}
                                            />
                                        </div>
                                    </Group>
                                </div>
                            )}
                        </Group>
                    </div>
                    <Switch
                        defaultChecked={props.quizData.email_enabled}
                        onClick={() => handleChange(1)} className={checkedList[1] ? 'ir-checked ir-course-access-p-settings ir-parent-settings' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings'}
                        mt={20} labelPosition="left" label={__('Email notifications', 'wdm_instructor_role')}
                        {...props.quizForm.getInputProps('email_enabled')}
                    />
                    <div className="ir-conditional-settings">
                        <Group spacing={0} mt={25} align="center">
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {__('Admin', 'wdm_instructor_role')}
                            </Text>
                            {props.wisdmQuizData && (
                                <Switch
                                    defaultChecked={props.wisdmQuizData?.email_admin_enabled === 0 ? false : true}
                                    {...props.quizForm.getInputProps('email_admin_enabled')}
                                />
                            )}
                        </Group>
                        <Group spacing={0} mt={10} align="center">
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            </Text>
                            <div>
                                <Text fw={700}>{__('Email trigger', 'wdm_instructor_role')}</Text>
                                <Text color="#6F717C">{sprintf(__('The admin will receive an email notification when the following users have taken the %s', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)}</Text>
                                {props.wisdmQuizData && (
                                    <Select className="ir-select-width-400" mt={5}
                                        placeholder={__('Select an option', 'wdm_instructor_role')}
                                        defaultValue={props.wisdmQuizData?.email_admin_enabled}
                                        data={[
                                            { value: 2, label: __('All Users', 'wdm_instructor_role') },
                                            { value: 1, label: __('Registered users only', 'wdm_instructor_role') }
                                        ]}
                                        {...props.quizForm.getInputProps('email_admin_enabled')}
                                    />
                                )}

                            </div>
                        </Group>
                        <Group spacing={0} mt={25} align="center">
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {__('User', 'wdm_instructor_role')}
                            </Text>
                            <Switch
                                defaultChecked={props.quizData.email_user_enabled}
                                {...props.quizForm.getInputProps('email_user_enabled')}
                            />
                        </Group>
                    </div>
                    <Switch
                        onClick={() => handleChange(3)} className={checkedList[3] ? 'ir-checked ir-course-access-p-settings ir-parent-settings' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings'}
                        mt={20} labelPosition="left" label={sprintf(__('%s templates', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}
                    />
                    <div className="ir-conditional-settings">
                        {props.wisdmQuizData && props.wisdmQuizData?.quiz_templates && (
                            <Group spacing={0} mt={25} align="top">
                                <Text className="w-40 mantine-InputWrapper-label ir-d-flex" mt={10}>
                                    {sprintf(__('Use template', 'wdm_instructor_role'), '')}
                                </Text>
                                <div>
                                    <Alert icon={<AlertCircle size={20} />} color="red" mb={10}>
                                        {sprintf(__('Loading a template into this %s will replace ALL existing settings.', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}
                                    </Alert>
                                    <Select className="ir-select-width-400"
                                        mb={10}
                                        placeholder={__('Select an option', 'wdm_instructor_role')}
                                        data={props.wisdmQuizData.quiz_templates}
                                        {...props.quizForm.getInputProps('load_template_id')}
                                    />
                                    <Button
                                        className="ir-btn-outline"
                                        variant="outline"
                                        radius="md"
                                        size="sm"
                                        loading={template_loading}
                                        loaderPosition="right"
                                        onClick={loadTemplate}
                                    >
                                        {__('Load Template', 'wdm_instructor_role')}
                                    </Button>
                                </div>
                            </Group>
                        )}
                        {/* </div>
                    <div className="ir-conditional-settings"> */}
                        <Group spacing={0} mt={25} align="top">
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex" mt={10}>
                                {sprintf(__('Save as template', 'wdm_instructor_role'), '')}
                            </Text>
                            {props.wisdmQuizData && (
                                <div>
                                    <Select className="ir-select-width-400"
                                        placeholder={__('Select an option', 'wdm_instructor_role')}
                                        value={save_template}
                                        onChange={setSaveTemplate}
                                        data={getSaveTemplateData()}
                                    />
                                    {'new' === save_template && (
                                        <TextInput mt={15}
                                            placeholder="Enter new template name"
                                            styles={{ input: { width: 400, borderRadius: '10px' } }}
                                            {...props.quizForm.getInputProps('new_template_name')}
                                        />
                                    )}
                                </div>
                            )}
                        </Group>
                    </div>
                    {props.wisdmQuizData && (
                        <div>
                            <Switch
                                defaultChecked={props.wisdmQuizData.time_limit_cookie > 0 ? true : false}
                                onClick={() => handleChange(4)} className={checkedList[4] ? 'ir-checked ir-course-access-p-settings ir-parent-settings' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings'}
                                mt={20} labelPosition="left" label={__('Advanced settings', 'wdm_instructor_role')}
                            />
                            <div className="ir-conditional-settings">
                                <Group spacing={0} mt={25} align="center">
                                    <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                        {__('Browser cookie answer protection', 'wdm_instructor_role')}
                                        <div className="ir-textinfo">
                                            <Tooltip multiline width={260} p={15} label={sprintf(__('Browser cookies have limited memory. This may not work with large %s.', 'wdm_instructor_role'), ir_fqb_loc.quizzes_label)} withArrow>
                                                <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
                                            </Tooltip>
                                        </div>
                                    </Text>
                                    {props.wisdmQuizData && (
                                        <Switch
                                            defaultChecked={props.wisdmQuizData.time_limit_cookie > 0 ? true : false}
                                            onClick={() => handleChange(5)} className={checkedList[5] ? 'ir-checked' : 'ir-unchecked'}
                                            {...props.quizForm.getInputProps('time_limit_cookie_toggle')}
                                        />
                                    )}
                                    {props.wisdmQuizData && (
                                        <div className="ir-conditional-settings w-100">
                                            <Group spacing={0} mt={5} mb={15}>
                                                <Text className="w-40"></Text>
                                                <div className="ir-conditional-settings-2">
                                                    <Text fw={600}>{__('Cookie time limit', 'wdm_instructor_role')}</Text>
                                                    <Text c="#6F717C">{sprintf(__('Save the user’s answers into a browser cookie until the %s is submitted', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)}</Text>
                                                    <TextInput className="ir-label-right ir-jc-end" mt={15}
                                                        labelPosition="right"
                                                        styles={{ input: { width: 85, borderRadius: '10px' } }}
                                                        label={__('seconds', 'wdm_instructor_role')}
                                                        defaultValue={props.wisdmQuizData.time_limit_cookie}
                                                        {...props.quizForm.getInputProps('time_limit_cookie')}
                                                    />
                                                </div>
                                            </Group>
                                        </div>
                                    )}
                                </Group>
                                {/* <Group spacing={0} mt={25} align="center">
                                <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                    {__( 'Associated Settings', 'wdm_instructor_role' )}
                                </Text>
                                {props.wisdmQuizData && (
                                    <Switch
                                        onClick={() => handleChange(6)} className={checkedList[6] ? 'ir-checked' : 'ir-unchecked'}
                                    />
                                )}
                                {props.wisdmQuizData && (
                                <div className="ir-conditional-settings w-100">
                                    <Group spacing={0} mt={5} mb={15}>
                                        <Text className="w-40"></Text>
                                        <div className="ir-conditional-settings-2">
                                            <Text fw={600}>{sprintf(__( 'Associated %s Database Table', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label )}</Text>
                                            <Text c="#6F717C">{__( 'This will change the database association.We do not recommend editing this unless for a specific purpose.', 'wdm_instructor_role' )}</Text>
                                            <Select className="ir-select-width-400"
                                                placeholder={__( 'Select an option', 'wdm_instructor_role' )}
                                                data={[
                                                    { value: 'quiz-1', label: sprintf(__('Quiz 1', 'wdm_instructor_role'), '') },
                                                    { value: 'quiz-2', label: sprintf(__('Quiz 2', 'wdm_instructor_role'), '') },
                                                ]}
                                            />
                                        </div>
                                    </Group>
                                </div>
                                )}
                            </Group> */}
                            </div>
                        </div>
                    )}
                </div>
            )}
        </>
    );
}