import { useState, useEffect } from 'react';

import {
    Text,
    Input,
    Group,
    TextInput,
    Switch,
    Radio,
    NumberInput,
    Select,
    Tooltip,
    Button,
    Checkbox,
    Textarea
} from '@mantine/core';

import { InfoCircle } from 'tabler-icons-react';

import { __ } from "@wordpress/i18n";
import apiFetch from '@wordpress/api-fetch';

export default function ProgrssionRestriction(props) {
    
    const [selected, setSelected] = useState(null);
    const [additionalPoints, setAdditionalPoints] = useState(null);
    const [checkedList, setCheckedList] = useState([props.quizData.review_table_enabled, props.quizData.custom_sorting, props.quizData.question_random, false, props.quizData.materials_enabled]);
    let descTimer = 0;
    const handleChange = (index) => {
        const _checkedList = [...checkedList];
        _checkedList[index] = !_checkedList[index];
        setCheckedList(_checkedList);
    }
    const getSelectedValue = (value) => {
        const _wisdmQuizData = {...props.wisdmQuizData}
        _wisdmQuizData.quiz_modus = value;
        props.setWisdmQuizData(_wisdmQuizData);
        setSelected(value);
    };

    useEffect(() => {
        setSelected(props.wisdmQuizData?.quiz_modus);
        setTimeout(function(){
            wp.editor.initialize(
                'ir-quiz-material-editor',
                {
                    tinymce: {
                        setup:function(ed) {
                            ed.on('keyup change', function(e) {
                                setQuestionDescription(ed);
                            });
                        },
                        wpautop: true,
                        height: '300px',
                        plugins: 'charmap colorpicker compat3x directionality hr image lists media paste tabfocus textcolor wordpress wpautoresize wpdialogs wpeditimage link',
                        toolbar1: 'formatselect bold italic underline strikethrough | bullist numlist | blockquote hr wp_more | alignleft aligncenter alignright | link unlink |  media wp_add_media'
                    },
                    quicktags: false,
                    mediaButtons: true,

                }
            );
        })
    }, [props.wisdmQuizData]);

    const setQuestionDescription = (event) => {
        clearTimeout(descTimer);
        descTimer = setTimeout(function () {
            props.quizForm.setValues({
                materials: event.contentWindow.document.body.innerHTML
            });
        }, 500);
    }

    useEffect(() => {
        if(props.quizData.show_points || props.quizData.show_category || props.quizData.hide_question_position_overview || props.quizData.hide_question_numbering || 
            props.quizData.numbered_answer || props.quizData.answer_random){
            const _checkedList = [...checkedList];
            _checkedList[3] = true;
            setAdditionalPoints(true);
            setCheckedList(_checkedList);
        }
        else{
            const _checkedList = [...checkedList];
            _checkedList[3] = false;
            setAdditionalPoints(false);
            setCheckedList(_checkedList);
        }
        
    }, [props.quizData]);
    return (
        <>
            <div>
                {props.wisdmQuizData &&  (
                <div>
                <Group className="ir-course-material-wrap" spacing={0} mt={25} align="center">
                    <Text size="md" weight={600} className="w-40 mantine-InputWrapper-label ir-d-flex">
                        {sprintf(__('%s material', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}
                        <div className="ir-textinfo">
                            <Tooltip label={sprintf(__("List and display support materials for the %s. This is visible to any user having access to the %s.", 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label, ir_fqb_loc.lower_quiz_label)} withArrow>
                                <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
                            </Tooltip>
                        </div>
                    </Text>
                    <Switch
                        defaultChecked={props.quizData.materials_enabled}
                        onClick={() => handleChange(4)} className={checkedList[4] ? 'ir-checked ir-course-access-p-settings ir-parent-settings' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings'}
                        size="sm" 
                        {...props.quizForm.getInputProps('materials_enabled')}
                    />
                    <div className="ir-conditional-settings">
                        <Textarea mt={15}
                            defaultValue={props.quizData.materials.rendered}
                            className="ir-tiny-mce-editors"
                            id="ir-quiz-material-editor"
                        />
                    </div>
                </Group>
                <Group spacing={0} mt={25}>
                    <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                        {__('Auto start', 'wdm_instructor_role')}
                    </Text>
                    <Switch defaultChecked={props.quizData.auto_start} label={sprintf(__('Start automatically, without the start %s button', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)} 
                        {...props.quizForm.getInputProps('auto_start')}
                    />
                </Group>
                <Group className="ir-parent-settings" spacing={0} mt={25}>
                    <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                        {sprintf(__('%s display', 'wdm_instructor_role'), ir_fqb_loc.question_label)}
                    </Text>
                    
                        <Select className="ir-select-width-400" onChange={(e) => getSelectedValue(e)}
                            placeholder={__( 'Select an option', 'wdm_instructor_role' )}
                            value={props.wisdmQuizData?.quiz_modus}
                            data={[
                                { value: 'single', label: sprintf(__('One %s at a time', 'wdm_instructor_role'), ir_fqb_loc.lower_question_label) },
                                { value: 'multiple', label: sprintf(__('All %s at once(or paginated)', 'wdm_instructor_role'), ir_fqb_loc.questions_label) },
                            ]}
                        />
                   
                </Group>
                {selected == 'multiple' && 
                    <Group className="ir-parent-settings" spacing={0} mt={25}>
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                        </Text>
                        <TextInput className="ir-label-right"
                            label={sprintf(__('%s per page (0 = all)', 'wdm_instructor_role'), ir_fqb_loc.questions_label)}
                            labelPosition="right"
                            styles={{ input: { width: 85, borderRadius: '10px' } }}
                            defaultValue={props.wisdmQuizData?.multiple_questions_per_page}
                            {...props.quizForm.getInputProps('multiple_questions_per_page')}
                        />
                    </Group>
                }
                {selected == 'single' && 
                    <Group className="ir-parent-settings" spacing={0} mt={25}>
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                        </Text>
                        <Radio.Group
                            name="question_display"
                            orientation="vertical"
                            defaultValue={props.wisdmQuizData?.single_feedback}
                            {...props.quizForm.getInputProps('single_feedback')}
                            >
                            <Radio value="end" label={__( 'Display results at the end only', 'wdm_instructor_role' )}
                            />
                            <Checkbox ml={30} mt={-10} className="ir-radio-conditional" label={__( 'Display back button', 'wdm_instructor_role' )} 
                                defaultChecked={props.wisdmQuizData?.single_back_button === 'on' ? true : false}
                                {...props.quizForm.getInputProps('single_back_button')}
                            />
                            <Radio value="each" label={__( 'Display results after each submitted answer', 'wdm_instructor_role' )}
                            />
                            
                        </Radio.Group>
                    </Group>
                }
                </div>
                 )}
                <Switch
                    defaultChecked={props.quizData.review_table_enabled}
                    onClick={() => handleChange(0)} className={checkedList[0] ? 'ir-checked ir-course-access-p-settings ir-parent-settings' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings'}
                     mt={25} labelPosition="left" label={sprintf(__('%s overview table', 'wdm_instructor_role'), ir_fqb_loc.question_label)} description={sprintf(__('An overview table will be shown for all %s.', 'wdm_instructor_role'), ir_fqb_loc.questions_label)} 
                     {...props.quizForm.getInputProps('review_table_enabled', {type: 'checkbox'})}
                />
                <div className="ir-conditional-settings">
                    <Group spacing={0} mt={25} align="center">
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {sprintf(__('%s summary', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}
                        </Text>
                        <Switch
                            defaultChecked={props.quizData.summary_hide}
                            label={__( 'Display a summary table before submission', 'wdm_instructor_role' )}
                            {...props.quizForm.getInputProps('summary_hide', {type: 'checkbox'})}
                            
                        />
                    </Group>
                    <Group spacing={0} mt={25} align="center">
                    
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {sprintf(__('Skip %s', 'wdm_instructor_role'), ir_fqb_loc.lower_question_label)}
                        </Text>
                        <Switch defaultChecked={props.quizData.skip_question_disabled}
                            {...props.quizForm.getInputProps('skip_question_disabled', {type: 'checkbox'})}
                        />
                    </Group>
                </div>
                <Switch
                    defaultChecked={props.quizData.custom_sorting}
                    onClick={() => handleChange(1)} className={checkedList[1] ? 'ir-checked ir-course-access-p-settings ir-parent-settings' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings'}
                     mt={20} labelPosition="left" label={sprintf(__('Custom %s ordering', 'wdm_instructor_role'), ir_fqb_loc.lower_question_label)} 
                     {...props.quizForm.getInputProps('custom_sorting', {type: 'checkbox'})}
                />
                <div className="ir-conditional-settings">
                    <Group spacing={0} mt={25} align="center">
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {__( 'Sort by category', 'wdm_instructor_role' )}
                        </Text>
                        <Switch defaultChecked={props.quizData.sort_categories}
                            {...props.quizForm.getInputProps('sort_categories', {type: 'checkbox'})}
                        />
                    </Group>
                    <Group spacing={0} mt={25} align="center">
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {__( 'Randomize order', 'wdm_instructor_role' )}
                        </Text>
                        <Switch 
                            defaultChecked={props.quizData.question_random}
                            onClick={() => handleChange(2)} className={checkedList[2] ? 'ir-checked' : 'ir-unchecked'}
                            {...props.quizForm.getInputProps('question_random', {type: 'checkbox'})}
                        />
                        <div className="ir-conditional-settings w-100">
                            <Group spacing={0} mt={5} mb={15}>
                                <Text className="w-40"></Text>
                                <div className="ir-conditional-settings-2">
                                    {props.wisdmQuizData && (
                                        <Radio.Group
                                            name="randomize_order"
                                            orientation="vertical"
                                            defaultValue={props.wisdmQuizData?.show_max_question ? 'show_max' : 'display_all'}
                                            {...props.quizForm.getInputProps('show_max_question')}
                                            >
                                            <Radio value="display_all" label={sprintf(__('Display all %s', 'wdm_instructor_role'), ir_fqb_loc.questions_label)}
                                            />
                                            <Radio value="show_max" label={sprintf(__('Display subset of %s', 'wdm_instructor_role'), ir_fqb_loc.questions_label)}
                                            />
                                            <TextInput ml={30} className="ir-label-right ir-jc-end ir-radio-conditional"
                                                label={sprintf(__('Out of %s %s', 'wdm_instructor_role'), props.wisdmQuizData?.question_count, ir_fqb_loc.questions_label)}
                                                labelPosition="right"
                                                styles={{ input: { width: 85, borderRadius: '10px' } }}
                                                defaultValue={props.wisdmQuizData?.show_max_question_value}
                                                {...props.quizForm.getInputProps('show_max_question_value')}
                                            />
                                        </Radio.Group>
                                    )}
                                </div>
                            </Group>
                        </div>
                    </Group>
                </div>
                {props.quizData && additionalPoints !== null && (
                    <Switch
                        key={additionalPoints}
                        defaultChecked={additionalPoints}
                        onClick={() => handleChange(3)} className={checkedList[3] ? 'ir-checked ir-course-access-p-settings ir-parent-settings' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings'}
                         mt={20} labelPosition="left" label={sprintf(__('Additional %s options', 'wdm_instructor_role'), ir_fqb_loc.lower_question_label)} description={sprintf(__('Any enabled elements below will be displayed in each %s', 'wdm_instructor_role'), ir_fqb_loc.lower_question_label)}
                           
                    />
                )}
                
                <div className="ir-conditional-settings">
                    <Group spacing={0} mt={25} align="center">
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {__( 'Point value', 'wdm_instructor_role' )}
                        </Text>
                        <Switch 
                            defaultChecked={props.quizData.show_points}
                            {...props.quizForm.getInputProps('show_points')}
                        />
                    </Group>
                    <Group spacing={0} mt={25} align="center">
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {sprintf(__('%s category', 'wdm_instructor_role'), ir_fqb_loc.question_label)}
                        </Text>
                        <Switch
                            defaultChecked={props.quizData.show_category}
                            {...props.quizForm.getInputProps('show_category')}
                        />
                    </Group>
                    <Group spacing={0} mt={25} align="center">
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {sprintf(__('%s position', 'wdm_instructor_role'), ir_fqb_loc.question_label)}
                        </Text>
                        <Switch
                            defaultChecked={props.quizData.hide_question_position_overview}
                            {...props.quizForm.getInputProps('hide_question_position_overview')}
                        />
                    </Group>
                    <Group spacing={0} mt={25} align="center">
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {sprintf(__('%s numbering', 'wdm_instructor_role'), ir_fqb_loc.question_label)}
                        </Text>
                        <Switch
                            defaultChecked={props.quizData.hide_question_numbering}
                            {...props.quizForm.getInputProps('hide_question_numbering')}
                        />
                    </Group>
                    <Group spacing={0} mt={25} align="center">
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {__( 'Number answers', 'wdm_instructor_role' )}
                        </Text>
                        <Switch
                            defaultChecked={props.quizData.numbered_answer}
                            {...props.quizForm.getInputProps('numbered_answer')}
                        />
                    </Group>
                    <Group spacing={0} mt={25} align="center">
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {__( 'Randomize answers', 'wdm_instructor_role' )}
                            <div className="ir-textinfo">
                                <Tooltip label={sprintf(__('Answer display will be randomized within any given %s.', 'wdm_instructor_role'), ir_fqb_loc.lower_question_label)} withArrow>
                                    <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'}/></Button>
                                </Tooltip>
                            </div>
                        </Text>
                        <Switch
                            defaultChecked={props.quizData.answer_random}
                            {...props.quizForm.getInputProps('answer_random')}
                        />
                    </Group>
                </div>
                <Group spacing={0} mt={25}>
                    <Text className="w-40 mantine-InputWrapper-label ir-d-flex ir-parent-settings">
                        {sprintf(__('%s title', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}
                    </Text>
                    <Switch
                        defaultChecked={props.quizData.title_hidden}
                        label={sprintf(__('The %s title is displayed in addition to the %s post title. Recommended for %s shortcode usage.', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label, ir_fqb_loc.lower_quiz_label, ir_fqb_loc.lower_quiz_label)}
                        {...props.quizForm.getInputProps('title_hidden')}
                    />
                </Group>
            </div>
        </>
    );
}