import { useState, useEffect } from 'react';

import {
    Text,
    Input,
    Group,
    TextInput,
    Switch,
    Radio,
    NumberInput,
    Select,
    Tooltip,
    Button,
    Checkbox
} from '@mantine/core';

import { InfoCircle } from 'tabler-icons-react';

import { __ } from "@wordpress/i18n";
import apiFetch from '@wordpress/api-fetch';
import { showNotification } from '@mantine/notifications';

export default function ProgrssionRestriction(props) {

    const [checkedList, setCheckedList] = useState([props.quizData.retry_restrictions_enabled, props.quizData.time_limit_enabled, props.quizData.quiz_resume, false]);
    const [showReset, setShowReset] = useState(false);
    const handleChange = (index) => {
        const _checkedList = [...checkedList];
        _checkedList[index] = !_checkedList[index];
        setCheckedList(_checkedList);
    }
    const [certificates, setCertificates] = useState([]);

    useEffect(()=>{
        if ( null !== props.wisdmQuizData && props.wisdmQuizData.hasOwnProperty('quiz_certificates')) {
            setCertificates(props.wisdmQuizData.quiz_certificates);
        }
    }, props.wisdmQuizData);

    const resetUserIdentification = () => {
        jQuery.ajax({
            url: ir_fqb_loc.ajax_url + "?post=" + props.quizData.id + "&action=reset_lock",
            method: 'POST',
            data: {
                action: 'wp_pro_quiz_reset_lock',
                nonce: ir_fqb_loc.reset_lock_nonce
            },
            success: function (response) {
                showNotification({
                    title: __('User identification has been reset.', 'wdm_instructor_role')
                })
            }
        });
    }
    return (
        <>
            <div>
                <Group spacing={0} mt={25}>
                    <Text className="w-40 mantine-InputWrapper-label ir-d-flex ir-parent-settings" >
                        {__('Passing score', 'wdm_instructor_role')}
                    </Text>
                    <TextInput className="ir-label-right"
                        label="%"
                        labelPosition="right"
                        styles={{ input: { width: 85, borderRadius: '10px' } }}
                        defaultValue={props.quizData.passing_percentage}
                        {...props.quizForm.getInputProps('passing_percentage')}
                    />
                </Group>
                <Group spacing={0} mt={25}>
                    <Text className="w-40 mantine-InputWrapper-label ir-d-flex ir-parent-settings" >
                        {sprintf(__('%s certificate', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}
                    </Text>
                    <Select className="ir-select-width-400" clearable
                        placeholder={__('Select a Certificate', 'wdm_instructor_role')}
                        data={certificates}
                        {...props.quizForm.getInputProps('certificate')}
                    />
                </Group>
                <input type='hidden' className="showNextEle" data-value={props.quizForm.values.certificate} />
                <div className="ir-conditional-settings">
                    <Group spacing={0} mt={20}>
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {sprintf(__('Certificate awarded for', 'wdm_instructor_role'), '')}
                            <div className="ir-textinfo">
                                <Tooltip multiline width={260} p={15} label={sprintf(__('Set the score needed to receive a certificate. This can be different from the "Passing Score".', 'wdm_instructor_role'), '')} withArrow>
                                    <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
                                </Tooltip>
                            </div>
                        </Text>
                        <TextInput className="ir-label-right ir-jc-end" mb={10}
                            defaultValue={props.quizData.certificate_award_threshold}
                            labelPosition="right"
                            styles={{ input: { width: 85, borderRadius: '10px' } }}
                            label={__('% score', 'wdm_instructor_role')}
                            {...props.quizForm.getInputProps('certificate_award_threshold')}
                        />
                    </Group>
                </div>
                <Group className="ir-switch-with-tooltip" spacing={0} mt={25} align="center">
                    <Text size="md" weight={600} className="w-40 mantine-InputWrapper-label ir-d-flex">
                        {sprintf(__('Enable %s saving', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)}
                        <div className="ir-textinfo">
                            <Tooltip multiline width={260} p={15} label={sprintf(__('%s saving allows your users to save their current %s progress and return to it at a later date and preserve their progress.', 'wdm_instructor_role'), ir_fqb_loc.quiz_label, ir_fqb_loc.lower_quiz_label)} withArrow>
                                <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
                            </Tooltip>
                        </div>
                    </Text>
                    <Switch
                        defaultChecked={props.quizData.quiz_resume}
                        onClick={() => handleChange(2)} className={checkedList[2] ? 'ir-checked ir-course-access-p-settings ir-parent-settings' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings'}
                        {...props.quizForm.getInputProps('quiz_resume', { type: 'checkbox' })}
                        size="sm" />
                    <div className="ir-conditional-settings">
                        <Group spacing={0} mt={20}>
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {sprintf(__('Save %s data to the server every', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)}
                            </Text>
                            <TextInput className="ir-label-right ir-jc-end" mb={10}
                                defaultValue={props.quizData.quiz_resume_cookie_send_timer}
                                labelPosition="right"
                                styles={{ input: { width: 85, borderRadius: '10px' } }}
                                label={__('Seconds', 'wdm_instructor_role')}
                                {...props.quizForm.getInputProps('quiz_resume_cookie_send_timer')}
                            />
                        </Group>
                    </div>
                </Group>
                <Switch
                    defaultChecked={props.quizData.retry_restrictions_enabled}
                    onClick={() => handleChange(0)} className={checkedList[0] ? 'ir-checked ir-course-access-p-settings ir-parent-settings' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings'}
                    {...props.quizForm.getInputProps('retry_restrictions_enabled', { type: 'checkbox' })}

                    mt={20} labelPosition="left" label={sprintf(__('Restrict %s retakes', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)} />
                <div className="ir-conditional-settings">
                    <Group spacing={0} mt={25}>
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {__('Number of retries allowed ', 'wdm_instructor_role')}
                            <div className="ir-textinfo">
                                <Tooltip label={__('You must input a whole number value or leave blank to default to 0.', 'wdm_instructor_role')} withArrow>
                                    <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
                                </Tooltip>
                            </div>
                        </Text>
                        <TextInput className="ir-label-right"
                            labelPosition="right"
                            styles={{ input: { width: 85, borderRadius: '10px' } }}
                            defaultValue={props.quizData.retry_repeats}
                            {...props.quizForm.getInputProps('retry_repeats')}
                        />
                    </Group>

                    <Group spacing={0} mt={25} >
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {__('Retries applicable to', 'wdm_instructor_role')}
                        </Text>
                        {props.wisdmQuizData && (
                            <Select className="ir-select-width-400"
                                data={[
                                    { value: 1, label: __('All Users', 'wdm_instructor_role') },
                                    { value: 2, label: __('Registered users only', 'wdm_instructor_role') },
                                    { value: 3, label: __('Anonymous users only', 'wdm_instructor_role') },
                                ]}
                                defaultValue={parseInt(props.wisdmQuizData.retries_applicable_to)}
                                placeholder={__('Select an option', 'wdm_instructor_role')}
                                {...props.quizForm.getInputProps('retries_applicable_to')}
                            />
                        )}
                    </Group>
                    {props.wisdmQuizData && (
                        <input type="hidden"
                            defaultValue={parseInt(props.wisdmQuizData?.retries_applicable_to)}
                            {...props.quizForm.getInputProps('retries_applicable_to')}
                        />
                    )}
                    <Group spacing={0} className="ir-reset-action">
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                        </Text>
                        <Group spacing={0} mt={10} align="center">
                            <Button size="xs" className="ir-btn-outline" onClick={resetUserIdentification}>{__('Reset the user identification', 'wdm_instructor_role')}</Button>
                            <div className="ir-textinfo rui">
                                <Tooltip label={__('Anonymous visitors only.', 'wdm_instructor_role')} withArrow>
                                    <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'} /></Button>
                                </Tooltip>
                            </div>
                        </Group>

                    </Group>
                </div>
                <Group spacing={0} mt={25}>
                    <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                        {sprintf(__('%s completion', 'wdm_instructor_role'), ir_fqb_loc.question_label)}
                    </Text>
                    <Checkbox value="All Questions required to complete" label={sprintf(__('All %s required to complete', 'wdm_instructor_role'), ir_fqb_loc.questions_label)}
                        defaultChecked={props.quizData.answer_all_questions_enabled}
                        {...props.quizForm.getInputProps('answer_all_questions_enabled')}
                    />
                </Group>
                <Switch
                    defaultChecked={props.quizData.time_limit_enabled}
                    onClick={() => handleChange(1)} className={checkedList[1] ? 'ir-checked ir-course-access-p-settings ir-parent-settings' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings'}
                    mt={20} labelPosition="left" label={sprintf(__('Time limit', 'wdm_instructor_role'), '')}
                    {...props.quizForm.getInputProps('time_limit_enabled')}
                />
                <div className="ir-conditional-settings">
                    <Group spacing={0} mt={15}>
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {__('Automatically submit after', 'wdm_instructor_role')}
                        </Text>
                        <Group spacing='xs'>
                            <NumberInput
                                hideControls
                                placeholder="HH"
                                max={23}
                                min={0} 
                                styles={{ input: { width: 85, borderRadius: '10px' } }}
                                {...props.quizForm.getInputProps('tl_hour')}
                            />:
                            <NumberInput
                                hideControls
                                max={59}
                                min={0}
                                placeholder="MM"
                                styles={{ input: { width: 85, borderRadius: '10px' } }}
                                {...props.quizForm.getInputProps('tl_minute')}
                            />:
                            <NumberInput
                                hideControls
                                max={59}
                                min={0}
                                placeholder="SS"
                                styles={{ input: { width: 85, borderRadius: '10px' } }}
                                {...props.quizForm.getInputProps('tl_second')}
                            />
                        </Group>
                    </Group>
                </div>
            </div>
        </>
    );
}