import { useState, useEffect } from 'react';

import {
    Text,
    Input,
    Group,
    TextInput,
    Switch,
    Radio,
    NumberInput,
    Select,
    MultiSelect,
    Tooltip,
    Button,
    Checkbox
} from '@mantine/core';

import { InfoCircle } from 'tabler-icons-react';

import { __ } from "@wordpress/i18n";
import apiFetch from '@wordpress/api-fetch';

export default function QuizAccess(props) {
    const [quizRelease, setQuizRelease] = useState('');
    const [date, setDate] = useState(new Date(parseInt(props.wisdmQuizData?.visible_after_specific_date) * 1000));
    const [quizPrereq, setQuizPrereq] = useState([]);

    useEffect(() => {
        const specificDate = new Date(parseInt(props.wisdmQuizData?.visible_after_specific_date) * 1000); 
        setDate(specificDate);
        if ( null !== props.wisdmQuizData && props.wisdmQuizData.hasOwnProperty('quiz_pre_requisites')) {
            setQuizPrereq(props.wisdmQuizData?.quiz_pre_requisites);
        }
    }, [props.wisdmQuizData]);
    return (
        <>
            <div>
                <Radio.Group className="ir-trs"
                    name="QuizRelease"
                    orientation="vertical"
                    label={sprintf(__('%s release schedule', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}
                    defaultValue={props.quizData.visible_type}
                    {...props.quizForm.getInputProps('visible_type')}
                >
                    <Radio value="" label={__('Immediately', 'wdm_instructor_role')} description={sprintf(__('The %s is made available on %s enrollment', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label, ir_fqb_loc.lower_quiz_label)} />
                    <Radio value="visible_after" label={__('Enrollment-based', 'wdm_instructor_role')} description={sprintf(__('The %s will be available X days after %s enrollment', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label, ir_fqb_loc.lower_quiz_label)} />
                    <TextInput className="ir-input-settings ir-vcd-text" pl={32}
                        placeholder=""
                        label={__('days(s)', 'wdm_instructor_role')}
                        labelPosition="right"
                        type="number"
                        defaultValue={props.quizData.visible_after}
                        styles={{ input: { width: 85, borderRadius: '10px' } }}
                        {...props.quizForm.getInputProps('visible_after')}
                    />
                    <Radio value="visible_after_specific_date" label={__('Specific date', 'wdm_instructor_role')} description={sprintf(__('The %s will be available on a specific date.', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)} />
                    <Group className="ir-sp-date" pl={32}>
                        <Select
                            placeholder="MM"
                            labelPosition="right"
                            defaultValue={date.getMonth() + 1}
                            styles={{ input: { width: 80, borderRadius: '10px' } }}
                            data={[
                                { value: 1, label: 'Jan' },
                                { value: 2, label: 'Feb' },
                                { value: 3, label: 'Mar' },
                                { value: 4, label: 'Apr' },
                                { value: 5, label: 'May' },
                                { value: 6, label: 'Jun' },
                                { value: 7, label: 'Jul' },
                                { value: 8, label: 'Aug' },
                                { value: 9, label: 'Sep' },
                                { value: 10, label: 'Oct' },
                                { value: 11, label: 'Nov' },
                                { value: 12, label: 'Dec' },
                            ]}
                            {...props.quizForm.getInputProps('sp_month')}
                        />
                       
                        <strong>,</strong>
                        <TextInput
                            placeholder="DD"
                            label=""
                            labelPosition="right"
                            type="number"
                            defaultValue={date.getDate()}
                            styles={{ input: { width: 62, borderRadius: '10px' } }}
                            {...props.quizForm.getInputProps('sp_date')}
                        />
                        <strong>,</strong>
                        <TextInput
                            placeholder="YYYY"
                            label=""
                            labelPosition="right"
                            type="number"
                            defaultValue={date.getFullYear()}
                            styles={{ input: { width: 72, borderRadius: '10px' } }}
                            {...props.quizForm.getInputProps('sp_year')}
                        />
                        <strong>@</strong>
                        <TextInput
                            placeholder="HH"
                            label=""
                            labelPosition="right"
                            type="number"
                            defaultValue={date.getHours()}
                            styles={{ input: { width: 62, borderRadius: '10px' } }}
                            {...props.quizForm.getInputProps('sp_hour')}
                        />
                        <strong>:</strong>
                        <TextInput
                            placeholder="MM"
                            label=""
                            labelPosition="right"
                            type="number"
                            defaultValue={date.getMinutes()}
                            styles={{ input: { width: 62, borderRadius: '10px' } }}
                            {...props.quizForm.getInputProps('sp_minute')}
                        />
                    </Group>
                </Radio.Group>
                <Group spacing={0} mt={25}>
                    <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                        {sprintf(__('%s prerequisites', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}
                        <div className="ir-textinfo">
                            <Tooltip multiline width={260} p={15} label={sprintf(__('Select one or more %s that must be completed prior to taking this %s.', 'wdm_instructor_role'), ir_fqb_loc.quizzes_label, ir_fqb_loc.lower_quiz_label)} withArrow>
                                <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'}/></Button>
                            </Tooltip>
                        </div>
                    </Text>
                    <MultiSelect className="ir-select-width-400"
                        placeholder={__( 'Select an option', 'wdm_instructor_role' )}
                        data={quizPrereq}
                        // defaultValue={props.quizData.prerequisites}
                        {...props.quizForm.getInputProps('prerequisites')}
                    />
                </Group>
                <Group spacing={0} mt={25}>
                    <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                        {__('Allowed users', 'wdm_instructor_role')}
                        <div className="ir-textinfo">
                            <Tooltip multiline width={260} p={15} label={sprintf(__('This option is especially useful if administering %s via shortcodes on non-%s pages, or if your %s are open but you wish only authenticated users to take the %s.', 'wdm_instructor_role'), ir_fqb_loc.quizzes_label, ir_fqb_loc.lower_course_label, ir_fqb_loc.lower_course_label, ir_fqb_loc.lower_quiz_label)} withArrow>
                                <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'}/></Button>
                            </Tooltip>
                        </div>
                    </Text>
                    <Checkbox defaultChecked={props.quizData.registered_users_only} value="Only registered users can take this Quiz" label={sprintf(__('Only registered users can take this %s', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)} {...props.quizForm.getInputProps('registered_users_only')} />
                </Group>

            </div>
        </>
    );
}