import { useState, useEffect } from 'react';

import {
    Text,
    Input,
    Group,
    TextInput,
    Switch,
    Radio,
    NumberInput,
    Select,
    Tooltip,
    Button,
    Textarea,
    Paper
} from '@mantine/core';
import { showNotification } from '@mantine/notifications';


import { InfoCircle, Plus, PencilMinus, X } from 'tabler-icons-react';

import { __ } from "@wordpress/i18n";
import apiFetch from '@wordpress/api-fetch';
import { RichTextEditor } from '@mantine/rte';

export default function ResultPage(props) {
    const [checkedList, setCheckedList] = useState([props.wisdmQuizData?.result_text?.text?.length > 0 ? true : false, false, props.quizData.custom_answer_feedback, false]);
    const [additionalPoints, setAdditionalPoints] = useState(null);
    const [addGraduation, setAddGraduation] = useState(false);
    const [editGraduation, setEditGraduation] = useState(null);
    const {resultText, setResultText} = props;
    const handleChange = (index) => {
        const _checkedList = [...checkedList];
        _checkedList[index] = !_checkedList[index];
        setCheckedList(_checkedList);
    }


    useEffect(() => {
        setTimeout(function(){
            const _checkedList = [...checkedList];
            _checkedList[0] = props.wisdmQuizData?.result_text?.text?.length > 0 ? true : false;
            if(props.quizData.show_average_result || props.quizData.show_category_score || props.quizData.hide_result_points || props.quizData.hide_result_correct_question || 
                props.quizData.hide_result_quiz_time){
                _checkedList[1] = true;
                setAdditionalPoints(true);
            }
            else{
                _checkedList[1] = false;
                setAdditionalPoints(false);
            }
            setCheckedList(_checkedList);
            setResultText(props.wisdmQuizData?.result_text);
            
        })
        
    }, [props.quizData, props.wisdmQuizData]);

    useEffect(() => {
        const _editGraduation = {...editGraduation}
        resultText?.text?.map((textItem, index) => (
            _editGraduation[index] = false
        ))
        setEditGraduation(_editGraduation);
    }, [resultText]);

    useEffect(() => {
        wp.editor.remove('ir-tinymce');
        wp.editor.initialize(
            'ir-tinymce',
            {
                tinymce: {
                    wpautop: true,
                    height: '300px',
                    plugins: 'charmap colorpicker compat3x directionality hr image lists media paste tabfocus textcolor wordpress wpautoresize wpdialogs wpeditimage link',
                    toolbar1: 'formatselect bold italic underline strikethrough | bullist numlist | blockquote hr wp_more | alignleft aligncenter alignright | link unlink |  media wp_add_media'
                },
                quicktags: false,
                mediaButtons: true,

            }
        );
    }, [editGraduation]);

    useEffect(() => {
        wp.editor.remove('ir-tinymce-add-graduation');
        wp.editor.initialize(
            'ir-tinymce-add-graduation',
            {
                tinymce: {
                    wpautop: true,
                    height: '300px',
                    plugins: 'charmap colorpicker compat3x directionality hr image lists media paste tabfocus textcolor wordpress wpautoresize wpdialogs wpeditimage link',
                    toolbar1: 'formatselect bold italic underline strikethrough | bullist numlist | blockquote hr wp_more | alignleft aligncenter alignright | link unlink |  media wp_add_media'
                },
                quicktags: false,
                mediaButtons: true,

            }
        );
    }, [addGraduation]);

    const addGraduationFunc = () => {
        const _resultText = {...resultText}
        const _editGraduation = {...editGraduation}
        // console.log(props.quizForm.values.add_prozent);
        if(props.quizForm.values.add_prozent === '' || props.quizForm.values.add_prozent === undefined){
            showNotification({
                message: __('Please add percentage value', 'wdm_instructor_role')
            });
        }
        else{
            _resultText.prozent.push(parseInt(props.quizForm.values.add_prozent));
            _resultText.text.push(tinymce.get("ir-tinymce-add-graduation").getContent());
            _resultText.activ.push(1);
            _editGraduation[_resultText.prozent.length - 1] = false;
            setEditGraduation(_editGraduation);
            setResultText(_resultText);
            props.quizForm.setValues({
                add_prozent: '',
                add_message: ''
            })
            setAddGraduation(false);
        }
        
    }

    const editGraduationFunc = (index) => {
        const _resultText = {...resultText}
        const _editGraduation = {...editGraduation}
        if(props.quizForm.values['edit_prozent'+index] === '' || props.quizForm.values['edit_prozent'+index] === undefined){
            showNotification({
                message: __('Please add percentage value', 'wdm_instructor_role')
            });
        }
        else{
            _resultText.prozent[index] = props.quizForm.values['edit_prozent'+index] !== undefined ? parseInt(props.quizForm.values['edit_prozent'+index]) : _resultText.prozent[index];
            _resultText.text[index] = tinymce.get("ir-tinymce").getContent();
            setResultText(_resultText);
            _editGraduation[index] = false;
            setEditGraduation(_editGraduation);
        }
    }

    const deleteGraduation = (index) => {
        const _resultText = {...resultText}
        const _editGraduation = {...editGraduation}
        _editGraduation[index] = false;
        _resultText.text.splice(index, 1);
        _resultText.prozent.splice(index, 1);
        _resultText.activ.splice(index, 1);
        setResultText(_resultText);
        setEditGraduation(_editGraduation);
    }
    return (
        <>
            <div>
                <Group spacing={0} mt={25}>
                    <Text className="w-40 mantine-InputWrapper-label ir-d-flex ir-parent-settings">
                        {sprintf(__('Result message(s)', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}
                        <div className="ir-textinfo">
                            <Tooltip multiline width={260} p={15} label={sprintf(__('When enabled, the first message will be displayed to ALL users. To customize the message based on earned score, add new Graduation Levels and set the "From" field to the desired grade.', 'wdm_instructor_role'), '')} withArrow>
                                <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'}/></Button>
                            </Tooltip>
                        </div>
                    </Text>
                    <Switch
                        key={props.wisdmQuizData?.result_text?.text?.length}
                        defaultChecked={props.wisdmQuizData?.result_text?.text?.length> 0 ? true : false }
                        onClick={() => handleChange(0)} className={checkedList[0] ? 'ir-checked' : 'ir-unchecked'}
                        label={sprintf(__('The message below is displayed on the %s results page', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)}
                        {...props.quizForm.getInputProps('result_text')}
                    />
                    <div className="ir-conditional-settings ir-result-message w-100">
                        {resultText?.text?.map((textItem, index) => (
                            <div>
                            {editGraduation[index] === false && (
                            <Paper className="ir-fed-answers" mb={16} mt={16} radius="lg" p="sm" withBorder>
                                <Group align="center" spacing="xs" position="apart">
                                    <Text className="ir-width-850" size={14} fw={600} truncate>{textItem}</Text>
                                    <Group>
                                        <Group spacing={0}>
                                            <Text color="#6F717C">{__( 'From: ', 'wdm_instructor_role' )} </Text>
                                            <Text ml={5}>{index === 0 ? 0 : resultText.prozent[index]} %</Text>
                                        </Group>
                                        <PencilMinus
                                            size={24}
                                            strokeWidth={2}
                                            color={'#2067FA'}
                                            onClick={() => {
                                                const _editGraduation = {...editGraduation}
                                                _editGraduation[index] = true;
                                                setEditGraduation(_editGraduation);   
                                            }}
                                        />
                                        <X 
                                            size={24}
                                            strokeWidth={2}
                                            color={'#2067FA'}
                                            onClick={() => deleteGraduation(index)}
                                        />
                                    </Group>
                                </Group>
                            </Paper>
                            )}
                            {editGraduation[index] === true && (
                                <Group className="ir-answer-section ir-border br-10" mt={20} mb={16} p={15}>
                                    <div className="w-100">
                                        <Group>
                                            <Text fw={600} size={14} color="#444444">{__( 'From', 'wdm_instructor_role' )}</Text>
                                            <TextInput className="ir-result-perc" 
                                                disabled={index === 0 ? true : false}
                                                defaultValue={resultText.prozent[index]}
                                                styles={{ input: { width: 43, borderRadius: '6px', height: '30px' } }} 
                                                {...props.quizForm.getInputProps('edit_prozent'+index)}
                                            />
                                            <Text fw={600} size={14} color="#444444">{__( '% score, display this message :', 'wdm_instructor_role' )}</Text>
                                        </Group>
                                        <Textarea mt={17} mb={25}
                                            id="ir-tinymce"
                                            defaultValue={textItem}
                                            {...props.quizForm.getInputProps('edit_message'+index)}
                                        />
                                        <Group position="right">
                                            <Button onClick={() => {
                                                const _editGraduation = {...editGraduation}
                                                _editGraduation[index] = false;
                                                setEditGraduation(_editGraduation);
                                            }} size="xs" className="ir-btn-subtle">{__( 'Cancel', 'wdm_instructor_role' )}</Button>
                                            <Button onClick={() => editGraduationFunc(index)} size="xs" className="ir-btn-filled">{__( 'Save', 'wdm_instructor_role' )}</Button>
                                        </Group>
                                    </div>
                                </Group>
                            )}
                            </div>

                        ))}
                        {addGraduation && (
                            <Group className="ir-answer-section ir-border br-10" mt={20} mb={16} p={15}>
                                <div className="w-100">
                                    <Group>
                                        <Text fw={600} size={14} color="#444444">{__( 'From', 'wdm_instructor_role' )}</Text>
                                        <NumberInput className="ir-result-perc" 
                                            hideControls
                                            disabled={resultText.prozent.length === 0 ? true : false}
                                            styles={{ input: { width: 43, borderRadius: '6px', height: '30px' } }} 
                                            {...props.quizForm.getInputProps('add_prozent')}
                                        />
                                        <Text fw={600} size={14} color="#444444">{__( '% score, display this message :', 'wdm_instructor_role' )}</Text>
                                    </Group>
                                    <Textarea mt={17} mb={25}
                                        id="ir-tinymce-add-graduation"
                                        {...props.quizForm.getInputProps('add_message')}
                                    />
                                    <Group position="right">
                                        <Button onClick={() => setAddGraduation(false)} size="xs" className="ir-btn-subtle">{__( 'Cancel', 'wdm_instructor_role' )}</Button>
                                        <Button onClick={() => addGraduationFunc()} size="xs" className="ir-btn-filled">{__( 'Save', 'wdm_instructor_role' )}</Button>
                                    </Group>
                                </div>
                            </Group>
                        )}
                        <Button fw={600} mt={15} onClick={() => {
                                props.quizForm.setValues({
                                    add_prozent: resultText.prozent.length === 0 ? 0 : ''
                                })   
                                setAddGraduation(true)
                            }}  className="ir-btn-subtle h-auto ir-add-field" leftIcon={<Plus size={23} strokeWidth={2} />}  >{__('Add graduation', 'wdm_instructor_role')}</Button>
                    </div>
                </Group>
                <Switch 
                    defaultChecked={props.quizData.restart_button_hide}
                    className="ir-course-access-p-settings ir-parent-settings"
                     mt={25} labelPosition="left" label={sprintf(__('Restart %s button', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)} 
                    {...props.quizForm.getInputProps('restart_button_hide')}
                 />
                {props.quizData && additionalPoints !== null && (
                    <div>
                    <Switch
                        key={additionalPoints}
                        defaultChecked={additionalPoints}
                        onClick={() => handleChange(1)} className={checkedList[1] ? 'ir-checked ir-course-access-p-settings ir-parent-settings' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings'}
                         mt={25} labelPosition="left" label={__( 'Custom results display', 'wdm_instructor_role' )} description={__( 'Enable the items you wish to display on the Result Page.', 'wdm_instructor_role' )}
                    />
                
                    <div className="ir-conditional-settings">
                        <Group spacing={0} mt={25} align="center">
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {__( 'Average score', 'wdm_instructor_role' )}
                                <div className="ir-textinfo">
                                    <Tooltip label={sprintf(__('Display the average score of all users who took the %s.', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)} withArrow>
                                        <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'}/></Button>
                                    </Tooltip>
                                </div>
                            </Text>
                            <Switch
                                defaultChecked={props.quizData.show_average_result}
                                {...props.quizForm.getInputProps('show_average_result')}
                            />
                        </Group>
                        <Group spacing={0} mt={25} align="center">
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {__( 'Category score', 'wdm_instructor_role' )}
                                <div className="ir-textinfo">
                                    <Tooltip label={sprintf(__('Display the score achieved for each %s category.', 'wdm_instructor_role'), ir_fqb_loc.lower_question_label)} withArrow>
                                        <Button><InfoCircle size={20} strokeWidth={2} color={'#444444'}/></Button>
                                    </Tooltip>
                                </div>
                            </Text>
                            <Switch
                                defaultChecked={props.quizData.show_category_score}
                                {...props.quizForm.getInputProps('show_category_score')}
                            />
                        </Group>
                        <Switch mt={25} className="ir-course-access-p-settings ir-parent-settings label-w-12"
                            defaultChecked={props.quizData.hide_result_points}
                            label={__( 'Overall score', 'wdm_instructor_role' )}
                            labelPosition="left"
                            description={sprintf(__('If disabled, the achieved %s score is NOT be displayed on the Results page', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)}
                            {...props.quizForm.getInputProps('hide_result_points')}
                        />
                        <Switch mt={25} className="ir-course-access-p-settings ir-parent-settings label-w-12"
                            defaultChecked={props.quizData.hide_result_correct_question}
                            label={__( 'No. of correct answers', 'wdm_instructor_role' )}
                            labelPosition="left"
                            description={sprintf(__('If disabled, the number of correctly Answerd %s is NOT displayed on the Results page', 'wdm_instructor_role'), ir_fqb_loc.questions_label)}
                            {...props.quizForm.getInputProps('hide_result_correct_question')}
                        />
                        <Group spacing={0} mt={25} align="center">
                            <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                                {__( 'Time spent', 'wdm_instructor_role' )}
                            </Text>
                            <Switch
                                defaultChecked={props.quizData.hide_result_quiz_time}
                                {...props.quizForm.getInputProps('hide_result_quiz_time')}
                            />
                        </Group>
                    </div>
                    </div>
                )}
                <Switch
                    defaultChecked={props.quizData.custom_answer_feedback}
                    onClick={() => handleChange(2)} className={checkedList[2] ? 'ir-checked ir-course-access-p-settings ir-parent-settings' : 'ir-unchecked ir-course-access-p-settings ir-parent-settings'}
                     mt={25} labelPosition="left" label={__( 'Custom answer feedback', 'wdm_instructor_role' )} description={sprintf(__('The message below is displayed on the %s results page.', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)}
                     {...props.quizForm.getInputProps('custom_answer_feedback')}
                />
                <div className="ir-conditional-settings">
                    <Group spacing={0} mt={25} align="center">
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {__( 'Correct / Incorrect messages', 'wdm_instructor_role' )}
                        </Text>
                        <Switch
                            defaultChecked={props.quizData.hide_answer_message_box}
                            {...props.quizForm.getInputProps('hide_answer_message_box')}
                        />
                    </Group>
                    <Group spacing={0} mt={25} align="center">
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {__( 'Correct / Incorrect answer marks', 'wdm_instructor_role' )}
                        </Text>
                        <Switch
                            defaultChecked={props.quizData.disabled_answer_mark}
                            {...props.quizForm.getInputProps('disabled_answer_mark')}
                        />
                    </Group>
                    <Group spacing={0} mt={25} align="center">
                        <Text className="w-40 mantine-InputWrapper-label ir-d-flex">
                            {sprintf(__('View %s button', 'wdm_instructor_role'), ir_fqb_loc.lower_question_label)}
                        </Text>
                        <Switch
                            defaultChecked={props.quizData.view_question_button_hidden}
                            {...props.quizForm.getInputProps('view_question_button_hidden')}
                        />
                    </Group>
                </div>
            </div>
        </>
    );
}