import { useState, useEffect } from 'react';
import { useForm } from '@mantine/form';
import {
    AppShell,
    Navbar,
    Header,
    Accordion,
    MantineProvider,
    Text,
    Title,
    Grid,
    Paper,
    Input,
    Checkbox,
    Button,
    Group,
    Space,
    Center,
    CloseButton,
    Skeleton,
    TextInput,
    Modal,
    Tabs,
    FileButton,
    Switch,
    Radio,
    NumberInput,
    MultiSelect,
    Loader,
    Divider,
    HoverCard,
    Tooltip
} from '@mantine/core';

import { Upload, ExternalLink, InfoCircle } from 'tabler-icons-react';
import { showNotification, NotificationsProvider } from '@mantine/notifications';
import { PencilMinus } from 'tabler-icons-react';
import { X } from 'tabler-icons-react';
import { GridDots } from 'tabler-icons-react';
import { Plus } from 'tabler-icons-react';
import { Search } from 'tabler-icons-react';

import { __ } from "@wordpress/i18n";
import apiFetch from '@wordpress/api-fetch';

import { RichTextEditor } from '@mantine/rte';

import QuestionModal from '/src/quiz-builder/components/questionModal.js';
import EditQuestionModal from '/src/quiz-builder/components/editQuestionModal.js';



export default function QuizBuilder(props) {
    const [allQuestions, setAllQuestions] = useState(null);
    const [file, setFile] = useState(File | null > (null));
    const [quizNumberData, setQuizNumberData] = useState(null);
    const [checkedQuestion, setCheckedQuestion] = useState(false);
    const {questionData, setQuestionData} = props;
    const [data, setData] = useState([
        { value: 'elearning', label: 'E-Learning' },
        { value: 'education', label: 'Education' },
        { value: 'lms', label: 'LMS' },
        { value: 'wc', label: 'Ecommerce' },
    ]);
    const questionType = {
        'cloze_answer': 'Fill in the blanks',
        'single': 'Single Choice',
        'multiple': 'Multiple Choice',
        'sort_answer': 'Sorting Choice',
        'free_answer': 'Free Choice',
        'matrix_sort_answer': 'Matrix Sorting Choice',
        'assessment_answer': 'Assessment',
        'essay': 'Essay/Open Answer'
    }

    useEffect(() => {
        apiFetch(
            {
                path: "/ir/v1/question-library/"+props.quizId,
                method: 'GET',
            }
        ).then((data) => {
            setAllQuestions(data);
        })
    }, []);

    useEffect(() => {
        sortQuestions();
        if(questionData){
            fetchQuizPoints();
        }
    }, [questionData]);

    const sortQuestions = () => {
        jQuery(".ir-sortable-questions").sortable();
        jQuery(".ir-sortable-questions").sortable('destroy');
        jQuery('.ir-questions-library > .mantine-Stack-root').sortable();
        jQuery('.ir-questions-library > .mantine-Stack-root').sortable('destroy');
        setTimeout(function () {
            jQuery(".ir-sortable-questions").sortable({
                stop: function (event, ui) {
                    const index = parseInt(jQuery(ui.item).index());
                    jQuery(".ir-sortable-questions").sortable('cancel');
                    const initial_index = parseInt(jQuery(ui.item).index());
                    if(index !== initial_index){
                        var newData = [...questionData];
                        if(index < initial_index){
                            for (var i = index; i<initial_index+1; i++){
                                if(i == initial_index){
                                    newData[i].menu_order = index + 1;
                                }
                                else{

                                    newData[i].menu_order = i + 2;
                                }
                            } 
                        }
                        else{
                            for (var i = index; i>=initial_index; i--){
                                if(i == initial_index){
                                    newData[i].menu_order = index + 1;
                                }
                                else{

                                    newData[i].menu_order = i;
                                }
                            } 
                        }
                        const sorted = [...newData.sort((a, b) => parseFloat(a.menu_order) - parseFloat(b.menu_order))];
                        setQuestionData(sorted);
                    }
                    
                }
            })
            jQuery('.ir-questions-library > .mantine-Stack-root').sortable({
                connectWith: [".ir-sortable-questions"],
                dropOnEmpty: true,
                scroll: true,
                start: function(e, ui) {
                    jQuery(ui.item).addClass('ir-picked')
                },
                stop: function(e, ui) {
                    if (jQuery(ui.item).parent().hasClass('ir-sortable-questions')){
                        const questionArray =  [...questionData];
                        const index = parseInt(jQuery(ui.item).attr('data-index'));
                        let index1 = parseInt(jQuery(ui.item).index());
                        if(jQuery(ui.item).parents('.ir-dropzone-area').length){
                            index1 = parseInt(questionData.length);
                        }
                        jQuery(".ir-questions-library > .mantine-Stack-root").sortable('cancel');
                        jQuery(ui.item).removeClass('ir-picked');
                        const allQuestionsCopy = [...allQuestions];
                        const id = allQuestionsCopy[index].id;
                        const element = {
                            id: id,
                            title: {
                                rendered: allQuestionsCopy[index].title
                            },
                            question_type: allQuestionsCopy[index].type,
                            points_total: allQuestionsCopy[index].points,
                            post_status: allQuestionsCopy[index].post_status
                        }
                        questionArray.push(element);
                        if (index > -1) {
                            allQuestionsCopy.splice(index, 1);
                        }
                        for (var i = index1; i<questionArray.length; i++){
                            if(i == (questionArray.length - 1)){
                                questionArray[i].menu_order = index1 + 1;
                            }
                            else{

                                questionArray[i].menu_order = i + 2;
                            }
                        }
                        const sorted = [...questionArray.sort((a, b) => parseFloat(a.menu_order) - parseFloat(b.menu_order))];
                        setAllQuestions(allQuestionsCopy);
                        setQuestionData(sorted);
                    }
                    else{
                        jQuery(ui.item).removeClass('ir-picked');
                    }
                    
                    }

            })
            var conatinerWidth = jQuery('.ir-truncate').parents('.ir-fed-questions').width();
            jQuery('.ir-truncate').css('max-width', conatinerWidth - 350 +'px');
        })

        
    }

    const fetchQuizPoints = () => {
        const _questionData = [...questionData];
        const _quizNumberData = {...quizNumberData}
        let points = 0;
        _questionData.map((item) =>
            points+= item.points_total
        );
        _quizNumberData.points = points;
        _quizNumberData.questions = _questionData.length;
        setQuizNumberData(_quizNumberData);
    }

    const sortAlphabetically = (e) => {
        jQuery('.ir-recent').removeClass('ir-btn-grey');
        jQuery('.ir-view-all').addClass('ir-btn-grey');
        var mylist = jQuery('.ir-questions-checkboxes .mantine-CheckboxGroup-root > .mantine-Stack-root');
        var listitems = mylist.children('.ir-chk-wrap').get();
        listitems.sort(function(a, b) {
           return jQuery(a).text().toUpperCase().localeCompare(jQuery(b).text().toUpperCase());
        })
        jQuery.each(listitems, function(idx, itm) { mylist.append(itm); });
    }

    const showRecentQuestions = (e) => {
        jQuery('.ir-view-all').removeClass('ir-btn-grey');
        jQuery('.ir-recent').addClass('ir-btn-grey');
        jQuery(".ir-questions-checkboxes .mantine-Stack-root .ir-chk-wrap").sort(sort_li).appendTo('.ir-questions-checkboxes .mantine-Stack-root');
        function sort_li(a, b){
            return (jQuery(a).data('timestamp')) < (jQuery(b).data('timestamp')) ? 1 : -1;    
        }
    }

    const searchModule = (event, selector) => {
        const keyword = event.target.value.toLowerCase();
        jQuery(selector + ' .ir-chk-wrap').filter(function() {
          jQuery(this).toggle(jQuery(this).text().toLowerCase().indexOf(keyword) > -1)
        });
    }

    const addQuestionToBuilder = (index) => {
        const allQuestionsCopy = [...allQuestions];
        const questionArray =  [...questionData];
        const id = allQuestionsCopy[index].id;
        const element = {
            id: id,
            title: {
                rendered: allQuestionsCopy[index].title
            },
            question_type: allQuestionsCopy[index].type,
            points_total: allQuestionsCopy[index].points,
            menu_order: questionArray.length + 1,
            post_status: allQuestionsCopy[index].post_status
        }
        questionArray.push(element);
        if (index > -1) {
            allQuestionsCopy.splice(index, 1);
        }
        checkIfchecked();
        showNotification({
            title: sprintf(__('%s added to the builder!', 'wdm_instructor_role'), ir_fqb_loc.question_label),
            message: sprintf(__('Your %s has been added to the builder', 'wdm_instructor_role'), ir_fqb_loc.lower_question_label),
        })
        setAllQuestions(allQuestionsCopy);
        setQuestionData(questionArray);
    }

    const addSelectedQuestionToBuilder = () => {
        let questionArray =  [...questionData];
        let allQuestionsCopy = [...allQuestions];
        const checkedItems = jQuery('.ir-questions-checkboxes .mantine-Checkbox-root[data-checked=true]');
        checkedItems.each(function( index, element ) {
          const id = parseInt(jQuery(element).parent().next().attr('data-id'));
          const questionindex = parseInt(jQuery(element).parents('.ir-chk-wrap').attr('data-index'));
          const item = {
              id: id,
              title: {
                  rendered: allQuestionsCopy[questionindex].title
              },
              question_type: allQuestionsCopy[questionindex].type,
              points_total: allQuestionsCopy[questionindex].points,
              menu_order: questionArray.length + 1,
              post_status: allQuestionsCopy[questionindex].post_status
          }
          setTimeout(function(){
              const objWithIdIndex = allQuestionsCopy.findIndex((obj) => obj.id === id);
              if (objWithIdIndex > -1) {
                  allQuestionsCopy.splice(objWithIdIndex, 1);
              }
          })
          questionArray.push(item);
        });
        setTimeout(function(){
            showNotification({
                title: sprintf(__('Selected %s added to the builder!', 'wdm_instructor_role'), ir_fqb_loc.questions_label),
                message: sprintf(__('Your selected %s has been added to the builder', 'wdm_instructor_role'), ir_fqb_loc.questions_label),
            })
            setAllQuestions(allQuestionsCopy);
            setQuestionData(questionArray);
            checkIfchecked();
        })
    }

    const checkIfchecked = () => {
        setTimeout(function(){
            const checkedItems = jQuery('.ir-questions-checkboxes .mantine-Checkbox-root[data-checked=true]');
            if(checkedItems.length > 0){
                setCheckedQuestion(true);
            }
            else{
                setCheckedQuestion(false);   
            }   
        })
    }


    const removeQuestion = (id, title, type, points, status) => {
        let allQuestionsCopy = [...allQuestions];
        let questionArray =  [...questionData];
        const element = {
            id: id,
            title: title,
            type: type,
            points: points,
            post_status: status
        }
        allQuestionsCopy.push(element);
        const objWithIdIndex = questionArray.findIndex((obj) => obj.id === id);

        if (objWithIdIndex > -1) {
            questionArray.splice(objWithIdIndex, 1);
        }
        for (var i = objWithIdIndex; i<questionArray.length; i++){  
            
                questionArray[i].menu_order = i + 1;
        } 
        const sorted = [...questionArray.sort((a, b) => parseFloat(a.menu_order) - parseFloat(b.menu_order))];
        showNotification({
            title: sprintf(__('%s removed from builder!', 'wdm_instructor_role'), ir_fqb_loc.question_label),
            message: sprintf(__('Your %s has been removed from builder', 'wdm_instructor_role'), ir_fqb_loc.lower_question_label),
        })
        setQuestionData(sorted);
        setAllQuestions(allQuestionsCopy);
    };

    const html_entity_decode = (message) => {
        var domParser = new DOMParser();
        var decodedString = domParser.parseFromString(message, 'text/html').body.textContent;
        return decodedString;
    }

    const QuizPopoverNotification = () => {
        return (
            <Group position="center">
                <HoverCard width={280} shadow="md" withArrow>
                    <HoverCard.Target>
                        <Button style={{ border: 'none', padding: '0' }}><InfoCircle size={24} strokeWidth={2} color={'#F99B0E'} /></Button>
                    </HoverCard.Target>
                    <HoverCard.Dropdown>
                        <Text size={16} color="#ffffff" mb={5}>{sprintf(__("Currently, you can create or edit only single and multiple choice %s types from the frontend %s builder.", "wdm_instructor_role"), ir_fqb_loc.question_label, ir_fqb_loc.quiz_label)}</Text>
                    </HoverCard.Dropdown>
                </HoverCard>
            </Group>
        );
    }

    const DraftQuestionTooltip = () => {
        return (
            <Group position="center">
                <HoverCard width={280} shadow="md" withArrow>
                    <HoverCard.Target>
                        <Button style={{ border: 'none', padding: '0' }}><InfoCircle size={20} strokeWidth={2} color={'#ff613e'} /></Button>
                    </HoverCard.Target>
                    <HoverCard.Dropdown>
                        <Text size={16} color="#ffffff" mb={5}>{sprintf(__("Note: %s cannot be published with draft %s. Publish the draft %s or remove them from the %s builder. The removed draft %s will be available in the %s library", "wdm_instructor_role"), ir_fqb_loc.lower_quiz_label, ir_fqb_loc.lower_question_label, ir_fqb_loc.lower_question_label, ir_fqb_loc.lower_question_label, ir_fqb_loc.lower_question_label, ir_fqb_loc.lower_question_label)}</Text>
                    </HoverCard.Dropdown>
                </HoverCard>
            </Group>
        );
    }

    return (
        <>
            <Grid>
                <Grid.Col span={8}>
                    <Paper radius="xl" p="xl" className="ir-fed-course-page">
                        <Group align="center" position="apart">
                            <Title size={32} order={2}>{sprintf(__('%s', 'wdm_instructor_role'), ir_fqb_loc.questions_label)}</Title>
                            <Group spacing="xs" align="center">
                                <Text className="br-1" c="#444444" fw={400} size={14} mr={10}>{sprintf(__('No. of %s : ', 'wdm_instructor_role'), ir_fqb_loc.questions_label)}<b>{quizNumberData?.questions}</b></Text>
                                <Text c="#444444" fw={400} size={14} mr={10}>{__('No. of Points : ', 'wdm_instructor_role')} <b>{quizNumberData?.points}</b></Text>
                            </Group>
                        </Group>
                        {questionData?.length === 0 && (
                            <Text size={16} fw={700} c="#000000" align="center" mt={25} mb={25}>{sprintf(__('%s has no %s', 'wdm_instructor_role'), ir_fqb_loc.quiz_label, ir_fqb_loc.questions_label)}</Text>
                        )}
                        <div className="ir-sortable-questions">
                            
                            {null !== questionData && questionData.map((question, index) => (
                                <Paper className="ir-fed-questions" mb={16} radius="lg" p="md" withBorder data-id={question.id} data-menu-order={question.menu_order}>
                                    <Group align="center" spacing="xs" position="apart">
                                        <Group className="ir-quizzes-acc-top" align="center">
                                            <Group align="center" spacing="xs">
                                                <GridDots
                                                    size={20}
                                                    strokeWidth={2}
                                                    color={'#2067FA'}
                                                />
                                                <Group spacing="xs">
                                                    <Text className="ir-truncate" fz="md" fw={600} c="#222222">{html_entity_decode(question.title.rendered)}</Text>
                                                    {question.post_status === 'draft' && (
                                                        <Group align="center" spacing="xs">
                                                        <Text size={14} c="#ff613e" fw={600}>
                                                            {__('- Draft', 'wdm_instructor_role')}
                                                        </Text>
                                                        <DraftQuestionTooltip />
                                                        </Group>
                                                    )}
                                                    <input id={"ir-builder-element-"} className='ir-builder-quiz' type="hidden" />
                                                </Group>
                                            </Group>
                                        </Group>
                                        <Group align="center" spacing="xs">
                                            <Group spacing='xs' mr={10}>
                                                <Text c="#444444" fw={400} size={14}>{questionType[question.question_type]} : {question.points_total}</Text>
                                            </Group>
                                            <EditQuestionModal questionId={question.id} allQuestions={allQuestions} setAllQuestions={setAllQuestions} questionData={questionData} setQuestionData={setQuestionData} questionIndex={index} />
                                            <X onClick={() => removeQuestion(question.id, question.title.rendered, question.question_type, question.points_total, question.post_status)}
                                                size={24}
                                                strokeWidth={2}
                                                color={'#2067FA'}
                                            />
                                        </Group>
                                    </Group>
                                </Paper>
                            ))}
                        </div>
                        
                        <Paper className="ir-dropzone-area dotted-border" radius="lg" p="lg" withBorder>
                            <div className="ir-sortable-questions">
                            </div>
                            <span className="dropzone-text">{sprintf(__('Drag & drop existing one from %s library', 'wdm_instructor_role'), ir_fqb_loc.question_label)}</span>

                        </Paper>
                        
                        <Group spacing="xs" position="center" mt={30}>
                            <QuestionModal quizId={props.quizId} questionData={questionData} setQuestionData={setQuestionData}/>
                        </Group>
                    </Paper>
                </Grid.Col>
                <Grid.Col span={4}>
                    <Paper radius="xl" p="xl">
                        <Title size={32} order={2}>{sprintf(__('%s library', 'wdm_instructor_role'), ir_fqb_loc.question_label)}</Title>
                        <Text size="md" color="#555552" mb={16}>{sprintf(__('Select add or drag & drop previously made %s from below.', 'wdm_instructor_role'), ir_fqb_loc.questions_label)}</Text>
                        <Accordion variant='separated' radius={'md'} defaultValue={''} styles={{
                            item: {
                                // styles added to all items
                                backgroundColor: '#EFF0F7',
                                borderRadius: '15px',
                                marginBottom: "16px",
                                // styles added to expanded item
                                '&[data-active]': {
                                    backgroundColor: '#EFF0F7',
                                },
                            },

                            chevron: {
                                width: "28px",
                                marginLeft: "10px",
                                // styles added to chevron when it should rotate
                                '&[data-rotate]': {
                                    transform: 'rotate(-90deg)',
                                },
                            },
                        }}>
                            <Accordion.Item value="ir_other_lessons">
                                <Accordion.Control>
                                    <Group align="center" spacing="xs">
                                        <Text>{sprintf(__('%s', 'wdm_instructor_role'), ir_fqb_loc.questions_label)}</Text>
                                    </Group>
                                </Accordion.Control>
                                <Accordion.Panel className="ir-questions-checkboxes">
                                    <TextInput onKeyUp={(e) => searchModule(e, ".ir-questions-checkboxes")} className="ir-serachbox" placeholder={sprintf(__('Search %s', 'wdm_instructor_role'), ir_fqb_loc.question_label)} radius="md" icon={<Search size={18} />} />
                                    <Group align="center" spacing={0} mt={15} mb={15}>
                                        <Button onClick={(e) => showRecentQuestions(e)} size="xs" className="ir-btn-outline-black ir-btn-grey ir-recent">{__('Recent', 'wdm_instructor_role')}</Button>
                                        <Button onClick={(e) => sortAlphabetically(e)} size="xs" className="ir-btn-outline-black ir-view-all">{__('View All', 'wdm_instructor_role')}</Button>
                                    </Group>
                                    {null !== allQuestions && 0 === allQuestions.length && (
                                        <Text color="#6F717C">{sprintf(__('There are no existing %s', 'wdm_instructor_role'), ir_fqb_loc.questions_label)}</Text>
                                    )}
                                    <Checkbox.Group className="ir-draggable ir-questions-library" size="md" fw={600}
                                        orientation="vertical" key={allQuestions?.length}
                                        onChange={() => checkIfchecked()}
                                    >
                                        {null !== allQuestions && allQuestions.map((question, index) => (
                                            <Group className="ir-chk-wrap" position="apart" align="top" noWrap='true' data-timestamp={question.timestamp} data-index={index} id={"ir-lib-lesson-"+question.id}>
                                                <Group spacing="xs">
                                                    <Checkbox fw={600} label={html_entity_decode(question.title)} value={"check-"+question.id} />
                                                    {question.post_status === 'draft' && (
                                                        <Text size={14} c="#6F717C" fw={400}>{__('- Draft', 'wdm_instructor_role')}</Text>
                                                    )}
                                                </Group>
                                                <Button onClick={(e) => addQuestionToBuilder(index)} size="xs" className="ir-btn-add ir-btn-filled" data-id={question.id} >
                                                    {__('Add', 'wdm_instructor_role')}
                                                </Button>
                                            </Group>
                                        ))}

                                    </Checkbox.Group>
                                    {null !== allQuestions && allQuestions.length > 0 && (
                                        <Group mt={20} position="right">
                                            <Button onClick={() => addSelectedQuestionToBuilder()} className="ir-btn-filled" disabled={!checkedQuestion}>{__('Add Selected', 'wdm_instructor_role')}</Button>
                                        </Group>
                                    )}
                                </Accordion.Panel>
                            </Accordion.Item>
                        </Accordion>
                    </Paper>
                </Grid.Col>
            </Grid>
        </>
    );
}