import { useState, useEffect } from 'react';
import { useForm } from '@mantine/form';
import { Accordion, Text, Grid, Button, Group, TextInput, Textarea, Image, Anchor, Paper, MultiSelect, Checkbox, Loader, Select } from '@mantine/core';
import { showNotification } from '@mantine/notifications';

import { Trash, PhotoUp, Replace, ExclamationMark, Plus, X } from 'tabler-icons-react';
import { __ } from "@wordpress/i18n";
import apiFetch from '@wordpress/api-fetch';
import { MediaUpload } from '@wordpress/media-utils';


export default function QuizPage(props) {
	let timer = 0;
	let descTimer = 0;
	const [editSlug, setEditSlug] = useState(false);
	const [showTagLoader, setShowTagLoader] = useState(false);
	const [new_category, setNewCategory] = useState('');
	const [parent_category, setParentCategory] = useState('');
	const [showCatFields, setShowCatFields] = useState(false);
	const [category_loading, setCategoryLoader] = useState(false);
	const [authors, setAuthors] = useState([]);
	const { review_content, setReviewContent } = props;
	const [process_review, setReviewLoader] = useState(false);

	const setTitle = (event) => {
		clearTimeout(timer);
		timer = setTimeout(function () {
			const _quizData = { ...props.quizData };
			_quizData.title.rendered = event.target.value;
			props.setQuizData(_quizData);
		}, 500);
	}

	const html_entity_decode = (message) => {
		var domParser = new DOMParser();
		var decodedString = domParser.parseFromString(message, 'text/html').body.textContent;
		return decodedString;
	}

	const setDescription = (event) => {
		clearTimeout(descTimer);
		descTimer = setTimeout(function () {
			const _quizData = { ...props.quizData };
			_quizData.content.rendered = event.contentWindow.document.body.innerHTML;
			props.setQuizData(_quizData);
		}, 500);
	}

	const setSlug = (link) => {
		link = link.replace(/\/$/, "");
		link = link.substring(0, link.lastIndexOf("/") + 1);
		if (props.quizForm.values.slug == undefined) {
			props.quizForm.values.slug = props.quizData.slug
		}
		props.setQuizData({
			...props.quizData,
			link: link + props.quizForm.values.slug,
			slug: props.quizForm.values.slug
		})
		setEditSlug(false);
	}

	const GetLinkWithoutSlug = (props) => {
		let link = props.link.replace(/\/$/, "");
		link = link.substring(0, link.lastIndexOf("/") + 1);
		return (
			<>
				<Anchor color="#2067FA" size="sm">
					{link}
				</Anchor>
			</>
		);
	}

	const createNewQuizTag = (query) => {
		// Create New Quiz Tag.
		setShowTagLoader(true);
		apiFetch(
			{
				path: "/wp/v2/ld_quiz_tag",
				method: 'POST',
				data: {
					name: query
				}
			}
		).then((response) => {
			if (false != response && response.hasOwnProperty('id')) {
				setShowTagLoader(false);
				const item = { value: response.id.toString(), label: response.name };
				props.setQuizTags((current) => [...current, item]);
				props.quizForm.setFieldValue('ld_quiz_tag', [...props.quizForm.values.ld_quiz_tag, response.id.toString()])
			}
		});
	}

	const createQuizCategory = () => {
		if (new_category.length === 0) {
			showNotification({
				title: __('Warning', 'wdm_instructor_role'),
				message: __('Category name cannot be empty', 'wdm_instructor_role'),
				icon: <ExclamationMark />,
				color: 'yellow'
			});
			return;
		}

		setCategoryLoader(true);
		let data = {
			name: new_category
		}
		if (null !== parent_category && parent_category.length > 0) {
			data.parent = parent_category;
		}

		// Create New Quiz Category.
		apiFetch(
			{
				path: "/wp/v2/ld_quiz_category",
				method: 'POST',
				data
			}
		).then((response) => {
			if (false != response && response.hasOwnProperty('id')) {
				const item = { value: response.id.toString(), label: response.name };
				props.setQuizCategories((current) => [...current, item]);
				props.quizForm.setFieldValue('ld_quiz_category', [...props.quizForm.values.ld_quiz_category, response.id.toString()])
			}
			setShowCatFields(false);
			setCategoryLoader(false);
			setParentCategory('');
			setNewCategory('');
		});
	}

	const approveContent = () => {
		setReviewLoader(true);

		jQuery.ajax({
			url: ir_fqb_loc.ajax_url,
			method: 'POST',
			data: {
				action: 'approve_instructor_update_ajax',
				post_id: props.quizData?.id
			},
			success: function (response) {
				showNotification({
					title: __('Instructor updates approved successfully !!', 'wdm_instructor_role')
				})
				setReviewLoader(false);
				setReviewContent(null);
			}
		});
	}

	useEffect(() => {
		wp.editor.initialize(
			'ir-quiz-content-editor',
			{
				tinymce: {
					setup: function (ed) {
						ed.on('keyup change', function (e) {
							setDescription(ed);
						});
					},
					wpautop: true,
					height: '300px',
					plugins: 'charmap colorpicker compat3x directionality hr image lists media paste tabfocus textcolor wordpress wpautoresize wpdialogs wpeditimage link',
					toolbar1: 'formatselect bold italic underline strikethrough | bullist numlist | blockquote hr wp_more | alignleft aligncenter alignright | link unlink |  media wp_add_media'
				},
				quicktags: false,
				mediaButtons: true,

			}
		);

		// Get author users.
		apiFetch(
			{
				path: "/ir/v1/users?roles=wdm_instructor,administrator",
				method: "GET"
			}
		).then((data) => {
			let author_list = [];
			data.map((user) => {
				author_list.push({
					label: user.name,
					value: user.id.toString()
				});
			})
			setAuthors(author_list);
		})
	}, [props.quizData]);

	return (
		<>

			{null !== props.quizData && (
				<Grid>
					<Grid.Col span={8}>
						<Paper radius="xl" p="xl" className="ir-fed-course-page">
							<Group align="center" mt={10}>
								<TextInput className="ir-tt-text ir-parent-settings ir-quiz-name"
									label={sprintf(__('%s title', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}
									placeholder={__('Write title here', 'wdm_instructor_role')}
									size="lg"
									defaultValue={html_entity_decode(props.quizData.title.rendered)}
									onChange={(event) => setTitle(event)}
								/>
							</Group>
							{!editSlug && (ir_fqb_loc.is_admin || (false !== ir_fqb_loc.instructor_settings && ('off' !== ir_fqb_loc.instructor_settings?.enable_permalinks))) && (
								<Group className="ir-link-section" align="center" mt={20} pl={10} spacing="xs">
									<Text>{sprintf(__('%s URL:', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}</Text>
									<Anchor color="#2067FA" size="sm" href={props.quizData.link} target="_blank">
										{props.quizData.link}
									</Anchor>
									<Button onClick={() => setEditSlug(true)} size="xs" className="ir-btn-outline" disabled={props.quizData.status === 'draft' ? true : false}>{__('Edit', 'wdm_instructor_role')}</Button>
								</Group>
							)}
							{editSlug && (ir_fqb_loc.is_admin || (false !== ir_fqb_loc.instructor_settings && ('off' !== ir_fqb_loc.instructor_settings?.enable_permalinks))) && (
								<Group className="ir-link-section" align="center" mt={20} pl={10} spacing="xs">
									<Text>{sprintf(__('%s URL:', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}</Text>
									<GetLinkWithoutSlug link={props.quizData.link} />
									<TextInput className="ir-slug-input" size="xs"
										defaultValue={props.quizData.slug}
										{...props.quizForm.getInputProps('slug')}
									/>
									<Button onClick={() => setSlug(props.quizData.link)} size="xs" className="ir-btn-filled">{__('Ok', 'wdm_instructor_role')}</Button>
									<Button onClick={() => setEditSlug(false)} size="xs" className="ir-btn-outline">{__('Cancel', 'wdm_instructor_role')}</Button>
								</Group>
							)}
							<Group mb={34} mt={30} p={8} className="ir-featured-image-section">
								{null === props.featured_image && (

									<MediaUpload
										onSelect={(media) => {
											props.setFeaturedImage({
												id: media.id,
												url: media.url
											});
											props.setQuizData({
												...props.quizData,
												featured_media: media.id
											})
										}}
										allowedTypes={['image']}
										render={({ open }) => (
											<Group>
												<img src={require('/images/featured-placeholder.png')} />
												<Button fw={400} className="ir-btn-subtle" onClick={open} leftIcon={<PhotoUp size={23} strokeWidth={1} />}  >{__('Set Featured Image', 'wdm_instructor_role')}</Button>
											</Group>
										)}
									/>
								)}
								{null !== props.featured_image && (
									<Group>
										<div style={{ width: 88, marginLeft: 'auto', marginRight: 'auto' }}>
											<Image
												width={88}
												height={61}
												radius="md"
												src={props.featured_image.url}
											/>
										</div>
										<div>
											<MediaUpload
												onSelect={(media) => {
													props.setFeaturedImage({
														id: media.id,
														url: media.url
													});
													props.setQuizData({
														...props.quizData,
														featured_media: media.id
													})
												}}
												allowedTypes={['image']}
												value={props.featured_image.id}
												render={({ open }) => (
													<>
														<Button fw={400} className="ir-btn-subtle" onClick={open} leftIcon={<Replace size={23} strokeWidth={1} />} >{__('Replace', 'wdm_instructor_role')}</Button>
														<Button fw={400} className="ir-btn-subtle ir-red-txt" onClick={() => {
															props.setFeaturedImage(null);
															props.setQuizData({
																...props.quizData,
																featured_media: null
															})
														}} leftIcon={<Trash size={23} strokeWidth={1} />} >{__('Remove', 'wdm_instructor_role')}</Button>
													</>
												)}
											/>
										</div>
									</Group>
								)}
							</Group>
							<Text mb={5} className="ir-parent-settings" size="lg">{sprintf(__('%s description', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}</Text>
							<Textarea
								className="ir-tiny-mce-editors"
								id="ir-quiz-content-editor"
								defaultValue={props.quizData.content.rendered}
								onChange={(event) => setDescription(event)}
							/>
						</Paper>
					</Grid.Col>
					<Grid.Col span={4}>
						{ir_fqb_loc.instructor_settings?.review_course && ir_fqb_loc.is_admin && (
							<Paper radius="xl" p="xl" mb={20}>
								<Group spacing="xs" className="ir-fc-100">
									<Text className="ir-parent-settings ir-capitalize-letter" size="lg" width="100%">{__('Pending Approvals', 'wdm_instructor_role')}</Text>
									{ir_fqb_loc.instructor_settings?.review_course && !review_content && (
										<Text size={14} weight={400} color='#A0A3BD' mt={5} mb={5}>{__('No pending approvals', 'wdm_instructor_role')}</Text>
									)}
									{ir_fqb_loc.instructor_settings?.review_course && null !== review_content && 'pending' === review_content?.status && (
										<Group position='right' mt={20}>
											<Button
												className="ir-btn-outline"
												variant="outline"
												radius="md"
												size="sm"
												loading={process_review}
												loaderPosition="right"
												onClick={approveContent}
											>
												{__('Approve Instructor Updates', 'wdm_instructor_role')}
											</Button>
										</Group>
									)}
								</Group>
							</Paper>
						)}
						<Paper radius="xl" p="xl">
							{ir_fqb_loc.is_admin && (
								<Group spacing="xs" mb={34} className="ir-fc-100">
									<Text className="ir-parent-settings ir-capitalize-letter" size="lg" width="100%" >{__('Author', 'wdm_instructor_role')}</Text>
									<Accordion width="100%" variant="contained" radius="md">
										<Accordion.Item value="course-author">
											<Accordion.Control>
												{__('Author', 'wdm_instructor_role')}
											</Accordion.Control>
											<Accordion.Panel>
												<Select mt={6}
													placeholder={sprintf(__("Select %s Author", "wdm_instructor_role"), ir_fqb_loc.course_label)}
													data={authors}
													defaultValue={props.quizData.author.toString()}
													{...props.quizForm.getInputProps('author')}
												/>
											</Accordion.Panel>
										</Accordion.Item>
									</Accordion>
								</Group>
							)}
							<Group spacing="xs" mb={6} className="ir-fc-100">
								<Text className="ir-parent-settings ir-capitalize-letter" size="lg" width="100%">
									{(__('Tags and Categories', 'wdm_instructor_role'))}
								</Text>
								<Accordion width="100%" variant="contained" radius="md" defaultValue="customization">
									<Accordion.Item value="ld_quiz_tag">
										<Accordion.Control>
											{sprintf(__('%s Tags', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}

										</Accordion.Control>
										<Accordion.Panel>
											{props.quizTags !== null && (
												<MultiSelect className="ir-multiselect-loader"
													label={sprintf(__("Add %s tags", 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}
													icon={showTagLoader && (<Loader size="xs" />)}
													placeholder={__("Select items", 'wdm_instructor_role')}
													searchable
													data={props.quizTags}
													{...props.quizForm.getInputProps('ld_quiz_tag')}
													creatable
													getCreateLabel={(query) => `+ Create ${query}`}
													onCreate={createNewQuizTag}
												/>
											)}

											{props.quizTags === null && (
												<Text color="dimmed" weight={400}>{sprintf(__("%s tags are disabled from Learndash settings.", 'wdm_instructor_role'), ir_fqb_loc.quiz_label)} </Text>
											)}

										</Accordion.Panel>
									</Accordion.Item>
									<Accordion.Item value="ld_quiz_category">
										<Accordion.Control>
											{sprintf(__('%s Categories', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}
										</Accordion.Control>
										<Accordion.Panel>
											{((ir_fqb_loc.is_admin && "yes" === ir_fqb_loc.ld_cat_tag?.quiz) || false !== ir_fqb_loc.instructor_settings && (('off' !== ir_fqb_loc.instructor_settings?.enable_ld_category) && "yes" === ir_fqb_loc.ld_cat_tag?.quiz)) && props.quizCategories !== null && (
												<>
													<Text size="xs" color="dimmed" weight={400} mb={10} fs="italic">
														<strong>{__('Note: ', 'wdm_instructor_role')}</strong>{__("Child categories cannot be created from here.", "wdm_instructor_role")}
													</Text>
													<Checkbox.Group
														{...props.quizForm.getInputProps('ld_quiz_category')}
														orientation="vertical"
													>
														{props.quizCategories.map((category, index) => (
															<div>
																<Checkbox size="md" value={category.value} label={category.label} />
																{category.hasOwnProperty('children') && category.children.map((child) => (
																	<Checkbox ml={20} mt={20} size="md" value={child.id.toString()} label={child.name} />
																))}
															</div>
														))}
													</Checkbox.Group>
													<Group align="center" spacing="xs" mt={20}>
														<Text className="ir-add-cat" size={14} color="#2067FA" fw={600} onClick={() => setShowCatFields(true)}>{sprintf(__('Add new %s category', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}</Text>
														{!showCatFields && (
															<Plus onClick={() => setShowCatFields(true)}
																size={18}
																strokeWidth={2}
																color={'#2067FA'}

															/>
														)}
														{showCatFields && (
															<X onClick={() => setShowCatFields(false)}
																size={18}
																strokeWidth={2}
																color={'#2067FA'}

															/>
														)}
													</Group>
													{showCatFields && (
														<div>
															<TextInput
																placeholder={__("Enter new category name", "wdm_instructor_role")}
																value={new_category}
																onChange={(event) => setNewCategory(event.currentTarget.value)}
															/>
															{/* <Select mt={6}
                                                                    clearable
                                                                    placeholder="Select Parent Quiz Category "
                                                                    data={quizCategories}
                                                                    value={parent_category} onChange={setParentCategory}
                                                                /> */}
															<Button mt={6} className="ir-btn-filled" onClick={createQuizCategory} loading={category_loading}>{__('Add', 'wdm_instructor_role')}</Button>
														</div>
													)}
												</>
											)}
											{(((false === ir_fqb_loc.instructor_settings || (('off' === ir_fqb_loc.instructor_settings?.enable_ld_category) || "yes" !== ir_fqb_loc.ld_cat_tag?.quiz))) || props.quizCategories === null) && (
												<Text color="dimmed" weight={400}>{sprintf(__("%s categories are disabled from Learndash settings.", 'wdm_instructor_role'), ir_fqb_loc.quiz_label)} </Text>
											)}
										</Accordion.Panel>
									</Accordion.Item>

								</Accordion>
							</Group>
						</Paper>
					</Grid.Col>
				</Grid>
			)}
		</>
	);
}