import { useState } from 'react';

import {
    Accordion,
    Text,
    Title,
    Grid,
    Paper,
    Input,
    Checkbox,
    Button,
    Group,
    TextInput,
    FileButton,
    Switch,
    Radio,
    NumberInput,
    MultiSelect,
    Loader,
    Divider
} from '@mantine/core';

import { Upload } from 'tabler-icons-react';
import { __ } from "@wordpress/i18n";

import { RichTextEditor } from '@mantine/rte';
import QuizAccess from '/src/quiz-builder/components/quiz-settings/quizAccess.js';
import ProgressionRestriction from '/src/quiz-builder/components/quiz-settings/progressionRestriction.js';
import DisplayContent from '/src/quiz-builder/components/quiz-settings/displayContent.js';
import ResultPage from '/src/quiz-builder/components/quiz-settings/resultPage.js';
import AdminDataHandling from '/src/quiz-builder/components/quiz-settings/adminDataHandling.js';


export default function CourseSettings (props){
    const [file, setFile] = useState(File | null > (null));
    const [data, setData] = useState([
        { value: 'elearning', label: 'E-Learning' },
        { value: 'education', label: 'Education' },
        { value: 'lms', label: 'LMS' },
        { value: 'wc', label: 'Ecommerce' },
    ]);
    const {form, course_id} = props;
    const {resultText, setResultText, customField, setCustomField} = props;

    const settingsItem = [
      {
        id: 'quiz-access-settings' ,
        label: sprintf(__('%s access settings', 'wdm_instructor_role'), ir_fqb_loc.quiz_label),
        description: sprintf(__('Controls the requirements for accessing the %s', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label),
        content: <QuizAccess quizData={props.quizData} setQuizData={props.setQuizData} quizForm={props.quizForm} wisdmQuizData={props.wisdmQuizData} setWisdmQuizData={props.setWisdmQuizData}/>
      },

      {
        id: 'Progression-and-restriction-settings',
        label: __('Progression and restriction settings', 'wdm_instructor_role'),
        description: sprintf(__('Controls the requirements for accessing and completing the %s', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label),
        content: <ProgressionRestriction quizForm={props.quizForm} quizData={props.quizData} setQuizData={props.setQuizData} wisdmQuizData={props.wisdmQuizData} setWisdmQuizData={props.setWisdmQuizData} />
      },

      {
        id: 'display-and-content-options',
        label: __('Display and content options', 'wdm_instructor_role'),
        description: sprintf(__('Controls how the %s will look and what will be displayed', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label),
        content: <DisplayContent quizForm={props.quizForm} quizData={props.quizData} setQuizData={props.setQuizData} wisdmQuizData={props.wisdmQuizData} setWisdmQuizData={props.setWisdmQuizData} />
      },

      {
        id: 'result-page-display',
        label: __('Result page display', 'wdm_instructor_role'),
        description: __('Controls how the results page will look', 'wdm_instructor_role'),
        content: <ResultPage quizData={props.quizData} setQuizData={props.setQuizData} quizForm={props.quizForm} wisdmQuizData={props.wisdmQuizData} setWisdmQuizData={props.setWisdmQuizData} resultText={resultText} setResultText={setResultText} />
      },
      {
        id: 'Administrative-and-data-handling',
        label: __('Administrative and data handling', 'wdm_instructor_role'),
        description: __('Controls data handling options, notifications and templates', 'wdm_instructor_role'),
        content: <AdminDataHandling quizData={props.quizData} setQuizData={props.setQuizData} quizForm={props.quizForm} wisdmQuizData={props.wisdmQuizData} setWisdmQuizData={props.setWisdmQuizData} customField={customField} setCustomField={setCustomField} save_template={props.save_template} setSaveTemplate={props.setSaveTemplate}/>
      },
    ];

    return (
        <>
            <Grid>
                <Grid.Col span={8} offset={2}>
                    <Paper  radius="xl" className="ir-fed-course-settings">
                        <Accordion radius="xl" chevronPosition="right" variant="contained">
                            {settingsItem.map((item) => (
                               <Accordion.Item p="xs" value={item.id} key={item.label}>
                                 <Accordion.Control>
                                   <Group noWrap>
                                     <div>
                                       <Text className="ir-uppercase" size="md" weight={600}>{item.label}</Text>
                                       <Text size="sm" color="#6F717C" weight={400}>
                                         {item.description}
                                       </Text>
                                     </div>
                                   </Group>
                                 </Accordion.Control>
                                 <Accordion.Panel>
                                   {item.content}
                                 </Accordion.Panel>
                               </Accordion.Item>
                            ))}
                       </Accordion>
                    </Paper>
                </Grid.Col>
            </Grid>
        </>
    );
}