import { useBlockProps } from '@wordpress/block-editor';
import { useState, useEffect } from 'react';
import {
	AppShell,
	Navbar,
	Header,
	Accordion,
	MantineProvider,
	Text,
	Title,
	Grid,
	Paper,
	Input,
	Checkbox,
	Button,
	Group,
	Space,
	Center,
	CloseButton,
	Skeleton,
	TextInput,
	Modal,
	Tabs,
	FileButton,
	Switch,
	Radio,
	NumberInput,
	MultiSelect,
	Loader,
	Divider,
	Badge,
	Popover
} from '@mantine/core';

import { ChevronLeft, Eye, DeviceMobile, DeviceTablet, DeviceDesktop, CircleCheck, ClockHour4, CalendarEvent } from 'tabler-icons-react';
import { showNotification, NotificationsProvider } from '@mantine/notifications';
import { TimeInput, DatePicker } from '@mantine/dates';
import { ModalsProvider } from '@mantine/modals';
import { openConfirmModal } from '@mantine/modals';
import apiFetch from '@wordpress/api-fetch';
import { MediaUpload } from '@wordpress/media-utils';
import { useForm } from '@mantine/form';

import QuizPage from '/src/quiz-builder/components/quizPage.js';
import QuizBuilder from '/src/quiz-builder/components/quizBuilder.js';
import QuizSettings from '/src/quiz-builder/components/quizSettings.js';
import DummyQuizPage from '/src/quiz-builder/components/dummyPages/dummyQuizPage.js';

import { __ } from "@wordpress/i18n";

export default function save() {
	const quizId = getQuizId();
	const courseID = parseInt(document.getElementById('ir_course_id').value);
	const [quizData, setQuizData] = useState(null);
	const [wisdmQuizData, setWisdmQuizData] = useState(null);
	const [questionData, setQuestionData] = useState(null);
	const [quizTags, setQuizTags] = useState(null);
	const [quizCategories, setQuizCategories] = useState(null);
	const [featured_image, setFeaturedImage] = useState(null);
	const [showLoader, setShowLoader] = useState(false);
	const [showDraftLoader, setShowDraftLoader] = useState(false);
	const [resultText, setResultText] = useState({ activ: [], prozent: [], text: [] });
	const [customField, setCustomField] = useState([]);
	const [review_content, setReviewContent] = useState(null);
	const [save_template, setSaveTemplate] = useState('');

	const quizForm = useForm({
		initialValues: {
			title: '',
			content: '<p></p>',
			featured_image_url: null,
			featured_image: null,
			status: 'draft',
			ld_quiz_tag: [],
			visibility: 'public',
			password: ''
		}
	})

	function getQuizId() {
		let path = window.location.pathname;
		path = path.replace(/^\/+/g, '');
		path = path.replace(/\/+$/g, '');
		const path_segments = Object.values(path.split('/'));
		return parseInt(path_segments.pop());
	}

	useEffect(() => {
		apiFetch(
			{
				path: "/ldlms/v2/sfwd-quiz/" + quizId,
				method: 'GET',
			}
		).then((data) => {
			const specificDate = new Date(parseInt(data.visible_after_specific_date) * 1000);
			const timeLimit = parseInt(data.time_limit_time);
			quizForm.setValues({
				sp_year: specificDate.getFullYear(),
				sp_date: specificDate.getDate(),
				sp_hour: specificDate.getHours(),
				sp_minute: specificDate.getMinutes(),
				sp_month: specificDate.getMonth() + 1,
				tl_hour: Math.floor(timeLimit / 3600),
				tl_minute: Math.floor(timeLimit % 3600 / 60),
				tl_second: Math.floor(timeLimit % 3600 % 60),
				certificate: data.certificate,
				date: (data.date.length) ? new Date(data.date) : new Date(),
				time: (data.date.length) ? new Date(data.date) : new Date(),
				password: data.password
			});
			setQuizData(data);
			if (0 !== data.featured_media) {
				apiFetch(
					{
						path: "/wp/v2/media/" + data.featured_media,
						method: 'GET',
					}
				).then((data) => {
					setFeaturedImage({
						id: data.featured_media,
						url: data.source_url
					});
				})

			}
			if (data.ld_quiz_tag) {
				if ("yes" === ir_fqb_loc.ld_cat_tag?.quiz_tag) {
					apiFetch(
						{
							path: "/wp/v2/ld_quiz_tag?per_page=100",
							method: 'GET',
						}
					).then((data) => {
						let tags = [];
						data.map((tag, ind) => {
							tags.push({
								label: tag.name,
								value: tag.id.toString()
							})
						}
						)
						setQuizTags(tags);
					});
				}
			}
			if ("yes" === ir_fqb_loc.ld_cat_tag?.quiz) {
				// if (data.ld_quiz_category){
				apiFetch(
					{
						path: "/ir/v1/ld-quiz-category?per_page=100",
						method: 'GET',
					}
				).then((data) => {
					let categories = [];
					data.map((category, ind) => {
						if (category.hasOwnProperty('children')) {
							categories.push({
								label: category.name,
								value: category.id.toString(),
								children: category.children
							});
						} else {
							categories.push({
								label: category.name,
								value: category.id.toString()
							});
						}
					})
					setQuizCategories(categories);
				});
			}
			// }

			apiFetch(
				{
					path: "/ldlms/v2/sfwd-question/?quiz=" + quizId + "&per_page=100",
					method: 'GET'
				}
			).then((data) => {
				setQuestionData(data);
			});

			setVisibility(data);
		});

		apiFetch(
			{
				path: "/ir/v1/quiz-settings/" + quizId,
				method: 'GET'
			}

		).then((resp) => {
			// console.log('wisdm data');
			// console.log(resp);
			quizForm.setValues({
				result_text: resp.result_text,
				show_max_question_value: resp.show_max_question_value,
				statistics_ip_lock_enabled: resp.statistics_ip_lock_enabled,
				statistics_ip_lock_enabled_value: resp.statistics_ip_lock_enabled_value / 60,
				email_admin_enabled: resp.email_admin_enabled,
				quiz_modus: resp.quiz_modus,
				multiple_questions_per_page: resp.multiple_questions_per_page,
				single_feedback: resp.single_feedback,
				single_back_button: resp.single_back_button,
				ld_quiz_tag: resp.ld_quiz_tag?.map(String),
				ld_quiz_category: resp.ld_quiz_category?.toString().split(','),
				prerequisites: resp.prerequisites,
				toplist_enabled: resp.toplist_enabled,
				toplist_data_add_permissions: resp.toplist_data_add_permissions,
				toplist_data_add_multiple: resp.toplist_data_add_multiple,
				toplist_data_time: resp.toplist_data_time,
				toplist_data_show_limit: resp.toplist_data_show_limit,
				toplist_data_add_automatic: resp.toplist_data_add_automatic,
				toplist_data_sort: resp.toplist_data_sort,
				toplist_data_showin_enabled: resp.toplist_data_showin_enabled,
				toplist_data_showin: resp.toplist_data_showin === 0 ? "1" : resp.toplist_data_showin.toString(),
				really_simple_captcha: resp.really_simple_captcha,
				custom_field_display_position: resp.custom_field_display_position.toString()
			});
			setCustomField(resp.custom_fields);
			setWisdmQuizData(resp);
		});

		if (ir_fqb_loc.instructor_settings?.review_course && ir_fqb_loc.is_admin) {
			// Get quiz review info
			apiFetch(
				{
					path: "/ir/v1/sfwd-quiz/" + quizId + "/review",
					method: "GET"
				}
			).then((data) => {
				setReviewContent(data);
			});
		}
	}, []);

	const html_entity_decode = (message) => {
		var domParser = new DOMParser();
		var decodedString = domParser.parseFromString(message, 'text/html').body.textContent;
		return decodedString;
	}


	const confirmDraft = () => {
		openConfirmModal({
			modal: 'switch-draft',
			title: __('Switch to draft', 'wdm_instructor_role'),
			children: (
				<Text size="sm">
					{sprintf(__('Are you sure you want to unpublish this %s?', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)}
					{__(' This will be saved as draft.', 'wdm_instructor_role')}
				</Text>
			),
			labels: { confirm: 'Yes', cancel: 'Cancel' },
			confirmProps: { color: 'red' },
			modalId: "bgdvbsj",
			onCancel: () => setShowDraftLoader(false),
			onClose: () => setShowDraftLoader(false),
			onConfirm: () => updateQuizData('draft', 'switch'),
		});
	}

	const openIframeInTab = (device) => {
		const win = window.open();
		win.document.write('<iframe frameborder="1" style="width:' + device + '; height:100vh; display:block; margin: auto;" src=' + quizData.link + ' allowfullscreen></iframe>')
	}

	const quizPublished = (link) => openConfirmModal({
		modal: 'quiz-published',
		centered: true,
		children: (
			<>
				<CircleCheck
					size={95}
					strokeWidth={1}
					color={'#4DCE11'}
				/>
				<Text size={18} fw={600}>
					{sprintf(__('Congratulations your %s is published!', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}
				</Text>
			</>
		),
		labels: { confirm: sprintf(__('View %s', 'wdm_instructor_role'), ir_fqb_loc.quiz_label), cancel: 'Back' },
		confirmProps: { color: '#2067FA' },
		modalId: "bgdvbsj",
		onCancel: () => console.log('Cancel'),
		onConfirm: () => window.open(link, '_blank'),
	});

	const updateAlert = (status, label) => {
		const _questiondata = [...questionData];
		let hasDraft = false;
		_questiondata.map((questionItem) => {
			if (questionItem.post_status === 'draft') {
				hasDraft = true;
			}
		})
		if (hasDraft) {
			draftUpdateAlert(status, label);
		}
		else {
			updateQuizData(status, label);
		}
	}

	const draftUpdateAlert = (status, label) => {
		openConfirmModal({
			modal: 'switch-draft',
			title: sprintf(__('Draft %s Found!', 'wdm_instructor_role'), ir_fqb_loc.questions_label),
			children: (
				<div>
					<Text size="sm">
						{sprintf(__('Note: Quiz cannot be published with draft questions.', 'wdm_instructor_role'), ir_fqb_loc.questions_label, ir_fqb_loc.quiz_label)}
					</Text>
					<Text className="ir-d-inline" size="sm" fw={600}>
						{sprintf(__('Publish the draft questions or remove them from the question builder. ', 'wdm_instructor_role'), ir_fqb_loc.questions_label, ir_fqb_loc.quiz_label)}
					</Text>
					<Text className="ir-d-inline" size="sm">
						{sprintf(__('The removed draft question will be available in the question library', 'wdm_instructor_role'), ir_fqb_loc.questions_label, ir_fqb_loc.quiz_label)}
					</Text>
				</div>
			),
			labels: { confirm: 'Ok' },
			confirmProps: { color: 'red' },
			cancelProps: { id: 'ir-hidden' },
			modalId: "bgdvbsj",
			onCancel: () => setShowLoader(false),
			onClose: () => setShowLoader(false),
			onConfirm: () => setShowLoader(false),
		});
	}

	const updateQuizData = (status, label) => {
		const date_str = parseInt(quizForm.values.sp_year) + "-" + parseInt(quizForm.values.sp_month) + "-" + parseInt(quizForm.values.sp_date) + " " + parseInt(quizForm.values.sp_hour) + ":" + parseInt(quizForm.values.sp_minute);
		const specific_date = new Date(date_str);
		const timestamp = (Math.trunc(specific_date.getTime() / 1000)).toString();
		const time_str = (parseInt(quizForm.values.tl_hour) * 60 * 60) + (parseInt(quizForm.values.tl_minute) * 60) + parseInt(quizForm.values.tl_second);
		const time_limit_time = Math.trunc(time_str).toString();
		let show_max = null;
		let prerequisites = quizForm.values.prerequisites;
		if (quizForm.values.prerequisites.length === 1 && quizForm.values.prerequisites[0] === '') {
			prerequisites = [];
		}
		if (quizForm.values.show_max_question === 'show_max') {
			show_max = '1';
		}
		if (quizForm.values.show_max_question === 'display_all') {
			show_max = '0';
		}
		if (quizForm.values.single_back_button === true) {
			quizForm.values.single_back_button = 'on';
		}
		else if (quizForm.values.single_back_button === false) {
			quizForm.values.single_back_button = 'off';
		}
		if (quizForm.values.time_limit_cookie_toggle === false) {
			quizForm.setValues({
				time_limit_cookie: 0,
			});
		}

		// Check if future published date.
		if (new Date().getTime() < getCombinedDate(quizForm.values.date, quizForm.values.time).getTime()) {
			status = 'future';
		}

		if ('draft' !== status && 'private' === quizForm.values.visibility) {
			status = 'private';
		}

		apiFetch(
			{
				path: "/ldlms/v2/sfwd-quiz/" + quizId,
				method: 'POST',
				data:
				{
					title: quizData.title.rendered,
					status: status,
					author: quizForm.values.author,
					content: quizData.content.rendered,
					featured_media: quizData.featured_media,
					visible_type: quizForm.values.visible_type,
					visible_after: quizForm.values.visible_after,
					slug: quizForm.values.slug,
					registered_users_only: quizForm.values.registered_users_only,
					retry_restrictions_enabled: quizForm.values.retry_restrictions_enabled,
					retry_repeats: quizForm.values.retry_repeats,
					answer_all_questions_enabled: quizForm.values.answer_all_questions_enabled,
					review_table_enabled: quizForm.values.review_table_enabled,
					summary_hide: quizForm.values.summary_hide,
					skip_question_disabled: quizForm.values.skip_question_disabled,
					custom_sorting: quizForm.values.custom_sorting,
					sort_categories: quizForm.values.sort_categories,
					question_random: quizForm.values.question_random,
					passing_percentage: quizForm.values.passing_percentage,
					show_points: quizForm.values.show_points,
					show_category: quizForm.values.show_category,
					hide_question_position_overview: quizForm.values.hide_question_position_overview,
					hide_question_numbering: quizForm.values.hide_question_numbering,
					numbered_answer: quizForm.values.numbered_answer,
					answer_random: quizForm.values.answer_random,
					title_hidden: quizForm.values.title_hidden,
					restart_button_hide: quizForm.values.restart_button_hide,
					show_average_result: quizForm.values.show_average_result,
					show_category_score: quizForm.values.show_category_score,
					hide_result_points: quizForm.values.hide_result_points,
					hide_result_correct_question: quizForm.values.hide_result_correct_question,
					hide_result_quiz_time: quizForm.values.hide_result_quiz_time,
					custom_answer_feedback: quizForm.values.custom_answer_feedback,
					hide_answer_message_box: quizForm.values.hide_answer_message_box,
					disabled_answer_mark: quizForm.values.disabled_answer_mark,
					view_question_button_hidden: quizForm.values.view_question_button_hidden,
					statistics_enabled: quizForm.values.statistics_enabled,
					view_profile_statistics_enabled: quizForm.values.view_profile_statistics_enabled,
					email_enabled: quizForm.values.email_enabled,
					email_user_enabled: quizForm.values.email_user_enabled,
					questions: questionData,
					quiz_modus: wisdmQuizData.quiz_modus,
					single_feedback: quizForm.values.single_feedback,
					single_back_button: quizForm.values.single_back_button,
					multiple_questions_per_page: quizForm.values.multiple_questions_per_page,
					ld_quiz_category: (null === quizForm.values.ld_quiz_category) ? null : quizForm.values.ld_quiz_category?.filter(function (item) { return parseInt(item); }),
					ld_quiz_tag: quizForm.values.ld_quiz_tag,
					result_text: resultText,
					prerequisites: prerequisites,
					certificate_award_threshold: quizForm.values.certificate_award_threshold,
					certificate: quizForm.values.certificate,
					quiz_resume: quizForm.values.quiz_resume,
					quiz_resume_cookie_send_timer: quizForm.values.quiz_resume_cookie_send_timer,
					auto_start: quizForm.values.auto_start,
					time_limit_enabled: quizForm.values.time_limit_enabled,
					time_limit_time: time_limit_time,
					materials_enabled: quizForm.values.materials_enabled,
					materials: quizForm.values.materials,
					toplist_enabled: quizForm.values.toplist_enabled,
					toplist_data_add_permissions: quizForm.values.toplist_data_add_permissions,
					toplist_data_add_multiple: quizForm.values.toplist_data_add_multiple,
					toplist_data_add_automatic: quizForm.values.toplist_data_add_automatic,
					toplist_data_show_limit: quizForm.values.toplist_data_show_limit,
					toplist_data_sort: quizForm.values.toplist_data_sort,
					toplist_data_showin_enabled: quizForm.values.toplist_data_showin_enabled,
					date: getCombinedDate(quizForm.values.date, quizForm.values.time),
					password: quizForm.values.password,
				}
			}
		).then((resp) => {
			if ('update' === label) {
				// Check if course review enabled.
				if (ir_fqb_loc.instructor_settings?.review_course && !ir_fqb_loc.is_admin) {
					showNotification({
						message: sprintf(__('Your %1$s has been submitted for review to the administrator. Please wait for approval before it can be published. In the meantime, your %1$s is saved as draft.', 'wdm_instructor_role'), ir_fqb_loc.lower_course_label),
						autoClose: 5000
					})
				} else {
					showNotification({
						title: sprintf(__('%s Updated!', 'wdm_instructor_role'), ir_fqb_loc.quiz_label),
						message: sprintf(__('Your %s has successfully been updated', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label),
					})
				}
				setShowLoader(false)
			}
			else if ('publish' === label) {
				// Check if course review enabled.
				if (ir_fqb_loc.instructor_settings?.review_course && !ir_fqb_loc.is_admin) {
					showNotification({
						message: sprintf(__('Your %1$s has been submitted for review to the administrator. Please wait for approval before it can be published. In the meantime, your %1$s is saved as draft.', 'wdm_instructor_role'), ir_fqb_loc.lower_course_label),
						autoClose: 5000
					})
				} else {
					if (!wisdmQuizData.is_published) {
						quizPublished(quizData.link)
					}
					else {
						showNotification({
							title: sprintf(__('%s Published!', 'wdm_instructor_role'), ir_fqb_loc.quiz_label),
							message: sprintf(__('Your %s has successfully been published', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label),
						})
					}
				}
				setShowLoader(false)
			}
			else if ('switch' === label) {
				showNotification({
					title: sprintf(__('%s switched to draft!', 'wdm_instructor_role'), ir_fqb_loc.quiz_label),
					message: sprintf(__('Your %s has successfully been switched to draft', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label),
				})
				setShowDraftLoader(false)
			}
			else if ('save' === label) {
				showNotification({
					title: sprintf(__('%s saved as draft!', 'wdm_instructor_role'), ir_fqb_loc.quiz_label),
					message: sprintf(__('Your %s has successfully been saved as a draft', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label),
				})
				setShowDraftLoader(false)
			}
			setQuizData(resp);


			apiFetch(
				{
					path: "/ir/v1/quiz-settings/" + quizId,
					method: 'POST',
					data: {
						visible_after_specific_date: timestamp,
						show_max_question: parseInt(show_max),
						show_max_question_value: quizForm.values.show_max_question_value,
						statistics_ip_lock_enabled: quizForm.values.statistics_ip_lock_enabled ? 1 : 0,
						email_admin_enabled: quizForm.values.email_admin_enabled,
						retries_applicable_to: quizForm.values.retries_applicable_to,
						statistics_ip_lock_enabled_value: quizForm.values.statistics_ip_lock_enabled_value * 60,
						is_published: ('publish' === resp.status) ? true : false,
						time_limit_cookie: quizForm.values.time_limit_cookie,
						toplist_data_time: quizForm.values.toplist_data_time,
						toplist_data_showin: quizForm.values.toplist_data_showin,
						really_simple_captcha: quizForm.values.really_simple_captcha,
						custom_field_display_position: quizForm.values.custom_field_display_position.toString(),
						custom_fields: customField,
						really_simple_captcha: quizForm.values.really_simple_captcha,
						save_as_template: save_template,
						new_template_name: quizForm.values.new_template_name,
						// @todo: Add dynamic values for save template
						// New Template Creation
						// save_as_template: 'new',
						// new_template_name: 'Avya',
						// Save as template override
						// save_as_template: 'existing',
						// new_template: '5'
					}
				}
			).then((resp) => {
				// console.log('wisdm data');
				// console.log(resp);
			});

			setVisibility(resp);
		});
	}

	const getVisibility = () => {
		let visibility = __('Public', 'wdm_instructor_role');
		if ('password' === quizForm.values.visibility) {
			visibility = __('Password Protected', 'wdm_instructor_role');
		} else if ('private' === quizForm.values.visibility) {
			visibility = __('Private', 'wdm_instructor_role')
		}
		return visibility;
	}

	const setVisibility = (data) => {
		// Set course visibility
		let _visibility = data.status;
		if (data.content.protected) {
			_visibility = 'password';
		} else if ('private' === data.status) {
			_visibility = 'private';
			// Remove keyword Private from title.
			// if ( -1 !== data.title.rendered.indexOf('Private:')) {
			// 	const post_title = data.title.rendered;
			// 	courseform.setFieldValue('title', post_title.replace('Private:', ''));
			// }
		} else {
			_visibility = 'public';
		}

		quizForm.setFieldValue('visibility', _visibility);
	}

	const getPublishedDate = () => {
		let date_string = '';
		const options = { month: 'long', day: 'numeric', hour12: true, hour: 'numeric', minute: 'numeric' };
		const publish_date = getCombinedDate(quizForm.values.date, quizForm.values.time);

		return publish_date.toLocaleDateString(undefined, options);
	}


	const handleVisibilityChange = (value) => {
		if ('private' === value) {
			quizForm.setFieldValue('password', '');
			openConfirmModal({
				modal: 'switch-draft',
				title: sprintf(__('Publish %s Privately?', 'wdm_instructor_role'), ir_fqb_loc.quiz_label),
				children: (
					<Text size="sm">
						{sprintf(__('Would you like to privately publish this %s now?', 'wdm_instructor_role'), ir_fqb_loc.lower_quiz_label)}
					</Text>
				),
				labels: { confirm: 'Confirm', cancel: 'Cancel' },
				onCancel: () => console.log('Cancel'),
				onConfirm: () => {
					setShowLoader(true);
					// Make quiz private.
					apiFetch(
						{
							path: "/ldlms/v2/sfwd-quiz/" + quizId,
							method: 'POST',
							data: {
								status: value,
							}
						}
					).then((resp) => {
						setShowLoader(false);
						quizForm.setFieldValue('visibility', value);
					})
				},
			});
		} else if ('password' === value) {
			quizForm.setFieldValue('visibility', value);
		} else {
			quizForm.setFieldValue('password', '');
			quizForm.setFieldValue('visibility', value);
		}
	}

	const getCombinedDate = (date_object, time_object) => {
		if ( date_object instanceof Date && time_object instanceof Date ) {
			let combined_date = '';
			combined_date = date_object.getFullYear() + '-' + (date_object.getMonth() + 1) + '-' + date_object.getDate() + ' ' + time_object.getHours() + ':' + time_object.getMinutes() + ':' + time_object.getSeconds();
	
			return new Date(combined_date);
		} else {
			return new Date();
		}
	}

	return (

		<div className="ir-quiz-builder-container-inner">
			{null === quizData && (
				<DummyQuizPage />
			)}
			<NotificationsProvider>
				<ModalsProvider>
					{null !== quizData && (
						<div className="ir-fed-header" height={150} span={4} offset={8} mb={40}>
							<Group className="ir-header-top" height='80px' position='apart' align="center" pl={25} pr={35}>
								<Group align="center">
									{0 === courseID && (
										<Button className="ir-btn-subtle ir-color" component="a" href={ir_fqb_loc.all_quizzes_url} variant="subtle" leftIcon={<ChevronLeft size={20} mr={5} />}>
											{__('Back', 'wdm_instructor_role')}
										</Button>
									)}
									{0 !== courseID && (
										<Button className="ir-btn-subtle ir-color" component="a" href={ir_fqb_loc.course_builder_url + '/' + courseID} variant="subtle" leftIcon={<ChevronLeft size={20} mr={5} />}>
											{ir_fqb_loc.course_label}
										</Button>
									)}
									<Title className="ir-course-title" order={2} color="#000000">
										{html_entity_decode(quizData.title.rendered)}
										{'publish' === quizData.status &&
											<Badge className="ir-published" color="#00B61D" variant="light" ml={15}>
												{__('Published', 'wdm_instructor_role')}
											</Badge>
										}
										{'draft' === quizData.status &&
											<Badge className="ir-drafted" color="#00B61D" ml={15}>
												{__('Draft', 'wdm_instructor_role')}
											</Badge>
										}
									</Title>
								</Group>
								<Group>
									<Popover width={165} position="bottom" withArrow shadow="lg" radius={6}>
										<Popover.Target>
											<Button size="sm" fw={600} className="ir-btn-subtle" radius="md" variant="subtle" leftIcon={<Eye size={22} />} >
												{sprintf(__('View %s', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}
											</Button>
										</Popover.Target>
										<Popover.Dropdown className="ir-preview-module">
											<Button className="ir-btn-subtle" onClick={() => openIframeInTab('100%')} size="sm" variant="subtle" leftIcon={<DeviceDesktop size={22} color={'#000000'} />} >
												{__('Desktop view', 'wdm_instructor_role')}
											</Button>
											<Button className="ir-btn-subtle" onClick={() => openIframeInTab('768px')} size="sm" variant="subtle" leftIcon={<DeviceTablet size={22} color={'#000000'} />} >
												{__('Tablet view', 'wdm_instructor_role')}
											</Button>
											<Button className="ir-btn-subtle" onClick={() => openIframeInTab('475px')} size="sm" variant="subtle" leftIcon={<DeviceMobile size={22} color={'#000000'} />} >
												{__('Mobile view', 'wdm_instructor_role')}
											</Button>
										</Popover.Dropdown>
									</Popover>
									<Popover position="bottom" withArrow shadow="lg" radius={6} width={320}>
										<Popover.Target>
											<Button
												size="sm"
												fw={600}
												className="ir-btn-subtle"
												radius="md"
												variant="subtle"
											>
												{sprintf(__('Status and Visibility', 'wdm_instructor_role'), ir_fqb_loc.course_label)}
											</Button>
										</Popover.Target>
										<Popover.Dropdown className="ir-status-and-visibility">
											<Accordion width={320}>
												<Accordion.Item value="visibility" variant="filled">
													<Accordion.Control>
														<Group align="center" spacing="xs" position="apart">
															<Text size="sm" fw={600}>{__('Visibility', 'wdm_instructor_role')}</Text>
															<Text size="sm" fw={600} color="#2067FA;">{getVisibility()}</Text>
														</Group>
													</Accordion.Control>
													<Accordion.Panel>
														<Radio.Group
															defaultValue='public'
															orientation='vertical'
															value={quizForm.values.visibility}
															onChange={handleVisibilityChange}
														>
															<Radio value="public" label={__('Public', 'wdm_instructor_role')} description={__('Visible to everyone', 'wdm_instructor_role')} />
															<Radio value="private" label={__('Private', 'wdm_instructor_role')} description={__('Only visible to site admins and editors', 'wdm_instructor_role')} />
															<Radio value="password" label={__('Password Protected', 'wdm_instructor_role')} description={__('Protected with a password you choose. Only those with the password can view this post.', 'wdm_instructor_role')} />
														</Radio.Group>
														{'password' === quizForm.values.visibility && (
															<TextInput
																mt={5}
																placeholder={__('Use a secure Password', 'wdm_instructor_role')}
																size="sm"
																{...quizForm.getInputProps('password')}
															/>
														)}
													</Accordion.Panel>
												</Accordion.Item>

												<Accordion.Item value="publish">
													<Accordion.Control>
														<Group align="center" spacing="xs" position="apart">
															<Text size="sm" fw={600}>{__('Publish', 'wdm_instructor_role')}</Text>
															<Text size="sm" fw={600} color="#2067FA;">{getPublishedDate()}</Text>
														</Group>
													</Accordion.Control>
													<Accordion.Panel>
														<TimeInput
															className='ir-noborder'
															format="12"
															label={__('Time', 'wdm_instructor_role')}
															defaultValue={new Date()}
															icon={<ClockHour4 size={16} />}
															{...quizForm.getInputProps('time')}
														/>
														<DatePicker
															label={__('Date', 'wdm_instructor_role')}
															defaultValue={new Date()}
															icon={<CalendarEvent size={16} />}
															{...quizForm.getInputProps('date')}
														/>
													</Accordion.Panel>
												</Accordion.Item>
											</Accordion>
										</Popover.Dropdown>
									</Popover>
									<Button onClick={() => {
										setShowDraftLoader(true)
										let label = 'save';
										if ('publish' === quizData.status) {
											label = 'switch'
										}
										{ 'publish' === quizData.status && confirmDraft() }
										{ 'draft' === quizData.status && updateQuizData('draft', label) }
									}}
										className="ir-btn-outline ir-quiz-draft" variant="outline" radius="md" size="sm"

									>
										{('publish' === quizData.status || 'future' === quizData.status || 'private' === quizData.status) && __('Switch to Draft', 'wdm_instructor_role')}
										{'draft' === quizData.status && __('Save to Draft', 'wdm_instructor_role')}
										{showDraftLoader && <Loader color="#2067FA" ml={10} size={15} />}
									</Button>
									<Button onClick={() => {
										setShowLoader(true)
										let label = 'publish';
										if ('publish' === quizData.status || 'future' === quizData.status) {
											label = 'update'
										}
										updateAlert('publish', label);

									}} disabled={showLoader} className="ir-publish ir-btn-filled ir-quiz-publish" variant="filled" radius="md" size="sm" color="#2067FA" >
										{'draft' === quizData.status && __('Publish', 'wdm_instructor_role')}
										{('publish' === quizData.status || 'private' === quizData.status) && __('Update', 'wdm_instructor_role')}
										{'future' === quizData.status && __('Schedule', 'wdm_instructor_role')}
										{showLoader && <Loader color="#ffffff" ml={10} size={15} />}
									</Button>
								</Group>
							</Group>
							<Group className="ir-header-bottom" position='left' align="center">
								<Tabs defaultValue="ir-quiz-page" className="ir-fed-tabs">
									<Tabs.List>
										<Tabs.Tab value="ir-quiz-page">{sprintf(__('%s Page', 'wdm_instructor_role'), ir_fqb_loc.quiz_label)}</Tabs.Tab>
										<Tabs.Tab value="ir-quiz-builder">
											{__('Builder', 'wdm_instructor_role')}
										</Tabs.Tab>
										<Tabs.Tab value="ir-quiz-settings">
											{__('Settings', 'wdm_instructor_role')}
										</Tabs.Tab>
									</Tabs.List>
									<Tabs.Panel className="ir-main-panel ir-quiz-page" value="ir-quiz-page">
										<QuizPage quizForm={quizForm} quizData={quizData} setQuizData={setQuizData} featured_image={featured_image} setFeaturedImage={setFeaturedImage} quizTags={quizTags} setQuizTags={setQuizTags} quizCategories={quizCategories} setQuizCategories={setQuizCategories} review_content={review_content} setReviewContent={setReviewContent} />
									</Tabs.Panel>
									<Tabs.Panel className="ir-main-panel" value="ir-quiz-builder">
										<QuizBuilder quizId={quizId} questionData={questionData} setQuestionData={setQuestionData} wisdmQuizData={wisdmQuizData} setWisdmQuizData={setWisdmQuizData} />
									</Tabs.Panel>
									<Tabs.Panel className="ir-main-panel" value="ir-quiz-settings">
										<QuizSettings quizData={quizData} setQuizData={setQuizData} quizForm={quizForm} wisdmQuizData={wisdmQuizData} setWisdmQuizData={setWisdmQuizData} resultText={resultText} setResultText={setResultText} customField={customField} setCustomField={setCustomField} save_template={save_template} setSaveTemplate={setSaveTemplate} />
									</Tabs.Panel>
								</Tabs>
							</Group>
						</div>
					)}
				</ModalsProvider>
			</NotificationsProvider>
		</div>

	);
}

document.addEventListener("DOMContentLoaded", function (event) {

	let elem = document.getElementsByClassName('wisdm-quiz-builder');
	if (elem.length > 0) {
		ReactDOM.render(React.createElement(save), elem[0]);
	}

});