<?php
/**
 * Banner Module
 *
 * @since      4.3.1
 * @package    Instructor_Role
 * @subpackage Instructor_Role/modules/classes
 * @author     WisdmLabs <support@wisdmlabs.com>
 */

namespace InstructorRole\Modules\Classes;

use InstructorRole\Modules\Classes\Instructor_Role_Bfcm_Banner as Instructor_Role_Bfcm_Banner;

defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'Instructor_Role_Bfcm_Banner' ) ) {
	/**
	 * Class to handle ___
	 */
	class Instructor_Role_Bfcm_Banner {

		/**
		 * Instance of this class
		 *
		 * @since 4.3.1
		 *
		 * @var object
		 */
		protected static $instance = null;

		/**
		 * Initialization.
		 */
		public function __construct() {

			add_action( 'admin_notices', array( $this, 'ir_banner_logic' ) );

		}

		/**
		 * Returns an instance of this class.
		 *
		 * @since 4.3.1
		 *
		 * @return object A single instance of this class.
		 */
		public static function get_instance() {
			// If the single instance hasn't been set, set it now.
			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		/**
		 * This function handles the banner display logic
		 *
		 * @since 4.3.1
		 */
		public function ir_banner_logic() {
			global $current_user;

			if ( ( in_array( 'wdm_instructor', $current_user->roles, true ) || in_array( 'group_leader', $current_user->roles, true ) ) && ! in_array( 'administrator', $current_user->roles, true ) ) {
				return;
			}

			$get_data = filter_var_array( $_GET, FILTER_UNSAFE_RAW ); // phpcs:ignore WordPress.Security.NonceVerification

			if ( isset( $get_data['wdm_banner_type'] ) ) {
				if ( 'pre' === $get_data['wdm_banner_type'] ) {
					update_option( 'wdm_pre_bfcm_dismiss', true );
				};

				if ( 'upgrade' === $get_data['wdm_banner_type'] ) {
					update_option( 'wdm_ir_upgrade_bfcm_dismiss', true );
				};

				if ( 'lifetime' === $get_data['wdm_banner_type'] ) {
					update_option( 'wdm_ir_lifetime_bfcm_dismiss', true );
				};
			}

			$date_from_user = gmdate( 'Y-m-d' );

			// Spinner banner per BFCM.
			if ( ! get_option( 'wdm_pre_bfcm_dismiss' ) ) {
				$start_date = '2022-11-04';
				$end_date   = '2022-11-23';
				$is_pre     = $this->ir_check_in_range( $start_date, $end_date, $date_from_user );
				if ( $is_pre && ! defined( 'WRLD_PLUGIN_VERSION' ) ) {
					$this->ir_bfcm_black_friday();
				}
			}

			// During BFCM Banner.
			$start_date = '2022-11-24';
			$end_date   = '2022-11-30';
			$is_during  = $this->ir_check_in_range( $start_date, $end_date, $date_from_user );
			if ( $is_during ) {
				$validity = get_option( 'edd_instructor_role_license_status', false );
				if ( 'valid' !== $validity ) {
					if ( ! get_option( 'wdm_ir_upgrade_bfcm_dismiss' ) ) {
						$this->ir_to_leap();
					}
				} else {
					if ( ! get_option( 'wdm_ir_lifetime_bfcm_dismiss' ) ) {
						$response = get_transient( 'ir_expire_validity' );
						// Set expire transient.
						if ( empty( $response ) ) {
							$license_key = trim( get_option( 'edd_instructor_role_license_key' ) );
							$api_params  = array(
								'edd_action'      => 'activate_license',
								'license'         => $license_key,
								'item_name'       => rawurlencode( 'Instructor Role' ),
								'plugin_slug'     => 'instructor_role',
								'current_version' => INSTRUCTOR_ROLE_PLUGIN_VERSION,
							);
							$response    = wp_remote_post(
								add_query_arg( $api_params, 'https://wisdmlabs.com/license-check/' ),
								array(
									'timeout'   => 15,
									'sslverify' => false,
									'blocking'  => true,
								)
							);
							$response    = json_decode( wp_remote_retrieve_body( $response ) );
							set_transient( 'ir_license_data', $response, 86400 );
						}
						if ( ! empty( $response ) ) {
							$expiration_date = $response->expires;
							if ( 'lifetime' !== $expiration_date ) {
								$this->ir_leap_to_lifetime();
							}
						} else {
							$this->ir_leap_to_lifetime();
						}
					}
				}
			}
		}

		/**
		 * Helper function that checks the specified date is in a given range or not.
		 *
		 * @param date $start_date This is the start date of the pre BFCM Sale.
		 * @param date $end_date This is the end date of the pre BFCM Sale.
		 * @param date $date_from_user This is the referenced current date of the system.
		 *
		 * @since 4.3.1
		 */
		public function ir_check_in_range( $start_date, $end_date, $date_from_user ) {
			// Convert to timestamp.
			$start_ts = strtotime( $start_date );
			$end_ts   = strtotime( $end_date );
			$user_ts  = strtotime( $date_from_user );

			// Check that user date is between start & end.
			return ( ( $user_ts >= $start_ts ) && ( $user_ts <= $end_ts ) );
		}

		/**
		 * Includes html bfcm content.
		 *
		 * @since 4.3.1
		 */
		public function ir_bfcm_black_friday() {
			global $wp;
			$current_url = get_permalink( add_query_arg( array(), $wp->request ) );
			wp_enqueue_style( 'ir_bfcm_style', plugins_url( 'modules/css/bfcm.css', INSTRUCTOR_ROLE_BASE ), array(), INSTRUCTOR_ROLE_PLUGIN_VERSION );

			$banner_head       = __( 'Play a game with WisdmLabs to get ahead of the black friday sale', 'wdm_instructor_role' );
			$banner_message    = __( 'Spin the Wheel to Win Free Access or discount on our Premium WordPress and LearnDash Product', 'wdm_instructor_role' );
			$button_text       = __( 'SPIN AND WIN', 'wdm_instructor_role' );
			$link              = 'https://wisdmlabs.com/wisdm-black-friday-giveaway?utm_source=giveaway&utm_medium=spinthewheel&utm_campaign=bfcm22';
			$wisdm_logo        = plugins_url( 'modules/images/banner_wisdmlabs_logo.png', INSTRUCTOR_ROLE_BASE );
			$background        = plugins_url( 'modules/images/spin_wheel.png', INSTRUCTOR_ROLE_BASE );
			$dismiss_attribute = add_query_arg( array( 'wdm_banner_type' => 'pre' ), $current_url );

			include INSTRUCTOR_ROLE_ABSPATH . 'modules/templates/banners/bfcm-banner.php';
		}

		/**
		 * Includes html bfcm content.
		 *
		 * @since 4.3.1
		 */
		public function ir_to_leap() {
			global $wp;
			$current_url = get_permalink( add_query_arg( array(), $wp->request ) );
			wp_enqueue_style( 'ir_bfcm_style', plugins_url( 'modules/css/bfcm.css', INSTRUCTOR_ROLE_BASE ), array(), INSTRUCTOR_ROLE_PLUGIN_VERSION );
			$banner_head          = __( 'Get everything to build a successful online education business in one bundle! ', 'wdm_instructor_role' );
			$banner_message       = __( 'Unlock the power of 5 must-have plugins to boost course and student management this Black Friday Season', 'wdm_instructor_role' );
			$banner_message_addon = __( 'Get up to 70% off on LearnDash Essentials Add-on Pack (LEAP)', 'wdm_instructor_role' );
			$button_text          = __( 'UPGRADE NOW', 'wdm_instructor_role' );
			$link                 = 'https://wisdmlabs.com/instructor-role-for-learndash/?utm_source=freeplugin&utm_medium=banner&utm_campaign=bfcm22';
			$wisdm_logo           = plugins_url( 'modules/images/banner_wisdmlabs_logo.png', INSTRUCTOR_ROLE_BASE );
			$background           = plugins_url( 'modules/images/bfcm_baloons.png', INSTRUCTOR_ROLE_BASE );
			$dismiss_attribute    = add_query_arg( array( 'wdm_banner_type' => 'upgrade' ), $current_url );

			include INSTRUCTOR_ROLE_ABSPATH . 'modules/templates/banners/bfcm-banner.php';
		}

		/**
		 * Includes html bfcm content.
		 *
		 * @since 4.3.1
		 */
		public function ir_leap_to_lifetime() {
			global $wp;
			$current_url = get_permalink( add_query_arg( array(), $wp->request ) );
			wp_enqueue_style( 'ir_bfcm_style', plugins_url( 'modules/css/bfcm.css', INSTRUCTOR_ROLE_BASE ), array(), INSTRUCTOR_ROLE_PLUGIN_VERSION );
			$banner_head          = __( 'Get everything to build a successful online education business in one bundle! ', 'wdm_instructor_role' );
			$banner_message       = __( 'Unlock the power of 5 must-have plugins to boost course and student management this Black Friday Season', 'wdm_instructor_role' );
			$banner_message_addon = __( 'Get up to 70% off on LearnDash Essentials Add-on Pack (LEAP) Lifetime Pack', 'wdm_instructor_role' );
			$button_text          = __( 'Upgrade to Lifetime', 'wdm_instructor_role' );
			$link                 = 'https://wisdmlabs.com/instructor-role-for-learndash/?utm_source=irannual&utm_medium=banner&utm_campaign=bfcm22';
			$wisdm_logo           = plugins_url( 'modules/images/banner_wisdmlabs_logo.png', INSTRUCTOR_ROLE_BASE );
			$background           = plugins_url( 'modules/images/bfcm_baloons.png', INSTRUCTOR_ROLE_BASE );
			$dismiss_attribute    = add_query_arg( array( 'wdm_banner_type' => 'lifetime' ), $current_url );

			include INSTRUCTOR_ROLE_ABSPATH . 'modules/templates/banners/bfcm-banner.php';
		}
	}
	Instructor_Role_Bfcm_Banner::get_instance();
}
