<?php
/**
 * Instructor Frontend Dashboard Settings Template
 *
 * @since 4.4.0
 *
 * @param bool $ir_enable_frontend_dashboard
 * @param bool $ir_disable_ld_links
 * @param string $image_url
 * @param string $admin_image_url
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

?>
<div class="wrap">
	<form method="POST">
		<h1>
			<?php
			echo esc_html(
				sprintf(
					/* translators: Course Label */
					__( 'Frontend %s Creator', 'wdm_instructor_role' ),
					\LearnDash_Custom_Label::get_label( 'course' )
				)
			);
			?>
		</h1>
		<div class="ir-fcc-settings">
			<div class="ir-col-1">
				<em>
					<?php
					echo wp_kses(
						sprintf(
							/* translators: 1.Course Label 2.Courses label */
							__(
								'Enabling the %1$s creator will provide the <strong>Instructors</strong> and the <strong>Admins</strong> with an option to create and edit %2$s via WisdmLabs Frontend %3$s Creator',
								'wdm_instructor_role'
							),
							\LearnDash_Custom_Label::label_to_lower( 'course' ),
							\LearnDash_Custom_Label::label_to_lower( 'courses' ),
							\LearnDash_Custom_Label::get_label( 'course' )
						),
						array(
							'strong' => array(),
						)
					);
					?>
				</em>
				<table class="form-table">
					<tbody>
						<tr class="ir-setting ir-fcc-enable" scope="row">
							<th scope="row">
								<label for="ir_enable_frontend_dashboard">
									<?php
									echo esc_html(
										/* translators: Course Label. */
										sprintf( __( 'Enable Frontend %s Creator', 'wdm_instructor_role' ), \LearnDash_Custom_Label::get_label( 'course' ) )
									);
									?>
								</label>
							</th>
							<td>
								<label class="ir-switch">
									<input type="checkbox" name="ir_enable_frontend_dashboard" id="ir_enable_frontend_dashboard" <?php echo ( 'on' === $ir_enable_frontend_dashboard ) ? esc_html( 'checked' ) : ''; ?>/>
									<span class="ir-slider round"></span>
								</label>	
							</td>
						</tr>
						<tr class="ir-disable-ld-links" style="<?php echo ( 'on' !== $ir_enable_frontend_dashboard ) ? esc_html( 'display: none;' ) : ''; ?>">
							<th scope="row">
								<label for="ir_disable_ld_links">
									<?php
										echo esc_html(
											sprintf(
												/* translators: Course label */
												__( 'Disable LearnDash’s backend %s creator for instructors', 'wdm_instructor_role' ),
												\LearnDash_Custom_Label::label_to_lower( 'course' )
											)
										);
										?>
								</label>
								<p class="ir-help-text">
									<?php
									echo wp_kses(
										sprintf(
											/* translators: Course Label, Courses Label, Course Label */
											__( '<strong>Note:</strong> For the Instructors, the LearnDash %1$s creator along with the %2$s and %3$s listing page will be hidden and they can only  create or edit the %4$s via Wisdmlabs Frontend %5$s Creator', 'wdm_instructor_role' ),
											\LearnDash_Custom_Label::label_to_lower( 'course' ),
											\LearnDash_Custom_Label::label_to_lower( 'lesson' ),
											\LearnDash_Custom_Label::label_to_lower( 'topic' ),
											\LearnDash_Custom_Label::get_label( 'courses' ),
											\LearnDash_Custom_Label::get_label( 'course' )
										),
										array(
											'strong' => array(),
										)
									);
									?>
								</p>
							</th>
							<td>
								<label class="ir-switch">
									<input type="checkbox" name="ir_disable_ld_links" id="ir_disable_ld_links" <?php echo 'off' === $ir_disable_ld_links ? '' : esc_html( 'checked' ); ?>/>
									<span class="ir-slider round"></span>
								</label>
							</td>
						</tr>
					</tbody>
				</table>
				<p class="ir-permalink-help">
					<?php
					echo wp_kses(
						sprintf(
							/* translators: 1.Course Label 2.Courses label */
							__(
								'<strong>Important:</strong> For the Frontend %1$s Creator to work, your permalink structure must be set to <a target="_blank" href="https://wordpress.org/documentation/article/customize-permalinks/#pretty-permalinks">pretty permalinks</a> (i.e. anything except Plain) and you need to save the permalink settings once again after the Frontend %2$s Creator is enabled.',
								'wdm_instructor_role'
							),
							\LearnDash_Custom_Label::get_label( 'course' ),
							\LearnDash_Custom_Label::get_label( 'course' )
						),
						array(
							'strong' => array(),
							'a'      => array(
								'href'   => array(),
								'target' => array(),
							),
						)
					);
					?>
				</p>
			</div>
			<div class="ir-col-2" style="<?php echo ( 'on' !== $ir_enable_frontend_dashboard ) ? esc_html( 'display: none;' ) : ''; ?>">
				<?php if ( 'off' === $ir_disable_ld_links ) : ?>
					<img src="<?php echo esc_url_raw( $admin_image_url ); ?>" alt="<?php esc_html_e( 'Frontend Course Creator Settings', 'wdm_instructor_role' ); ?>">
				<?php else : ?>
					<img src="<?php echo esc_url_raw( $image_url ); ?>" alt="<?php esc_html_e( 'Frontend Course Creator Settings', 'wdm_instructor_role' ); ?>">
				<?php endif; ?>
			</div>
		</div>
		<?php wp_nonce_field( 'ir_frontend_dashboard_settings', 'ir_nonce' ); ?>
		<?php submit_button( __( 'Save Settings', 'wdm_instructor_role' ) ); ?>
	</form>
</div>
