<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
global $current_user;
$user_id      = get_current_user_id();
$current_user = wp_get_current_user();

$user_name                      = $current_user->user_firstname . ' ' . $current_user->user_lastname;
$user_name                      = ( $current_user->user_firstname == '' && $current_user->user_lastname == '' ) ? $current_user->user_login : $user_name;
$function_obj                   = Ld_Dashboard_Functions::instance();
$ld_dashboard_settings_data     = $function_obj->ld_dashboard_settings_data();
$welcome_screen                 = $ld_dashboard_settings_data['welcome_screen'];
$ld_dashboard_general_settings  = $ld_dashboard_settings_data['general_settings'];
$monetization_settings          = $ld_dashboard_settings_data['monetization_settings'];
$github_url                     = get_user_meta( $user_id, 'github_url', true );
$facebook_url                   = get_user_meta( $user_id, 'facebook_url', true );
$twitter_url                    = get_user_meta( $user_id, 'twitter_url', true );
$linkdin_url                    = get_user_meta( $user_id, 'linkedin_url', true );
$dashboard_landing_cover        = '';
$enable_instructor_earning_logs = isset( $ld_dashboard_general_settings['enable-instructor-earning-logs'] ) ? $ld_dashboard_general_settings['enable-instructor-earning-logs'] : '';

if ( isset( $welcome_screen['welcomebar_image'] ) && $welcome_screen['welcomebar_image'] != '' ) {
	$dashboard_landing_cover = "background-image: url({$welcome_screen['welcomebar_image']});";
}
?>
<div class="ld-dashboard-profile-summary-container" style="max-width: 100%;width: 100%;">
	<div class="ld-dashboard-profile-summary" style="<?php echo esc_attr( $dashboard_landing_cover ); ?>">
		<div class="ld-dashboard-profile">
			<div class="ld-dashboard-profile-avatar">
				<?php echo wp_kses_post( get_avatar( $user_id ) ); ?>
			</div>
			<?php if ( $user_name != '' ) : ?>
				<div class="ld-dashboard-profile-info">
					<div class="ld-dashboard-display-name">
						<h4><strong><?php echo esc_html( $user_name ); ?></strong></h4>
					</div>
					<?php do_action( 'ld_dashboard_banner_content' ); ?>
					<?php endif; ?>
					<?php if ( ! empty( $current_user->user_email ) ) : ?>
						<div class="ld-dashboard-profile-email">
							<?php echo esc_html( $current_user->user_email ); ?>
						</div>
					<?php endif; ?>
					<div class="ld-dashboard-social-media-url">
					<?php if ( ! empty( $github_url ) ) : ?>
						<a class="ld-social-media-link ld-profile-github-url" href="<?php echo esc_url( $github_url ); ?>" target="_blank" rel="external" alt="<?php echo esc_attr__( 'GitHub', 'ld-dashboard' ); ?>"><img src="<?php echo esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/github.svg'; ?>"></a>
					<?php endif; ?>
					<?php if ( ! empty( $facebook_url ) ) : ?>
						<a class="ld-social-media-link ld-profile-facebook-url" href="<?php echo esc_url( $facebook_url ); ?>" target="_blank" rel="external" alt="<?php echo esc_attr__( 'Facebook', 'ld-dashboard' ); ?>"><img src="<?php echo esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/facebook.svg'; ?>"></a>
					<?php endif; ?>
					<?php if ( ! empty( $twitter_url ) ) : ?>
						<a class="ld-social-media-link ld-profile-twitter-url" href="<?php echo esc_url( $twitter_url ); ?>" target="_blank" rel="external" alt="<?php echo esc_attr__( 'Twitter', 'ld-dashboard' ); ?>"><img src="<?php echo esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/twitter.svg'; ?>"></a>
					<?php endif; ?>
					<?php if ( ! empty( $linkdin_url ) ) : ?>
						<a class="ld-social-media-link ld-profile-linkedin-url" href="<?php echo esc_url( $linkdin_url ); ?>" target="_blank" rel="external" alt="<?php echo esc_attr__( 'Linkdin', 'ld-dashboard' ); ?>"><img src="<?php echo esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/linkedin.svg'; ?>"></a>
					<?php endif; ?>
					</div>
				</div>
				<?php if ( ( ! learndash_is_group_leader_user( $user_id ) && in_array( 'ld_instructor', (array) $current_user->roles ) ) || ( learndash_is_admin_user( $user_id ) || in_array( 'ld_instructor', (array) $current_user->roles ) ) ) : ?>
					<div class="ld-dashboard-header-button">
						<?php $course_nonce = wp_create_nonce( 'course-nonce' ); ?>
						<a class="ld-dashboard-add-course ld-dashboard-btn-bg" href="<?php echo esc_url( get_permalink() ) . '?action=add-course&tab=my-courses&_lddnonce=' . esc_attr( $course_nonce ); ?>">
							<img src="<?php echo esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/edit.svg'; ?>"> <?php printf( esc_html__( 'Add a new %s', 'ld-dashboard' ), LearnDash_Custom_Label::get_label( 'course' ) ); ?>
						</a>
					</div>
				<?php endif; ?>
				<?php if ( isset( $ld_dashboard_general_settings['become-instructor-button'] ) && 1 == $ld_dashboard_general_settings['become-instructor-button'] && ! learndash_is_group_leader_user( $user_id ) && ! learndash_is_admin_user( $user_id ) && ! in_array( 'ld_instructor', (array) $current_user->roles ) && ! in_array( 'ld_instructor_pending', (array) $current_user->roles ) ) : ?>
					<div class="ld-dashboard-header-button">
						<?php $instructor_nonce = wp_create_nonce( 'instructor-nonce' ); ?>
						<a class="ld-dashboard-add-course ld-dashboard-become-instructor-btn ld-dashboard-btn-bg" href="#">
							<img src="<?php echo esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/user-tie.svg'; ?>"> <?php esc_html_e( 'Become An Instructor', 'ld-dashboard' ); ?>
						</a>
					</div>
				<?php endif; ?>
		</div>
		<?php
		if ( isset( $ld_dashboard['welcome-screen'] ) && $ld_dashboard['welcome-screen'] == 1 ) {
			?>
		<div class="ld-dashboard-landing-content">
			<?php do_action( 'ld_dashboard_before_welcome_message' ); ?>
			<div class="ld-dashboard-landing-text">
				<?php
				if ( isset( $welcome_screen['welcome-message'] ) && $welcome_screen['welcome-message'] != '' ) {
					echo sprintf( $welcome_screen['welcome-message'], trim( $user_name ) );
				} else {
					echo sprintf( __( 'Welcome back, %s', 'ld-dashboard' ), trim( $user_name ) );
				}
				?>
			</div>
			<?php do_action( 'ld_dashboard_after_welcome_message' ); ?>
		</div>
		<?php } ?>
	</div>
</div>
<div class="ld-dashboard-content-wrapper">
	<div class="ld-dashboard-left-section ld-dashboard-sidebar-left">
		<?php do_action( 'ld_dashboard_before_profile_section' ); ?>
		<section id="ld-dashboard-profile" class="widget-ld-dashboard-profile ld-dashboard-profile">
			<div class="ld-dashboard-location">
				<?php
				$dashboard_page                    = Ld_Dashboard_Functions::instance()->ld_dashboard_get_url( 'dashboard' );
				$menu_items['all']['my-dashboard'] = array(
					'url'   => ( '' != $dashboard_page ) ? $dashboard_page : get_the_permalink(),
					'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/tachometer-alt.svg">',
					'label' => esc_html__( 'Dashboard', 'ld-dashboard' ),
				);

				$menu_items['all']['profile'] = array(
					'url'   => $dashboard_page . '?tab=profile',
					'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/user-alt.svg">',
					'label' => esc_html__( 'My Profile', 'ld-dashboard' ),
				);

				$menu_items['all']['enrolled-courses'] = array(
					'url'   => $dashboard_page . '?tab=enrolled-courses',
					'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/graduation-cap.svg">',
					'label' => sprintf( '%1s %2s', esc_html__( 'Enrolled', 'ld-dashboard' ), LearnDash_Custom_Label::get_label( 'courses' ) ),
				);

				$menu_items['all']['my-quiz-attempts'] = array(
					'url'   => $dashboard_page . '?tab=my-quiz-attempts',
					'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/cubes.svg">',
					'label' => sprintf( '%1s %2s %3s', esc_html__( 'My', 'ld-dashboard' ), LearnDash_Custom_Label::get_label( 'quiz' ), esc_html__( 'Attempts', 'ld-dashboard' ) ),
				);
				if ( $enable_live_feed ) {
					$menu_items['all']['my-activity'] = array(
						'url'   => $dashboard_page . '?tab=my-activity',
						'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/bell.svg">',
						'label' => sprintf( '%1s %2s %3s', esc_html__( 'My', 'ld-dashboard' ), LearnDash_Custom_Label::get_label( 'course' ), esc_html__( 'Activity', 'ld-dashboard' ) ),
					);
				}
				if ( $ld_dashboard_general_settings['enable-announcements'] == 1 ) {
					$menu_items['all']['announcements'] = array(
						'url'   => $dashboard_page . '?tab=announcements',
						'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/bullhorn.svg">',
						'label' => esc_html__( 'Announcements', 'ld-dashboard' ),
					);
				}
				$theme_locations = get_nav_menu_locations();
				if ( isset( $theme_locations['ld-dashboard-profile-menu'] ) ) {
					$menu_obj = get_term( $theme_locations['ld-dashboard-profile-menu'], 'nav_menu' );
					if ( is_object( $menu_obj ) && isset( $menu_obj->term_id ) ) {
						$custom_menu_items = wp_get_nav_menu_items( $menu_obj->term_id );
						if ( ! empty( $custom_menu_items ) ) {
							foreach ( $custom_menu_items as $menu_item ) :
								$menu_items['all'][ $menu_item->post_name ] = array(
									'url'   => $menu_item->url,
									'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/external-link-alt.svg">',
									'label' => $menu_item->title,
								);
							endforeach;
						}
					}
				}

				if ( learndash_is_admin_user( $user_id ) || in_array( 'ld_instructor', (array) $current_user->roles ) || ld_dashboard_is_instructor_group_leader() ) {
					$menu_items['instructor']['my-courses']   = array(
						'url'   => $dashboard_page . '?tab=my-courses',
						'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/course.svg">',
						'label' => esc_html__( 'My ', 'ld-dashboard' ) . LearnDash_Custom_Label::get_label( 'courses' ),
					);
					$menu_items['instructor']['my-lessons']   = array(
						'url'   => $dashboard_page . '?tab=my-lessons',
						'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/lessson.svg">',
						'label' => esc_html__( 'My ', 'ld-dashboard' ) . LearnDash_Custom_Label::get_label( 'lessons' ),
					);
					$menu_items['instructor']['my-topics']    = array(
						'url'   => $dashboard_page . '?tab=my-topics',
						'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/topic-management.svg">',
						'label' => esc_html__( 'My ', 'ld-dashboard' ) . LearnDash_Custom_Label::get_label( 'topics' ),
					);
					$menu_items['instructor']['my-quizzes']   = array(
						'url'   => $dashboard_page . '?tab=my-quizzes',
						'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/My-Quiz.svg">',
						'label' => esc_html__( 'My ', 'ld-dashboard' ) . LearnDash_Custom_Label::get_label( 'quizzes' ),
					);
					$menu_items['instructor']['my-questions'] = array(
						'url'   => $dashboard_page . '?tab=my-questions',
						'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/question-circle.svg">',
						'label' => esc_html__( 'My ', 'ld-dashboard' ) . LearnDash_Custom_Label::get_label( 'questions' ),
					);
					$menu_items['instructor']['assignments']  = array(
						'url'   => $dashboard_page . '?tab=assignments',
						'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/edit-alt.svg">',
						'label' => esc_html__( 'Assignments', 'ld-dashboard' ),
					);
					if ( ld_if_commission_enabled() ) {
						$menu_items['instructor']['withdrawal'] = array(
							'url'   => $dashboard_page . '?tab=withdrawal',
							'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/wallet-icon.svg">',
							'label' => esc_html__( 'Withdrawals', 'ld-dashboard' ),
						);
					}

					if ( $enable_instructor_earning_logs == 1 ) {
						$menu_items['instructor']['earnings'] = array(
							'url'   => $dashboard_page . '?tab=earnings',
							'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/withdrawal.svg">',
							'label' => esc_html__( 'Earning Logs', 'ld-dashboard' ),
						);
					}
					$menu_items['instructor']['certificates'] = array(
						'url'   => $dashboard_page . '?tab=certificates',
						'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/award.svg">',
						'label' => esc_html__( 'Certificates', 'ld-dashboard' ),
					);
					if ( $ld_dashboard_general_settings['enable-announcements'] == 1 ) {
						$menu_items['instructor']['my-announcements'] = array(
							'url'   => $dashboard_page . '?tab=my-announcements',
							'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/bullhorn.svg">',
							'label' => esc_html__( 'My Announcements', 'ld-dashboard' ),
						);
					}
				}
				if ( learndash_is_admin_user( $user_id ) || learndash_is_group_leader_user( $user_id ) ) {
					$menu_items['instructor']['groups'] = array(
						'url'   => $dashboard_page . '?tab=groups',
						'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/users.svg">',
						'label' => LearnDash_Custom_Label::get_label( 'groups' ),
					);
				}
				$menu_items['instructor']['quiz-attempts'] = array(
					'url'   => $dashboard_page . '?tab=quiz-attempts',
					'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/file-signature.svg">',
					'label' => sprintf( '%1s %2s', LearnDash_Custom_Label::get_label( 'quiz' ), esc_html__( 'Attempts', 'ld-dashboard' ) ),
				);
				if ( learndash_is_admin_user( $user_id ) || ( $enable_live_feed && ( learndash_is_group_leader_user( $user_id ) || in_array( 'ld_instructor', (array) $current_user->roles ) ) ) ) {
					$menu_items['instructor']['activity'] = array(
						'url'   => $dashboard_page . '?tab=activity',
						'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/bell.svg">',
						'label' => sprintf( esc_html__( '%s Activity', 'ld-dashboard' ), LearnDash_Custom_Label::get_label( 'course' ) ),
					);
				}
				if ( isset( $ld_dashboard_general_settings['enable-email-integration'] ) && $ld_dashboard_general_settings['enable-email-integration'] == 1 ) {
					$menu_items['instructor']['notification'] = array(
						'url'   => $dashboard_page . '?tab=notification',
						'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/private-msg.svg">',
						'label' => esc_html__( 'Send Mail', 'ld-dashboard' ),
					);
				}
				if ( isset( $ld_dashboard_general_settings['enable-messaging-integration'] ) && $ld_dashboard_general_settings['enable-messaging-integration'] == 1 && class_exists( 'BuddyPress' ) && bp_is_active( 'messages' ) ) {
					$menu_items['instructor']['private-messages'] = array(
						'url'   => $dashboard_page . '?tab=private-messages',
						'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/course-activity.svg">',
						'label' => esc_html__( 'Private Messages', 'ld-dashboard' ),
					);
				}
				$menu_items['both']['settings'] = array(
					'url'   => $dashboard_page . '?tab=settings',
					'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/cog.svg">',
					'label' => esc_html__( 'Settings', 'ld-dashboard' ),
				);
				$menu_items['both']['logout']   = array(
					'url'   => wp_logout_url( get_the_permalink() ),
					'icon'  => '<img src="' . esc_url( LD_DASHBOARD_PLUGIN_URL ) . 'public/img/icons/power-off.svg">',
					'label' => __( 'Logout', 'ld-dashboard' ),
				);

				if ( ! learndash_is_group_leader_user( $user_id ) && ! learndash_is_admin_user( $user_id ) && ! in_array( 'ld_instructor', (array) $current_user->roles ) ) {
					unset( $menu_items['instructor'] );
				}
				$menu_items = apply_filters( 'learndash_dashboard_nav_menu', $menu_items );
				if ( $menu_items && ! empty( $menu_items ) ) :
					echo '<ul class="ld-dashboard-left-panel">';
					$section = array();
					foreach ( $menu_items as $slug => $items ) :
						if ( ! in_array( $slug, array( 'all', 'both', 'instructor' ) ) ) {
							continue;
						}
						if ( ! empty( $section ) && ! in_array( $slug, $section ) ) {
							?>
								<li class="ld-dashboard-menu-divider"></li>
							<?php
						}
						if ( 'instructor' === $slug ) {
							$role_slug = '';
							if ( learndash_is_group_leader_user( $user_id ) && ! in_array( 'ld_instructor', (array) $current_user->roles ) ) {
								$role_slug = LearnDash_Custom_Label::get_label( 'group_leader' );
							} elseif ( in_array( 'ld_instructor', (array) $current_user->roles ) || learndash_is_admin_user( $user_id ) ) {
								$role_slug = esc_html__( 'Instructor', 'ld-dashboard' );
							}
							?>
								<li class="ld-dashboard-menu-divider-label ld-dashboard-label-color"><?php echo esc_html( $role_slug ); ?></li>
							<?php
						}
						foreach ( $items as $tb => $item ) :
							$active_tab = isset( $_GET['tab'] ) ? sanitize_text_field( wp_unslash( $_GET['tab'] ) ) : '';
							?>
							<li class="ld-dashboard-menu-tab <?php echo ( $active_tab == $tb ) ? 'ld-dashboard-active' : ''; ?> <?php echo ( ! isset( $_GET['tab'] ) && 'my-dashboard' == $tb ) ? 'ld-dashboard-active' : ''; ?> "> 
								<a class="<?php echo esc_attr( 'ld-focus-menu-link ld-focus-menu-' . $slug ); ?>" href="<?php echo ( isset( $item['url'] ) ) ? esc_url( $item['url'] ) : ''; ?>">
									<span class="ld-dashboard-menu-icon"><?php echo ( isset( $item['icon'] ) ) ? wp_kses_post( $item['icon'] ) : ''; ?></span>
								<?php echo ( isset( $item['label'] ) ) ? esc_html( $item['label'] ) : ''; ?>
								</a>
							</li>
							<?php
						endforeach;
						$section[] = $slug;
					endforeach;
					echo '</ul>';
					endif;
				?>
			</div>
		</section>
		<?php do_action( 'ld_dashboard_after_profile_section' ); ?>
	</div>
