<?php
/**
 * Block class framework
 *
 * @since 3.0.0
 *
 * @package LearnDash_Gradebook
 * @subpackage LearnDash_Gradebook/includes
 */

defined( 'ABSPATH' ) || die();

/**
 * Class LD_GB_Block
 *
 * Template for each block.
 *
 * @since 3.0.0
 *
 * @package LearnDash_Gradebook
 * @subpackage LearnDash_Gradebook/includes
 */
abstract class LD_GB_Block {

	/**
	 * The block ID (tag).
	 *
	 * @since 3.0.0
	 *
     * @var string $path
	 */
    public $path;

    /**
	 * LD_GB_Block constructor.
	 *
	 * @since 3.0.0
	 *
	 * @param string $path
	 */
	function __construct( $path ) {

        $this->path = $path;

        add_action( 'init', array( $this, 'register_ld_block' ), 11 );

	}

	/**
	 * Registers the block.
	 *
	 * @since 3.0.0
	 */
	function register_ld_block() {

		register_block_type_from_metadata(
		    $this->path,
			array(
				'render_callback' => array( $this, "render_callback" ),
			)
		);

	}

    function render_callback( $attributes ) {
        // Override me
    }
	
}