<?php
/**
 * Manages all plugin blocks.
 *
 * @since 3.0.0
 *
 * @package LearnDash_Gradebook
 * @subpackage LearnDash_Gradebook/includes
 */

defined( 'ABSPATH' ) || die();

/**
 * Class LD_GB_Blocks
 *
 * Outputs the included blocks.
 *
 * @since 3.0.0
 *
 * @package LearnDash_Gradebook
 * @subpackage LearnDash_Gradebook/includes
 */
class LD_GB_Blocks {

	/**
	 * All plugin blocks.
	 *
	 * @since 3.0.0
	 *
	 * @var array
	 */
	public $blocks = array();

	/**
	 * LD_GB_Blocks constructor.
	 *
	 * @since 3.0.0
	 */
	function __construct() {

		add_filter( 'ld_gb_blocks', array( $this, 'included_blocks' ) );
		add_action( 'init', array( $this, 'init_blocks' ) );

		add_action( 'enqueue_block_assets', array( $this, 'localize_block_scripts' ) );

	}

	/**
	 * Adds included blocks.
	 *
	 * @access public
	 * @since 3.0.0
	 * @return array
	 */
	public function included_blocks( $blocks ) {

		require_once LEARNDASH_GRADEBOOK_DIR . 'core/blocks/frontend-gradebook/class-ld-gb-bk-frontendgradebook.php';

		$blocks['ld_gradebook'] = new LD_GB_BK_FrontendGradebook( LEARNDASH_GRADEBOOK_DIR . 'core/blocks/frontend-gradebook/' );

		require_once LEARNDASH_GRADEBOOK_DIR . 'core/blocks/overall-grade/class-ld-gb-bk-overallgrade.php';

		$blocks['ld_overallgrade'] = new LD_GB_BK_OverallGrade( LEARNDASH_GRADEBOOK_DIR . 'core/blocks/overall-grade/' );

		require_once LEARNDASH_GRADEBOOK_DIR . 'core/blocks/report-card/class-ld-gb-bk-reportcard.php';

		$blocks['ld_reportcard'] = new LD_GB_BK_ReportCard( LEARNDASH_GRADEBOOK_DIR . 'core/blocks/report-card/' );

		return $blocks;

	}

	/**
	 * Initializes all plugin blocks.
	 *
	 * @access public
	 * @since 3.0.0
	 * return void
	 */
	public function init_blocks() {

		/**
		 * Blocks for GradeBook for LearnDash.
		 *
		 * @since 3.0.0
		 */
		$blocks = apply_filters( 'ld_gb_blocks', array() );

		foreach ( $blocks as $id => $block ) {
			$this->blocks[ $id ] = $block;
		}

	}

	/**
	 * Since each Block has its own script and @wordpress/create-block doesn't give us a way to lock onto a script handle, we will localize some data this way
	 * 
	 * Note: Once https://github.com/wp-pot/wp-pot/ has official support for JS and it is integrated with gulp-wp-pot we should try to revisit this
	 *
	 * @access	public
	 * @since	3.0.0
	 * @return  void
	 */
	public function localize_block_scripts() {

		if ( ! is_admin() ) return;

        $l10n = apply_filters( 'ld_gb_gutenberg_l10n', array(
			'gradebookLabel' => _x( 'Grade Book', 'Gutenberg Block Grade Book dropdown label', 'learndash-gradebook' ),
			'searchForGradebook' => _x( 'Type to search for a Grade Book...', 'Gutenberg Block type to search for a Grade Book', 'learndash-gradebook' ),
			'userLabel' => _x( 'User', ' Gutenberg Block User dropdown label', 'learndash-gradebook' ),
			'userOverallGradeDescription' => _x( 'Leave empty to show Overall Grade data for the currently logged-in User', 'Gutenberg Block User field description', 'learndash-gradebook' ),
			'gradebookReportCardDescription' => _x( 'Leave empty to show a Report Card for each Grade Book the User is in', 'Report Card Gutenberg Block Grade Book field description', 'learndash-gradebook' ),
			'userReportCardDescription' => _x( 'Leave empty to show Report Card data for the currently logged-in User', 'Report Card Gutenberg Block User field description', 'learndash-gradebook' ),
			'searchForUser' => _x( 'Type to search for a User...', 'Gutenberg Block type to search for a User', 'learndash-gradebook' ),
			'defaultPlaceholder' => _x( 'Search...', 'Gutenberg Block search field placeholder', 'learndash-gradebook' ),
		) );

        foreach ( $l10n as $key => $value ) {

            if ( ! is_scalar( $value ) )
                continue;

            $l10n[$key] = html_entity_decode( (string) $value, ENT_QUOTES, 'UTF-8' );

        }

        $script = "var ldGBgutenberg = " . wp_json_encode( $l10n ) . ';';

        $script = "/* <![CDATA[ */\n" . $script . "\n/* ]]> */";

        ?>

        <script type="text/javascript"><?php echo $script; ?></script>

        <?php

	}

}