<?php
/**
 * GradeBook for LearnDash
 *
 * @package     LearnDash_Gradebook
 * @author      Real Big Plugins
 * @copyright   2016 Real Big Plugins
 * @license     GPL2
 *
 * Plugin Name: GradeBook for LearnDash
 * Description: Adds Grade Book functionality to LearnDash LMS.
 * Version: 4.1.3
 * Requires at least: 4.8.0
 * Requires PHP: 5.3.0
 * Requires LearnDash: 3.4.0
 * Author: Real Big Plugins
 * Author URI: https://realbigplugins.com
 * Plugin URI: https://realbigplugins.com/plugins/gradebook-for-learndash
 * Text Domain: learndash-gradebook
 * Domain Path: /languages
 * License: GPL2
 * License URI: http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 */

defined( 'ABSPATH' ) || die();

if ( ! class_exists( 'LearnDash_Gradebook' ) ) {

	define( 'LEARNDASH_GRADEBOOK_VERSION', '4.1.3' );
	define( 'LEARNDASH_GRADEBOOK_DIR', plugin_dir_path( __FILE__ ) );
	define( 'LEARNDASH_GRADEBOOK_URI', trailingslashit( plugins_url( '', __FILE__ ) ) );

	/**
	 * Class LearnDash_Gradebook
	 *
	 * Initiates the plugin.
	 *
	 * @since 1.0.0
	 *
	 * @package LearnDash_Gradebook
	 */
	final class LearnDash_Gradebook {

		/**
		 * API module.
		 *
		 * @since 1.2.0
		 *
		 * @var LD_GB_API
		 */
		public $api;

		/**
		 * RBM Field Helpers instance.
		 *
		 * @since 1.2.0
		 *
		 * @var RBM_FieldHelpers
		 */
		public $field_helpers;

		/**
		 * RBP Support instance.
		 *
		 * @since 1.2.0
		 *
		 * @var RBP_Support
		 */
		public $support;

		/**
		 * Post Types module.
		 *
		 * @since 1.2.0
		 *
		 * @var LD_GB_PostTypes
		 */
		public $posttypes;

		/**
		 * Upgrade module.
		 *
		 * @since 1.2.0
		 *
		 * @var LD_GB_Upgrade
		 */
		public $upgrade;

		/**
		 * Admin Pages module.
		 *
		 * @since 1.1.0
		 *
		 * @var LD_GB_AdminPages
		 */
		public $admin_pages;

		/**
		 * Grade Book Page module.
		 *
		 * @since 1.0.0
		 *
		 * @var LD_GB_AdminPage_Gradebook
		 */
		public $gradebook_page;

		/**
		 * Shortcodes module.
		 *
		 * @since 1.0.0
		 *
		 * @var LD_GB_Shortcodes
		 */
		public $shortcodes;

		/**
		 * Blocks module.
		 *
		 * @since 1.0.0
		 *
		 * @var LD_GB_Blocks
		 */
		public $blocks;

		/**
		 * Dashboard Widgets module.
		 *
		 * @since 1.1.0
		 *
		 * @var LD_GB_Dashboard_Widgets
		 */
		public $dashboard_widgets;

		/**
		 * Settings page module.
		 *
		 * @since 1.0.0
		 *
		 * @var LD_GB_AdminPage_Settings
		 */
		public $settings_page;

		/**
		 * User Grades page module.
		 *
		 * @since 1.2.0
		 *
		 * @var LD_GB_AdminPage_UserGrades
		 */
		public $usergrades_page;

		/**
		 * Notices module.
		 *
		 * @since 1.0.0
		 *
		 * @var LD_GB_Notices
		 */
		public $notices;

		/**
		 * Quickstart module.
		 *
		 * @since 1.0.0
		 *
		 * @var LD_GB_QuickStart
		 */
		public $quickstart;

		/**
		 * Disable cloning.
		 *
		 * @since 1.0.0
		 */
		protected function __clone() {
		}

		/**
		 * Call this method to get singleton
		 *
		 * @since 1.0.0
		 *
		 * @return LearnDash_Gradebook()
		 */
		public static function instance() {

			static $instance = null;

			if ( $instance === null ) {
				$instance = new LearnDash_Gradebook();
			}

			return $instance;
		}

		/**
		 * AC constructor.
		 *
		 * @since 1.0.0
		 */
		private function __construct() {

			$this->load_textdomain();

			$this->require_necessities();

			$this->setup_fieldhelpers();

			add_filter( 'learndash_gradebook_download_id', array( $this, 'set_download_id' ) );

			$this->setup_support();

			add_action( 'init', array( $this, 'register_assets' ) );

			add_action( 'current_screen', array( $this, 'maybe_enqueue_assets' ), 999 );

			if ( isset( $_GET['ld_gb_install_roles'] ) ) {
				add_action( 'init', array( $this, 'setup_roles' ) );
			}

			add_filter( 'learndash_get_label', array( $this, 'learndash_get_label' ), 10, 2 );

		}

		/**
		 * Requires all plugin files.
		 *
		 * @since 1.0.0
		 */
		private function require_necessities() {

			require_once LEARNDASH_GRADEBOOK_DIR . 'core/ld-gb-fieldhelper-functions.php';
			require_once LEARNDASH_GRADEBOOK_DIR . 'core/api/class-ld-gb-api.php';
			require_once LEARNDASH_GRADEBOOK_DIR . 'core/post-types/class-ld-gb-posttypes.php';
			require_once LEARNDASH_GRADEBOOK_DIR . 'core/class-ld-gb-upgrade.php';
			require_once LEARNDASH_GRADEBOOK_DIR . 'core/class-ld-gb-user-grade.php';
			require_once LEARNDASH_GRADEBOOK_DIR . 'core/class-ld-gb-frontendgradebook.php';
			require_once LEARNDASH_GRADEBOOK_DIR . 'core/class-ld-gb-overallgrade.php';
			require_once LEARNDASH_GRADEBOOK_DIR . 'core/class-ld-gb-reportcard.php';
			require_once LEARNDASH_GRADEBOOK_DIR . 'core/class-ld-gb-shortcode.php';
			require_once LEARNDASH_GRADEBOOK_DIR . 'core/class-ld-gb-shortcodes.php';
			require_once LEARNDASH_GRADEBOOK_DIR . 'core/class-ld-gb-block.php';
			require_once LEARNDASH_GRADEBOOK_DIR . 'core/class-ld-gb-blocks.php';

			$this->api        = new LD_GB_API();
			$this->posttypes  = new LD_GB_PostTypes();
			$this->upgrade    = new LD_GB_Upgrade();
			$this->shortcodes = new LD_GB_Shortcodes();
			$this->blocks     = new LD_GB_Blocks();

			$this->frontend_gradebook = new LD_GB_FrontendGradebook();
			$this->overall_grade = new LD_GB_OverallGrade();
			$this->report_card = new LD_GB_ReportCard();

			// Admin
			if ( is_admin() ) {

				require_once LEARNDASH_GRADEBOOK_DIR . 'admin/includes/class-ld-gb-gradebook-list-table.php';
				require_once LEARNDASH_GRADEBOOK_DIR . 'admin/class-ld-gb-admin-pages.php';
				require_once LEARNDASH_GRADEBOOK_DIR . 'admin/class-ld-gb-adminpage-gradebook.php';
				require_once LEARNDASH_GRADEBOOK_DIR . 'admin/class-ld-gb-adminpage-settings.php';
				require_once LEARNDASH_GRADEBOOK_DIR . 'admin/class-ld-gb-adminpage-user-grades.php';
				require_once LEARNDASH_GRADEBOOK_DIR . 'admin/class-ld-gb-dashboard-widgets.php';
				require_once LEARNDASH_GRADEBOOK_DIR . 'admin/class-ld-gb-notices.php';
				require_once LEARNDASH_GRADEBOOK_DIR . 'admin/class-ld-gb-quickstart.php';

				$this->admin_pages       = new LD_GB_AdminPages();
				$this->gradebook_page    = new LD_GB_AdminPage_Gradebook();
				$this->settings_page     = new LD_GB_AdminPage_Settings();
				$this->usergrades_page   = new LD_GB_AdminPage_UserGrades();
				$this->dashboard_widgets = new LD_GB_Dashboard_Widgets();
				$this->notices           = new LD_GB_Notices();

				if ( version_compare( get_bloginfo( 'version' ), '3.3', '>' ) ) {

					$this->quickstart = new LD_GB_QuickStart();
				}
			}
		}

		/**
		 * Internationalization
		 *
		 * @access	private
		 * @since	3.1.0
		 * @return  void
		 */
		private function load_textdomain() {

			// Set filter for language directory
			$lang_dir = LEARNDASH_GRADEBOOK_DIR . 'languages/';
			$lang_dir = apply_filters( 'learndash_gradebook_languages_directory', $lang_dir );
		
			// Traditional WordPress plugin locale filter
			$locale = apply_filters( 'plugin_locale', determine_locale(), 'learndash-gradebook' );
			$mofile = sprintf( '%1$s-%2$s.mo', 'learndash-gradebook', $locale );
		
			// Setup paths to current locale file
			$mofile_local = $lang_dir . $mofile;
			$mofile_global = trailingslashit( WP_LANG_DIR ) . 'learndash-gradebook/' . $mofile;
		
			if ( file_exists( $mofile_global ) ) {
				// Look in global /wp-content/languages/learndash-gradebook/ folder
				// This way translations can be overridden via the Theme/Child Theme
				load_textdomain( 'learndash-gradebook', $mofile_global );
			}
			else if ( file_exists( $mofile_local ) ) {
				// Look in local /wp-content/plugins/learndash-gradebook/languages/ folder
				load_textdomain( 'learndash-gradebook', $mofile_local );
			}
			else {
				// Load the default language files
				load_plugin_textdomain( 'learndash-gradebook', false, $lang_dir );
			}
		
		}

		/**
		 * Initializes Field Helpers.
		 *
		 * @since 1.2.0
		 * @access private
		 */
		private function setup_fieldhelpers() {

			require_once LEARNDASH_GRADEBOOK_DIR . 'core/library/rbm-field-helpers/rbm-field-helpers.php';

			// Last l10n update: RBP Field Helpers v1.4.8
			$this->field_helpers = new RBM_FieldHelpers( array(
				'ID'   => 'ld_gb',
				'l10n' => array(
					'field_table'    => array(
						'delete_row'    => _x( 'Delete Row', 'Delete Row text for Table Fields', 'learndash-gradebook' ),
						'delete_column' => _x( 'Delete Column', 'Delete Column text for Table Fields', 'learndash-gradebook' ),
					),
					'field_select'   => array(
						'no_options'       => _x( 'No select options.', 'No options text for Select Fields', 'learndash-gradebook' ),
						'error_loading'    => _x( 'The results could not be loaded', 'Results could not be loaded text for Select Fields', 'learndash-gradebook' ),
						/* translators: Delete extra characters message in search for Select fields. %d is number of characters over input limit */
						'input_too_long'   => __( 'Please delete %d character', 'learndash-gradebook' ),
						/* translators: Add more characters message in search for Select fields. %d is number of characters under input limit */
						'input_too_short'  => __( 'Please enter %d or more characters', 'learndash-gradebook' ),
						'loading_more'     => _x( 'Loading more results...', 'Loading more results text for Select Fields', 'learndash-gradebook' ),
						/* translators: Maximum number of items selected text for Select Fields. %d is maximum number items selectable */
						'maximum_selected' => __( 'You can only select %d item(s)', 'learndash-gradebook' ),
						'no_results'       => _x( 'No results found', 'No results found text for Select Fields', 'learndash-gradebook' ),
						'searching'        => _x( 'Searching...', 'Searching status text for Select Fields', 'learndash-gradebook' ),
					),
					'field_repeater' => array(
						'collapsable_title' => _x( 'New Row', 'Collapsible Row title text for Repeater Fields', 'learndash-gradebook' ),
						'confirm_delete'    => _x( 'Are you sure you want to delete this element?', 'Row deletion confirmation message for Repeater Fields', 'learndash-gradebook' ),
						'delete_item'       => _x( 'Delete', 'Row delete button text for Repeater Fields', 'learndash-gradebook' ),
						'add_item'          => _x( 'Add', 'Row add button text for Repeater Fields', 'learndash-gradebook' ),
					),
					'field_media'    => array(
						'button_text'        => _x( 'Upload / Choose Media', 'Upload/Choose Media button text for Media Fields', 'learndash-gradebook' ),
						'button_remove_text' => _x( 'Remove Media', 'Remove Media button text for Media Fields', 'learndash-gradebook' ),
						'window_title'       => _x( 'Choose Media', 'Choose Media window title for Media Fields', 'learndash-gradebook' ),
					),
					'field_checkbox' => array(
						'no_options_text' => _x( 'No options available.', 'No options text for Checkbox Fields', 'learndash-gradebook' ),
					),
				),
			) );
		}

		/**
		 * Initialize RBP Support.
		 *
		 * @since 1.2.0
		 * @access private
		 */
		private function setup_support() {

			require_once LEARNDASH_GRADEBOOK_DIR . 'core/library/rbp-support/rbp-support.php';

			// Last l10n update: RBP Support v1.2.3
			$this->support = new RBP_Support( __FILE__, admin_url( 'admin.php?page=learndash-gradebook-settings&section=licensing' ), array(
				'support_form'           => array(
					'enabled'  => array(
						'title'           => _x( 'Need some help with %s?', 'Support Form Title. %s is the Plugin Name', 'learndash-gradebook' ),
						'subject_label'   => _x( 'Subject', 'Support Form Subject Field Label', 'learndash-gradebook' ),
						'message_label'   => _x( 'Message', 'Support Form Message Field Label', 'learndash-gradebook' ),
						'send_button'     => _x( 'Send', 'Support Form Send Button Label', 'learndash-gradebook' ),
						'subscribe_text'  => _x( 'We make other cool plugins and share updates and special offers to anyone who %ssubscribes here%s.', 'Support Form Newsletter Subscription text. Both %s are used to place HTML for the <a> in the message', 'learndash-gradebook' ),
						'validationError' => _x( 'This field is required', 'Support Form validation error message. Only used by legacy browsers for JavaScript Form Validation', 'learndash-gradebook' ),
						'success'         => _x( 'Support message succesfully sent!', 'Support Form successfully sent message', 'learndash-gradebook' ),
						'error'           => _x( 'Could not send support message.', 'Support Form could not send message', 'learndash-gradebook' ),
					),
					'disabled' => array(
						'title'            => _x( 'Need some help with %s?', 'Support Form Title. %s is the Plugin Name', 'learndash-gradebook' ),
						'disabled_message' => _x( 'Premium support is disabled. Please register your product and activate your license for this website to enable.', 'Support Form disabled text', 'learndash-gradebook' )
					),
				),
				'licensing_fields'       => array(
					'title'                    => _x( '%s License', 'License Key field label. %s is the Plugin Name', 'learndash-gradebook' ),
					'deactivate_button'        => _x( 'Deactivate', 'License Key deactivation button text', 'learndash-gradebook' ),
					'activate_button'          => _x( 'Activate', 'License Key activation button text', 'learndash-gradebook' ),
					'delete_deactivate_button' => _x( 'Delete and Deactivate', 'License Key delete and deactivate button', 'learndash-gradebook' ),
					'delete_button'            => _x( 'Delete', 'License Key delete button text', 'learndash-gradebook' ),
					'license_active_label'     => _x( 'License Active', 'License Key active label', 'learndash-gradebook' ),
					'license_inactive_label'   => _x( 'License Inactive', 'License Key inactive label', 'learndash-gradebook' ),
					'save_activate_button'     => _x( 'Save and Activate', 'License Key save and activate button text', 'learndash-gradebook' ),
				),
				'license_nag'            => array(
					'register_message' => _x( 'Register your copy of %s now to receive automatic updates and support.', 'Licenese Key Activation reminder that shows on the Plugins list. %s is the Plugin Name', 'learndash-gradebook' ),
					'purchase_message' => _x( 'If you do not have a license key, you can %spurchase one%s.', 'License Key purchase reminder that shows on the Plugins list. Both %s are used to place HTML for the <a> in the message', 'learndash-gradebook' ),
				),
				'license_activation'     => _x( '%s license successfully activated.', 'License Key successfully activated message. %s is the Plugin Name', 'learndash-gradebook' ),
				'license_deletion'       => _x( '%s license successfully deleted.', 'License Key successfully deleted message. %s is the Plugin Name', 'learndash-gradebook' ),
				'license_deactivation'   => array(
					'error'   => _x( 'Error: could not deactivate the license for %s', 'License Key deactivation error message. %s is the Plugin Name', 'learndash-gradebook' ),
					'success' => _x( '%s license successfully deactivated.', 'License Key deactivation success message. %s is the Plugin Name', 'learndash-gradebook' ),
				),
				'license_error_messages' => array(
					'expired'             => _x( 'Your license key expired on %s.', 'License Key has expired message. %s is a localized timestamp', 'learndash-gradebook' ),
					'revoked'             => _x( 'Your license key has been disabled.', 'License key has been revoked message', 'learndash-gradebook' ),
					'missing'             => _x( 'Invalid license.', 'Invalid license key message', 'learndash-gradebook' ),
					'site_inactive'       => _x( 'Your license is not active for this URL.', 'License key is not active for the current site error', 'learndash-gradebook' ),
					'item_name_mismatch'  => _x( 'This appears to be an invalid license key for %s.', 'License Key invalid for this plugin error. %s is the Plugin Name', 'learndash-gradebook' ),
					'no_activations_left' => _x( 'Your license key has reached its activation limit.', 'License Key reached its activation limit error', 'learndash-gradebook' ),
					'no_connection'       => _x( '%s cannot communicate with %s for License Key Validation. Please check your server configuration settings.', 'Unable to communicate with the Licensing server error message. %s is the Plugin Name followed by the Store URL', 'learndash-gradebook' ),
					'default'             => _x( 'An error occurred, please try again.', 'Fallback License Key transaction error message.', 'learndash-gradebook' ),
				),
				'beta_checkbox'          => array(
					'label'            => _x( 'Enable Beta Releases', 'Enable Beta Releases checkbox label', 'learndash-gradebook' ),
					'disclaimer'       => _x( 'Beta Releases should not be considered as Stable. Enabling this on your Production Site is done at your own risk.', 'Beta Releases warning message', 'learndash-gradebook' ),
					'enabled_message'  => _x( 'Beta Releases for %s enabled.', 'Beta Releases successfully enabled message. %s is the Plugin Name', 'learndash-gradebook' ),
					'disabled_message' => _x( 'Beta Releases for %s disabled.', 'Beta Releases successfully disabled message. %s is the Plugin Name', 'learndash-gradebook' ),
				),
			) );

			add_action( 'learndash_gradebook_debug_file_start', array( $this, 'add_debug_info' ) );

		}

		/**
		 * Sets the Download ID on RBP. This will allow the Plugin/Download name to be changed without causing issues.
		 *
		 * @param	integer  $id  Download ID
		 *
		 * @access	public
		 * @since	2.1.1
		 * @return	integer       Download ID
		 */
		public function set_download_id( $id ) {

			return 695;

		}

		/**
		 * Adds some GradeBook info to the RBP Support Debug File
		 *
		 * @access	public
		 * @since	3.0.0
		 * @return  void
		 */
		public function add_debug_info() {

			$current_locale = determine_locale();

			if ( $current_locale ) {

				// Get all English strings, please
				switch_to_locale( 'en_US' );

			}

			$settings_sections = LearnDash_Gradebook()->settings_page->get_settings();

			// List of default English strings for anything that LD would allow the user to override via its Settings screen
			// Plurals are listed first for easy search/replacing
			$learndash_custom_labels = array(
				'courses' => __( 'Courses', 'learndash' ),
				'course' => __( 'Course', 'learndash' ),
				'lessons' => __( 'Lessons', 'learndash' ),
				'lesson' => __( 'Lesson', 'learndash' ),
				'topics' => __( 'Topics', 'learndash' ),
				'topic' => __( 'Topic', 'learndash' ),
				'quizzes' => __( 'Quizzes', 'learndash' ),
				'quiz' => __( 'Quiz', 'learndash' ),
				'questions' => __( 'Questions', 'learndash' ),
				'question' => __( 'Question', 'learndash' ),
				'groups' => __( 'Groups', 'learndash' ),
				'group' => __( 'Group', 'learndash' ),
				'group_leader' => __( 'Group Leader', 'learndash' ),
				'assignments' => __( 'Assignments', 'learndash' ),
				'assignment' => __( 'Assignment', 'learndash' ),
				'button_take_this_course' => __( 'Take this Course', 'learndash' ),
				'button_take_this_group' => __( 'Enroll in Group', 'learndash' ),
				'button_mark_complete' => __( 'Mark Complete', 'learndash' ),
				'button_click_here_to_continue' => __( 'Click Here to Continue', 'learndash' ),
			);

			echo "\n= Global GradeBook Settings =\n\n";

			foreach ( $settings_sections as $section ) {

				foreach ( $section['fields'] as $setting ) {

					if ( isset( $setting['args']['option_field'] ) && ! $setting['args']['option_field'] ) continue;

					$field_id = $setting['id'];

					$label = ( isset( $setting['label'] ) && $setting['label'] ) ? $setting['label'] : $field_id;

					$label = trim( preg_replace( '/\<div\s*?class="fieldhelpers-field-description fieldhelpers-field-tip">[\s|\S]*?\<\/div\>/sim', '', $label ) );

					foreach ( $learndash_custom_labels as $key => $default ) {

						$label = str_replace( learndash_get_custom_label( $key ), $default, $label );
						$label = str_replace( learndash_get_custom_label_lower( $key ), strtolower( $default ), $label );

					}

					$default = ( isset( $setting['args']['default'] ) && $setting['args']['default'] ) ? $setting['args']['default'] : '';

					$value = ld_gb_get_option_field( $field_id, $default );

					if ( ! $value && $setting['callback'] == 'ld_gb_do_field_toggle' ) {
						$value = 'no';
					}

					if ( isset( $setting['args']['role_selector'] ) && $setting['args']['role_selector'] && isset( $setting['args']['value'] ) && $setting['args']['value'] ) {
						$value = $setting['args']['value'];
					}

					if ( is_array( $value ) || is_object( $value ) ) {
						$value = json_encode( $value, JSON_PRETTY_PRINT );
					}

					echo "{$label}: {$value}\n";

				}

			}

			echo "\n= Key LearnDash Constants =\n\n";

			echo "LEARNDASH_GROUP_LEADER_CAPABILITY_CHECK: " . ( defined( 'LEARNDASH_GROUP_LEADER_CAPABILITY_CHECK' ) ? LEARNDASH_GROUP_LEADER_CAPABILITY_CHECK : "Not defined?" ) . "\n";

			echo "LEARNDASH_ADMIN_CAPABILITY_CHECK: " . ( defined( 'LEARNDASH_ADMIN_CAPABILITY_CHECK' ) ? LEARNDASH_ADMIN_CAPABILITY_CHECK : "Not defined?" ) . "\n";

			echo "\n";

			echo "\n= LearnDash Custom Labels =\n\n";

			foreach ( $learndash_custom_labels as $key => $default ) {

				echo "{$default} => " . learndash_get_custom_label( $key ) . "\n";

			}

			if ( $current_locale ) {

				switch_to_locale( $current_locale );

			}

			echo "\n";

		}

		/**
		 * Registers all plugin assets.
		 *
		 * @since 1.0.0
		 * @access private
		 */
		function register_assets() {

			/**
			 * Report Card frontend style.
			 *
			 * @since 2.0.0
			 */
			wp_register_style(
				'ld-gb-report-card',
				LEARNDASH_GRADEBOOK_URI . 'assets/dist/css/report-card.css',
				apply_filters( 'ld_gb_report_card_style_dependencies', array() ),
				defined( 'WP_DEBUG' ) && WP_DEBUG ? time() : LEARNDASH_GRADEBOOK_VERSION
			);

			/**
			 * Frontend Grade Book style.
			 *
			 * @since 2.0.0
			 */
			wp_register_style(
				'ld-gb-frontend-gradebook',
				apply_filters( 'ld_gb_frontend_gradebook_style_src', LEARNDASH_GRADEBOOK_URI . 'assets/dist/css/frontend-gradebook.css' ),
				apply_filters( 'ld_gb_frontend_gradebook_style_dependencies', array( 'dashicons' ) ),
				defined( 'WP_DEBUG' ) && WP_DEBUG ? time() : LEARNDASH_GRADEBOOK_VERSION
			);

			/**
			 * Frontend Grade Book script
			 *
			 * @since 2.0.0
			 */
			wp_register_script(
				'ld-gb-frontend-gradebook',
				LEARNDASH_GRADEBOOK_URI . 'assets/dist/js/frontend-gradebook.js',
				apply_filters( 'ld_gb_frontend_gradebook_script_dependencies', array( 'jquery' ) ),
				defined( 'WP_DEBUG' ) && WP_DEBUG ? time() : LEARNDASH_GRADEBOOK_VERSION,
				true
			);

			wp_localize_script(
				'ld-gb-frontend-gradebook',
				'LD_GB_FrontendGradebook',
				apply_filters( 'ld_gb_frontend_gradebook_localize_script', array(
					'l10n' => array(
						'ldFrontendGradebookTableListOptions' => array(
							// These are the CSS Classes for fields to search in
							'valueNames' => array(
								'id',
							),
							'page' => apply_filters( 'ld_gb_frontend_gradebook_per_page', 15, 0, 0 ), // This is the number of results per-page
							'pagination' => true,
							'listClass' => 'ld-gb-frontend-gradebook-list-tbody', // The CSS Class of our Table
						),
						'nonce' => wp_create_nonce( 'wp_rest' ),
						'rest' => trailingslashit( esc_url_raw( rest_url( 'ld-gb/v1' ) ) ),
						'uri' => LEARNDASH_GRADEBOOK_URI,
					),
					'i18n' => array(
						'validationError' => _x( 'This field is required', 'Required field message for the Frontend Grade Book', 'learndash-gradebook' ),
						'deleteGrade' => _x( 'Are you sure you want to delete this grade?', 'Grade deletion confirmation message for the Frontend Grade Book', 'learndash-gradebook' ),
						'select2Warning' => _x( 'Select2 has been loaded by a plugin other than GradeBook for LearnDash. This may cause problems.', 'Select2 already loaded warning message', 'learndash-gradebook' )
					)
				) )
			);

			/**
			 * Global admin style.
			 *
			 * @since 1.0.0
			 */
			wp_register_style(
				'ld-gb-admin',
				LEARNDASH_GRADEBOOK_URI . 'assets/dist/css/admin.css',
				array(),
				defined( 'WP_DEBUG' ) && WP_DEBUG ? time() : LEARNDASH_GRADEBOOK_VERSION
			);

			/**
			 * Global admin script.
			 *
			 * @since 1.0.0
			 */
			wp_register_script(
				'ld-gb-admin',
				LEARNDASH_GRADEBOOK_URI . 'assets/dist/js/admin.js',
				array( 'jquery' ),
				defined( 'WP_DEBUG' ) && WP_DEBUG ? time() : LEARNDASH_GRADEBOOK_VERSION,
				true
			);
		}

		/**
		 * Prevents an issue with Gravity Forms where if RBM FH loads, Select2 is somehow broken despite us renaming it for our own use
		 * Since we're having to unhook RBM FH's scripts, we cannot check for only GradeBook for LearnDash's pages since they could be using another one of our plugins that includes RBM FH and that would break those plugins.
		 * Instead, we'll just explicitly check for Gravity Forms' settings page
		 * 
		 * @access	public
		 * @since	1.4.7
		 * @return  void
		 */
		public function maybe_enqueue_assets() {

			global $current_screen;

			if ( strpos( $current_screen->base, 'toplevel_page_gf' ) !== false ) {

				learndash_gradebook_remove_class_action( 'admin_enqueue_scripts', 'RBM_FieldHelpers', 'enqueue_scripts' );

			}
			else {

				add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_assets' ) );

			}

		}

		/**
		 * Enqueues all global plugin admin assets.
		 *
		 * @since 1.0.0
		 * @access private
		 */
		function admin_enqueue_assets() {

			$current_screen = get_current_screen();

			// Data
			$data = apply_filters( 'ld_gb_admin_script_data', array(
				'current_user_id' => get_current_user_id(),
				'l10n'            => array(
					'no_users'          => _x( 'No Users', 'No Users message for the Grade Book Dashboard Widget', 'learndash-gradebook' ),
					'component_no_name' => _x( '- No Name -', 'Component without a name message for the Grade Book Dashboard Widget', 'learndash-gradebook' ),
					'select_a_user'     => _x( 'Select a User', 'Select a user message for the Grade Book Dashboard Widget', 'learndash-gradebook' ),
				),
			) );

			wp_localize_script( 'ld-gb-admin', 'LD_GB_Admin', $data );

			// Global admin style
			wp_enqueue_style( 'ld-gb-admin' );
			wp_style_add_data( 'ld-gb-admin', 'rtl', 'replace' );

			// Global admin script
			wp_enqueue_script( 'ld-gb-admin' );
		}

		/**
		 * Manually setup roles when called.
		 *
		 * @since 1.3.4
		 * @access private
		 */
		function setup_roles() {

			LD_GB_Install::setup_capabilities();
		}

		/**
		 * Add support for Assignments in LearnDash_Custom_Label::get_label()
		 * This only operates as a fallback, so if support is added in for Assignments in the future this will not run
		 *
		 * @param   string  $label  Label
		 * @param   string  $key    Key
		 *
		 * @access	public
		 * @since	1.6.0
		 * @return  string          Label
		 */
		public function learndash_get_label( $label, $key ) {

			if ( $label !== '' ) return $label;

			if ( $key == 'assignment' ) {
				return __( 'Assignment', 'learndash' );
			}

			if ( $key == 'assignments' ) {
				return __( 'Assignments', 'learndash' );
			}

			return $label;

		}

	}

	// Helper functions
	require_once LEARNDASH_GRADEBOOK_DIR . 'core/ld-gb-functions.php';

	// Load the bootstrapper
	require_once LEARNDASH_GRADEBOOK_DIR . 'learndash-gradebook-bootstrapper.php';
	new LearnDash_Gradebook_Bootstrapper();

	// Install the plugin
	require_once LEARNDASH_GRADEBOOK_DIR . 'core/class-ld-gb-install.php';
	register_activation_hook( __FILE__, array( 'LD_GB_Install', 'install' ) );

	/**
	 * Gets the main class object.
	 *
	 * Used to instantiate the plugin class for the first time and then used subsequent times to return the existing object.
	 *
	 * @since 1.0.0
	 *
	 * @return LearnDash_Gradebook
	 */
	function LearnDash_Gradebook() {

		return LearnDash_Gradebook::instance();
	}
}