<?php

/**
 * Implements Customizer functionality.
 *
 * Add custom sections and settings to the Customizer.
 *
 * @package   lqc-learndash-quiz-customizer
 * @copyright Copyright (c) 2019, Escape Creative, LLC
 * @license   GPL2+
 */
class LQC_Learndash_Quiz_Customizer_Setup {

	/**
	 * LQC_Learndash_Quiz_Customizer_Setup constructor.
	 *
	 * @access public
	 * @since  1.0
	 * @return void
	 */
	public function __construct() {

		add_action( 'customize_register', array( $this, 'lqc_register_customize_sections' ) );

	}

	/**
	 * Add all sections and panels to the Customizer
	 *
	 * @param WP_Customize_Manager $wp_customize
	 *
	 * @access public
	 * @since  1.0
	 * @return void
	 */
	public function lqc_register_customize_sections( $wp_customize ) {

		/**
		 * Add Panels
		 */

		// Panel containing all Quiz sub-sections
		$wp_customize->add_panel( 'lqc_learndash_quiz_panel', array(
			'title' => 'Quiz Customizer for LearnDash',
			'description' => __( 'These styles only apply to LearnDash quiz pages. Use the preview window to visit a page that contains a LearnDash quiz.', 'learndash-quiz-customizer' ),
			'priority' => 161
		) );

		// Text: Buttons
		// $wp_customize->add_section( 'lqc_quiz_text_buttons', array(
		// 	'title'    => __( 'Text: Buttons', 'learndash-quiz-customizer' ),
		// 	'panel'    => 'lqc_learndash_quiz_panel',
		// 	'priority' => 110
		// ) );

		// Text: Labels
		// $wp_customize->add_section( 'lqc_quiz_text_labels', array(
		// 	'title'    => __( 'Text: Labels', 'learndash-quiz-customizer' ),
		// 	'panel'    => 'lqc_learndash_quiz_panel',
		// 	'priority' => 120
		// ) );

		// Text: Messages
		// $wp_customize->add_section( 'lqc_quiz_text_messages', array(
		// 	'title'    => __( 'Text: Messages', 'learndash-quiz-customizer' ),
		// 	'panel'    => 'lqc_learndash_quiz_panel',
		// 	'priority' => 130
		// ) );

		// Design: Global
		$wp_customize->add_section( 'lqc_quiz_design_global', array(
			'title'    => __( 'Design: Global', 'learndash-quiz-customizer' ),
			'panel'    => 'lqc_learndash_quiz_panel',
			'priority' => 140
		) );

		// Design: Colors
		$wp_customize->add_section( 'lqc_quiz_design_colors', array(
			'title'    => __( 'Design: Colors', 'learndash-quiz-customizer' ),
			'panel'    => 'lqc_learndash_quiz_panel',
			'priority' => 150
		) );

		// Design: Buttons
		$wp_customize->add_section( 'lqc_quiz_design_buttons', array(
			'title'    => __( 'Design: Buttons', 'learndash-quiz-customizer' ),
			'panel'    => 'lqc_learndash_quiz_panel',
			'priority' => 160
		) );

		// Question Style
		$wp_customize->add_section( 'lqc_quiz_question_style', array(
			'title'    => sprintf( esc_html_x( '%s Style', 'placeholder: Question', 'learndash-quiz-customizer' ), LearnDash_Custom_Label::get_label( 'question' ) ),
			'panel'    => 'lqc_learndash_quiz_panel',
			'priority' => 170
		) );

		// Review Box
		$wp_customize->add_section( 'lqc_quiz_review_box', array(
			'title'    => __( 'Review Box', 'learndash-quiz-customizer' ),
			'panel'    => 'lqc_learndash_quiz_panel',
			'priority' => 180
		) );

		// Quiz Timer
		$wp_customize->add_section( 'lqc_quiz_timer', array(
			'title'    => __( 'Timer', 'learndash-quiz-customizer' ),
			'panel'    => 'lqc_learndash_quiz_panel',
			'priority' => 190
		) );

		// Sticky Elements
		$wp_customize->add_section( 'lqc_quiz_sticky', array(
			'title'    => __( 'Sticky Elements', 'learndash-quiz-customizer' ),
			'description' => __( '<b>Experimental:</b> These options should work, but may not look great on all themes & setups.', 'learndash-quiz-customizer' ),
			'panel'    => 'lqc_learndash_quiz_panel',
			'priority' => 200
		) );

		/*
		 * Add settings to sections.
		 */
		// $this->lqc_quiz_text_buttons_section( $wp_customize );
		// $this->lqc_quiz_text_labels_section( $wp_customize );
		// $this->lqc_quiz_text_messages_section( $wp_customize );
		$this->lqc_quiz_design_global_section( $wp_customize );
		$this->lqc_quiz_design_colors_section( $wp_customize );
		$this->lqc_quiz_design_buttons_section( $wp_customize );
		$this->lqc_quiz_question_style_section( $wp_customize );
		$this->lqc_quiz_review_box_section( $wp_customize );
		$this->lqc_quiz_timer_section( $wp_customize );
		$this->lqc_quiz_sticky_section( $wp_customize );

	}

	/**
	 * Section: Text: Buttons
	 *
	 * @param WP_Customize_Manager $wp_customize
	 *
	 * @access private
	 * @since  1.0
	 * @return void
	 * @removed 2.0
	 */


	/**
	 * Section: Text: Labels
	 *
	 * @param WP_Customize_Manager $wp_customize
	 *
	 * @access private
	 * @since  1.0
	 * @return void
	 * @removed 2.0
	 */


	/**
	 * Section: Text: Messages
	 *
	 * @param WP_Customize_Manager $wp_customize
	 *
	 * @access private
	 * @since  1.0
	 * @return void
	 * @removed 2.0
	 */


	/**
	 * Section: Design: Global
	 *
	 * @param WP_Customize_Manager $wp_customize
	 *
	 * @access private
	 * @since  1.0
	 * @return void
	 */
	private function lqc_quiz_design_global_section( $wp_customize ) {

		/**
		 * Global Border Radius
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[global_border_radius]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_text_field'
		) );
		$wp_customize->add_control( 'lqc_quiz_options[global_border_radius]', array(
			'type'     => 'number',
			'label'    =>  __( 'Global Border Radius', 'learndash-quiz-customizer' ),
			'input_attrs' => array(
				'min'   => 1,
				'max'   => 100,
				'style' => 'width: 60px; display: block;'
			),
			'description' => __( 'Value is in pixels (px).', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_design_global',
			'settings' => 'lqc_quiz_options[global_border_radius]',
			'priority' => 10
		) );

	} // function lqc_quiz_design_global_section( $wp_customize )


	/**
	 * Section: Design: Colors
	 *
	 * @param WP_Customize_Manager $wp_customize
	 *
	 * @access private
	 * @since  1.0
	 * @return void
	 */
	private function lqc_quiz_design_colors_section( $wp_customize ) {

		/**
		 * Primary Color (Dark)
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[color_primary_dark]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[color_primary_dark]', array(
			'label'    => __( 'Primary Color (Dark)', 'learndash-quiz-customizer' ),
			'description' => __( 'Mainly used when selecting answers. <br />Default #00a2e8', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_design_colors',
			'settings' => 'lqc_quiz_options[color_primary_dark]',
			'priority' => 10
		) ) );

		/**
		 * Primary Color (Light)
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[color_primary_light]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[color_primary_light]', array(
			'label'    => __( 'Primary Color (Light)', 'learndash-quiz-customizer' ),
			'description' => __( 'Should be a subtle, much lighter version of the above. Default #e0f5fe', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_design_colors',
			'settings' => 'lqc_quiz_options[color_primary_light]',
			'priority' => 15
		) ) );

		/**
		 * Correct Color (Dark)
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[color_correct_dark]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[color_correct_dark]', array(
			'label'    => __( 'Correct Color (Dark)', 'learndash-quiz-customizer' ),
			'description' => __( 'Mainly used for correct answers. <br />Default #019e7c', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_design_colors',
			'settings' => 'lqc_quiz_options[color_correct_dark]',
			'priority' => 20
		) ) );

		/**
		 * Correct Color (Light)
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[color_correct_light]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[color_correct_light]', array(
			'label'    => __( 'Correct Color (Light)', 'learndash-quiz-customizer' ),
			'description' => __( 'Should be a subtle, much lighter version of the above. Default #c8e6c9', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_design_colors',
			'settings' => 'lqc_quiz_options[color_correct_light]',
			'priority' => 25
		) ) );

		/**
		 * Incorrect Color (Dark)
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[color_incorrect_dark]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[color_incorrect_dark]', array(
			'label'    => __( 'Incorrect Color (Dark)', 'learndash-quiz-customizer' ),
			'description' => __( 'Mainly used for incorrect answers. <br />Default #c62828', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_design_colors',
			'settings' => 'lqc_quiz_options[color_incorrect_dark]',
			'priority' => 30
		) ) );

		/**
		 * Incorrect Color (Light)
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[color_incorrect_light]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[color_incorrect_light]', array(
			'label'    => __( 'Incorrect Color (Light)', 'learndash-quiz-customizer' ),
			'description' => __( 'Should be a subtle, much lighter version of the above. Default #ffcdd2', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_design_colors',
			'settings' => 'lqc_quiz_options[color_incorrect_light]',
			'priority' => 35
		) ) );

	} // function lqc_quiz_design_colors_section( $wp_customize )


	/**
	 * Section: Design: Buttons
	 *
	 * @param WP_Customize_Manager $wp_customize
	 *
	 * @access private
	 * @since  1.0
	 * @return void
	 */
	private function lqc_quiz_design_buttons_section( $wp_customize ) {

		/**
		 * Button Border Radius
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[button_border_radius]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_text_field'
		) );
		$wp_customize->add_control( 'lqc_quiz_options[button_border_radius]', array(
			'type'     => 'number',
			'label'    =>  __( 'Button Border Radius', 'learndash-quiz-customizer' ),
			'input_attrs' => array(
				'min'   => 1,
				'max'   => 100,
				'style' => 'width: 60px; display: block;'
			),
			'description' => __( 'Value is in pixels (px).', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_design_buttons',
			'settings' => 'lqc_quiz_options[button_border_radius]',
			'priority' => 10
		) );

		/**
		 * Primary Button: BG Color
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[button_primary_bg_color]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[button_primary_bg_color]', array(
			'label'    => __( 'Primary Button: Background', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_design_buttons',
			'settings' => 'lqc_quiz_options[button_primary_bg_color]',
			'priority' => 20
		) ) );

		/**
		 * Primary Button: Text Color
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[button_primary_text_color]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[button_primary_text_color]', array(
			'label'    => __( 'Primary Button: Text', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_design_buttons',
			'settings' => 'lqc_quiz_options[button_primary_text_color]',
			'priority' => 25
		) ) );

		/**
		 * Primary Button: Hover: BG Color
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[button_primary_bg_color_hover]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[button_primary_bg_color_hover]', array(
			'label'    => __( 'Primary Button: Hover: Background', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_design_buttons',
			'settings' => 'lqc_quiz_options[button_primary_bg_color_hover]',
			'priority' => 30
		) ) );

		/**
		 * Primary Button: Hover: Text Color
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[button_primary_text_color_hover]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[button_primary_text_color_hover]', array(
			'label'    => __( 'Primary Button: Hover: Text', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_design_buttons',
			'settings' => 'lqc_quiz_options[button_primary_text_color_hover]',
			'priority' => 35
		) ) );

		/**
		 * Secondary Button: BG Color
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[button_secondary_bg_color]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[button_secondary_bg_color]', array(
			'label'    => __( 'Secondary Button: Background', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_design_buttons',
			'settings' => 'lqc_quiz_options[button_secondary_bg_color]',
			'priority' => 40
		) ) );

		/**
		 * Secondary Button: Text Color
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[button_secondary_text_color]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[button_secondary_text_color]', array(
			'label'    => __( 'Secondary Button: Text', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_design_buttons',
			'settings' => 'lqc_quiz_options[button_secondary_text_color]',
			'priority' => 45
		) ) );

		/**
		 * Secondary Button: Hover: BG Color
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[button_secondary_bg_color_hover]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[button_secondary_bg_color_hover]', array(
			'label'    => __( 'Secondary Button: Hover: Background', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_design_buttons',
			'settings' => 'lqc_quiz_options[button_secondary_bg_color_hover]',
			'priority' => 50
		) ) );

		/**
		 * Secondary Button: Hover: Text Color
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[button_secondary_text_color_hover]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[button_secondary_text_color_hover]', array(
			'label'    => __( 'Secondary Button: Hover: Text', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_design_buttons',
			'settings' => 'lqc_quiz_options[button_secondary_text_color_hover]',
			'priority' => 55
		) ) );

	} // function lqc_quiz_design_buttons_section( $wp_customize )


	/**
	 * Section: Question Style
	 *
	 * @param WP_Customize_Manager $wp_customize
	 *
	 * @access private
	 * @since  1.0
	 * @return void
	 */
	private function lqc_quiz_question_style_section( $wp_customize ) {

		/**
		 * Question Style: Single Choice
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[question_style_single_choice]', array(
			'type'              => 'option',
			'default'           => 'stacked',
			'sanitize_callback' => 'sanitize_text_field'
		) );
		$wp_customize->add_control( 'lqc_quiz_options[question_style_single_choice]', array(
			'type'     => 'select',
			'label'    =>  __( 'Single Choice', 'learndash-quiz-customizer' ),
			'choices'  => array(
				'stacked'   => __( 'Stacked (default)', 'learndash-quiz-customizer' ),
				'inline'   => __( 'Inline', 'learndash-quiz-customizer' )
			),
			'description' => __( '<b>Inline</b> works on screens 600px wide & up.', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_question_style',
			'settings' => 'lqc_quiz_options[question_style_single_choice]',
			'priority' => 10
		) );

		/**
		 * Question Style: Multiple Choice
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[question_style_multiple_choice]', array(
			'type'              => 'option',
			'default'           => 'stacked',
			'sanitize_callback' => 'sanitize_text_field'
		) );
		$wp_customize->add_control( 'lqc_quiz_options[question_style_multiple_choice]', array(
			'type'     => 'select',
			'label'    =>  __( 'Multiple Choice', 'learndash-quiz-customizer' ),
			'choices'  => array(
				'stacked'   => __( 'Stacked (default)', 'learndash-quiz-customizer' ),
				'inline'   => __( 'Inline', 'learndash-quiz-customizer' )
			),
			'description' => __( '<b>Inline</b> works on screens 600px wide & up.', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_question_style',
			'settings' => 'lqc_quiz_options[question_style_multiple_choice]',
			'priority' => 15
		) );

		/**
		 * Question Style: Fill in the Blank
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[question_style_cloze]', array(
			'type'              => 'option',
			'default'           => 'background',
			'sanitize_callback' => 'sanitize_text_field'
		) );
		$wp_customize->add_control( 'lqc_quiz_options[question_style_cloze]', array(
			'type'     => 'select',
			'label'    =>  __( 'Fill in the Blank', 'learndash-quiz-customizer' ),
			'choices'  => array(
				'background'       => __( 'Background (default)', 'learndash-quiz-customizer' ),
				'underline_solid'  => __( 'Underline, Solid', 'learndash-quiz-customizer' ),
				'underline_dashed' => __( 'Underline, Dashed', 'learndash-quiz-customizer' )
			),
			'section'  => 'lqc_quiz_question_style',
			'settings' => 'lqc_quiz_options[question_style_cloze]',
			'priority' => 20
		) );

	} // function lqc_quiz_question_style_section( $wp_customize )


	/**
	 * Section: Review Box
	 *
	 * @param WP_Customize_Manager $wp_customize
	 *
	 * @access private
	 * @since  1.0
	 * @return void
	 */
	private function lqc_quiz_review_box_section( $wp_customize ) {

		/**
		 * Review Box Container: Background Color
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[review_box_bg_color]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[review_box_bg_color]', array(
			'label'    => __( 'Container: Background', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_review_box',
			'settings' => 'lqc_quiz_options[review_box_bg_color]',
			'priority' => 1
		) ) );

		/**
		 * Review Box Container: Border Width
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[review_box_border_width]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_text_field'
		) );
		$wp_customize->add_control( 'lqc_quiz_options[review_box_border_width]', array(
			'type'     => 'number',
			'label'    =>  __( 'Container: Border Width', 'learndash-quiz-customizer' ),
			'input_attrs' => array(
				'min'   => 1,
				'max'   => 100,
				'style' => 'width: 60px; display: block;'
			),
			'description' => __( 'Value is in pixels (px).', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_review_box',
			'settings' => 'lqc_quiz_options[review_box_border_width]',
			'priority' => 2
		) );

		/**
		 * Review Box Container: Border Color
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[review_box_border_color]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[review_box_border_color]', array(
			'label'    => __( 'Container: Border Color', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_review_box',
			'settings' => 'lqc_quiz_options[review_box_border_color]',
			'priority' => 3
		) ) );

		/**
		 * Review Box: Number Style
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[review_numbers_style]', array(
			'type'              => 'option',
			'default'           => 'default',
			'sanitize_callback' => 'sanitize_text_field'
		) );
		$wp_customize->add_control( 'lqc_quiz_options[review_numbers_style]', array(
			'type'     => 'select',
			'label'    =>  __( 'Number Style', 'learndash-quiz-customizer' ),
			'description' => __( 'Default inherits global border radius.', 'learndash-quiz-customizer' ),
			'choices'  => array(
				'default'   => __( 'Default', 'learndash-quiz-customizer' ),
				'circular'   => __( 'Circular', 'learndash-quiz-customizer' ),
				'square'   => __( 'Square', 'learndash-quiz-customizer' )
			),
			'section'  => 'lqc_quiz_review_box',
			'settings' => 'lqc_quiz_options[review_numbers_style]',
			'priority' => 10
		) );

		/**
		 * Mark Answered Color
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[color_mark_answered]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[color_mark_answered]', array(
			'label'    => __( 'Mark Answered', 'learndash-quiz-customizer' ),
			'description' => __( 'Default #6ca54c', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_review_box',
			'settings' => 'lqc_quiz_options[color_mark_answered]',
			'priority' => 20
		) ) );

		/**
		 * Mark Review Color
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[color_mark_review]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[color_mark_review]', array(
			'label'    => __( 'Mark For Review', 'learndash-quiz-customizer' ),
			'description' => __( 'Default #ffb800', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_review_box',
			'settings' => 'lqc_quiz_options[color_mark_review]',
			'priority' => 25
		) ) );

	} // function lqc_quiz_review_box_section( $wp_customize )


	/**
	 * Section: Quiz Timer
	 *
	 * @param WP_Customize_Manager $wp_customize
	 *
	 * @access private
	 * @since  1.0
	 * @return void
	 */
	private function lqc_quiz_timer_section( $wp_customize ) {

		/**
		 * Timer Container: Background Color
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[timer_container_bg_color]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[timer_container_bg_color]', array(
			'label'    => __( 'Container: Background', 'learndash-quiz-customizer' ),
			'description' => __( 'Default #f0f3f6', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_timer',
			'settings' => 'lqc_quiz_options[timer_container_bg_color]',
			'priority' => 1
		) ) );

		/**
		 * Timer Container: Text Color
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[timer_container_text_color]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[timer_container_text_color]', array(
			'label'    => __( 'Container: Text', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_timer',
			'settings' => 'lqc_quiz_options[timer_container_text_color]',
			'priority' => 2
		) ) );

		/**
		 * Timer Container: Border Width
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[timer_container_border_width]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_text_field'
		) );
		$wp_customize->add_control( 'lqc_quiz_options[timer_container_border_width]', array(
			'type'     => 'number',
			'label'    =>  __( 'Container: Border Width', 'learndash-quiz-customizer' ),
			'input_attrs' => array(
				'min'   => 1,
				'max'   => 100,
				'style' => 'width: 60px; display: block;'
			),
			'description' => __( 'Value is in pixels (px).', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_timer',
			'settings' => 'lqc_quiz_options[timer_container_border_width]',
			'priority' => 3
		) );

		/**
		 * Timer Container: Border Color
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[timer_container_border_color]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[timer_container_border_color]', array(
			'label'    => __( 'Container: Border Color', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_timer',
			'settings' => 'lqc_quiz_options[timer_container_border_color]',
			'priority' => 4
		) ) );

		/**
		 * Quiz Timer: Bar Style
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[timer_bar_style]', array(
			'type'              => 'option',
			'default'           => 'solid',
			'sanitize_callback' => 'sanitize_text_field'
		) );
		$wp_customize->add_control( 'lqc_quiz_options[timer_bar_style]', array(
			'type'     => 'select',
			'label'    =>  __( 'Bar Style', 'learndash-quiz-customizer' ),
			'choices'  => array(
				'solid'     => __( 'Solid', 'learndash-quiz-customizer' ),
				'striped'   => __( 'Striped', 'learndash-quiz-customizer' )
			),
			'section'  => 'lqc_quiz_timer',
			'settings' => 'lqc_quiz_options[timer_bar_style]',
			'priority' => 10
		) );

		/**
		 * Quiz Timer: Bar Height
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[timer_bar_height]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_text_field'
		) );
		$wp_customize->add_control( 'lqc_quiz_options[timer_bar_height]', array(
			'type'     => 'number',
			'label'    =>  __( 'Bar Height', 'learndash-quiz-customizer' ),
			'input_attrs' => array(
				'min'   => 1,
				'max'   => 100,
				'style' => 'width: 60px; display: block;'
			),
			'description' => __( 'Value is in pixels (px).', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_timer',
			'settings' => 'lqc_quiz_options[timer_bar_height]',
			'priority' => 20
		) );

		/**
		 * Bar Background Color
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[timer_bar_bg_color]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[timer_bar_bg_color]', array(
			'label'    => __( 'Bar Background', 'learndash-quiz-customizer' ),
			'description' => __( 'Default #ffffff', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_timer',
			'settings' => 'lqc_quiz_options[timer_bar_bg_color]',
			'priority' => 30
		) ) );

		/**
		 * Bar Background Color
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[timer_bar_color]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'lqc_quiz_options[timer_bar_color]', array(
			'label'    => __( 'Bar Color', 'learndash-quiz-customizer' ),
			'description' => __( 'Default inherits dark primary color.', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_timer',
			'settings' => 'lqc_quiz_options[timer_bar_color]',
			'priority' => 40
		) ) );

	} // function lqc_quiz_timer_section( $wp_customize )


	/**
	 * Section: Sticky Elements
	 *
	 * @param WP_Customize_Manager $wp_customize
	 *
	 * @access private
	 * @since  1.0
	 * @return void
	 */
	private function lqc_quiz_sticky_section( $wp_customize ) {

		/**
		 * Sticky: Stick to Top
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[stick_to_top]', array(
			'type'              => 'option',
			'default'           => 'disabled',
			'sanitize_callback' => 'sanitize_text_field'
		) );
		$wp_customize->add_control( 'lqc_quiz_options[stick_to_top]', array(
			'type'        => 'select',
			'label'       =>  __( 'Stick to Top', 'learndash-quiz-customizer' ),
			'description' =>  __( 'Does not work well with Focus Mode on desktop.', 'learndash-quiz-customizer' ),
			'choices'     => array(
				'disabled'          => __( '-Disabled-', 'learndash-quiz-customizer' ),
				'question_xofy'     => __( 'Question X of Y', 'learndash-quiz-customizer' ),
				'review_area_1'     => __( 'Review Area, 1 Row', 'learndash-quiz-customizer' ),
				'review_area_2'     => __( 'Review Area, 2 Rows', 'learndash-quiz-customizer' )
			),
			'section'  => 'lqc_quiz_sticky',
			'settings' => 'lqc_quiz_options[stick_to_top]',
			'priority' => 10
		) );

		/**
		 * Sticky: Stick to Bottom
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[stick_to_bottom]', array(
			'type'              => 'option',
			'default'           => 'disabled',
			'sanitize_callback' => 'sanitize_text_field'
		) );
		$wp_customize->add_control( 'lqc_quiz_options[stick_to_bottom]', array(
			'type'        => 'select',
			'label'       => __( 'Stick to Bottom', 'learndash-quiz-customizer' ),
			'description' => __( 'Navigation buttons work on screens below 800px.', 'learndash-quiz-customizer' ),
			'choices'     => array(
				'disabled'             => __( '-Disabled-', 'learndash-quiz-customizer' ),
				'quiz_nav_buttons'     => __( 'Navigation Buttons', 'learndash-quiz-customizer' ),
				'time_limit_full'      => __( 'Time Limit, Full', 'learndash-quiz-customizer' ),
				'time_limit_small_bar' => __( 'Time Limit, Small Bar', 'learndash-quiz-customizer' ),
				'time_limit_text_only' => __( 'Time Limit, Text Only', 'learndash-quiz-customizer' )
			),
			'section'     => 'lqc_quiz_sticky',
			'settings'    => 'lqc_quiz_options[stick_to_bottom]',
			'priority'    => 15
		) );

		/**
		 * Sticky: Max Width
		 */
		$wp_customize->add_setting( 'lqc_quiz_options[sticky_max_width]', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_text_field'
		) );
		$wp_customize->add_control( 'lqc_quiz_options[sticky_max_width]', array(
			'type'     => 'number',
			'label'    =>  __( 'Sticky: Max Width', 'learndash-quiz-customizer' ),
			'input_attrs' => array(
				'min'   => 1,
				'style' => 'width: 70px; display: block;'
			),
			'description' => __( 'Value is in pixels (px).', 'learndash-quiz-customizer' ),
			'section'  => 'lqc_quiz_sticky',
			'settings' => 'lqc_quiz_options[sticky_max_width]',
			'priority' => 20
		) );

	} // function lqc_quiz_sticky_section( $wp_customize )


	/**
	 * Sanitize Checkbox
	 *
	 * Accepts only "true" or "false" as possible values.
	 *
	 * @param $input
	 *
	 * @access public
	 * @since  1.0
	 * @return bool
	 */
	public function lqc_sanitize_checkbox( $input ) {
		return ( $input === true ) ? true : false;
	}

} // class LQC_Learndash_Quiz_Customizer_Setup