<?php

/**
* Thrivecart integration class
*/
class LearnDash_Thrivecart_Integration {

	public function __construct()
	{
		add_action( 'init', array( $this, 'process_webhook_url' ) );
	}

	/**
	 * Process Thrivecart notification URL HTTP POST
	 */
	public function process_webhook_url() {
		if ( ! isset( $_GET['learndash-integration'] ) || $_GET['learndash-integration'] != 'thrivecart' ) {
			return;
		}

		if ( ! empty( $_POST ) && ! $this->is_transaction_valid( $_POST ) ) {
			wp_die( __( 'Cheatin\' huh?', 'learndash-thrivecart' ), '', array( 'response' => 200 ) );
		}

		// if ( $this->was_transaction_proccessed( $_POST ) ) {
		// 	wp_die( __( 'This transaction has already been proccessed. You can\'t validate your transaction twice.', 'learndash-thrivecart' ) );
		// }

		$_POST = $this->sanitize_array( $_POST );

		if ( ! apply_filters( 'learndash_thrivecart_process_webhook', true, $_POST ) ) {
            return;
        }

		if ( ! empty( $_POST['order'] ) ) {
			$thrivecart = $_POST;
			$type 		= $thrivecart['event'];
			$customer   = $thrivecart['customer'];

			if ( $type == 'order.success' ) {
				$purchases  = $thrivecart['purchase_map'];

				foreach ( $purchases as $product_id ) {
					$access = $this->add_access( $customer, $product_id );
				}
			} else if ( $type == 'order.refund' ) {
				$refund     = $thrivecart['refund'];
				$product_id = $refund['type'] . '-' . $refund['id'];

				$access = $this->remove_access( $customer, $product_id );
			} else if ( $type == 'order.subscription_payment' || $type == 'order.subscription_completed' ) {
				$subscription = $thrivecart['subscription'];
				$product_id   = $subscription['type'] . '-' . $subscription['id'];

				$access = $this->add_access( $customer, $product_id );
			} else if ( $type == 'order.subscription_cancelled' ) {
				$subscription = $thrivecart['subscription'];
				$product_id   = $subscription['type'] . '-' . $subscription['id'];

				$access = $this->remove_access( $customer, $product_id );
			}

			if ( ! empty( $access['access_ids'] ) ) {
				$this->record_transaction( $_POST, $access['product_title'], $access['access_ids'], $access['user'], $access['remove'] );
			}

			wp_die( __( 'Success.', 'learndash-thrivecart' ), '', array( 'response' => 200 ) );
		} else {
			wp_die( __( 'There\'s no purchase in your transaction.', 'learndash-thrivecart' ), '', array( 'response' => 200 ) );
		}

	}

	/**
	 * Add course access to the user based on Thrivecart product ID
	 * @param array $customer   Customer details array
	 * @param int   $product_id Thrivecart product ID
	 */
	public function add_access( $customer, $product_id ) {
		if ( false !== strpos( $product_id, 'product' ) ) {
			preg_match( '/product-(\d+)/', $product_id, $matches );
			$alt_product_id = $matches[1];
		}

		$args = array(
			'post_type'  => 'ld-thrivecart',
			'meta_query' => array(
				array(
					'key'   => '_ld_thrivecart_product_id',
					'value' => $product_id,
				)
			)
		);

		if ( false !== strpos( $product_id, 'product' ) ) {
			$args['meta_query'][] = array(
				'key' => '_ld_thrivecart_product_id',
				'value' => $alt_product_id,
			);

			$args['meta_query']['relation'] = 'OR';
		}

		$ld_products = new WP_Query( $args );

		$product_title = '';
		$access_ids = array();
		$remove = false;
		$user = '';

		if ( $ld_products->have_posts() ) {
			$user    = $this->maybe_create_user( $customer );
			$user_id = $user->ID;

			while ( $ld_products->have_posts() ) {
				$ld_products->the_post();

				$product_title = get_the_title();

				$courses = (array) get_post_meta( get_the_ID(), '_ld_thrivecart_courses', true );
				$groups = (array) get_post_meta( get_the_ID(), '_ld_thrivecart_groups', true );

				foreach ( $courses as $course_id ) {
					$access_ids[] = $course_id;
					ld_update_course_access( $user_id, $course_id );
				}

				foreach ( $groups as $group_id ) {
					$access_ids[] = $group_id;
					ld_update_group_access( $user_id, $group_id );
				}
			}
			
			wp_reset_postdata();
		}

		wp_reset_query();

		return compact( 'product_title', 'access_ids', 'remove', 'user' );
	}

	/**
	 * Remove course access from the user based on Thrivecart product ID
	 * @param array $customer   Customer details array
	 * @param int   $product_id Thrivecart product ID
	 */
	public function remove_access( $customer, $product_id ) {
		if ( false !== strpos( $product_id, 'product' ) ) {
			preg_match( '/product-(\d+)/', $product_id, $matches );
			$alt_product_id = $matches[1];
		}

		$args = array(
			'post_type'  => 'ld-thrivecart',
			'meta_query' => array(
				array(
					'key'   => '_ld_thrivecart_product_id',
					'value' => $product_id,
				)
			)
		);

		if ( false !== strpos( $product_id, 'product' ) ) {
			$args['meta_query'][] = array(
				'key' => '_ld_thrivecart_product_id',
				'value' => $alt_product_id,
			);

			$args['meta_query']['relation'] = 'OR';
		}

		$ld_products = new WP_Query( $args );

		$product_title = '';
		$access_ids = array();
		$remove = true;
		$user = '';

		if ( $ld_products->have_posts() ) {
			$user    = $this->maybe_create_user( $customer );
			$user_id = $user->ID;

			while ( $ld_products->have_posts() ) {
				$ld_products->the_post();

				$product_title = get_the_title();

				$courses = (array) get_post_meta( get_the_ID(), '_ld_thrivecart_courses', true );
				$groups = (array) get_post_meta( get_the_ID(), '_ld_thrivecart_groups', true );

				foreach ( $courses as $course_id ) {
					$access_ids[] = $course_id;
					ld_update_course_access( $user_id, $course_id, $remove );
				}

				foreach ( $groups as $group_id ) {
					$access_ids[] = $group_id;
					ld_update_group_access( $user_id, $group_id, $remove );
				}
			}

			wp_reset_postdata();
		}

		wp_reset_query();

		return compact( 'product_title', 'access_ids', 'remove', 'user' );
	}

	/**
	 * Create or retrieve existing user
	 * 
	 * @param  array  $customer Customer data passed by Thrivecart webhook
	 * @return object           WP_User object
	 */
	public function maybe_create_user( $customer ) {
		// retrieve or create user if doesn't exist
		$user = get_user_by( 'email', $customer['email'] );

		if ( false === $user ) {
			$password = wp_generate_password( 12, true, false );
			$username = preg_replace( '/(.*)\@.*/', '$1', $customer['email'] );
			$user_id  = $this->create_user( $username, $password, $customer );
			$user     = get_user_by( 'id', $user_id );
			wp_new_user_notification( $user_id, null, 'both' );
		}

		return $user;
	}

	/**
	 * Create user if not exists
	 * 
	 * @param  string $username 
	 * @param  string $password 
	 * @param  array  $customer  Thrivecart customer data  
	 * @return int               Newly created user ID
	 */
	public function create_user( $username, $password, $customer ) {
		$user_id  = wp_create_user( $username, $password, $customer['email'] );

		if ( is_wp_error( $user_id ) ) {
			if ( $user_id->get_error_code() == 'existing_user_login' ) {
				$random_chars = str_shuffle( substr( md5( time() ), 0, 5 ) );
				$username = $username . '-' . $random_chars;
				$user_id = $this->create_user( $username, $password, $customer );
			}
		}

		$user = get_user_by( 'ID', $user_id );
		$user->first_name = $customer['first_name'];
		$user->last_name  = $customer['last_name'];

		$update_user = wp_insert_user( $user );

		do_action( 'learndash_thrivecart_after_create_user', $user_id, $customer, $password );

		return $user_id;
	}

	/**
	 * Sanitize associative array
	 * @param  array  $array Associative array or one dimensional array
	 * @return array         Sanitized array
	 */
	public function sanitize_array( $array )
	{
		foreach ( $array as $key => $value ) {
			if ( ! is_array( $value ) ) {
				$array[ $key ] = sanitize_text_field( $value );
			} else {
				$this->sanitize_array( $value );
			}
		}

		return $array;
	}

	/**
	 * Record transaction in database
	 * @param  array   $_post         Thrivecart POST data
	 * @param  string  $product_title Product title
	 * @param  array   $course_ids    Associated course ids
	 * @param  object  $user          WP_User object
	 * @param  boolean $refund        True if refund|false otherwise
	 * @return void
	 */
	public function record_transaction( $_post, $product_title, $course_ids, $user, $refund = false )
	{
		$_post['user_id']    = $user->ID;
		$_post['course_id']  = implode( ', ', $course_ids );

		$post_title = $refund ? sprintf( __( 'Product %s Refunded By %s via Thrivecart', 'learndash-thrivecart' ), $product_title, $user->user_email ) : sprintf( __( 'Product %s Purchased By %s via Thrivecart', 'learndash-thrivecart' ), $product_title, $user->user_email );

		$post_id = wp_insert_post( 
			array( 
				'post_title'  => $post_title, 
				'post_type'   => 'sfwd-transactions', 
				'post_status' => 'publish', 
				'post_author' => $user->ID 
		) );

		$this->record_transaction_meta( $post_id, $_post );
	}

	/**
	 * Record transaction meta
	 * @param  int    $post_id Transaction post ID
	 * @param  array  $array   $_POST data
	 * @param  string $parent  Parent key
	 */
	public function record_transaction_meta( $post_id, $array, $parent = array() )
	{
		foreach ( $array as $key => $value ) {
			if ( ! is_array( $value ) ) {
				$prefix = ! empty( $parent ) ? implode( '_', $parent ) : '';
				if ( ! empty( $prefix ) ) {
					$prefix = $prefix . '_';
				}

				update_post_meta( $post_id, $prefix . $key, $value );
			} else {
				$new_parent = array( $key );
				$parent_key = array_merge( $parent, $new_parent );

				$this->record_transaction_meta( $post_id, $value, $parent_key );
			}	
		}
	}

	/**
	 * Check if thrivecart transaction is valid
	 * 
	 * @param  array   $_post Transaction query string
	 * @return boolean       
	 */
	public function is_transaction_valid( $_post ) {
		if ( isset( $_post['thrivecart_secret'] ) ) {
			$secret  = $_post['thrivecart_secret'];
			$options = get_option( 'learndash_thrivecart_settings', array() );
			
			if ( ! isset( $options['secret_word'] ) ) {
				wp_die( __( 'Thrivecart secret word is not set up on this site. Please contact website administrator.', 'learndash-thrivecart' ), '', array( 'response' => 200 ) );
			}

			$check = trim( $options['secret_word'] );

			if ( $secret === $check ) {
				return true;
			}
		}

		return false;
	}

	/**
	 * Check if a transaction has already been proccessed
	 *
	 * Store a value in DB if it hasn't been proccessed.
	 * 
	 * @param  array   $_get Transaction query string
	 * @return boolean       
	 */
	// public function was_transaction_proccessed( $_get ) {
	// 	$transactions = maybe_unserialize( get_option( 'learndash_thrivecart_transactions', '' ) );

	// 	if ( empty( $transactions ) ) {
	// 		$transactions = array();
	// 	}

	// 	if ( in_array( $_get['thrivecart_hash'], $transactions ) ) {
	// 		return true;
	// 	} else {
	// 		$transactions[] = $_get['thrivecart_hash'];
	// 		update_option( 'learndash_thrivecart_transactions', $transactions );

	// 		return false;
	// 	}
	// }
}

new LearnDash_Thrivecart_Integration();